@@ -20,38 +20,27 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifndef ADDFRIEND_H
-#define ADDFRIEND_H 1
+#define ADDFRIEND_H
 
-#include "FriendList.h"                 // Needed for AddFriend
-
-#include <wx/dialog.h>                  // Needed for wxDialog
-// CAddFriend dialog
+#include <wx/dialog.h>                      // Needed for wxDialog
 
 class CAddFriend : public wxDialog
 {
-  //DECLARE_DYNAMIC(CAddFriend)
-  DECLARE_DYNAMIC_CLASS(CAddFriend)
+    DECLARE_DYNAMIC_CLASS(CAddFriend)
 
 public:
-  CAddFriend() {};
+    CAddFriend() {};
 
-	CAddFriend(wxWindow* parent);   // standard constructor
-	void Localize();
-	virtual ~CAddFriend();
-	virtual BOOL OnInitDialog();
-// Dialog Data
-	enum { IDD = IDD_ADDFRIEND };
+    CAddFriend(wxWindow* parent);   // standard constructor
+    void Localize();
+    virtual ~CAddFriend();
+    virtual bool OnInitDialog();
 
-protected:
-#if 0
-	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-
-	DECLARE_MESSAGE_MAP()
-#endif
-	  DECLARE_EVENT_TABLE()
 private:
-	void OnAddBtn(wxCommandEvent& evt);
-	void OnCloseBtn(wxCommandEvent& evt);
+    DECLARE_EVENT_TABLE()
+
+    void OnAddBtn(wxCommandEvent& evt);
+    void OnCloseBtn(wxCommandEvent& evt);
 };
 
 #endif
