@@ -19,10 +19,10 @@
 #ifndef BARSHADER_H
 #define BARSHADER_H
 
-#include "wintypes.h"                   // Needed for DWORD
-#include "types.h"                      // Needed for uint32
+#include "wintypes.h"                       // Needed for DWORD
+#include "types.h"                          // Needed for uint32
 
-#include <wx/dcmemory.h>                // Needed for wxDC
+class wxDC;
 
 #define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
 
@@ -77,7 +77,7 @@ public:
 
 protected:
 	void BuildModifiers();
-	void FillRect(wxDC *dc, RECT* rectSpan, float fRed, float fGreen, float fBlue, bool bFlat);
+	void FillRect(wxDC* dc, RECT* rectSpan, float fRed, float fGreen, float fBlue, bool bFlat);
 	void FillRect(wxDC* dc, RECT* rectSpan, DWORD color, bool bFlat);
 
 	int    m_iWidth;
@@ -97,7 +97,7 @@ private:
 			start = s;
 			end = e;
 			color = cr;
-			next = NULL;
+			next = 0;
 		}
 
 		BarSpan(BarSpan *prev, uint32 s, uint32 e, DWORD cr) {
