@@ -23,20 +23,28 @@
     #include "xmule-headers.h"
 #endif
 
-#include <arpa/inet.h>                      // Needed for in_addr
-
 #include "updownclient.h"                   // Needed for this Interface's Prototype
 
 #include "ClientCredits.h"                  // Needed for CClientCredits::GetCredit
 #include "ClientList.h"                     // Needed for CClientList
 #include "config.h"                         // Needed for PACKAGE_VERSION
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
 #include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "Friend.h"                         // Needed for CFriend
 #include "FriendList.h"                     // Needed for CFriendList
 #include "IPFilter.h"                       // Needed for CIPFilter
+#include "ListenSocket.h"                   // Needed for CClientReqServer
 #include "NewSockets.h"                     // Needed for NewSocket_SendPacketOPdata
-#include "otherfunctions.h"                 // Needed for nstrdupf
+#include "otherfunctions.h"                 // Needed for nstrdup
+#include "otherstructs.h"                   // Needed for Requested_Block_Struct
+#include "packets.h"                        // Needed for CTag
 #include "PartFile.h"                       // Needed for RemoveDownloadingSource
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "server.h"                         // Needed for CServer
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
 #include "ServerWnd.h"                      // Needed for CServerWnd
+#include "sockets.h"                        // Needed for CServerConnect
 #include "TransferWnd.h"                    // Needed for CTransferWnd
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmule.h"                          // Needed for theApp
@@ -44,12 +52,9 @@
 
 #include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
 
-#ifdef _DEBUG
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
-
-#define new DEBUG_NEW
-#endif
+#include <arpa/inet.h>                      // Needed for in_addr
+#include <wx/sckaddr.h>                     // Needed for wxIPV4address
+#include <zlib.h>                           // Needed for z_stream
 
 // some client testing variables
 static wxString crash_name = "[Invalid User Name]";
@@ -60,27 +65,6 @@ extern int newprefs01_opt[];
 
 extern int newprefs03_opt[];
 
-// prevent fscking dns queries
-class xmuleIPV4Address: public wxIPV4address
-{
-    public:
-    xmuleIPV4Address(): wxIPV4address()
-    {
-        };
-    virtual bool Hostname(unsigned long addr)
-    {
-        return GAddress_INET_SetHostAddress(m_address, addr) == GSOCK_NOERROR;
-        };
-    virtual bool Hostname(char * addr)
-    {
-        struct in_addr inaddr;
-        inet_aton(addr, & inaddr);
-        return GAddress_INET_SetHostAddress(m_address, inaddr.s_addr) == GSOCK_NOERROR;
-    }
-}
-
-;
-
 //	members of CUpDownClient
 //	which are used by down and uploading functions
 
@@ -91,9 +75,10 @@ CUpDownClient::CUpDownClient(CClientReqSocket * sender)
     Init();
 }
 
-CUpDownClient::CUpDownClient(uint16 in_port, uint32 in_userid, uint32 in_serverip, uint16 in_serverport, CPartFile * in_reqfile)
+CUpDownClient::CUpDownClient(wxUint16 in_port, wxUint32 in_userid, wxUint32 in_serverip, wxUint16 in_serverport, CPartFile * in_reqfile)
 {
     socket = 0;
+    SpecialPerson = false;
     Init();
     m_nUserID = in_userid;
     m_nUserPort = in_port;
@@ -272,7 +257,7 @@ CUpDownClient::~ CUpDownClient()
     SetUploadFileID(NULL);
 }
 
-bool CUpDownClient::ProcessHelloPacket(char * pachPacket, uint32 nSize)
+bool CUpDownClient::ProcessHelloPacket(char * pachPacket, wxUint32 nSize)
 {
     CMemFile data((BYTE *) pachPacket, nSize);
     uint8 hashsize;
@@ -286,7 +271,7 @@ bool CUpDownClient::ProcessHelloPacket(char * pachPacket, uint32 nSize)
     }
 }
 
-bool CUpDownClient::ProcessHelloAnswer(char * pachPacket, uint32 nSize)
+bool CUpDownClient::ProcessHelloAnswer(char * pachPacket, wxUint32 nSize)
 {
     CMemFile data((BYTE *) pachPacket, nSize);
     return ProcessHelloTypePacket( & data);
@@ -299,7 +284,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CMemFile * data)
     DWORD dwEmuleTags = 0;
     if (data->Read( & m_achUserHash, 16) == 16)
     {
-        uint32 nUserID;
+        wxUint32 nUserID;
         if (data->Read( & nUserID, 4) == 4)
         {
             //fsch2010:if (!m_nUserID || nUserID < 16777216)
@@ -307,14 +292,14 @@ bool CUpDownClient::ProcessHelloTypePacket(CMemFile * data)
             // hmm clientport is sent twice - why?:
             if (data->Read( & m_nUserPort, 2) == 2)
             {
-                uint32 tagcount;
+                wxUint32 tagcount;
                 if (data->Read( & tagcount, 4) == 4)
                 {
                     // TODO: Check if we get everything needed!
  /* It seems that various Mules and Donkeys send tagcount 2, Old MLDonkey sends
  tagcount 3, new mldonkeys 4. There are also some clients
     sending tagcount 5 and 7, what are those? */
-                    for (uint32 i = 0 ; i < tagcount ; i++)
+                    for (wxUint32 i = 0 ; i < tagcount ; i++)
                     {
                         CTag * temptag = new CTag(data);
                         if (temptag->tag)
@@ -359,7 +344,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CMemFile * data)
                                             }
                                             else
                                             {
-                                                theApp.listensocket->offensecounter[id] = (uint32) 1;
+                                                theApp.listensocket->offensecounter[id] = (wxUint32) 1;
                                             }
                                             theApp.listensocket->offensecounter[0]++;
                                         }
@@ -462,13 +447,13 @@ bool CUpDownClient::ProcessHelloTypePacket(CMemFile * data)
                     {
                         if (data->Read( & m_nServerPort, 2) == 2)
                         {
-                            // Hybrid now has an extra uint32.. What is it for?
+                            // Hybrid now has an extra wxUint32.. What is it for?
                             // Also, many clients seem to send an extra 6? These are not eDonkeys or Hybrids..
                             if (data->GetLength() - data->GetPosition() == 4)
                             {
-                                uint32 test;
+                                wxUint32 test;
                                 data->Read( & test, 4);
-                                if (test == (uint32) "KDLM")
+                                if (test == (wxUint32) "KDLM")
                                 {
                                     m_bIsML = true;
                                 }
@@ -517,7 +502,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CMemFile * data)
                     {
                         m_nUserID = m_dwUserIP;
                     }
-                    uchar key[16];
+                    byte key[16];
                     md4cpy(key, m_achUserHash);
                     credits = theApp.clientcredits->GetCredit(key);
                     if ((m_Friend = theApp.friendlist->LinkFriend(key, m_dwUserIP, m_nUserPort)) != NULL)
@@ -545,7 +530,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CMemFile * data)
                             if (theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
                             theApp.listensocket->offensecounter[id]++;
                             else
-                            theApp.listensocket->offensecounter[id] = (uint32) 1;
+                            theApp.listensocket->offensecounter[id] = (wxUint32) 1;
                         }
                         // Detection id change [BlackRat]
  /*
@@ -564,7 +549,7 @@ bool CUpDownClient::ProcessHelloTypePacket(CMemFile * data)
                             if (theApp.listensocket->offensecounter.find(id) != theApp.listensocket->offensecounter.end())
                             theApp.listensocket->offensecounter[id]++;
                             else
-                            theApp.listensocket->offensecounter[id] = (uint32) 1;
+                            theApp.listensocket->offensecounter[id] = (wxUint32) 1;
                             theApp.listensocket->offensecounter[0]++;
                         }
                         theApp.listensocket->hashbase[id] = thishash;
@@ -639,7 +624,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
         data->Write( & version, 1);
         uint8 protversion = EMULE_PROTOCOL;
         data->Write( & protversion, 1);
-        uint32 tagcount = 7;
+        wxUint32 tagcount = 7;
         tagcount++;
         data->Write( & tagcount, 4);
         CTag tag(ET_COMPRESSION, 1);
@@ -654,7 +639,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
         tag5.WriteTagToFile(data);
         CTag tag6(ET_EXTENDEDREQUEST, 2);
         tag6.WriteTagToFile(data);
-        uint32 dwTagValue = (theApp.clientcredits->CryptoAvailable() ? 3 : 0);
+        wxUint32 dwTagValue = (theApp.clientcredits->CryptoAvailable() ? 3 : 0);
         CTag tag7(ET_FEATURES, dwTagValue);
         tag7.WriteTagToFile(data);
 
@@ -677,7 +662,7 @@ void CUpDownClient::SendMuleInfoPacket(bool bAnswer)
     }
 }
 
-void CUpDownClient::ProcessMuleInfoPacket(char * pachPacket, uint32 nSize)
+void CUpDownClient::ProcessMuleInfoPacket(char * pachPacket, wxUint32 nSize)
 {
     CMemFile * data = new CMemFile((BYTE *) pachPacket, nSize);
     //The version number part of this packet will soon be useless since it is only able to go to v.99.
@@ -711,7 +696,7 @@ void CUpDownClient::ProcessMuleInfoPacket(char * pachPacket, uint32 nSize)
                 // MLdonkey currently does not support shared directories:
                 if (m_byEmuleVersion >= 0x28 && !m_bIsML) m_bSharedDirectories = true;
                 m_bEmuleProtocol = true;
-                uint32 tagcount;
+                wxUint32 tagcount;
                 if (data->Read( & tagcount, 4) == 4)
                 {
                     for (unsigned int i = 0 ; i < tagcount ; i++)
@@ -806,11 +791,11 @@ void CUpDownClient::SendHelloTypePacket(CMemFile * data)
  hexprintf("",theApp.glob_prefs->GetUserHash(),16);
     */
     data->Write(theApp.glob_prefs->GetUserHash(), 16);
-    uint32 clientid = theApp.serverconnect->GetClientID();
+    wxUint32 clientid = theApp.serverconnect->GetClientID();
     data->Write( & clientid, 4);
-    uint16 nPort = theApp.glob_prefs->GetPort();
+    wxUint16 nPort = theApp.glob_prefs->GetPort();
     data->Write( & nPort, 2);
-    uint32 tagcount = 5;
+    wxUint32 tagcount = 5;
     data->Write( & tagcount, 4);
     ////////START adding by sivka [xrmb: -HashThief Protection-]
     //to change from 1 to 5 -->theApp.glob_prefs->IsHashThiefProtectionEnabled()):
@@ -870,7 +855,7 @@ void CUpDownClient::SendHelloTypePacket(CMemFile * data)
     ////////STOP adding by sivka [xrmb: -HashThief Protection-]
     CTag tagVersion(CT_VERSION, EDONKEYVERSION);
     tagVersion.WriteTagToFile(data);
-    CTag tagUDPports(CT_EMULE_UDPPORTS, (uint32) theApp.glob_prefs->GetUDPPort());
+    CTag tagUDPports(CT_EMULE_UDPPORTS, (wxUint32) theApp.glob_prefs->GetUDPPort());
     tagUDPports.WriteTagToFile(data);
     wxUint32 uUdpVer;
     const wxUint32 uDataCompVer = 1;
@@ -885,8 +870,12 @@ void CUpDownClient::SendHelloTypePacket(CMemFile * data)
     (uUdpVer << 4 * 6) | (uDataCompVer << 4 * 5) | (uSupportSecIdent << 4 * 4) | (uSourceExchangeVer << 4 * 3) |
     (uExtendedRequestsVer << 4 * 2) | (uAcceptCommentVer << 4));
     tagMiscOptions.WriteTagToFile(data);
-    CTag tagMuleVersion(CT_EMULE_VERSION, 43904);
-    tagMuleVersion.WriteTagToFile(data);    uint32 dwIP;
+/* 
+    10     0000001 0001001 001     0000001 base 2
+    client maj v   minor v release revision
+*/
+    CTag tagMuleVersion(CT_EMULE_VERSION, 33694849);
+    tagMuleVersion.WriteTagToFile(data);    wxUint32 dwIP;
     if (theApp.serverconnect->IsConnected())
     {
         dwIP = theApp.serverconnect->GetCurrentServer()->GetIP();
@@ -901,7 +890,7 @@ void CUpDownClient::SendHelloTypePacket(CMemFile * data)
     data->Write( & nPort, 2);
 }
 
-void CUpDownClient::ProcessMuleCommentPacket(char * pachPacket, uint32 nSize)
+void CUpDownClient::ProcessMuleCommentPacket(char * pachPacket, wxUint32 nSize)
 {
     if (reqfile)
     {
@@ -1181,6 +1170,7 @@ void CUpDownClient::ConnectionEstablished()
 void CUpDownClient::ReGetClientSoft()
 {
     int iHashType = GetHashType();
+
     if (m_pszUsername == NULL)
     {
         m_clientSoft = SO_UNKNOWN;
@@ -1191,12 +1181,6 @@ void CUpDownClient::ReGetClientSoft()
     }
     else if(iHashType == SO_EMULE)
     {
-        if (m_byEmuleVersion != 0x99)
-        {
-            CString temp;
-            temp.Format("%02X", m_byEmuleVersion);
-            m_nClientVersion = atoi(temp.GetBuffer()) * 10;
-        }
         switch (m_byCompatibleClient)
         {
         case SO_CDONKEY:
@@ -1210,11 +1194,17 @@ void CUpDownClient::ReGetClientSoft()
             break;
         default:
             if (m_bIsML)
-            m_clientSoft = SO_MLDONKEY;
-            else if(m_bIsHybrid)
-            m_clientSoft = SO_EDONKEYHYBRID;
+            {
+                m_clientSoft = SO_MLDONKEY;
+            }
+            else if (m_bIsHybrid)
+            {
+                m_clientSoft = SO_EDONKEYHYBRID;
+            }
             else
-            m_clientSoft = SO_EMULE;
+            {
+                m_clientSoft = SO_EMULE;
+            }
         }
         //return;
     }
@@ -1230,42 +1220,79 @@ void CUpDownClient::ReGetClientSoft()
     {
         m_clientSoft = SO_EDONKEY;
     }
+
     // Format name of client
     switch (GetClientSoft())
     {
-    case SO_EDONKEY:
-        m_clientVerString.Format(_T("eDonkey v%.1f"), (float) GetVersion() / 10.0f);
-        break;
-    case SO_EDONKEYHYBRID:
-        m_clientVerString.Format(_T("eDonkeyHybrid v%.1f"), (float) GetVersion() / 10.0f);
-        break;
-    case SO_EMULE:
-        m_clientVerString.Format(_T("eMule v%.2f"), (float) GetVersion() / 1000.0f);
-        break;
-    case SO_OLDEMULE:
-        m_clientVerString.Format(_T("old eMule v%.2f"), (float) GetVersion() / 1000.0f);
-        break;
-    case SO_CDONKEY:
-        m_clientVerString.Format(_T("cDonkey v%.2f"), (float) GetVersion() / 1000.0f);
-        break;
-    case SO_XMULE:
-        m_clientVerString.Format(_T("lMule v%.2f"), (float) GetVersion() / 1000.0f);
-        break;
-    case SO_MLDONKEY:
-        m_clientVerString = _T("Old MlDonkey");
-        break;
-        //modified by sivka [Maella: - better identify for remote clients-]:
-    case SO_SHAREAZA:
-        m_clientVerString.Format(_T("ShareAZA v%.2f"), (float) GetVersion() / 1000.0f);
-        break;
-    default:
-        m_clientVerString = GetResString(IDS_UNKNOWN);
+        case SO_EDONKEY:
+            m_clientVerString.Printf(wxT("eDonkey v%.1f"), static_cast<float>(GetVersion()) / 10.0f);
+            break;
+        case SO_EDONKEYHYBRID:
+            m_clientVerString.Printf(wxT("eDonkeyHybrid v%.1f"), static_cast<float>(GetVersion()) / 10.0f);
+            break;
+        case SO_OLDEMULE:
+            m_clientVerString.Printf(wxT("old eMule v%.2f"), static_cast<float>(GetVersion()) / 1000.0f);
+            break;
+        case SO_EMULE:
+            m_clientVerString = wxT("eMule");
+            break;
+        case SO_CDONKEY:
+            m_clientVerString.Printf(wxT("cDonkey v%.2f"), static_cast<float>(GetVersion()) / 1000.0f);
+            break;
+        case SO_XMULE:
+            m_clientVerString = wxT("xMule");
+            break;
+        case SO_MLDONKEY:
+            m_clientVerString = _T("Old MlDonkey");
+            break;
+        case SO_SHAREAZA:
+            m_clientVerString = wxT("Shareaza");
+            break;
+        default:
+            m_clientVerString = GetResString(IDS_UNKNOWN);
     }
-    if (m_clientModString.IsEmpty() == false)
+    
+    if (iHashType == SO_EMULE)
     {
-        m_clientVerString += _T(" [");
-        m_clientVerString += m_clientModString;
-        m_clientVerString += _T("]");
+        if (m_byEmuleVersion != 0x99)
+        {
+            if (m_clientModString.IsEmpty() == false)
+            {
+                m_clientVerString += _T(" [");
+                m_clientVerString += m_clientModString;
+                m_clientVerString += _T("]");
+                return;
+            }
+
+            wxString temp;
+            long tmp_version;
+            temp.Printf(wxT("%02X"), m_byEmuleVersion);
+            temp.ToLong(&tmp_version);
+            m_nClientVersion = tmp_version;
+            m_nClientVersion *= 10;
+            m_clientVerString.Printf(m_clientVerString + wxT(" v0.%02X"), GetMuleVersion());
+        }
+        else
+        {
+            wxUint32 nClientMajVersion = (m_nClientVersion >> 17) & 0x7f;
+            wxUint32 nClientMinVersion = (m_nClientVersion >> 10) & 0x7f;
+            wxUint32 nClientUpVersion  = (m_nClientVersion >>  7) & 0x07;
+            m_nClientVersion = form_version(nClientMajVersion, nClientMinVersion, nClientUpVersion);
+            
+            if (m_clientSoft == SO_EMULE)
+            {
+                m_clientVerString.Printf(m_clientVerString + wxT(" v%u.%u%c"), nClientMajVersion, nClientMinVersion, _T('a') + nClientUpVersion);
+            }
+            else if (m_clientSoft == SO_AMULE || nClientUpVersion != 0 || m_clientSoft == SO_XMULE)
+            {
+                m_clientVerString.Printf(m_clientVerString + wxT(" v%u.%u.%u"), nClientMajVersion, nClientMinVersion, nClientUpVersion);
+            }
+            else
+            {
+                m_clientVerString.Printf(m_clientVerString + wxT(" v%u.%u"), nClientMajVersion, nClientMinVersion);
+            }
+            
+        }
     }
 }
 
@@ -1299,7 +1326,7 @@ void CUpDownClient::RequestSharedFileList()
     (void) TryToConnect(true);
 }
 
-void CUpDownClient::ProcessSharedFileList(char * pachPacket, uint32 nSize)
+void CUpDownClient::ProcessSharedFileList(char * pachPacket, wxUint32 nSize)
 {
     if (m_iFileListRequested > 0)
     {
@@ -1337,7 +1364,7 @@ void CUpDownClient::Destroy()
     socket->Destroy();
 }
 
-void CUpDownClient::SetUserHash(uchar * m_achTempUserHash)
+void CUpDownClient::SetUserHash(byte * m_achTempUserHash)
 {
     if (m_achTempUserHash == NULL)
     {
@@ -1382,7 +1409,7 @@ void CUpDownClient::ProcessSecIdentStatePacket(unsigned char * pachPacket, wxUin
                 m_SecureIdentState = IS_KEYANDSIGNEEDED;
                 break;
             }
-            uint32 dwRandom;
+            wxUint32 dwRandom;
             memcpy( & dwRandom, pachPacket + 1, 4);
             credits->m_dwCryptRndChallengeFrom = dwRandom;
         }
@@ -1415,7 +1442,7 @@ void CUpDownClient::SendSignaturePacket()
                         bUseV2 = true;
                     }
                     uint8 byChaIPKind = 0;
-                    uint32 ChallengeIP = 0;
+                    wxUint32 ChallengeIP = 0;
                     if (bUseV2)
                     {
                         if (theApp.serverconnect->GetClientID() == 0 || theApp.serverconnect->IsLowID())
@@ -1431,7 +1458,7 @@ void CUpDownClient::SendSignaturePacket()
                         }
                     }
                     //end v2
-                    uchar achBuffer[250];
+                    byte achBuffer[250];
                     uint8 siglen = theApp.clientcredits->CreateSignature(credits, achBuffer, 250, ChallengeIP, byChaIPKind);
                     (void) theApp.clientcredits->VerifyIdent(credits, achBuffer, siglen, GetIP(), byChaIPKind);
                     if (siglen)
@@ -1473,7 +1500,7 @@ void CUpDownClient::ResetFileStatusInfo()
  }
     */
 
-void CUpDownClient::ProcessPublicKeyPacket(uchar * pachPacket, uint32 nSize)
+void CUpDownClient::ProcessPublicKeyPacket(byte * pachPacket, wxUint32 nSize)
 {
     //fsch2010removedtheApp.clientlist->AddTrackClient(this);
     /// delete this line later
@@ -1520,7 +1547,7 @@ void CUpDownClient::SendSecIdentStatePacket()
         if (nValue)
         {
             // crypt: send random data to sign
-            uint32 dwRandom = rand() + 1;
+            wxUint32 dwRandom = rand() + 1;
             credits->m_dwCryptRndChallengeFor = dwRandom;
             Packet * packet = new Packet(OP_SECIDENTSTATE, 5, OP_EMULEPROT);
             packet->pBuffer[0] = nValue;
@@ -1530,7 +1557,7 @@ void CUpDownClient::SendSecIdentStatePacket()
     }
 }
 
-void CUpDownClient::ProcessSignaturePacket(uchar * pachPacket, uint32 nSize)
+void CUpDownClient::ProcessSignaturePacket(byte * pachPacket, wxUint32 nSize)
 {
     /// delete this line later
     // here we spread the good guys from the bad ones ;)
@@ -1631,25 +1658,25 @@ void CUpDownClient::InfoPacketsReceived()
  printf("CUpDownClient::SendPreviewAnswer: OP_PREVIEWANSWER size=%ld\n",packet->size);
  SafeSendPacket(packet);//okdeb
  }
- void CUpDownClient::ProcessPreviewReq(char* pachPacket, uint32 nSize) {
+ void CUpDownClient::ProcessPreviewReq(char* pachPacket, wxUint32 nSize) {
  if (nSize < 16)
  throw GetResString(IDS_ERR_WRONGPACKAGESIZE);
  if (m_bPreviewAnsPending|| theApp.glob_prefs->ServePreview() ==2|| (theApp.glob_prefs->ServePreview() ==1&& !IsFriend()))
  return;
  m_bPreviewAnsPending = true;
- CKnownFile* previewFile = theApp.sharedfiles->GetFileByID((uchar*) pachPacket);
+ CKnownFile* previewFile = theApp.sharedfiles->GetFileByID((byte*) pachPacket);
  if (previewFile == NULL) {
  SendPreviewAnswer(NULL, NULL, 0);
  } else {
  previewFile->GrabImage(4,0,true,450,this);
  }
  }
- void CUpDownClient::ProcessPreviewAnswer(char* pachPacket, uint32 nSize) {
+ void CUpDownClient::ProcessPreviewAnswer(char* pachPacket, wxUint32 nSize) {
  if (!m_bPreviewReqPending)
  return;
  m_bPreviewReqPending = false;
  CMemFile data((BYTE*) pachPacket,nSize);
- uchar Hash[16];
+ byte Hash[16];
  data.Read(Hash,16);
  uint8 nCount;
  data.Read(&nCount,1);
