@@ -23,7 +23,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     29/01/98
-// RCS-ID:      $Id: CFile.h,v 1.17 2004/08/13 15:50:58 HopeSeekr Exp $
+// RCS-ID:      $Id: CFile.h,v 1.19 2004/08/28 02:37:37 HopeSeekr Exp $
 // Copyright:   (c) 1998 Vadim Zeitlin <zeitlin@dptmaths.ens-cachan.fr>
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -35,11 +35,9 @@
 #pragma interface "CFile.h"
 #endif
 
-#ifndef WX_PRECOMP
-  #include  "wx/filefn.h"               // Needed for malloc
-#endif
+#include <wx/filefn.h>                   // Needed for malloc
 
-#include "mfc.h"                        // Needed for CString
+#include "mfc.h"                            // Needed for CString
 
 // ----------------------------------------------------------------------------
 // constants
