@@ -28,7 +28,6 @@ class CUpDownClient;
 
 class CChatWnd : public wxPanel //CResizableDialog
 {
-  //DECLARE_DYNAMIC(CChatWnd)
 public:
 	CChatWnd(wxWindow* pParent = NULL);   // standard constructor
 	virtual ~CChatWnd();
@@ -43,15 +42,6 @@ public:
 	void Localize();
 	//CChatSelector chatselector;
 protected:
-#if 0
-	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support	
-	DECLARE_MESSAGE_MAP()
-	virtual BOOL OnInitDialog(); 
-	afx_msg void OnBnClickedCsend();
-	void	OnShowWindow(BOOL bShow,UINT nStatus);
-	virtual BOOL	PreTranslateMessage(MSG* pMsg);
-public:
-	afx_msg void OnBnClickedCclose();
-#endif
 };
+
 #endif
