@@ -23,28 +23,32 @@
     #include "xmule-headers.h"
 #endif
 
-#include <cmath>                            // Needed for std::sqrt
-#include <fcntl.h>                          // Needed for open
-
 #include "ClientCredits.h"                  // Needed for this Interface's Prototype
 
 #include "NewFunctions.h"                   // Needed for MAP
+#include "opcodes.h"                        // Needed for CREDITFILE_VERSION
 #include "otherfunctions.h"                 // Needed for md4cpy
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_ERR_CREDITFILEOLD
+#include "ServerList.h"                     // Needed for CServerList
 #include "sockets.h"                        // Needed for CServerConnect
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for CxmuleDlg
 
 #include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
 
-#if 1
-#	include "CryptoXMpp.h"                  // Needed for Crypto++
+#include <cmath>                            // Needed for std::sqrt
+#include <fcntl.h>                          // Needed for open
+
+#if USE_CRYPTO 
+    #include <cryptopp/config.h>
+    #include <cryptopp/osrng.h>
+    #include <cryptopp/base64.h>
+    #include <cryptopp/files.h>
+    #include <cryptopp/sha.h>
+    #define	CryptoXMpp	CryptoPP
 #else
-#	include <cryptopp/config.h>
-#	include <cryptopp/osrng.h>
-#	include <cryptopp/base64.h>
-#	include <cryptopp/files.h>
-#	include <cryptopp/sha.h>
-#	define	CryptoXMpp	CryptoPP
+    #include "CryptoXMpp.h"                 // Needed for Crypto++
 #endif
 
 #ifdef _DEBUG
@@ -57,7 +61,7 @@ static char THIS_FILE[] = __FILE__;
 #define		CLIENTS_MET_FILENAME	"clients.met"
 
 MAP * mcc = NULL;
-
+CryptoXMpp::RSASSA_PKCS1v15_SHA_Signer* m_pSignkey;
 uint32 ldwForIP;
 
 using namespace CryptoXMpp;
@@ -388,7 +392,7 @@ CClientCredits * CClientCreditsList::GetCredit(uchar * key)
 
 void CClientCreditsList::Process()
 {
-    if (::GetTickCount() - m_nLastSaved > MIN2MS(13))
+    if (::GetTickCount() - m_nLastSaved > (13 * 60000))
     {
         SaveList();
     }
