@@ -22,15 +22,13 @@
 #ifndef CLIENTCRED_H
 #define CLIENTCRED_H
 
-#include "Preferences.h"                // Needed for CPreferences
+#include "types.h"                          // Needed for uchar
+#include "wintypes.h"                       // Needed for BYTE
 
-#if USE_CRYPTO 
-#   include <cryptopp/cryptlib.h>
-#   include <cryptopp/rsa.h>
-#   define CryptoXMpp CryptoPP
-#else
-#   include "CryptoXMpp.h"              // Needed for CrytoXMpp
-#endif
+#include <ctime>                            // Needed for time
+#include <wx/defs.h>                        // Needed for wxUint32
+
+class CPreferences;
 
 /* winemaker: #pragma pack(1) */
 #define		MAXPUBKEYSIZE		80
@@ -137,8 +135,7 @@ protected:
 	void CreateKeyPair();
 private:
 	CPreferences*	m_pAppPrefs;
-	uint32			m_nLastSaved;
-	CryptoXMpp::RSASSA_PKCS1v15_SHA_Signer*		m_pSignkey;
+	uint32			m_nLastSaved;	
 	BYTE			m_abyMyPublicKey[80];
 	uint8			m_nMyPublicKeyLen;
 };
