@@ -9,7 +9,7 @@
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -22,36 +22,30 @@
 #ifndef CLIENTDETAILDLG_H
 #define CLIENTDETAILDLG_H
 
-#include "updownclient.h"               // Needed for CUpDownClient
-#include <wx/dialog.h>                  // Needed for wxDialog
+#include <wx/dialog.h>                      // Needed for wxDialog
+
+class CUpDownClient;
 
 class CClientDetailDialog : public wxDialog
 {
-  //DECLARE_DYNAMIC(CClientDetailDialog)
-
 public:
-	CClientDetailDialog(wxWindow*parent,CUpDownClient* client);   // standard constructor
-	void Localize();
-	virtual ~CClientDetailDialog();
-	virtual BOOL OnInitDialog();
+        CClientDetailDialog(wxWindow*parent,CUpDownClient* client);   // standard constructor
+        void Localize();
+        virtual ~CClientDetailDialog();
+        virtual bool OnInitDialog();
 // Dialog Data
-	enum
+        enum
         {
             IDD_SOURCEDETAILWND,
             IDD = IDD_SOURCEDETAILWND
         };
 
 protected:
-#if 0
-	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
+          void OnBnClose(wxCommandEvent& evt);
 
-	DECLARE_MESSAGE_MAP()
-#endif
-	  void OnBnClose(wxEvent& evt);
-
-	  DECLARE_EVENT_TABLE()
+          DECLARE_EVENT_TABLE()
 
 private:
-	CUpDownClient* m_client;
+        CUpDownClient* m_client;
 };
 #endif
