@@ -19,20 +19,31 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#include "stdafx.h"
-
 #ifdef PRECOMP
     #include "xmule-headers.h"
 #endif
 
 #include "ClientList.h"                     // Needed for this Interface's Prototype
 
+#include "config.h"                         // Needed for HAVE_EXT_SLIST
 #include "DownloadQueue.h"                  // Needed for CDownloadQueue
 #include "ListenSocket.h"                   // Needed for CClientReqSocket
+#include "MapKey.h"                         // Needed for HashKey
+#include "NewFunctions.h"                   // Needed for MAP
+#include "otherfunctions.h"                 // Needed for GetTickCount
+#include "updownclient.h"                   // Needed for CUpDownClient
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmule.h"                          // Needed for theApp
 
-MAP * listof_UpDownClients = NULL;
+#ifdef HAVE_EXT_SLIST
+    #include <ext/slist>
+    using __gnu_cxx::slist;
+#else
+    #include <list>
+    typedef std::list slist;
+#endif
+
+slist<CUpDownClient *> list_UpDownClients;
 
 CClientList::CClientList()
 {
@@ -42,11 +53,9 @@ CClientList::~ CClientList()
 {
 }
 
-// xrmb : statsclientstatus
 void CClientList::GetStatistics(uint32 & totalclient, int stats[], CMap <uint8, uint8, uint32, uint32 > * clientStatus, CMap <uint16, uint16, uint32, uint32 > * clientVersionEDonkey, CMap <uint16, uint16, uint32, uint32 > * clientVersionEDonkeyHybrid, CMap <uint8, uint8, uint32, uint32 > * clientVersionEMule)
 {
-    //if(clientStatus)		clientStatus->RemoveAll();
-    totalclient = listof_UpDownClients->Data;
+    totalclient = list_UpDownClients.size();
     if (clientVersionEDonkey)
     {
         clientVersionEDonkey->RemoveAll();
@@ -60,11 +69,10 @@ void CClientList::GetStatistics(uint32 & totalclient, int stats[], CMap <uint8,
         stats[i] = 0;
     }
     CUpDownClient * cur_client;
-    MAP * pos;
-    pos = listof_UpDownClients->next;
-    while (pos->Key)
+    slist<CUpDownClient *>::const_iterator it;
+    for (it = list_UpDownClients.begin(); it != list_UpDownClients.end(); ++it)
     {
-        cur_client = (CUpDownClient *) pos->Data;
+        cur_client = *it;
         switch (cur_client->GetClientSoft())
         {
         case SO_UNKNOWN: stats[0]++;
@@ -104,124 +112,94 @@ void CClientList::GetStatistics(uint32 & totalclient, int stats[], CMap <uint8,
             stats[7]++;
             break;
         }
-        pos = pos->next;
     }
 }
 
 void CClientList::AddClient(CUpDownClient * toadd, bool bSkipDupTest)
 {
-    bool found = false;
     if (!bSkipDupTest)
     {
-        MAP * pos;
-        pos = listof_UpDownClients->next;
-        while (pos->Key && (!found))
+        slist<CUpDownClient *>::const_iterator it;
+        for (it = list_UpDownClients.begin(); it != list_UpDownClients.end(); ++it)
         {
-            if (toadd == (CUpDownClient *) pos->Data)
+            if (toadd == *it)
             {
-                found = true;
-            }
-            else
-            {
-                pos = pos->next;
+                return;
             }
         }
     }
-    if (!found)
-    {
-        //faz:printf("CClientList::AddClient(%u): %u\n", listof_UpDownClients->Data, (uint32) toadd);
-        MapData_Insert(listof_UpDownClients, toadd, toadd, 4);
-    }
+    list_UpDownClients.push_front(toadd);
 }
 
 void CClientList::RemoveClient(CUpDownClient * toremove)
 {
-    bool found = false;
-    MAP * pos;
-    pos = listof_UpDownClients->next;
-    while (pos->Key && (!found))
+    slist<CUpDownClient *>::iterator it;
+    for (it = list_UpDownClients.begin(); it != list_UpDownClients.end(); ++it)
     {
-        if (toremove == (CUpDownClient *) pos->Data)
+        if (toremove == *it)
         {
-            found = true;
             theApp.uploadqueue->RemoveFromUploadQueue(toremove);
             theApp.uploadqueue->RemoveFromWaitingQueue(toremove);
             theApp.downloadqueue->RemoveSource(toremove);
-            //printf("CClientList::RemoveClient(%u): %u\n", listof_UpDownClients->Data, (wxUint32) toremove);
-            pos = MapData_Remove(listof_UpDownClients, pos);
-        }
-        else
-        {
-            pos = pos->next;
+            list_UpDownClients.erase(it);
         }
     }
 }
 
 void CClientList::DeleteAll()
 {
-    CUpDownClient * cur_client = NULL;
     theApp.uploadqueue->DeleteAll();
     theApp.downloadqueue->DeleteAll();
-    MAP * pos;
-    pos = listof_UpDownClients->next;
-    while (pos->Key)
+    slist<CUpDownClient *>::const_iterator it;
+    for (it = list_UpDownClients.begin(); it != list_UpDownClients.end(); ++it)
     {
-        cur_client = (CUpDownClient*)pos->Data;
-        pos = MapData_Remove(listof_UpDownClients, pos);
-        (void) cur_client->Disconnected();
+        (*it)->Disconnected();
+        delete *it;
     }
 }
 
-bool CClientList::AttachToAlreadyKnown(CUpDownClient ** client, CClientReqSocket * sender)
+bool CClientList::AttachToAlreadyKnown(CUpDownClient** client, CClientReqSocket * sender)
 {
     bool found = false;
-    //faz:printf("CClientList::AttachToAlreadyKnown_start(%u): ", * ((uint32 *) client));
-    CUpDownClient * tocheck = ( * client);
-    CUpDownClient * cur_client = NULL;
-    MAP * pos;
-    pos = listof_UpDownClients->next;
-    while (pos->Key && (!found))
+    CUpDownClient* tocheck = (*client);
+    if (tocheck != NULL)
     {
-        cur_client = (CUpDownClient*)pos->Data;
-        if (tocheck == cur_client)
+        CUpDownClient* cur_client = NULL;
+        slist<CUpDownClient *>::const_iterator it;
+        for (it = list_UpDownClients.begin(); it != list_UpDownClients.end(); ++it)
         {
-            found = true;
-        }
-        else if(tocheck->Compare(cur_client))
-        {
-            if (sender)
+            cur_client = *it;
+            if (tocheck == cur_client)
             {
-                if (cur_client->socket)
-                {
-                    cur_client->socket->deletethis = true;
-                }
-                delete tocheck;
-                tocheck = NULL;
-                cur_client->socket = sender;
-                * client = cur_client;
                 found = true;
             }
+            else if ((tocheck != NULL) && (tocheck->Compare(cur_client)))
+            {
+                if (sender)
+                {
+                    if (cur_client->socket)
+                    {
+                        cur_client->socket->deletethis = true;
+                    }
+                    delete tocheck;
+                    tocheck = NULL;
+                    cur_client->socket = sender;
+                    *client = cur_client;
+                    found = true;
+                }
+            }
         }
-        pos = pos->next;
-    }
-    if (found)
-    {
-        return true;
-    }
-    else
-    {
-        return false;
     }
+    return found;
 }
 
 CUpDownClient * CClientList::FindClientByIP(uint32 clientip, uint16 port)
 {
     CUpDownClient * cur_client = NULL;
-    MAP * pos;
-    pos = listof_UpDownClients->next;
-    while (pos->Key)
+    slist<CUpDownClient *>::const_iterator it;
+    for (it = list_UpDownClients.begin(); it != list_UpDownClients.end(); ++it)
     {
-        cur_client = (CUpDownClient*)pos->Data;
+        cur_client = *it;
         if (cur_client->GetIP() == clientip)
         {
             if (cur_client->GetUserPort() == port)
@@ -229,7 +207,6 @@ CUpDownClient * CClientList::FindClientByIP(uint32 clientip, uint16 port)
                 return cur_client;
             }
         }
-        pos = pos->next;
     }
     return NULL;
 }
@@ -237,16 +214,14 @@ CUpDownClient * CClientList::FindClientByIP(uint32 clientip, uint16 port)
 CUpDownClient * CClientList::FindClientByUserHash(uchar * clienthash)
 {
     CUpDownClient * cur_client = NULL;
-    MAP * pos;
-    pos = listof_UpDownClients->next;
-    while (pos->Key)
+    slist<CUpDownClient *>::const_iterator it;
+    for (it = list_UpDownClients.begin(); it != list_UpDownClients.end(); ++it)
     {
-        cur_client = (CUpDownClient*)pos->Data;
+        cur_client = *it;
         if (md4cmp(cur_client->GetUserHash(), clienthash))
         {
             return cur_client;
         }
-        pos = pos->next;
     }
     return NULL;
 }
