@@ -27,6 +27,12 @@
 
 #include "DownloadQueue.h"                  // Needed for CDownloadQueue
 #include "NewSockets.h"                     // Needed for NewSocket_SendPacketOPdata
+#include "opcodes.h"                        // Needed for OP_EMULEPROT
+#include "otherfunctions.h"                 // Needed for GetTickCount
+#include "Preferences.h"                    // Needed for CPreferences
+#include "packets.h"                        // Needed for CTag
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "updownclient.h"                   // Needed for CUpDownClient
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for wxSocketBase::SetEventHandler
