@@ -20,26 +20,22 @@
 #ifndef COMMENTDLG_H
 #define COMMENTDLG_H
 
-#include <wx/dialog.h>                  // Needed for wxDialog
+#include <wx/dialog.h>                      // Needed for wxDialog
 
-#include "resource.h"                   // Needed for IDS_PW_APPLY
-#include "wintypes.h"                   // Needed for BOOL
+#include "resource.h"                       // Needed for IDS_PW_APPLY
+#include "wintypes.h"                       // Needed for BOOL
 
 class CKnownFile;
 class wxComboBox;
 
 class CCommentDialog : public wxDialog
 { 
-  //DECLARE_DYNAMIC(CCommentDialog) 
-
 public: 
    CCommentDialog(wxWindow* pParent,CKnownFile* file);   // standard constructor 
    virtual ~CCommentDialog(); 
    void Localize(); 
    virtual BOOL OnInitDialog(); 
 
-    
-
 // Dialog Data 
     enum
     {
@@ -47,14 +43,10 @@ public:
         IDD = IDD_COMMENT
     };
 protected: 
-   //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support 
-   //DECLARE_MESSAGE_MAP() 
    DECLARE_EVENT_TABLE()
 public: 
-   void OnBnClickedApply(wxEvent& evt); 
-   void OnBnClickedCancel(wxEvent& evt); 
+   void OnBnClickedApply(wxCommandEvent& evt);
 private: 
-   //CComboBox   ratebox;//For rate 
    wxComboBox* ratebox;
    CKnownFile* m_file; 
 }; 
