@@ -20,17 +20,34 @@
     #include "xmule-headers.h"
 #endif
 
-#include "CommentDialogLst.h"                   // Needed for this Interface's Prototype
+#include "CommentDialogLst.h"               // Needed for this Interface's Prototype
 
-#include "PartFile.h"                           // Needed for CPartFile
-#include "updownclient.h"                       // Needed for CUpDownClient
+#include "PartFile.h"                       // Needed for CPartFile
+#include "updownclient.h"                   // Needed for CUpDownClient
 
-#include <wx/intl.h>                            // Needed for _
-#include <wx/xrc/xmlres.h>                      // Needed for wxXmlResource
+#include <wx/intl.h>                        // Needed for _
+#include <wx/listctrl.h>                    // Needed for wxListCtrl
+#include <wx/panel.h>                       // Needed for wxPanel
+#include <wx/settings.h>                    // Needed for wxSystemSettings
 
-#define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
-#define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
-#define CheckDlgButton(x,y) XRCCTRL(*this,#x,wxCheckBox)->SetValue(y)
+#if defined(HAVE_XRC)
+    #include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
+    #define SMARTID(A) (XRCID(#A))
+    #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
+#else
+    #include <wx/button.h>                  // Needed for wxButton
+    #include <wx/stattext.h>                // Needed for wxStaticText
+
+    #define SMARTID(A) (A)
+    #define GetDlgItem(id, type) (static_cast<type *>(this->FindWindow(id)))
+
+    enum
+    {
+        IDC_CMSTATUS,
+        IDCOK,
+        IDCREF
+    };
+#endif
 
 //IMPLEMENT_DYNAMIC(CCommentDialogLst, CDialog)
 CCommentDialogLst::CCommentDialogLst(wxWindow *parent, CPartFile *file)
@@ -41,11 +58,21 @@ wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE |wxSYSTEM_MENU)
     m_file = file;
     //wxSizer* content=commentLstDlg(this,TRUE);
     //content->Show(this,TRUE);
-    wxPanel *content = wxXmlResource::Get()->LoadPanel(this, "DLG_COMMENTLST");
+    CCommentDialogLst* content;
+#if defined(HAVE_XRC)
+    content = wxXmlResource::Get()->LoadPanel(this, "DLG_COMMENTLST");
     SetSize(content->GetSize());
     content->SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWFRAME));
+#else
+    content = this;
+    wxListCtrl* item2 = new wxListCtrl( content, IDC_LST, wxPoint(7, 14), wxSize(696, 218), wxLC_REPORT|wxSUNKEN_BORDER );
+    wxButton* item3 = new wxButton(content, IDCREF, _("Refresh"), wxPoint(456, 238), wxSize(94, 28), 0 );
+    wxButton* item4 = new wxButton(content, IDCOK, _("OK"), wxPoint(609, 238), wxSize(94, 28), 0 );
+    wxStaticText* item5 = new wxStaticText(content, IDC_CMSTATUS, _("Static"), wxPoint(7, 234), wxSize(413, 18), 0 );
+    SetSize(300, 400);
+#endif
     Centre();
-    pmyListCtrl = XRCCTRL( *this, "IDC_LST", wxListCtrl);
+    pmyListCtrl = GetDlgItem(IDC_LST, wxListCtrl);
     OnInitDialog();
 }
 
@@ -54,30 +81,17 @@ CCommentDialogLst::~CCommentDialogLst()
 }
 
 BEGIN_EVENT_TABLE(CCommentDialogLst, wxDialog)
-EVT_BUTTON(XRCID("IDCOK"), CCommentDialogLst::OnBnClickedApply)
-EVT_BUTTON(XRCID("IDCREF"), CCommentDialogLst::OnBnClickedRefresh)
+    EVT_BUTTON(SMARTID(IDCOK), CCommentDialogLst::OnBnClickedApply)
+    EVT_BUTTON(SMARTID(IDCREF), CCommentDialogLst::OnBnClickedRefresh)
 END_EVENT_TABLE()
 
-#if 0
-void CCommentDialogLst::DoDataExchange(CDataExchange *pDX)
-{
-    CDialog::DoDataExchange(pDX);
-}
-
-BEGIN_MESSAGE_MAP(CCommentDialogLst, CDialog)
-ON_BN_CLICKED(IDCOK, OnBnClickedApply)
-ON_BN_CLICKED(IDCREF, OnBnClickedRefresh)
-END_MESSAGE_MAP()
-
-#endif
-
-void CCommentDialogLst::OnBnClickedApply(wxEvent &evt)
+void CCommentDialogLst::OnBnClickedApply(wxCommandEvent &evt)
 {
     //CDialog::OnOK();
     EndModal(0);
 }
 
-void CCommentDialogLst::OnBnClickedRefresh(wxEvent &evt)
+void CCommentDialogLst::OnBnClickedRefresh(wxCommandEvent &evt)
 {
     CompleteList();
 }
