@@ -25,10 +25,18 @@
 
 #include "updownclient.h"                   // Needed for this Interface's Prototype
 
+#include "BarShader.h"                      // Needed for CBarShader
 #include "ClientCredits.h"                  // Needed for CClientCredits
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
 #include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "ListenSocket.h"                   // Needed for CClientReqServer
 #include "NewSockets.h"                     // Needed for NewSocket_SendPacketOPdata
+#include "otherstructs.h"                   // Needed for Requested_Block_Struct
+#include "packets.h"                        // Needed for CTag
 #include "PartFile.h"                       // Needed for CPartFile
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "sockets.h"                        // Needed for CServerConnect
 #include "TransferWnd.h"                    // Needed for CTransferWnd
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for CxmuleDlg
@@ -45,7 +53,7 @@ extern int newprefs03_opt[];
 
 CBarShader CUpDownClient::s_StatusBar(16);
 
-void CUpDownClient::DrawStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
+void CUpDownClient::DrawStatusBar(wxDC* dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
     DWORD crBoth;
     DWORD crNeither;
