@@ -22,8 +22,11 @@
 #ifndef DOWNLOADLISTCTRL_H
 #define DOWNLOADLISTCTRL_H
 
-#include <map>                          // Needed for std::multimap
-#include "MuleListCtrl.h"               // Needed for CMuleListCtrl
+#include "mfc.h"                            // Needed for CPtrList
+#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl
+#include "types.h"                          // Needed for uint8
+
+#include <map>                              // Needed for std::multimap
 
 class CPartFile;
 class CUpDownClient;
@@ -38,11 +41,9 @@ struct CtrlItem_Struct{
   wxBitmap*          status;
    ~CtrlItem_Struct() {delete status; }
 };
-// CDownloadListCtrl
 
 class CDownloadListCtrl : public CMuleListCtrl
 {
-  //DECLARE_DYNAMIC(CDownloadListCtrl)
   DECLARE_DYNAMIC_CLASS(CDownloadListCtrl)
 
 public:
@@ -50,7 +51,6 @@ public:
 	CDownloadListCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags);
 
 	virtual ~CDownloadListCtrl();
-	//virtual void DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct);
 	uint8 curTab;
 	void	UpdateItem(void* toupdate);
 	void	Init();
@@ -60,8 +60,6 @@ public:
 	void	RemoveSource(CUpDownClient* source,CPartFile* owner);
 	void	RemoveFile(CPartFile* toremove);
 	void	ClearCompleted();
-	//virtual BOOL OnCommand(WPARAM wParam,LPARAM lParam );
-	//virtual BOOL Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID);
 	void	SetStyle();
 	void	CreateMenues();
 	void	Localize();
@@ -90,20 +88,6 @@ protected:
 
 	void DrawFileItem(wxDC* dc,int nColumn,LPRECT lpRect,CtrlItem_Struct* lpCtrlItem);
 	void DrawSourceItem(wxDC* dc,int nColumn,LPRECT lpRect,CtrlItem_Struct* lpCtrlItem);
-	/*
-	void	DrawFileItem(CDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
-	void	DrawSourceItem(CDC *dc, int nColumn, LPRECT lpRect, CtrlItem_Struct *lpCtrlItem);
-	afx_msg void OnLvnItemActivate(NMHDR *pNMHDR, LRESULT *pResult);
-	afx_msg void OnNMReleasedcapture(NMHDR *pNMHDR, LRESULT *pResult);
-	afx_msg void OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult);
-	afx_msg	void OnColumnClick( NMHDR* pNMHDR, LRESULT* pResult);
-	afx_msg void OnListModified(NMHDR *pNMHDR, LRESULT *pResult);
-    static int CALLBACK SortProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort);    
-    static int Compare(CPartFile* file1, CPartFile* file2, LPARAM lParamSort);
-    static int Compare(CUpDownClient* client1, CUpDownClient* client2, LPARAM lParamSort);
-    
-	DECLARE_MESSAGE_MAP()
-	*/
 	void OnColumnClick(wxListEvent& evt);
 	static int SortProc(long lp1,long lp2,long lpSort);
 	static int Compare(CPartFile* file1, CPartFile* file2, long lParamSort);
@@ -125,15 +109,11 @@ protected:
 private:
 	bool ShowItemInCurrentCat(CPartFile* file,int newsel);
 
-	typedef std::pair<void*,CtrlItem_Struct*> ListItemsPair;
-	typedef std::multimap<void*,CtrlItem_Struct*> ListItems;
+	typedef std::pair<void*, CtrlItem_Struct*> ListItemsPair;
+	typedef std::multimap<void*, CtrlItem_Struct*> ListItems;
 	ListItems m_ListItems;
-	
-	//CTypedPtrList<CPtrList, CtrlItem_Struct*> listcontent;
-	//CtrlItemList listcontent;
-	//CMap<void*,void*,CtrlItem_Struct*,CtrlItem_Struct*> listcontent;
 
-	wxImageList  m_ImageList;
+    wxImageList  m_ImageList;
 	wxMenu*	m_ClientMenu;
 	wxMenu*		m_PrioMenu;
 	wxMenu*	m_FileMenu;
