@@ -26,9 +26,19 @@
 #include "DownloadQueue.h"                  // Needed for this Interface's Prototype
 
 #include "ClientList.h"                     // Needed for CClientList
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
 #include "ED2KLink.h"                       // Needed for HasValidSources
 #include "otherfunctions.h"                 // Needed for GetTickCount
+#include "packets.h"                        // Needed for CTag
 #include "PartFile.h"                       // Needed for CPartFile
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "SearchList.h"                     // Needed for CSearchFile
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerSocket.h"                   // Needed for CServerSocket
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServer
 #include "SysTray.h"                        // Needed for TBN_DLOAD
 #include "TransferWnd.h"                    // Needed for CTransferWnd
 #include "updownclient.h"                   // Needed for CUpDownClient
@@ -104,7 +114,7 @@ void CDownloadQueue::UpdateDisplayedInfo(bool force)
 
 void CDownloadQueue::AddPartFilesToShare()
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if (cur_file->GetStatus(true) == PS_READY)
@@ -124,7 +134,7 @@ void CDownloadQueue::CompDownDatarateOverhead()
     }
     m_nDownDatarateOverhead = 0;
     m_nDownDataRateMSOverhead = 0;
-    for (POSITION pos = m_AvarageDDRO_list.GetHeadPosition() ; pos != 0 ; m_AvarageDDRO_list.GetNext(pos))
+    for (POSITION pos = m_AvarageDDRO_list.GetHeadPosition(); pos != 0; m_AvarageDDRO_list.GetNext(pos))
     m_nDownDatarateOverhead += m_AvarageDDRO_list.GetAt(pos);
     if (m_AvarageDDRO_list.GetCount() > 10)
     {
@@ -195,10 +205,10 @@ CDownloadQueue::~CDownloadQueue()
 {
     //	if (!theApp.xmuledlg->m_app_state== APP_STATE_SHUTINGDOWN )
     //		SavePartFiles(true);	// changed by InterCeptor
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
-        //filelist.GetAt(pos)->m_hpartfile.Flush() ; // Flush before close app [Tarod]
-        //filelist.GetAt(pos)->SavePartFile();
+        filelist.GetAt(pos)->m_hpartfile->Flush(); // Flush before close app [Tarod]
+        filelist.GetAt(pos)->SavePartFile();
         delete filelist.GetAt(pos);
     }
 }
@@ -208,9 +218,9 @@ CDownloadQueue::~CDownloadQueue()
 
 )
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
-        filelist.GetAt(pos)->m_hpartfile.Flush();
+        filelist.GetAt(pos)->m_hpartfile->Flush();
         filelist.GetAt(pos)->SavePartFile();
         if (del)
         delete filelist.GetAt(pos);
@@ -252,7 +262,7 @@ void CDownloadQueue::StartNextFile()
     if (!theApp.glob_prefs->StartNextFile())
     return;
     CPartFile *pfile = NULL;
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if (cur_file->GetStatus() == PS_PAUSED)
@@ -342,7 +352,7 @@ void CDownloadQueue::Process()
     if (app_prefs->GetMaxDownload() != UNLIMITED &&datarate > 1500)
     {
         //(uint16)((float)((float)(app_prefs->GetMaxDownload()*1024)/(datarate+1)) * 100);:
-        downspeed = (app_prefs->GetMaxDownload() *1024 *100) / (datarate + 1);
+        downspeed = (app_prefs->GetMaxDownload() * 1024 * 100) / (datarate + 1);
         if (downspeed < 50)
         downspeed = 50;
         else if(downspeed > 200)
@@ -351,7 +361,7 @@ void CDownloadQueue::Process()
         //	downspeed = 0xFFF;
     }
     datarate = 0;
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() &&cur_file->GetDownPriority() == PR_HIGH))
@@ -359,7 +369,7 @@ void CDownloadQueue::Process()
             datarate += cur_file->Process(downspeed);
         }
     }
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (!cur_file->IsAutoDownPriority() &&cur_file->GetDownPriority() == PR_NORMAL))
@@ -367,7 +377,7 @@ void CDownloadQueue::Process()
             datarate += cur_file->Process(downspeed);
         }
     }
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if ((cur_file->GetStatus() == PS_READY || cur_file->GetStatus() == PS_EMPTY) && (cur_file->GetDownPriority() == PR_LOW || cur_file->IsAutoDownPriority()))
@@ -404,7 +414,7 @@ void CDownloadQueue::Process()
 
 CPartFile *CDownloadQueue::GetFileByID(uchar *filehash)
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         if (!memcmp(filehash, filelist.GetAt(pos)->GetFileHash(), 16))
         return filelist.GetAt(pos);
@@ -416,7 +426,7 @@ CPartFile *CDownloadQueue::GetFileByIndex(int index)
 {
     //      if (index>=filelist.GetCount()) return 0;
     int count = 0;
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         if (count == index) return filelist.GetAt(pos);
         count++;
@@ -426,7 +436,7 @@ CPartFile *CDownloadQueue::GetFileByIndex(int index)
 
 bool CDownloadQueue::IsPartFile(void *totest)
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     if (totest == filelist.GetAt(pos))
     return true;
     return false;
@@ -449,11 +459,11 @@ void CDownloadQueue::CheckAndAddSource(CPartFile *sender, CUpDownClient *source)
  }
     */
     // uses this only for temp. clients
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0 ; sl < SOURCESSLOTS ; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition() ; pos2 != 0 ; cur_file->srclists[sl].GetNext(pos2))
+        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
+        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition(); pos2 != 0; cur_file->srclists[sl].GetNext(pos2))
         {
             if (cur_file->srclists[sl].GetAt(pos2)->Compare(source))
             {
@@ -497,10 +507,10 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile *sender, CUpDownClient *so
     if (!source->HasLowID() && (source->GetUserID() &0xFF) == 0x7F)
     return;
     // use this for client which are already know (downloading for example)
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0 ; sl < SOURCESSLOTS ; sl++) if(!cur_file->srclists[sl].IsEmpty())
+        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
         if (cur_file->srclists[sl].Find(source))
         {
             if (cur_file == sender)
@@ -519,11 +529,11 @@ void CDownloadQueue::CheckAndAddKnownSource(CPartFile *sender, CUpDownClient *so
 bool CDownloadQueue::RemoveSource(CUpDownClient *toremove, bool updatewindow)
 {
     bool removed = false;
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0 ; sl < SOURCESSLOTS ; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition() ; pos2 != 0 ; cur_file->srclists[sl].GetNext(pos2))
+        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
+        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition(); pos2 != 0; cur_file->srclists[sl].GetNext(pos2))
         {
             if (toremove == cur_file->srclists[sl].GetAt(pos2))
             {
@@ -534,7 +544,7 @@ bool CDownloadQueue::RemoveSource(CUpDownClient *toremove, bool updatewindow)
                 if (!toremove->m_OtherRequests_list.IsEmpty())
                 {
                     POSITION pos3, pos4;
-                    for (pos3 = toremove->m_OtherRequests_list.GetHeadPosition() ; (pos4 = pos3) != NULL ;)
+                    for (pos3 = toremove->m_OtherRequests_list.GetHeadPosition(); (pos4 = pos3) != NULL;)
                     {
                         toremove->m_OtherRequests_list.GetNext(pos3);
                         POSITION pos5 = toremove->m_OtherRequests_list.GetAt(pos4)->A4AFSourcesList.Find(toremove);
@@ -570,7 +580,7 @@ bool CDownloadQueue::RemoveSource(CUpDownClient *toremove, bool updatewindow)
 
 void CDownloadQueue::RemoveFile(CPartFile *toremove)
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         if (toremove == filelist.GetAt(pos))
         {
@@ -583,10 +593,10 @@ void CDownloadQueue::RemoveFile(CPartFile *toremove)
 void CDownloadQueue::DeleteAll()
 {
     POSITION pos;
-    for (pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0 ; sl < SOURCESSLOTS ; sl++) if(!cur_file->srclists[sl].IsEmpty())
+        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
         cur_file->srclists[sl].RemoveAll();
         // Barry - Should also remove all requested blocks
         // Don't worry about deleting the blocks, that gets handled
@@ -713,7 +723,7 @@ bool CDownloadQueue::SendNextUDPPacket()
  /*
  if (filelist.GetCount() >= MAX_REQUESTS_PER_SERVER)
  {
- for (int i = 0 ; i != MAX_REQUESTS_PER_SERVER ; i++)
+ for (int i = 0; i != MAX_REQUESTS_PER_SERVER; i++)
  {
  filelist.AddHead(filelist.RemoveTail());
  }
@@ -745,7 +755,7 @@ void CDownloadQueue::SortByPriority()
 {
     POSITION pos1, pos2;
     uint16 i = 0;
-    for (pos1 = filelist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
+    for (pos1 = filelist.GetHeadPosition(); (pos2 = pos1) != NULL;)
     {
         filelist.GetNext(pos1);
         CPartFile *cur_file = filelist.GetAt(pos2);
@@ -769,7 +779,7 @@ void CDownloadQueue::GetDownloadStats(int results[])
 {
     results[0] = 0;
     results[1] = 0;
-    for (POSITION pos = theApp.downloadqueue->filelist.GetHeadPosition() ; pos != 0 ; theApp.downloadqueue->filelist.GetNext(pos))
+    for (POSITION pos = theApp.downloadqueue->filelist.GetHeadPosition(); pos != 0; theApp.downloadqueue->filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         results[0] += cur_file->GetSourceCount();
@@ -779,11 +789,11 @@ void CDownloadQueue::GetDownloadStats(int results[])
 
 CUpDownClient *CDownloadQueue::GetDownloadClientByIP(uint32 dwIP)
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
-        for (int sl = 0 ; sl < SOURCESSLOTS ; sl++) if(!cur_file->srclists[sl].IsEmpty())
-        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition() ; pos2 != 0 ; cur_file->srclists[sl].GetNext(pos2))
+        for (int sl = 0; sl < SOURCESSLOTS; sl++) if(!cur_file->srclists[sl].IsEmpty())
+        for (POSITION pos2 = cur_file->srclists[sl].GetHeadPosition(); pos2 != 0; cur_file->srclists[sl].GetNext(pos2))
         {
             if (dwIP == cur_file->srclists[sl].GetAt(pos2)->GetIP())
             {
@@ -804,7 +814,7 @@ void CDownloadQueue::AddLinksFromFile()
         link = linksfile.GetFirstLine();
         // GetLineCount returns the actual number of lines in file, but line numbering
         // starts from zero. Thus we must loop until i = GetLineCount()-1.
-        for (unsigned int i = 0 ; i < linksfile.GetLineCount() ; i++)
+        for (unsigned int i = 0; i < linksfile.GetLineCount(); i++)
         {
             // Need the links to end with /, otherwise CreateLinkFromUrl crashes us.
             if (link.Right(1) != "/")
@@ -875,7 +885,7 @@ void CDownloadQueue::RemoveSourceFromPartFile(CPartFile *file, CUpDownClient *cl
         // Some positions
         POSITION position, temp_position;
         // For every position in other requests list of client...
-        for (position = client->m_OtherRequests_list.GetHeadPosition() ; (temp_position = position) != NULL ;)
+        for (position = client->m_OtherRequests_list.GetHeadPosition(); (temp_position = position) != NULL;)
         {
             // Get next position in position
             client->m_OtherRequests_list.GetNext(position);
@@ -908,7 +918,7 @@ void CDownloadQueue::RemoveSourceFromPartFile(CPartFile *file, CUpDownClient *cl
 void CDownloadQueue::DisableAnyA4AFAuto(void)
 {
     // For all position in filelist...
-    for (POSITION position = filelist.GetHeadPosition() ; position != NULL ; filelist.GetNext(position))
+    for (POSITION position = filelist.GetHeadPosition(); position != NULL; filelist.GetNext(position))
     {
         // Get file at position in filelist
         CPartFile *file = (CPartFile *) filelist.GetAt(position);
@@ -923,7 +933,7 @@ void CDownloadQueue::DisableAnyA4AFAuto(void)
 
 void CDownloadQueue::ResetCatParts(int cat)
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if (cur_file->GetCategory() == cat)
@@ -939,7 +949,7 @@ void CDownloadQueue::ResetCatParts(int cat)
 
 void CDownloadQueue::SetCatPrio(int cat, uint8 newprio)
 {
-    for (POSITION pos = filelist.GetHeadPosition() ; pos != 0 ; filelist.GetNext(pos))
+    for (POSITION pos = filelist.GetHeadPosition(); pos != 0; filelist.GetNext(pos))
     {
         CPartFile *cur_file = filelist.GetAt(pos);
         if (cat == 0 || cur_file->GetCategory() == cat)
