@@ -22,9 +22,17 @@
 #ifndef DOWNLOADQUEUE_H
 #define DOWNLOADQUEUE_H
 
-#include "SharedFileList.h"             // Needed for CSharedFileList
-#include "Preferences.h"                // Needed for CPreferences
-#include "SearchList.h"                 // Needed for CSearchFile
+#include "mfc.h"                            // Needed for CString
+#include "types.h"                          // Needed for uchar
+#include "wintypes.h"                       // Needed for DWORD
+
+class CPartFile;
+class CPreferences;
+class CSafeMemFile;
+class CSearchFile;
+class CServer;
+class CSharedFileList;
+class CUpDownClient;
 
 class CDownloadQueue
 {
