@@ -23,6 +23,7 @@
 
 #include "ED2KLink.h"                       // Needed for this Interface's Prototype
 
+#include "CMemFile.h"                       // Needed for CMemFile
 #include "otherfunctions.h"                 // Needed for GetResString
 #include "resource.h"                       // Needed for IDS_ERR_ILLFORMEDHASH
 
@@ -416,62 +417,3 @@ CED2KLink::CreateLinkFromUrl(const TCHAR *uri)
     }
     return 0;
 }
-
-#if 0
-//static
-CED2KLink *
-CED2KLink::CreateLinkFromUrl(const TCHAR *uri)
-{
-    // Parse pseudo-URI
-    const TCHAR *pChArray[7];
-    if (uri == 0)
-    throw wxString(("null ed2k link"));
-    TCHAR *pNewString = strdup(uri);
-    autoFree liberator(pNewString);
-    TCHAR *pCh = pNewString;
-    const TCHAR *pStart = pCh;
-    int idx = 0;
-    for (idx = 0 ; idx < 7 ; idx++) pChArray[idx] = NULL;
-    idx = 0;
-    while (idx < 7 && ((pCh = strchr(pCh, ('|'))) != 0))
-    {
-        pChArray[idx++] = pStart;
-        *pCh = 0;
-        ++pCh;
-        pStart = pCh;
-    }
-    if ( *pStart != ('/'))
-    {
-        throw wxString((GetResString(IDS_ERR_BADED2KLINK)));
-    }
-    if (idx < 3
-    || pChArray[0] == 0
-    || pChArray[1] == 0
-    || pChArray[2] == 0
-    || pChArray[3] == 0
-    || strcmp(("ed2k://"), pChArray[0]) != 0
-    )
-    {
-        throw GetResString(IDS_ERR_BADED2KLINK);
-    }
-    if (strcmp(("file"), pChArray[1]) == 0 &&idx == 5 &&pChArray[4] != 0)
-    {
-        return new CED2KFileLink(pChArray[2], pChArray[3], pChArray[4]);
-    }
-    else if(strcmp(("serverlist"), pChArray[1]) == 0 &&idx == 3)
-    {
-        return new CED2KServerListLink(pChArray[2]);
-    }
-    else if(strcmp(("server"), pChArray[1]) == 0 &&idx == 4)
-    {
-        return new CED2KServerLink(pChArray[2], pChArray[3]);
-    }
-    else
-    {
-        throw GetResString(IDS_ERR_NOSLLINK);
-    }
-    return 0;
-}
-
-#endif
-
