@@ -20,9 +20,11 @@
 #ifndef ED2KLINK_H
 #define ED2KLINK_H
 
-#include "CMemFile.h"                   // Needed for CMemFile
-#include "types.h"                      // Needed for uint32
+#include "types.h"                          // Needed for uint32
 
+#include <wx/string.h>                      // Needed for wxString
+
+class CMemFile;
 typedef char TCHAR;
 
 class CED2KLink {
