@@ -22,8 +22,12 @@
 #ifndef EMSOCKET_H
 #define EMSOCKET_H
 
-#include "packets.h"                    // Needed for Packet
-#include "wx/socket.h"                  // Needed for wxSocketClient
+#include "mfc.h"                            // Needed for CList
+#include "types.h"                          // Needed for uint8
+
+#include <wx/socket.h>                      // Needed for wxSocketClient
+
+class Packet;
 
 #define ERR_WRONGHEADER		0x01
 #define ERR_TOOBIG			0x02
@@ -34,8 +38,6 @@
 
 #define PACKET_HEADER_SIZE 6
 
-//WX_DECLARE_LIST(Packet,PacketListL);
-
 class CEMSocket :
 	public wxSocketClient
 {
@@ -51,7 +53,6 @@ public:
 	void	SetDownloadLimit(uint32 limit);
 	void	DisableDownloadLimit();
 	bool	AsyncSelect(long lEvent);
-	//protected:
  public:
 	virtual void	PacketReceived(Packet* packet)		{}
 	virtual void	OnError(int nErrorCode)				{}
