@@ -20,13 +20,14 @@
 #ifndef FLOWCHART_H
 #define FLOWCHART_H
 
-#include <wx/timer.h>                   // Needed for wxTimer and wxTimerEvent
-#include <wx/scrolwin.h>                // Needed for wxScrollWindow
-#include <wx/colordlg.h>                // Needed for GetColourFromUser
+#include <wx/scrolwin.h>                    // Needed for wxScrollWindow
 
 class DynamicPreferencesCtrl;
+class wxClientDC;
+class wxTimer;
+class wxTimerEvent;
 
-class CFlowChart : public wxScrolledWindow 
+class CFlowChart: public wxScrolledWindow 
 {
 public:
     CFlowChart(wxWindow* pParent);
@@ -34,8 +35,7 @@ public:
 	void OnMouseMove(wxMouseEvent &event);
 	void OnPaint(wxPaintEvent &event);
 	void OnTimer(wxTimerEvent &event);
-	void CreateEntry(wxUint16 type,wxUint16 index,wxUint16 x,wxUint16 y,wxUint16 width,
-			wxUint16 height,wxUint32 ip,wxUint16 port,wxString info,wxClientDC *dc);
+	void CreateEntry(wxUint16 type, wxUint16 index, wxUint16 x, wxUint16 y, wxUint16 width, wxUint16 height, wxUint32 ip, wxUint16 port, wxString info, wxClientDC* dc);
 	void ShowEntry(wxUint16 type,wxClientDC *dc);
 	void Sync(wxUint32 socketnumber,wxUint16 index,
 		wxUint32 ip,wxUint16 port,unsigned char *buffer);
@@ -85,11 +85,11 @@ public:
         void            op04_Serverlist_Clients(wxCommandEvent& evt);
         void            op04_Use_Priority_System(wxCommandEvent& evt);
         void            op04_Use_Smart_LowID_Check(wxCommandEvent& evt);
- 	void            op04_Safe_Connect(wxCommandEvent& evt);
+        void            op04_Safe_Connect(wxCommandEvent& evt);
         void            op04_Connect_Static_List_only(wxCommandEvent& evt);
         void            op04_Manually_Server_High_prio(wxCommandEvent& evt);
         void            op04_Dead_Server_Retrys(wxCommandEvent& evt);
-	void            op04_SetOldPrefs(void);
+        void            op04_SetOldPrefs(void);
         void            op05_See_Share_Everybody(wxCommandEvent& evt);
         void            op05_See_Share_Friends(wxCommandEvent& evt);
         void            op05_See_Share_Noone(wxCommandEvent& evt);
@@ -99,16 +99,16 @@ public:
         void            op05_Add_With_Auto_Priority(wxCommandEvent& evt);
         void            op05_Transfer_Full_Chunks(wxCommandEvent& evt);
         void            op05_Start_Next_File(wxCommandEvent& evt);
- 	void            op05_SetOldPrefs(void);
+        void            op05_SetOldPrefs(void);
         void            op06_Backup_Video_Preview(wxCommandEvent& evt);
         void            op06_Video_Player(wxCommandEvent& evt);
         void            op06_Incomming_Dir(wxCommandEvent &evt);
         void            op06_Temp_Dir(wxCommandEvent &evt);
-        void            op06_Share_Folder(wxCommandEvent &evt);  
+        void            op06_Share_Folder(wxCommandEvent &evt);
         void            op06_Unshare_Folder(wxCommandEvent &evt);
         void            op06_ScrollDown(wxCommandEvent &evt);
         void            op06_ScrollUp(wxCommandEvent &evt);
- 	void            op06_SetOldPrefs(void);
+        void            op06_SetOldPrefs(void);
         void            op07_Graph_Update_Delay(wxCommandEvent &evt);
         void            op07_Time_Average_Graph(wxCommandEvent &evt);
         void            op07_Statistic_Update_Delay(wxCommandEvent &evt);
@@ -141,14 +141,14 @@ public:
         void            SetOldPrefs( void);
         void            WriteOldPrefs(void);
         void            ReadOldPrefs( void);
-        void OnLoseFocus(wxFocusEvent* event);
+        void OnLoseFocus(wxFocusEvent& event);
 
-        wxWindow*	my_owner;
-	wxUint32	lastindex; 
-	wxUint32	lastsocketnumber;
+        wxWindow*       my_owner;
+        wxUint32        lastindex;
+        wxUint32        lastsocketnumber;
 private:
     void Init();
-    DECLARE_EVENT_TABLE()	
+    DECLARE_EVENT_TABLE()
 };
 
 #endif // FLOWCHART_H
