@@ -24,9 +24,10 @@
 
 #include "Friend.h"                         // Needed for this Interface's Prototype
 
-//#include "packets.h"
-//#include "xmule.h"
-
+#include "CFile.h"                          // Needed for CFile
+#include "otherfunctions.h"                 // Needed for GetTickCount
+#include "packets.h"                        // Needed for CInvalidPacket
+#include "updownclient.h"                   // Needed for CUpDownClient
 
 CFriend::CFriend(void)
 {
