@@ -20,7 +20,12 @@
 #ifndef __FRIEND_H
 #define __FRIEND_H
 
-#include "updownclient.h"               // Needed for CUpDownClient
+#include "types.h"                          // Needed for uchar
+
+#include <wx/string.h>                      // Needed for wxString
+
+class CFile;
+class CUpDownClient;
 
 #define	FF_NAME		0x01
 
