@@ -24,6 +24,14 @@
 #endif
 
 #include "FriendList.h"                     // Needed for this Interface's Prototype
+
+#include "CFile.h"                          // Needed for CFile
+#include "Friend.h"                         // Needed for CFriend
+#include "FriendListCtrl.h"                 // Needed for CFriendListCtrl
+#include "otherfunctions.h"                 // Needed for GetTickCount
+#include "packets.h"                        // Needed for CInvalidPacket
+#include "Preferences.h"                    // Needed for CPreferences
+#include "updownclient.h"                   // Needed for CUpDownClient
 #include "xmule.h"                          // Needed for theApp
 
 #include <wx/listimpl.cpp>                  // Needed for WX_DEFINE_LIST
@@ -54,7 +62,7 @@ bool CFriendList::LoadList()
     wxString strFileName = wxString(theApp.glob_prefs->GetAppDir()) + wxString("emfriends.met");
     if (!wxFileExists(strFileName))
     return false;
-    uint8 header;
+    wxUint8 header;
     file.Open(CString(strFileName));
     try
     {
@@ -62,10 +70,10 @@ bool CFriendList::LoadList()
         throw CInvalidPacket();
         if (header != MET_HEADER)
         throw CInvalidPacket();
-        uint32 nRecordsNumber;
+        wxUint32 nRecordsNumber;
         if (4 != file.Read( &nRecordsNumber, 4))
         throw CInvalidPacket();
-        for (uint32 i = 0 ; i < nRecordsNumber ; i++)
+        for (wxUint32 i = 0 ; i < nRecordsNumber ; i++)
         {
             Record = new CFriend();
             Record->LoadFromFile( &file);
@@ -81,22 +89,6 @@ bool CFriendList::LoadList()
     file.Close();
     return true;
     //}
-#if 0
-    catch(CFileException *error)
-    {
-        OUTPUT_DEBUG_TRACE();
-        if (error->m_cause == CFileException::endOfFile)
-        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_EMFRIENDSINVALID));
-        else
-        {
-            char buffer[150];
-            error->GetErrorMessage(buffer, 150);
-            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_READEMFRIENDS), buffer);
-        }
-        error->Delete();
-        return false;
-    }
-#endif
 }
 
 void CFriendList::SaveList()
@@ -111,9 +103,9 @@ void CFriendList::SaveList()
         //
         return;
     }
-    uint8 header = MET_HEADER;
+    wxUint8 header = MET_HEADER;
     file.Write( &header, 1);
-    uint32 nRecordsNumber = m_listFriends.GetCount();
+    wxUint32 nRecordsNumber = m_listFriends.GetCount();
     file.Write( &nRecordsNumber, 4);
     for (FriendList::Node *pos = m_listFriends.GetFirst() ; pos != 0 ; pos = pos->GetNext())
     {
@@ -122,7 +114,7 @@ void CFriendList::SaveList()
     file.Close();
 }
 
-CFriend *CFriendList::LinkFriend(uchar *abyUserHash, uint32 m_dwIp, uint16 m_nPort)
+CFriend *CFriendList::LinkFriend(unsigned char *abyUserHash, wxUint32 m_dwIp, wxUint16 m_nPort)
 {
     CFriend *backup_friend = NULL;
     for (FriendList::Node *pos = m_listFriends.GetFirst() ; pos != 0 ; pos = pos->GetNext())
@@ -168,7 +160,7 @@ void CFriendList::ShowFriends()
 }
 
 //Added this to work with the IRC.. Probably a better way to do it.. But wanted this in the release..
-void CFriendList::AddFriend(uchar t_m_abyUserhash[16], uint32 tm_dwLastSeen, uint32 tm_dwLastUsedIP, uint32 tm_nLastUsedPort, uint32 tm_dwLastChatted, wxString tm_strName, uint32 tm_dwHasHash)
+void CFriendList::AddFriend(unsigned char t_m_abyUserhash[16], wxUint32 tm_dwLastSeen, wxUint32 tm_dwLastUsedIP, wxUint32 tm_nLastUsedPort, wxUint32 tm_dwLastChatted, wxString tm_strName, wxUint32 tm_dwHasHash)
 {
     CFriend *Record = 0;
     Record = new CFriend(t_m_abyUserhash, tm_dwLastSeen, tm_dwLastUsedIP, tm_nLastUsedPort, tm_dwLastChatted, tm_strName, tm_dwHasHash);
@@ -178,7 +170,7 @@ void CFriendList::AddFriend(uchar t_m_abyUserhash[16], uint32 tm_dwLastSeen, uin
 }
 
 // Added for the friends function in the IRC..
-bool CFriendList::IsAlreadyFriend(uint32 tm_dwLastUsedIP, uint32 tm_nLastUsedPort)
+bool CFriendList::IsAlreadyFriend(wxUint32 tm_dwLastUsedIP, wxUint32 tm_nLastUsedPort)
 {
     for (FriendList::Node *pos = m_listFriends.GetFirst() ; pos != 0 ; pos = pos->GetNext())
     {
