@@ -32,6 +32,11 @@
 #include "ClientDetailDialog.h"             // Needed for CClientDetailDialog
 #include "ClientList.h"                     // Needed for AddClient
 #include "Friend.h"                         // Needed for RemoveFriend
+#include "FriendList.h"                     // Needed for CFriendList
+#include "ListenSocket.h"                   // Needed for CClientReqServer
+#include "opcodes.h"                        // Needed for MP_DETAIL
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "updownclient.h"                   // Needed for CUpDownClient
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for CxmuleDlg
 
@@ -41,7 +46,6 @@ BEGIN_EVENT_TABLE(CFriendListCtrl, CMuleListCtrl)
 EVT_RIGHT_DOWN(CFriendListCtrl::OnNMRclick)
 END_EVENT_TABLE()
 
-//IMPLEMENT_DYNAMIC(CFriendListCtrl, CListCtrl)
 CFriendListCtrl::CFriendListCtrl()
 {
 }
@@ -56,56 +60,19 @@ CFriendListCtrl::CFriendListCtrl(wxWindow *&parent, int id, const wxPoint &pos,
     Init();
 }
 
-#if 0
-BEGIN_MESSAGE_MAP(CFriendListCtrl, CListCtrl)
-ON_NOTIFY_REFLECT(NM_RCLICK, OnNMRclick)
-END_MESSAGE_MAP()
-#endif
-
-// CFriendListCtrl message handlers
-
 void CFriendListCtrl::Init()
 {
     wxRect rc = GetClientRect();
     InsertColumn(0, GetResString(IDS_QL_USERNAME), wxLIST_FORMAT_LEFT, rc.width - 4);
-    // not not here
-    //theApp.friendlist->SetWindow(this);
-    //theApp.friendlist->ShowFriends();
-#if 0
-    SetExtendedStyle(LVS_EX_FULLROWSELECT);
-    RECT rcWindow;
-    GetWindowRect( &rcWindow);
-    InsertColumn(0, GetResString(IDS_QL_USERNAME), LVCFMT_LEFT,
-    rcWindow.right - rcWindow.left - 4, 0);
-    imagelist.Create(16, 16, ILC_COLOR32 |ILC_MASK, 0, 10);
-    imagelist.SetBkColor(RGB(255, 255, 255));
-    imagelist.Add(theApp.LoadIcon(IDI_FRIENDS1));
-    imagelist.Add(theApp.LoadIcon(IDI_FRIENDS2));
-    imagelist.Add(theApp.LoadIcon(IDI_FRIENDS3));
-    SetImageList( &imagelist, LVSIL_SMALL);
-    theApp.friendlist->SetWindow(this);
-    theApp.friendlist->ShowFriends();
-#endif
 }
 
 void CFriendListCtrl::Localize()
 {
-#if 0
-    CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-    HDITEM hdi;
-    hdi.mask = HDI_TEXT;
-    CString strRes;
-    strRes = GetResString(IDS_QL_USERNAME);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(0, &hdi);
-    strRes.ReleaseBuffer();
-#endif
 }
 
 void CFriendListCtrl::AddFriend(CFriend *toadd)
 {
     uint32 itemnr = GetItemCount();
-    //itemnr = InsertItem(LVIF_TEXT|LVIF_PARAM|LVIF_IMAGE,itemnr,toadd->m_strName.GetBuffer(),0,0,1,(LPARAM)toadd);
     itemnr = InsertItem(itemnr, toadd->m_strName.GetData());
     SetItemData(itemnr, (long) toadd);
     RefreshFriend(toadd);
@@ -113,9 +80,6 @@ void CFriendListCtrl::AddFriend(CFriend *toadd)
 
 void CFriendListCtrl::RemoveFriend(CFriend *toremove)
 {
-    //LVFINDINFO find;
-    //find.flags = LVFI_PARAM;
-    //find.lParam = (LPARAM)toremove;
     sint32 result = FindItem( - 1, (long) toremove);
     if (result != ( - 1))
     DeleteItem(result);
@@ -123,9 +87,6 @@ void CFriendListCtrl::RemoveFriend(CFriend *toremove)
 
 void CFriendListCtrl::RefreshFriend(CFriend *toupdate)
 {
-    //LVFINDINFO find;
-    //find.flags = LVFI_PARAM;
-    //find.lParam = (LPARAM)toupdate;
     sint32 itemnr = FindItem( - 1, (long) toupdate);
     CString temp;
     temp.Format("%s", toupdate->m_strName.GetData());
@@ -145,7 +106,6 @@ void CFriendListCtrl::RefreshFriend(CFriend *toupdate)
     {
         image = 1;
     }
-    //SetItem(itemnr,0,LVIF_IMAGE,0,image,0,0,0,0);
 }
 
 void CFriendListCtrl::OnNMRclick(wxMouseEvent &evt)
@@ -177,45 +137,7 @@ void CFriendListCtrl::OnNMRclick(wxMouseEvent &evt)
     PopupMenu(menu, evt.GetPosition());
 }
 
-#if 0
-void CFriendListCtrl::OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult)
-{
-    POINT point;
-    ::GetCursorPos( &point);
-    CFriend *cur_friend;
-    if (m_ClientMenu) m_ClientMenu.DestroyMenu();
-    m_ClientMenu.CreatePopupMenu();
-    m_ClientMenu.AddMenuTitle(GetResString(IDS_FRIENDLIST));
-    if (GetSelectionMark() != ( - 1))
-    {
-        cur_friend = (CFriend *) GetItemData(GetSelectionMark());
-        m_ClientMenu.AppendMenu(MF_STRING, MP_DETAIL, GetResString(IDS_SHOWDETAILS));
-        m_ClientMenu.EnableMenuItem(MP_DETAIL, ((cur_friend->m_LinkedClient) ? MF_ENABLED: MF_GRAYED));
-    }
-    m_ClientMenu.AppendMenu(MF_STRING, MP_ADDFRIEND, GetResString(IDS_ADDAFRIEND));
-    if (GetSelectionMark() != ( - 1))
-    {
-        m_ClientMenu.AppendMenu(MF_STRING, MP_REMOVEFRIEND, GetResString(IDS_REMOVEFRIEND));
-        m_ClientMenu.AppendMenu(MF_STRING, MP_MESSAGE, GetResString(IDS_SEND_MSG));
-        m_ClientMenu.AppendMenu(MF_STRING, MP_SHOWLIST, GetResString(IDS_VIEWFILES));
-        m_ClientMenu.AppendMenu(MF_STRING, MP_FRIENDSLOT, GetResString(IDS_FRIENDSLOT));
-        if (cur_friend->m_LinkedClient)
-        {
-            m_ClientMenu.EnableMenuItem(MP_FRIENDSLOT, MF_ENABLED);
-            m_ClientMenu.CheckMenuItem(MP_FRIENDSLOT, ((cur_friend->m_LinkedClient->GetFriendSlot()) ?MF_CHECKED: MF_UNCHECKED));
-        }
-        else
-        m_ClientMenu.EnableMenuItem(MP_FRIENDSLOT, MF_GRAYED);
-    }
-    SetMenu( &m_ClientMenu);
-    m_ClientMenu.TrackPopupMenu(TPM_LEFTALIGN |TPM_RIGHTBUTTON, point.x, point.y, this);
-    *pResult = 0;
-    m_ClientMenu.DestroyMenu();
-}
-
-#endif
-
-bool CFriendListCtrl::ProcessEvent(wxEvent &evt)
+bool CFriendListCtrl::ProcessEvent(wxEvent& evt)
 {
     CFriend *cur_friend;
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
