@@ -9,7 +9,7 @@
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -22,39 +22,42 @@
 #ifndef HTTP_DOWNLOADDLG_H
 #define HTTP_DOWNLOADDLG_H
 
-#include <wx/dialog.h>                  // Needed for wxDialog
-#include <wx/process.h>                 // Needed for wxProcess
+#include <wx/dialog.h>                      // Needed for wxDialog
+#include <wx/process.h>                     // Needed for wxProcess
 
 class CHTTPDownloadDlg;
 
-class myWGetProcess : public wxProcess
+class myWGetProcess: public wxProcess
 {
- public:
-  myWGetProcess(wxEvtHandler* parent) 
-    : wxProcess(parent) {
-    myDlg=(CHTTPDownloadDlg*)parent;
-  };
+public:
+    myWGetProcess(wxEvtHandler* parent): wxProcess(parent)
+    {
+        myDlg = reinterpret_cast<CHTTPDownloadDlg *>(parent);
+    }
 
-  void OnTerminate(int pid,int status);
- private:
-  CHTTPDownloadDlg* myDlg;
+    void OnTerminate(int pid,int status);
+
+private:
+    CHTTPDownloadDlg* myDlg;
 };
 
-class CHTTPDownloadDlg : public wxDialog
+class CHTTPDownloadDlg: public wxDialog
 {
- public:
-  CHTTPDownloadDlg(wxWindow*parent,wxString url,wxString tempName);
-  ~CHTTPDownloadDlg() {
-    if(process) {
-      process->Detach();
+public:
+    CHTTPDownloadDlg(wxWindow* parent, wxString url, wxString tempName);
+    ~CHTTPDownloadDlg()
+    {
+        if (process)
+        {
+            process->Detach();
+        }
     }
-  }
 
- private:
-  DECLARE_EVENT_TABLE()
+private:
+    DECLARE_EVENT_TABLE()
 
-  void OnBtnCancel(wxEvent& evt);
-  myWGetProcess *process;
+    void OnBtnCancel(wxCommandEvent& evt);
+    myWGetProcess* process;
 };
 
 #endif
