@@ -25,6 +25,7 @@
 
 #include "IPFilter.h"                       // Needed for this Interface's Prototype
 
+#include "Preferences.h"                    // Needed for CPreferences
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for AddLogLine
 
@@ -120,40 +121,6 @@ int CIPFilter::LoadFromFile()
                 ip1 |= (uint32)(s3[i] << (8 * (3 - i)));
                 ip2 |= (uint32)(s4[i] << (8 * (3 - i)));
             }
-#if 0
-            for (int i = 0 ; i < 4 ; i++)
-            {
-                //sbuffer3.Tokenize(".",counter);
-                Tokenize(sbuffer3, ".", counter);
-                if (counter == - 1)
-                {
-                    skip = true;
-                    break;
-                }
-            }
-            counter = 0;
-            for (int i = 0 ; i < 4 ; i++)
-            {
-                //sbuffer4.Tokenize(".",counter);
-                Tokenize(sbuffer4, counter);
-                if (counter == - 1)
-                {
-                    skip = true;
-                    break;
-                }
-            }
-            if (skip) continue;
-            counter = 0;
-            for (int i = 0 ; i < 4 ; i++)
-            {
-                //sbuffer3.Tokenize(".",counter);:
-                temp = Tokenize(sbuffer3, ".", counter);
-                ip1 |= (uint32)(atoi(temp) << (8 * (3 - i)));
-                //sbuffer4.Tokenize(".",counter);:
-                temp = Tokenize(sbuffer4, ".", counter);
-                ip2 |= (uint32)(atoi(temp) << (8 * (3 - i)));
-            }
-#endif
             // filter
             bool found = false;
             for (int m = pos + 1 ; m < sbuffer.Length() ; m++)
