@@ -26,13 +26,18 @@
 
 #include <sys/stat.h>                       // Needed for stat
 
-#include "KnownFile.h"
+#include "KnownFile.h"                      // Needed for this Interface's Prototype
 
-#include "PartFile.h"                       // Needed for PR_HIGH
+#include "BarShader.h"                      // Needed for CBarShader
+#include "CMemFile.h"                       // Needed for CMemFile
 #include "ini2.h"                           // Needed for CIni
 #include "KnownFileList.h"                  // Needed for CKnownFileList
 #include "otherfunctions.h"                 // Needed for nstrdup
+#include "packets.h"                        // Needed for CTag
+#include "PartFile.h"                       // Needed for PR_HIGH
+#include "Preferences.h"                    // Needed for CPreferences
 #include "SharedFileList.h"                 // Needed for UpdateItem
+#include "SharedFilesCtrl.h"                // Needed for CSharedFilesCtrl
 #include "SharedFilesWnd.h"                 // Needed for CSharedFilesWnd
 #include "updownclient.h"                   // Needed for IsUpPartAvailable
 #include "UploadQueue.h"                    // Needed for FindSourcesForFileById
@@ -121,7 +126,7 @@ CKnownFile::~CKnownFile()
 
 CBarShader CKnownFile::s_ShareStatusBar(16);
 
-void CKnownFile::DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
+void CKnownFile::DrawShareStatusBar(wxDC* dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
  /*
  DWORD crBoth;
@@ -309,7 +314,7 @@ bool CKnownFile::LoadHashsetFromFile(CFile *file, bool checkhash)
         {
             memcpy(buffer + (i *16), hashlist[i], 16);
         }
-        CreateHashFromString(buffer, hashlist.GetCount() *16, checkid);
+        CreateHashFromString(buffer, hashlist.GetCount() * 16, checkid);
         delete[] buffer;
     }
     if (!memcmp(m_abyFileHash, checkid, 16))
