@@ -22,8 +22,16 @@
 #ifndef KNOWNFILE_H
 #define KNOWNFILE_H
 
-#include "packets.h"                    // Needed for Packet
-#include "BarShader.h"                  // Needed for CBarShader
+#include "mfc.h"                            // Needed for CArray
+#include "opcodes.h"                        // Needed for PARTSIZE
+#include "types.h"                          // Needed for uint16
+
+class CBarShader;
+class CFile;
+class CTag;
+class Packet;
+class wxDC;
+class wxRect;
 
 class CFileStatistic{
 	friend class CKnownFile;
@@ -140,13 +148,13 @@ public:
 
 	// file sharing
 	virtual	Packet*	CreateSrcInfoPacket(CUpDownClient* forClient);
+	void	CreateHashFromString(uchar* in_string, int Length, uchar* Output)	{CreateHashFromInput(0,0,Length,Output,in_string);}
 
 protected:
 	bool	LoadTagsFromFile(CFile* file);
 	bool	LoadDateFromFile(CFile* file);
 	void	CreateHashFromFile(FILE* file, int Length, uchar* Output)	{CreateHashFromInput(file,0,Length,Output,0);}
 	void	CreateHashFromFile(CFile* file, int Length, uchar* Output)	{CreateHashFromInput(0,file,Length,Output,0);}
-	void	CreateHashFromString(uchar* in_string, int Length, uchar* Output)	{CreateHashFromInput(0,0,Length,Output,in_string);}
 	void	LoadComment();//comment
 	CArray<uchar*,uchar*> hashlist;
 	CArray<CTag*,CTag*> taglist;
