@@ -30,8 +30,18 @@
 #include "DownloadQueue.h"                  // Needed for AddDownDataOverheadOther
 #include "IPFilter.h"                       // Needed for IsFiltered
 #include "KnownFile.h"                      // Needed for CKnownFile
+#include "NewFunctions.h"                   // Needed for MAP
 #include "NewSockets.h"                     // Needed for NewSocket_DebugPP
+#include "otherstructs.h"                   // Needed for Requested_Block_Struct
+#include "packets.h"                        // Needed for Packet
 #include "PartFile.h"                       // Needed for CPartFile
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "SearchList.h"                     // Needed for CSearchFile
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServer
 #include "updownclient.h"                   // Needed for CUpDownClient
 #include "xmule.h"                          // Needed for theApp
 #include "xmuleDlg.h"                       // Needed for CxmuleDlg
