@@ -22,9 +22,9 @@
 #ifndef MAPKEY_H
 #define MAPKEY_H
 
-#include "types.h"                      // Needed for uchar
-#include "mfc.h"                        // Needed for an unknown reason
-#include <wx/object.h>                  // Needed for wxObject
+#include "types.h"                          // Needed for uchar
+
+#include <wx/object.h>                      // Needed for wxObject
 
 class CCKey : public wxObject{
 public:
@@ -42,6 +42,13 @@ public:
 	uchar* m_key;
 };
 
+// default hasher
+template <class ARG_KEY>
+inline unsigned int HashKey(ARG_KEY key)
+{
+    return((unsigned int)(void *)(unsigned long) key);
+}
+
 template<> inline unsigned int HashKey(CCKey key){
    uint32 hash = 1;
    for (int i = 0;i != 16;i++)
