@@ -20,14 +20,13 @@
 #ifndef MULELISTCTRL_H
 #define MULELISTCTRL_H
 
-#include "resource.h"                   // Needed for IBD_DOWN
-#include <wx/event.h>                   // Needed for DECLARE_DYNAMIC_CLASS
-#include "listctrl.h"                   // Needed for wxODListCtrl
-#include "Preferences.h"                // Needed for CPreferences
+#include "resource.h"                       // Needed for IDB_DOWN
+#include <wx/event.h>                       // Needed for DECLARE_DYNAMIC_CLASS
+#include "listctrl.h"                       // Needed for wxODListCtrl
+#include "wintypes.h"                       // Needed for BOOL
 
 class CMuleListCtrl : public wxODListCtrl
 {
-  //  	DECLARE_DYNAMIC(CMuleListCtrl)
   DECLARE_DYNAMIC_CLASS(CMuleListCtrl)
 
 public:
@@ -67,10 +66,10 @@ public:
 	}
 
 	//save to preferences
-	void SaveSettings(CPreferences::Table tID);
+	void SaveSettings(const short int tID);
 
 	//load from preferences
-	void LoadSettings(CPreferences::Table tID);
+	void LoadSettings(const short int tID);
 
 	enum ArrowType { arrowDown = IDB_DOWN, arrowUp = IDB_UP,
 		arrowDoubleDown = IDB_DOWN2X, arrowDoubleUp = IDB_UP2X };
@@ -78,29 +77,14 @@ public:
 protected:
 	virtual bool ProcessEvent(wxEvent& evt);
 	virtual void PreSubclassWindow();
-	//virtual BOOL OnWndMsg(UINT message, WPARAM wParam, LPARAM lParam, LRESULT* pResult);
-	//virtual BOOL OnChildNotify(UINT message, WPARAM wParam, LPARAM lParam, LRESULT* pResult);
 
-#if 0
-	DECLARE_MESSAGE_MAP()
-	afx_msg void DrawItem(LPDRAWITEMSTRUCT lpDrawItemStruct);
-	afx_msg BOOL OnEraseBkgnd(CDC* pDC);
-	afx_msg void OnSysColorChange();
-#endif
-
-	void         SetColors();
+    void         SetColors();
 	void         SetSortArrow(int iColumn, ArrowType atType);
 	void         SetSortArrow(int iColumn, bool bAscending) {
 		SetSortArrow(iColumn, bAscending ? arrowUp : arrowDown);
 	}
-#if 0
-	DWORD        SetExtendedStyle(DWORD dwNewStyle) {
-		return CListCtrl::SetExtendedStyle(dwNewStyle | LVS_EX_HEADERDRAGDROP);
-	}
-#endif
 
 	wxString          m_Name;
-	//NMLVCUSTOMDRAW   m_lvcd;
 	wxMenu *m_ColumnMenu;
 	bool             m_bCustomDraw;
 	COLORREF         m_crWindow;
