@@ -21,26 +21,16 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#ifdef PRECOMP
+    #include "xmule-headers.h"
+#endif
 
-#include <netdb.h>
-#include <pthread.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
+#include "NewFunctions.h"                   // Needed for this Interface's Prototype
 
-#include "xmule.h"
-
-#include "ClientCredits.h"
-#include "NewFunctions.h"
-#include "otherfunctions.h"
-
-#include <wx/filesys.h>
-#include <wx/msgdlg.h>
-#include <wx/fs_zip.h>
-#include <wx/zstream.h>
-#include <wx/wfstream.h>
-#include <wx/sckaddr.h>
-#include <wx/scrolwin.h>
+#include <wx/fs_zip.h>                      // Needed for wxFSFile
+#include <wx/menu.h>                        // Needed for wxMenu
+#include <wx/scrolwin.h>                    // Needed for wxScrolledWindow
+#include <wx/wfstream.h>                    // Needed for wxFileInputStream
 
 MAP * ToDelete_ClientReqSockets = NULL;
 MAP * ToDelete_UpDownClients = NULL;
