@@ -24,8 +24,10 @@
 #ifndef _NEWFUNCTIONS
 #define _NEWFUNCTIONS
 
-#include <wx/defs.h>                    // Needed for wxUint32
-#include <wx/menu.h>                    // Needed for wxMenu
+#include <wx/defs.h>                        // Needed for wxUint32
+#include <wx/event.h>                       // Needed for wxObjectEventFunction
+
+class wxMenu;
 
 #define MAPCLIENTS_MAX 30000
 
@@ -61,16 +63,14 @@ void ascprintf(char *info,const void *buffer,int length);
 void md4printf(const void *hash);
 void hexprintf(char *info,const void *buffer,int length);
 
-typedef struct _MAP
+struct MAP
 {
-	_MAP*	next;
-	_MAP* 	prev;
+	MAP*	next;
+	MAP* 	prev;
 	wxUint32 Data;
 	wxUint32 Data2;
 	unsigned char *Key;
-}
-
-MAP;
+};
 
 extern wxUint32 globaldata2;
 
