@@ -24,15 +24,18 @@
 #ifndef NEWSOCKETS_H
 #define NEWSOCKETS_H
 
-#include "packets.h"                    // Needed for Packet
+#include <wx/defs.h>                        // Needed for wxUint8
+
+class CMemFile;
+class Packet;
 
 void NewSocket_Start(wxUint8 type, wxUint32 ip, wxUint16 port);
 
 void NewSocket_Stop(wxUint8 type);
 
-void NewSocket_SendPacket(wxUint8 type, Packet *sendpacket, wxUint32 destinationip, wxUint32 destinationport);
-void NewSocket_SendPacketOP(wxUint8 type, wxUint8 opcode,Packet *sendpacket, wxUint32 destinationip, wxUint32 destinationport);
-void NewSocket_SendPacketOPdata(wxUint8 type, wxUint8 opcode,CMemFile *data, wxUint32 destinationip, wxUint32 destinationport);
-void NewSocket_DebugPP(void *client,uint8 opcode,long size,unsigned char *packet);
+void NewSocket_SendPacket(wxUint8 type, Packet* sendpacket, wxUint32 destinationip, wxUint32 destinationport);
+void NewSocket_SendPacketOP(wxUint8 type, wxUint8 opcode,Packet* sendpacket, wxUint32 destinationip, wxUint32 destinationport);
+void NewSocket_SendPacketOPdata(wxUint8 type, wxUint8 opcode, CMemFile* data, wxUint32 destinationip, wxUint32 destinationport);
+void NewSocket_DebugPP(void* client, wxUint8 opcode, long size, unsigned char* packet);
 
 #endif
