@@ -20,22 +20,13 @@
 // OScopeCtrl.cpp : implementation file//
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "OScopeCtrl.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <math.h>
+#include "OScopeCtrl.h"                     // Needed for this Interface's Prototype
 
-#ifdef _DEBUG
-#define new DEBUG_NEW
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
-
-#endif
+#include <cmath>                            // Needed for fabs
+#include <wx/dcmemory.h>                    // Needed for wxMemoryDC
 
 #define GetRValue(rgb) (((rgb)>>16)&0xff)
 #define GetGValue(rgb) (((rgb)>>8)&0xff)
@@ -178,37 +169,6 @@ COScopeCtrl::~COScopeCtrl()
     // ~COScopeCtrl:
 }
 
-#if 0
-BEGIN_MESSAGE_MAP(COScopeCtrl, CWnd)
-//{{AFX_MSG_MAP(COScopeCtrl)
-ON_WM_PAINT()
-ON_WM_SIZE()
-//}}AFX_MSG_MAP
-END_MESSAGE_MAP()
-#endif
-
-/////////////////////////////////////////////////////////////////////////////
-// COScopeCtrl message handlers
-
-/////////////////////////////////////////////////////////////////////////////
-#if 0
-BOOL COScopeCtrl::Create(DWORD dwStyle, const RECT &rect,
-CWnd *pParentWnd, UINT nID)
-{
-    BOOL result;
-    static CString className = AfxRegisterWndClass(CS_HREDRAW | CS_VREDRAW);
-    result = CWnd::CreateEx(WS_EX_CLIENTEDGE | WS_EX_STATICEDGE,
-    className, NULL, dwStyle,
-    rect.left, rect.top, rect.right - rect.left, rect.bottom - rect.top,
-    pParentWnd->GetSafeHwnd(), (HMENU) nID);
-    if (result != 0)
-    InvalidateCtrl();
-    return result;
-    // Create:
-}
-
-#endif
-
 /////////////////////////////////////////////////////////////////////////////
 void COScopeCtrl::SetRange(double dLower, double dUpper, int iTrend)
 {
@@ -355,14 +315,7 @@ void COScopeCtrl::InvalidateCtrl(bool deleteGraph)
     // draw the plot rectangle
     //oldPen = m_dcGrid.SelectObject (&solidPen) ;
     m_dcGrid->SetPen(solidPen);
-#if 0
-    m_dcGrid.MoveTo(m_rectPlot.left, m_rectPlot.top);
-    m_dcGrid.LineTo(m_rectPlot.right + 1, m_rectPlot.top);
-    m_dcGrid.LineTo(m_rectPlot.right + 1, m_rectPlot.bottom + 1);
-    m_dcGrid.LineTo(m_rectPlot.left, m_rectPlot.bottom + 1);
-    m_dcGrid.LineTo(m_rectPlot.left, m_rectPlot.top);
-    m_dcGrid.SelectObject(oldPen);
-#endif
+
     m_dcGrid->DrawLine(m_rectPlot.left, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.top);
     m_dcGrid->DrawLine(m_rectPlot.right + 1, m_rectPlot.top, m_rectPlot.right + 1, m_rectPlot.bottom + 1);
     m_dcGrid->DrawLine(m_rectPlot.right + 1, m_rectPlot.bottom + 1, m_rectPlot.left, m_rectPlot.bottom + 1);
@@ -381,30 +334,6 @@ void COScopeCtrl::InvalidateCtrl(bool deleteGraph)
         //m_dcGrid.SetPixel ( i, GridPos, m_crGridColor ) ;
         m_dcGrid->DrawPoint(i, GridPos);
     }
- /*
- for( j=1 ; j<(m_nXGrids+1) ; j++ ){
- GridPos = m_rectPlot.Width()*j/( m_nXGrids + 1 ) + m_rectPlot.left ;
- for (i=m_rectPlot.top; i<m_rectPlot.bottom; i+=4)
- m_dcGrid.SetPixel ( GridPos, i, m_crGridColor ) ;
- }
-    */
-    // create some fonts (horizontal and vertical)
-    // use a height of 14 pixels and 300 weight
-    // (these may need to be adjusted depending on the display)
-#if 0
-    axisFont.CreateFont(14, 0, 0, 0, 300,
-    FALSE, FALSE, 0, ANSI_CHARSET,
-    OUT_DEFAULT_PRECIS,
-    CLIP_DEFAULT_PRECIS,
-    DEFAULT_QUALITY,
-    DEFAULT_PITCH |FF_SWISS, "Arial");
-    yUnitFont.CreateFont(14, 0, 900, 0, 300,
-    FALSE, FALSE, 0, ANSI_CHARSET,
-    OUT_DEFAULT_PRECIS,
-    CLIP_DEFAULT_PRECIS,
-    DEFAULT_QUALITY,
-    DEFAULT_PITCH |FF_SWISS, "Arial");
-#endif
     wxFont *axisFont, *oldFont;
     axisFont = new wxFont(10, wxSWISS, wxNORMAL, wxNORMAL, FALSE);
     // grab the horizontal font
@@ -867,12 +796,7 @@ void COScopeCtrl::OnSize(wxSizeEvent &evt)
 {
     int iTrend;
     //CWnd::OnSize(nType, cx, cy) ;
-#if 0
-    if (!theApp.xmuledlg)
-    return;
-    if (!theApp.xmuledlg->IsRunning())
-    return;
-#endif
+
     if (oldwidth == evt.GetSize() .GetWidth() &&oldheight == evt.GetSize() .GetHeight())
     {
         // same size. don't touch
@@ -930,27 +854,7 @@ void COScopeCtrl::OnSize(wxSizeEvent &evt)
         m_bitmapPlot = NULL;
         m_dcPlot = NULL;
     }
-#if 0
-    // destroy and recreate the grid bitmap
-    CClientDC dc(this);
-    if (m_pbitmapOldGrid &&m_bitmapGrid.GetSafeHandle() &&m_dcGrid.GetSafeHdc())
-    {
-        m_dcGrid.SelectObject(m_pbitmapOldGrid);
-        m_bitmapGrid.DeleteObject();
-        m_bitmapGrid.CreateCompatibleBitmap( &dc, m_nClientWidth, m_nClientHeight);
-        m_pbitmapOldGrid = m_dcGrid.SelectObject( &m_bitmapGrid);
-    }
-    // destroy and recreate the plot bitmap
-    if (m_pbitmapOldPlot &&m_bitmapPlot.GetSafeHandle() &&m_dcPlot.GetSafeHdc())
-    {
-        m_dcPlot.SelectObject(m_pbitmapOldPlot);
-        m_bitmapPlot.DeleteObject();
-        m_bitmapPlot.CreateCompatibleBitmap( &dc, m_nClientWidth, m_nClientHeight);
-        m_pbitmapOldPlot = m_dcPlot.SelectObject( &m_bitmapPlot);
-    }
-    if (m_nPlotWidth > 0 &&m_nPlotHeight > 0)
-    InvalidateCtrl();
-#endif
+
     if (m_nPlotWidth > 0 &&m_nPlotHeight > 0)
     InvalidateCtrl();
     // OnSize:
@@ -978,10 +882,6 @@ int COScopeCtrl::ReCreateGraph(void)
     {
         for (int iTrend = 0 ; iTrend < m_NTrends ; iTrend++)
         {
-#if 0
-            m_PlotData[iTrend].nPrevY = - 1;
-            m_PlotData[iTrend].dPreviousPosition = 0.0;
-#endif
             POSITION pos = m_PlotData[iTrend].lstPoints.FindIndex(i);
             if (pos)
             pAddPoints[iTrend] = m_PlotData[iTrend].lstPoints.GetAt(pos);
@@ -997,20 +897,8 @@ int COScopeCtrl::ReCreateGraph(void)
 //void COScopeCtrl::OnTimer(UINT nIDEvent)
 void COScopeCtrl::OnTimer(wxTimerEvent &evt)
 {
-    if (!theApp.xmuledlg->IsRunning())
-    return;
     m_nRedrawTimer.Stop();
     m_bDoUpdate = true;
     ReCreateGraph();
-#if 0
-    if (nIDEvent == m_nRedrawTimer)
-    {
-        KillTimer(m_nRedrawTimer);
-        m_nRedrawTimer = 0;
-        m_bDoUpdate = true;
-        ReCreateGraph();
-    }
-    CWnd::OnTimer(nIDEvent);
-#endif
 }
 
