@@ -18,37 +18,33 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#include "opcodes.h"                    // Needed for UNLIMITED
-#include "otherfunctions.h"             // Needed for GetResString
-#	include "muuli_wdr.h"
-#	include "PPgConnection.h"
-#	include "Preferences.h"
-#	include "StatisticsDlg.h"
-#	include "wintypes.h"
-#	include "Wizard.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/checkbox.h>
-#include <wx/msgdlg.h>
-#include <wx/notebook.h>
-#include <wx/slider.h>
-#include <wx/textctrl.h>                // Needed for wxTextCtrl::SetValue
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
+#include "PPgConnection.h"                  // Needed for this Interface's Prototype
+
+#include "opcodes.h"                        // Needed for UNLIMITED
+#include "otherfunctions.h"                 // Needed for GetMaxConnections
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_PW_WARNING
+#include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <wx/checkbox.h>                    // Needed for wxCheckBox
+#include <wx/msgdlg.h>                      // Needed for wxMessageBox
+#include <wx/notebook.h>                    // Needed for wxNotebook
+#include <wx/textctrl.h>                    // Needed for wxTextCtrl::SetValue
+
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
 #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
 #define CheckDlgButton(x,y) XRCCTRL(*this,#x,wxCheckBox)->SetValue(y)
 
-//IMPLEMENT_DYNAMIC(CPPgConnection, CPropertyPage)
 IMPLEMENT_DYNAMIC_CLASS(CPPgConnection, wxPanel)
 
 CPPgConnection::CPPgConnection(wxWindow *parent)
-//: CPropertyPage(CPPgConnection::IDD):
 : wxPanel(parent, CPPgConnection::IDD)
 {
     wxNotebook *book = (wxNotebook *) parent;
@@ -131,78 +127,102 @@ void CPPgConnection::OnApply()
     wxString buffer;
     int lastmaxgu = app_prefs->prefs->maxGraphUploadRate;
     int lastmaxgd = app_prefs->prefs->maxGraphDownloadRate;
- if (GetDlgItem(IDC_DOWNLOAD_CAP, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_DOWNLOAD_CAP, wxTextCtrl)->GetValue();
- app_prefs->prefs->maxGraphDownloadRate = (atoi(buffer)) ? atoi(buffer): 100;
- }
- if (GetDlgItem(IDC_UPLOAD_CAP, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_UPLOAD_CAP, wxTextCtrl)->GetValue();
- app_prefs->prefs->maxGraphUploadRate = (atoi(buffer)) ? atoi(buffer): 25;
- }
- if (GetDlgItem(IDC_MAXUP, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_MAXUP, wxTextCtrl)->GetValue();
- app_prefs->prefs->maxupload = (atoi(buffer)) ? atoi(buffer): 0xFFFF;
- }
- if (GetDlgItem(IDC_MAXDOWN, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_MAXDOWN, wxTextCtrl)->GetValue();
- app_prefs->prefs->maxdownload = (atoi(buffer)) ? atoi(buffer): 0xFFFF;
- }
- if (GetDlgItem(IDC_PORT, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_PORT, wxTextCtrl)->GetValue();
- app_prefs->prefs->port = (atoi(buffer)) ? atoi(buffer): 4662;
- }
- if (GetDlgItem(IDC_MAXSOURCEPERFILE, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_MAXSOURCEPERFILE, wxTextCtrl)->GetValue();
- app_prefs->prefs->maxsourceperfile = (atoi(buffer)) ? atoi(buffer): 1;
- }
- if (GetDlgItem(IDC_UDPPORT, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_UDPPORT, wxTextCtrl)->GetValue();
- app_prefs->prefs->udpport = (atoi(buffer) && !IsDlgButtonChecked(IDC_UDPDISABLE)) ? atoi(buffer): 0;
- }
- if (IsDlgButtonChecked(IDC_SHOWOVERHEAD))
- app_prefs->prefs->m_bshowoverhead = true;
- else
- app_prefs->prefs->m_bshowoverhead = false;
- //	if(IsDlgButtonChecked(IDC_UDPDISABLE)) app_prefs->prefs->udpport=0;
- GetDlgItem(IDC_UDPPORT, wxControl)->Enable(!IsDlgButtonChecked(IDC_UDPDISABLE));
- app_prefs->prefs->autoconnect = (int8) IsDlgButtonChecked(IDC_AUTOCONNECT);
- app_prefs->prefs->reconnect = (int8) IsDlgButtonChecked(IDC_RECONN);
- if (lastmaxgu != app_prefs->prefs->maxGraphUploadRate)
- theApp.xmuledlg->statisticswnd->SetARange(false, app_prefs->prefs->maxGraphUploadRate);
- if (lastmaxgd != app_prefs->prefs->maxGraphDownloadRate)
- theApp.xmuledlg->statisticswnd->SetARange(true, app_prefs->prefs->maxGraphDownloadRate);
- uint16 tempcon = app_prefs->prefs->maxconnections;
- if (GetDlgItem(IDC_MAXCON, wxTextCtrl)->GetValue() .Length())
- {
- buffer = GetDlgItem(IDC_MAXCON, wxTextCtrl)->GetValue();
- tempcon = (atoi(buffer)) ? atoi(buffer): CPreferences::GetRecommendedMaxConnections();
- }
- if (tempcon > (unsigned)::GetMaxConnections())
- {
- CString strMessage;
- strMessage.Format(GetResString(IDS_PW_WARNING), GetResString(IDS_PW_MAXC) .GetData(),::GetMaxConnections());
- int iResult = wxMessageBox(strMessage, GetResString(IDS_PW_MAXC), wxICON_WARNING | wxYES_NO);
- if (iResult != wxYES)
- {
- //TODO: set focus to max connection?
- strMessage.Format("%d", app_prefs->prefs->maxconnections);
- GetDlgItem(IDC_MAXCON, wxTextCtrl)->SetValue(strMessage);
- tempcon =::GetMaxConnections();
- }
- }
- app_prefs->prefs->maxconnections = tempcon;
- //SetModified(FALSE);
- //	app_prefs->Save();
- //LoadSettings();
- //	theApp.xmuledlg->preferenceswnd.m_wndTweaks.LoadSettings();
- //return CPropertyPage::OnApply();
+
+    if (GetDlgItem(IDC_DOWNLOAD_CAP, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_DOWNLOAD_CAP, wxTextCtrl)->GetValue();
+        app_prefs->prefs->maxGraphDownloadRate = (atoi(buffer)) ? atoi(buffer): 100;
+    }
+    
+    if (GetDlgItem(IDC_UPLOAD_CAP, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_UPLOAD_CAP, wxTextCtrl)->GetValue();
+        app_prefs->prefs->maxGraphUploadRate = (atoi(buffer)) ? atoi(buffer): 25;
+    }
+
+    if (GetDlgItem(IDC_MAXUP, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_MAXUP, wxTextCtrl)->GetValue();
+        app_prefs->prefs->maxupload = (atoi(buffer)) ? atoi(buffer): 0xFFFF;
+    }
+
+    if (GetDlgItem(IDC_MAXDOWN, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_MAXDOWN, wxTextCtrl)->GetValue();
+        app_prefs->prefs->maxdownload = (atoi(buffer)) ? atoi(buffer): 0xFFFF;
+    }
+
+    if (GetDlgItem(IDC_PORT, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_PORT, wxTextCtrl)->GetValue();
+        app_prefs->prefs->port = (atoi(buffer)) ? atoi(buffer): 4662;
+    }
+
+    if (GetDlgItem(IDC_MAXSOURCEPERFILE, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_MAXSOURCEPERFILE, wxTextCtrl)->GetValue();
+        app_prefs->prefs->maxsourceperfile = (atoi(buffer)) ? atoi(buffer): 1;
+    }
+
+    if (GetDlgItem(IDC_UDPPORT, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_UDPPORT, wxTextCtrl)->GetValue();
+        app_prefs->prefs->udpport = (atoi(buffer) && !IsDlgButtonChecked(IDC_UDPDISABLE)) ? atoi(buffer): 0;
+    }
+
+    if (IsDlgButtonChecked(IDC_SHOWOVERHEAD))
+    {
+        app_prefs->prefs->m_bshowoverhead = true;
+    }
+    else
+    {
+        app_prefs->prefs->m_bshowoverhead = false;
+    }
+    
+    if (IsDlgButtonChecked(IDC_UDPDISABLE))
+    {
+        app_prefs->prefs->udpport = 0;
+    }
+    
+    GetDlgItem(IDC_UDPPORT, wxControl)->Enable(!IsDlgButtonChecked(IDC_UDPDISABLE));
+    app_prefs->prefs->autoconnect = (int8) IsDlgButtonChecked(IDC_AUTOCONNECT);
+    app_prefs->prefs->reconnect = (int8) IsDlgButtonChecked(IDC_RECONN);
+    
+    if (lastmaxgu != app_prefs->prefs->maxGraphUploadRate)
+    {
+        theApp.xmuledlg->statisticswnd->SetARange(false, app_prefs->prefs->maxGraphUploadRate);
+    }
+    
+    if (lastmaxgd != app_prefs->prefs->maxGraphDownloadRate)
+    {
+        theApp.xmuledlg->statisticswnd->SetARange(true, app_prefs->prefs->maxGraphDownloadRate);
+    }
+    
+    uint16 tempcon = app_prefs->prefs->maxconnections;
+    if (GetDlgItem(IDC_MAXCON, wxTextCtrl)->GetValue() .Length())
+    {
+        buffer = GetDlgItem(IDC_MAXCON, wxTextCtrl)->GetValue();
+        tempcon = (atoi(buffer)) ? atoi(buffer): CPreferences::GetRecommendedMaxConnections();
+    }
+
+#if defined(__WIN32__)
+    if (tempcon > (unsigned)::GetMaxConnections())
+    {
+        CString strMessage;
+        strMessage.Format(GetResString(IDS_PW_WARNING), GetResString(IDS_PW_MAXC) .GetData(),::GetMaxConnections());
+
+        int iResult = wxMessageBox(strMessage, GetResString(IDS_PW_MAXC), wxICON_WARNING | wxYES_NO);
+
+        if (iResult != wxYES)
+        {
+            //TODO: set focus to max connection?
+            strMessage.Format("%d", app_prefs->prefs->maxconnections);
+            GetDlgItem(IDC_MAXCON, wxTextCtrl)->SetValue(strMessage);
+            tempcon =::GetMaxConnections();
+        }
+    }
+#endif
+    app_prefs->prefs->maxconnections = tempcon;
 }
 
 void CPPgConnection::Localize(void)
@@ -228,24 +248,16 @@ void CPPgConnection::Localize(void)
         GetDlgItem(IDC_RECONN, wxControl)->SetLabel(GetResString(IDS_PW_RECON));
         GetDlgItem(IDC_MAXSRCHARD_LBL, wxControl)->SetLabel(GetResString(IDS_HARDLIMIT));
         //GetDlgItem(IDC_WIZARD, wxControl)->SetLabel(GetResString(IDS_WIZARD));
-        // okok, these seems to have vanished.. needs to be fixed at some point
-        //GetDlgItem(IDC_UDPPORTLABEL,wxControl)->SetLabel(GetResString(IDS_UDPPORT));
         GetDlgItem(IDC_UDPPORTLABEL, wxControl)->SetLabel("UDP Port");
         GetDlgItem(IDC_UDPDISABLE, wxControl)->SetLabel(GetResString(IDS_UDPDISABLED));
     }
 }
 
-void CPPgConnection::OnBnClickedWizard(wxEvent &evt)
+void CPPgConnection::OnBnClickedWizard(wxCommandEvent &evt)
 {
- /*
- Wizard test(this);
- test.SetPrefs(app_prefs);
- test.OnInitDialog();
- test.ShowModal();
-    */
 }
 
-void CPPgConnection::OnUDPDISABLEChecked(wxEvent &evt)
+void CPPgConnection::OnUDPDISABLEChecked(wxCommandEvent &evt)
 {
     GetDlgItem(IDC_UDPPORT, wxControl)->Enable(!IsDlgButtonChecked(IDC_UDPDISABLE));
 }
