@@ -20,13 +20,13 @@
 #ifndef PPGDIR_H
 #define PPGDIR_H
 
-#include "DirectoryTreeCtrl.h"          // Needed for CDirectoryTreeCtrl
-#include "Preferences.h"                // Needed for CPreferences
-#include <wx/panel.h>                   // Needed for wxPanel
+#include <wx/panel.h>                       // Needed for wxPanel
+
+class CDirectoryTreeCtrl;
+class CPreferences;
 
 class CPPgDirectories : public wxPanel
 {
-  //DECLARE_DYNAMIC(CPPgDirectories)
   DECLARE_DYNAMIC_CLASS(CPPgDirectories)
     CPPgDirectories() {};
 
@@ -44,34 +44,20 @@ public:
         };
 
 protected:
-	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-	//DECLARE_MESSAGE_MAP()
 	DECLARE_EVENT_TABLE()
 
 public:
-	//virtual BOOL OnInitDialog();
 public:
 	CDirectoryTreeCtrl* m_ShareSelector;
 	CPreferences* app_prefs;
 private:
 	bool SelectDir(char* outdir, char* titletext);
 public:
-	void OnBnClickedSelincdir(wxEvent& e);
-	void OnBnClickedSeltempdir(wxEvent& e);
-	void BrowseVideoplayer(wxEvent& e);
+    void OnBnClickedSelincdir(wxCommandEvent& e);
+    void OnBnClickedSeltempdir(wxCommandEvent& e);
+    void BrowseVideoplayer(wxCommandEvent& e);
 
-	virtual BOOL OnApply();
-#if 0
-
-	afx_msg void OnBnClickedSelincdir();
-	afx_msg void OnBnClickedSeltempdir();
-	
-	afx_msg void OnEnChangeIncfiles()	{ SetModified(); }
-	afx_msg void OnEnChangeTempfiles()	{ SetModified(); }
-	afx_msg void OnBnClickedCheck1()	{ SetModified(); }
-protected:
-	virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
-#endif
+	virtual bool OnApply();
 public:
 	void Localize(void);
 	void LoadSettings(void);
