@@ -16,26 +16,23 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-// PPgFiles.cpp : implementation file
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "otherfunctions.h"
-#	include "PPgFiles.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#include "resource.h"                   // Needed for IDS_PW_ICH
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/radiobut.h>
-#include <wx/checkbox.h>
+#include "PPgFiles.h"                       // Needed for this Interface's Prototype
 
-#include <wx/checkbox.h>
-#include <wx/notebook.h>
-#include <wx/slider.h>
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_PW_ICH
+
+#include <wx/checkbox.h>                    // Needed for wxCheckBox
+#include <wx/intl.h>                        // Needed for _
+#include <wx/notebook.h>                    // Needed for wxNotebook
+#include <wx/radiobut.h>                    // Needed for wxRadioButton
+
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
 // CPPgFiles dialog
 #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
@@ -62,32 +59,6 @@ CPPgFiles::~CPPgFiles()
 {
 }
 
-#if 0
-void CPPgFiles::DoDataExchange(CDataExchange *pDX)
-{
-    CPropertyPage::DoDataExchange(pDX);
-}
-
-BEGIN_MESSAGE_MAP(CPPgFiles, CPropertyPage)
-
-ON_BN_CLICKED(IDC_SEESHARE1, OnBnClickedSeeshare1)
-ON_BN_CLICKED(IDC_SEESHARE2, OnBnClickedSeeshare2)
-ON_BN_CLICKED(IDC_SEESHARE3, OnBnClickedSeeshare3)
-ON_BN_CLICKED(IDC_ICH, OnBnClickedIch)
-END_MESSAGE_MAP()
-
-BOOL CPPgFiles::OnInitDialog()
-{
-    CPropertyPage::OnInitDialog();
-    LoadSettings();
-    Localize();
-    // return TRUE unless you set the focus to a control:
-    return TRUE;
-    // EXCEPTION: OCX Property Pages should return FALSE
-}
-
-#endif
-
 void CPPgFiles::LoadSettings(void)
 {
     switch (app_prefs->prefs->m_iSeeShares)
