@@ -20,12 +20,12 @@
 #ifndef PPGFILES_H
 #define PPGFILES_H
 
-#include <wx/panel.h>                   // Needed for wxPanel
-#include "Preferences.h"                // Needed for CPreferences
+#include <wx/panel.h>                       // Needed for wxPanel
+
+class CPreferences;
 
 class CPPgFiles : public wxPanel
 {
-  //DECLARE_DYNAMIC(CPPgFiles)
   DECLARE_DYNAMIC_CLASS(CPPgFiles)
     CPPgFiles() {};
 
@@ -43,24 +43,10 @@ public:
         };
 protected:
 	CPreferences *app_prefs;
-protected:
-	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-
-	//DECLARE_MESSAGE_MAP()
 public:
-	//virtual BOOL OnInitDialog();
- public:
 	void LoadSettings(void);
 public:
-#if 0
-	virtual BOOL OnApply();
-	afx_msg void OnBnClickedSeeshare1()	{ SetModified(); }
-	afx_msg void OnBnClickedSeeshare2()	{ SetModified(); }
-	afx_msg void OnBnClickedSeeshare3()	{ SetModified(); }
-	afx_msg void OnBnClickedIch()		{ SetModified(); }
-#endif
 	virtual void OnApply();
-
 	void Localize(void);
 };
 
