@@ -16,25 +16,25 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-// PPgGeneral.cpp : implementation file
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "otherfunctions.h"
-#	include "PPgGeneral.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/button.h>
-#include <wx/checkbox.h>
-#include <wx/notebook.h>
-#include <wx/slider.h>
-#include <wx/textctrl.h>
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
+#include "PPgGeneral.h"                     // Needed for this Interface's Prototype
+
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_DAYS2
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <wx/checkbox.h>                    // Needed for wxCheckBox
+#include <wx/notebook.h>                    // Needed for wxNotebook
+#include <wx/slider.h>                      // Needed for wxSlider
+#include <wx/textctrl.h>                    // Needed for wxTextCtrl
+
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
 #define ID_DESKTOPMODE 3358
 
@@ -45,22 +45,15 @@
 #define CheckDlgButton3(x,y,z) XRCCTRL(*this,#x,z)->SetValue(y)
 #define CheckDlgButton(x,y) XRCCTRL(*this,#x,wxCheckBox)->SetValue(y)
 
-//IMPLEMENT_DYNAMIC(CPPgGeneral, CPropertyPage)
 IMPLEMENT_DYNAMIC_CLASS(CPPgGeneral, wxPanel)
 
-CPPgGeneral::CPPgGeneral(wxWindow *parent)
-//: CPropertyPage(CPPgGeneral::IDD):
-: wxPanel(parent, CPPgGeneral::IDD)
+CPPgGeneral::CPPgGeneral(wxWindow *parent): wxPanel(parent, CPPgGeneral::IDD)
 {
     wxNotebook *book = (wxNotebook *) parent;
     wxPanel *page1 = wxXmlResource::Get()->LoadPanel(this, "DLG_PPG_GENERAL");
     book->AddPage(this, _("General"));
     SetSize(page1->GetSize() .GetWidth(), page1->GetSize() .GetHeight() + 40);
     page1->SetSize(GetSize());
-    GetDlgItem(IDC_LANGS, wxComboBox)->Append(_("System Default"));
-    //  GetDlgItem(IDC_ROUND,wxControl)->SetWindowStyle(wxALIGN_RIGHT);
-    //  GetDlgItem(IDC_ROUND,wxControl)->Refresh();
-    // add extra button for configuring the desktop mode
     wxButton *mybtn = new wxButton(page1, ID_DESKTOPMODE, _("Systray Integration"),
     wxPoint(402, 245), wxSize(110, 24));
     Localize();
@@ -70,44 +63,16 @@ CPPgGeneral::~CPPgGeneral()
 {
 }
 
-#if 0
-void CPPgGeneral::DoDataExchange(CDataExchange *pDX)
-{
-    CPropertyPage::DoDataExchange(pDX);
-    DDX_Control(pDX, IDC_LANGS, m_language);
-}
-
-#endif
-
 BEGIN_EVENT_TABLE(CPPgGeneral, wxPanel)
 EVT_SCROLL(CPPgGeneral::OnHScroll)
 EVT_BUTTON(ID_DESKTOPMODE, CPPgGeneral::OnDesktopmode)
 END_EVENT_TABLE()
 
-void CPPgGeneral::OnDesktopmode(wxEvent &evt)
+void CPPgGeneral::OnDesktopmode(wxCommandEvent &evt)
 {
     theApp.xmuledlg->changeDesktopMode();
 }
 
-#if 0
-BEGIN_MESSAGE_MAP(CPPgGeneral, CPropertyPage)
-
-ON_EN_CHANGE(IDC_NICK, OnEnChangeNick)
-ON_BN_CLICKED(IDC_MINTRAY, OnBnClickedMintray)
-ON_BN_CLICKED(IDC_BEEPER, OnBnClickedBeeper)
-ON_BN_CLICKED(IDC_EXIT, OnBnClickedExit)
-ON_BN_CLICKED(IDC_SPLASHON, OnBnClickedSplashon)
-ON_BN_CLICKED(IDC_DBLCLICK, OnBnClickedDblclick)
-ON_BN_CLICKED(IDC_BRINGTOFOREGROUND, OnBnClickedBringtoforeground)
-ON_BN_CLICKED(IDC_NOTIFY, OnBnClickedNotify)
-ON_EN_CHANGE(IDC_TOOLTIPDELAY, OnEnChangeTooltipdelay)
-ON_CBN_SELCHANGE(IDC_LANGS, OnCbnSelchangeLangs)
-ON_BN_CLICKED(IDC_FLAT, OnBnClickedFlat)
-ON_BN_CLICKED(IDC_ED2KFIX, OnBnClickedEd2kfix)
-ON_BN_CLICKED(IDC_ONLINESIG, OnBnClickedOnlinesig)
-END_MESSAGE_MAP()
-#endif
-
 void CPPgGeneral::LoadSettings(void)
 {
     // Barry - Controls depth of 3d colour shading
@@ -118,10 +83,6 @@ void CPPgGeneral::LoadSettings(void)
     sliderUpdate->SetRange(2, 7);
     sliderUpdate->SetValue(app_prefs->GetUpdateDays());
     GetDlgItem(IDC_NICK, wxTextCtrl)->SetValue(app_prefs->prefs->nick);
-    //for(int i = 0; i != m_language.GetCount(); i++)
-    //  if(m_language.GetItemData(i) == app_prefs->GetLanguageID())
-    //    m_language.SetCurSel(i);
-    GetDlgItem(IDC_LANGS, wxComboBox)->SetSelection(0);
     if (app_prefs->prefs->startMinimized)
     CheckDlgButton(IDC_STARTMIN, 1);
     else
@@ -165,45 +126,6 @@ void CPPgGeneral::LoadSettings(void)
     GetDlgItem(IDC_DAYS, wxControl)->SetLabel(strBuffer);
 }
 
-#if 0
-BOOL CPPgGeneral::OnInitDialog()
-{
-    CPropertyPage::OnInitDialog();
-    ((CEdit *) GetDlgItem(IDC_NICK))->SetLimitText(49);
-    m_language.SetItemData(m_language.AddString("Bulgarian"), MAKELANGID(LANG_BULGARIAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Catalonian"), MAKELANGID(LANG_CATALAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Chinese (simplified)"), MAKELANGID(LANG_CHINESE, SUBLANG_CHINESE_SIMPLIFIED));
-    m_language.SetItemData(m_language.AddString("Chinese (traditional)"), MAKELANGID(LANG_CHINESE, SUBLANG_CHINESE_TRADITIONAL));
-    m_language.SetItemData(m_language.AddString("Danish"), MAKELANGID(LANG_DANISH, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Dutch"), MAKELANGID(LANG_DUTCH, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("English"), MAKELANGID(LANG_ENGLISH, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Finnish"), MAKELANGID(LANG_FINNISH, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("French"), MAKELANGID(LANG_FRENCH, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("German"), MAKELANGID(LANG_GERMAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Greek"), MAKELANGID(LANG_GREEK, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Italian"), MAKELANGID(LANG_ITALIAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Korean"), MAKELANGID(LANG_KOREAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Latvian"), MAKELANGID(LANG_LATVIAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Lithuanian"), MAKELANGID(LANG_LITHUANIAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Norwegian"), MAKELANGID(LANG_NORWEGIAN, SUBLANG_NORWEGIAN_BOKMAL));
-    m_language.SetItemData(m_language.AddString("Polish"), MAKELANGID(LANG_POLISH, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Portuguese"), MAKELANGID(LANG_PORTUGUESE, SUBLANG_PORTUGUESE));
-    m_language.SetItemData(m_language.AddString("Portuguese (Brasilian)"), MAKELANGID(LANG_PORTUGUESE, SUBLANG_PORTUGUESE_BRAZILIAN));
-    m_language.SetItemData(m_language.AddString("Russian"), MAKELANGID(LANG_RUSSIAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Slovenian"), MAKELANGID(LANG_SLOVENIAN, SUBLANG_DEFAULT));
-    m_language.SetItemData(m_language.AddString("Spanish"), MAKELANGID(LANG_SPANISH, SUBLANG_SPANISH));
-    m_language.SetItemData(m_language.AddString("Swedish"), MAKELANGID(LANG_SWEDISH, SUBLANG_DEFAULT));
-    GetDlgItem(IDC_ED2KFIX)->EnableWindow(Ask4RegFix(true));
-    LoadSettings();
-    Localize();
-    // return TRUE unless you set the focus to a control:
-    return TRUE;
-    // EXCEPTION: OCX Property Pages should return FALSE
-}
-
-BOOL CPPgGeneral::OnApply()
-#endif
-
 void CPPgGeneral::OnApply()
 {
     wxString buffer;
@@ -230,18 +152,13 @@ void CPPgGeneral::OnApply()
     else
     app_prefs->prefs->m_iToolDelayTime = atoi(buffer);
     // no setstyle as we can't do that anyway
-    //theApp.xmuledlg->transferwnd->downloadlistctrl->SetStyle();
-    //	app_prefs->Save();
     LoadSettings();
-    //SetModified(FALSE);
-    //return CPropertyPage::OnApply();
 }
 
 void CPPgGeneral::Localize(void)
 {
     if (1)
     {
-        //SetWindowText(GetResString(IDS_PW_GENERAL));
         GetDlgItem(IDC_NICK_FRM, wxControl)->SetLabel(GetResString(IDS_PW_NICK));
         GetDlgItem(IDC_LANG_FRM, wxControl)->SetLabel(GetResString(IDS_PW_LANG));
         GetDlgItem(IDC_MISC_FRM, wxControl)->SetLabel(GetResString(IDS_PW_MISC));
@@ -256,7 +173,6 @@ void CPPgGeneral::Localize(void)
         GetDlgItem(IDC_STARTMIN, wxControl)->SetLabel(GetResString(IDS_PREF_STARTMIN));
         GetDlgItem(IDC_3DDEP, wxControl)->SetLabel(GetResString(IDS_3DDEP));
         GetDlgItem(IDC_FLAT, wxControl)->SetLabel(GetResString(IDS_FLAT));
-        //      GetDlgItem(IDC_ROUND,wxControl)->SetLabel(GetResString(IDS_ROUND));
         GetDlgItem(IDC_WEBSVEDIT, wxControl)->SetLabel(GetResString(IDS_WEBSVEDIT));
         GetDlgItem(IDC_ED2KFIX, wxControl)->SetLabel(GetResString(IDS_ED2KLINKFIX));
         GetDlgItem(IDC_CHECK4UPDATE, wxControl)->SetLabel(GetResString(IDS_CHECK4UPDATE));
@@ -266,16 +182,12 @@ void CPPgGeneral::Localize(void)
 
 void CPPgGeneral::OnHScroll(wxScrollEvent &evt)
 {
-    //SetModified(TRUE);
     wxSlider *slider = (wxSlider *) evt.GetEventObject();
     if (slider == GetDlgItem(IDC_CHECKDAYS, wxSlider))
     {
-        //CSliderCtrl* slider =(CSliderCtrl*)pScrollBar;
         CString text;
         text.Format("%i %s", evt.GetPosition(), GetResString(IDS_DAYS2) .GetData());
         GetDlgItem(IDC_DAYS, wxControl)->SetLabel(text);
     }
-    //UpdateData(false);
-    //CPropertyPage::OnHScroll(nSBCode, nPos, pScrollBar);
 }
 
