@@ -17,27 +17,24 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// PPgServer.cpp : implementation file
-
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "EditServerListDlg.h"
-#	include "otherfunctions.h"
-#	include "PPgServer.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#include "resource.h"                   // Needed for IDS_PW_RDEAD
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/checkbox.h>
-#include <wx/notebook.h>
-#include <wx/slider.h>
+#include "PPgServer.h"                      // Needed for this Interface's Prototype
 
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
+#include "EditServerListDlg.h"              // Needed for EditServerListDlg
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_PW_RDEAD
+#include "xmule.h"                          // Needed for theApp
+
+#include <wx/checkbox.h>                    // Needed for wxCheckBox
+#include <wx/notebook.h>                    // Needed for wxNotebook
+#include <wx/textctrl.h>                    // Needed for wxTextCtrl
+
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
-// CPPgServer dialog
 #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
 #define CheckDlgButton(x,y) XRCCTRL(*this,#x,wxCheckBox)->SetValue(y)
@@ -62,50 +59,12 @@ CPPgServer::~CPPgServer()
 {
 }
 
-#if 0
-void CPPgServer::DoDataExchange(CDataExchange *pDX)
-{
-    CPropertyPage::DoDataExchange(pDX);
-}
-
-#endif
-
 BEGIN_EVENT_TABLE(CPPgServer, wxPanel)
 EVT_BUTTON(XRCID("IDC_EDITADR"), CPPgServer::OnBnClickedEditadr)
 END_EVENT_TABLE()
 
-#if 0
-BEGIN_MESSAGE_MAP(CPPgServer, CPropertyPage)
-ON_EN_CHANGE(IDC_SERVERRETRIES, OnEnChangeServerretries)
-ON_BN_CLICKED(IDC_AUTOSERVER, OnBnClickedAutoserver)
-ON_BN_CLICKED(IDC_UPDATESERVERCONNECT, OnBnClickedUpdateserverconnect)
-ON_BN_CLICKED(IDC_UPDATESERVERCLIENT, OnBnClickedUpdateserverclient)
-ON_BN_CLICKED(IDC_FILTER, OnBnClickedFilter)
-ON_BN_CLICKED(IDC_SCORE, OnBnClickedScore)
-ON_BN_CLICKED(IDC_REMOVEDEAD, OnBnClickedRemovedead)
-END_MESSAGE_MAP()
-#endif
-
 // CPPgServer message handlers
 
-#if 0
-void CPPgServer::OnBnClickedCheck1()
-{
-    // TODO: Add your control notification handler code here
-}
-
-BOOL CPPgServer::OnInitDialog()
-{
-    CPropertyPage::OnInitDialog();
-    LoadSettings();
-    Localize();
-    // return TRUE unless you set the focus to a control:
-    return TRUE;
-    // EXCEPTION: OCX Property Pages should return FALSE
-}
-
-#endif
-
 void CPPgServer::LoadSettings(void)
 {
     //	switch(app_prefs->prefs->deadserver)
@@ -217,7 +176,7 @@ void CPPgServer::Localize(void)
     }
 }
 
-void CPPgServer::OnBnClickedEditadr(wxEvent &evt)
+void CPPgServer::OnBnClickedEditadr(wxCommandEvent&evt)
 {
     char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
     sprintf(fullpath, "%sadresses.dat", theApp.glob_prefs->GetAppDir());
