@@ -20,12 +20,12 @@
 #ifndef PPGSERVER_H
 #define PPGSERVER_H
 
-#include "Preferences.h"                // Needed for CPreferences
-#include <wx/panel.h>                   // Needed for wxPanel
+#include <wx/panel.h>                       // Needed for wxPanel
+
+class CPreferences;
 
 class CPPgServer : public wxPanel
 {
-  //DECLARE_DYNAMIC(CPPgServer)
   DECLARE_DYNAMIC_CLASS(CPPgServer)
     CPPgServer() {};
 
@@ -44,28 +44,14 @@ public:
 protected:
 	CPreferences *app_prefs;
 protected:
-	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
 	DECLARE_EVENT_TABLE()
-	//DECLARE_MESSAGE_MAP()
 public:
-	//afx_msg void OnBnClickedCheck1();
-	//virtual BOOL OnInitDialog();
  public:
 	void LoadSettings(void);
 public:
 	void OnApply();
-#if 0
-	virtual BOOL OnApply();
-
-	afx_msg void OnEnChangeServerretries()			{ SetModified(); }
-	afx_msg void OnBnClickedRemovedead()			{ SetModified(); }
-	afx_msg void OnBnClickedAutoserver()			{ SetModified(); }
-	afx_msg void OnBnClickedUpdateserverconnect()	{ SetModified(); }
-	afx_msg void OnBnClickedUpdateserverclient()	{ SetModified(); }
-	afx_msg void OnBnClickedFilter()				{ SetModified(); }
-	afx_msg void OnBnClickedScore()					{ SetModified(); }
-#endif
 	void Localize(void);
-	void OnBnClickedEditadr(wxEvent& evt);
+	void OnBnClickedEditadr(wxCommandEvent & evt);
 };
+
 #endif
