@@ -17,27 +17,17 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// CPPgSourcesDropping implementation file
-
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "PPgSourcesDropping.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/slider.h>
-#include <wx/radiobox.h>                // Needed for wxRadioBox
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
+#include "PPgSourcesDropping.h"             // Needed for this Interface's Prototype
+#include "Preferences.h"                    // Needed for CPreferences
 
-#ifdef _DEBUG
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
+#include <wx/intl.h>                        // Needed for _
+#include <wx/radiobox.h>                    // Needed for wxRadioBox
 
-#define new DEBUG_NEW
-#endif
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
 #include <wx/notebook.h>
 #include <wx/checkbox.h>
