@@ -20,8 +20,9 @@
 #ifndef PPG_SOURCES_DROPPING_H
 #define PPG_SOURCES_DROPPING_H
 
-#include "Preferences.h"                // Needed for CPreferences
-#include <wx/panel.h>                   // Needed for wxPanel
+#include <wx/panel.h>                       // Needed for wxPanel
+
+class CPreferences;
 
 class CPPgSourcesDropping : public wxPanel
 {
