@@ -17,26 +17,25 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// PPgStats.cpp : implementation file
-
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#include "otherfunctions.h"             // Needed for GetResString
-#	include "PPgStats.h"
-#	include "StatisticsDlg.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/button.h>
-#include <wx/checkbox.h>
-#include <wx/colordlg.h>
-#include <wx/notebook.h>
-#include <wx/slider.h>
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
+#include "PPgStats.h"                       // Needed for this Interface's Prototype
+
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_GRAPHS
+#include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for CxmuleDlg
+
+#include <wx/colordlg.h>                    // Needed for wxGetColourFromUser
+#include <wx/combobox.h>                    // Needed for wxComboBox
+#include <wx/notebook.h>                    // Needed for wxNotebook
+#include <wx/slider.h>                      // Needed for wxSlider
+
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
 #define GetDlgItem(x,clas) XRCCTRL(*this,#x,clas)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
@@ -44,6 +43,7 @@
 #define GetRValue(rgb) (((rgb)>>16)&0xff)
 #define GetGValue(rgb) (((rgb)>>8)&0xff)
 #define GetBValue(rgb) ((rgb)&0xff)
+#define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
 
 // CPPgStats dialog
 
@@ -73,7 +73,7 @@ EVT_BUTTON(XRCID("IDC_COLOR_BUTTON"), CPPgStats::OnChangeColor)
 EVT_COMBOBOX(XRCID("IDC_COLORSELECTOR"), CPPgStats::OnCbnSelchangeColorselector)
 END_EVENT_TABLE()
 
-void CPPgStats::OnChangeColor(wxEvent &evt)
+void CPPgStats::OnChangeColor(wxCommandEvent&evt)
 {
     wxColour newcol = wxGetColourFromUser(this, XRCCTRL( *this, "IDC_COLOR_BUTTON", wxButton)->GetBackgroundColour());
     if (newcol.Ok())
@@ -85,34 +85,7 @@ void CPPgStats::OnChangeColor(wxEvent &evt)
     }
 }
 
-#if 0
-void CPPgStats::DoDataExchange(CDataExchange *pDX)
-{
-    CPropertyPage::DoDataExchange(pDX);
-}
-
-BEGIN_MESSAGE_MAP(CPPgStats, CPropertyPage)
-ON_WM_HSCROLL()
-END_MESSAGE_MAP()
-
-BOOL CPPgStats::OnInitDialog()
-{
-    CPropertyPage::OnInitDialog();
-    ((CSliderCtrl *) GetDlgItem(IDC_SLIDER))->SetPos(app_prefs->GetTrafficOMeterInterval());
-    ((CSliderCtrl *) GetDlgItem(IDC_SLIDER2))->SetPos(app_prefs->GetStatsInterval() - 4);
-    ((CSliderCtrl *) GetDlgItem(IDC_SLIDER3))->SetPos(app_prefs->GetStatsAverageMinutes() - 1);
-    mystats1 = app_prefs->GetTrafficOMeterInterval();
-    mystats2 = app_prefs->GetStatsInterval();
-    mystats3 = app_prefs->GetStatsAverageMinutes();
-    Localize();
-    // return TRUE unless you set the focus to a control:
-    return TRUE;
-    // EXCEPTION: OCX Property Pages should return FALSE
-}
-
-#endif
-
-BOOL CPPgStats::OnApply()
+bool CPPgStats::OnApply()
 {
     theApp.glob_prefs->SetTrafficOMeterInterval(mystats1);
     theApp.glob_prefs->SetStatsInterval(mystats2);
