@@ -17,22 +17,21 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// PgTweaks.cpp : implementation file
-
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "otherfunctions.h"
-#	include "PPgTweaks.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#include "resource.h"                   // Needed for IDS_FILEBUFFERSIZE
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/slider.h>
-#include <wx/textctrl.h>
-#include "wx/xrc/xmlres.h"
-#include "wx/xrc/xh_all.h"
+#include "PPgTweaks.h"                      // Needed for this Interface's Prototype
+
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_FILEBUFFERSIZE
+#include "xmule.h"                          // Needed for theApp
+
+#include <wx/slider.h>                      // Needed for wxSlider
+#include <wx/textctrl.h>                    // Needed for wxTextCtrl
+
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
 
 #ifdef _DEBUG
 #undef THIS_FILE
@@ -73,34 +72,10 @@ CPPgTweaks::~CPPgTweaks()
 {
 }
 
-#if 0
-void CPPgTweaks::DoDataExchange(CDataExchange *pDX)
-{
-    CPropertyPage::DoDataExchange(pDX);
-}
-
-BEGIN_MESSAGE_MAP(CPPgTweaks, CPropertyPage)
-
-ON_EN_CHANGE(IDC_MAXCON5SEC, OnSettingsChange)
-ON_BN_CLICKED(IDC_VERBOSE, OnSettingsChange)
-ON_BN_CLICKED(IDC_AUTOTAKEED2KLINKS, OnSettingsChange)
-ON_BN_CLICKED(IDC_UPDATEQUEUE, OnSettingsChange)
-ON_BN_CLICKED(IDC_SHOWRATEONTITLE, OnSettingsChange)
-ON_WM_HSCROLL()
-
-END_MESSAGE_MAP()
-
-#endif
-
 // CPPgTweaks message handlers
 
-BOOL CPPgTweaks::OnInitDialog()
+bool CPPgTweaks::OnInitDialog()
 {
-#if 0
-    CPropertyPage::OnInitDialog();
-    LoadSettings();
-    Localize();
-#endif
     // return TRUE unless you set the focus to a control:
     return TRUE;
     // EXCEPTION: OCX Property Pages should return FALSE
@@ -146,7 +121,7 @@ void CPPgTweaks::LoadSettings(void)
     OnHScroll(evt2);
 }
 
-BOOL CPPgTweaks::OnApply()
+bool CPPgTweaks::OnApply()
 {
     wxString buffer;
     if (GetDlgItem(IDC_MAXCON5SEC, wxTextCtrl)->GetValue() .Length())
@@ -183,7 +158,7 @@ BOOL CPPgTweaks::OnApply()
     return TRUE;
 }
 
-// UINT nSBCode, UINT nPos, CScrollBar* pScrollBar):
+// wxUint16 nSBCode, wxUint16 nPos, CScrollBar* pScrollBar):
 void CPPgTweaks::OnHScroll(wxScrollEvent &evt)
 {
     //SetModified(TRUE);
