@@ -20,13 +20,13 @@
 #ifndef PPG_TWEAKS_H
 #define PPG_TWEAKS_H
 
-#include "Preferences.h"                // Needed for CPreferences
-#include <wx/panel.h>                   // Needed for wxPanel
+#include <wx/panel.h>                       // Needed for wxPanel
+
+class CPreferences;
 
 class CPPgTweaks : public wxPanel
 {
   DECLARE_DYNAMIC_CLASS(CPPgTweaks)
-	//DECLARE_DYNAMIC(CPPgTweaks)
 
     CPPgTweaks() {};
 public:
@@ -43,27 +43,17 @@ public:
         };
 protected:
 	CPreferences *app_prefs;
-	uint8 m_iFileBufferSize;
-	uint8 m_iQueueSize;
+	wxUint8 m_iFileBufferSize;
+	wxUint8 m_iQueueSize;
 	wxPanel* _panel;
 
-#if 0
-	//{{AFX_MSG(CSpinToolBar)
-	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
-	//}}AFX_MSG
-
-	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-
-	DECLARE_MESSAGE_MAP()
-#endif
 	  DECLARE_EVENT_TABLE()
 
 	  void OnHScroll(wxScrollEvent& evt);
 public:
-	virtual BOOL OnInitDialog();
+	virtual bool OnInitDialog();
 	void LoadSettings(void);
-	virtual BOOL OnApply();
-	//afx_msg void OnSettingsChange()					{ SetModified(); }
+	virtual bool OnApply();
 
 	void Localize(void);
 
