@@ -22,10 +22,20 @@
 #ifndef PARTFILE_H
 #define PARTFILE_H
 
-#include "KnownFile.h"                  // Needed for CKnownFile
-#include "otherfunctions.h"             // Needed for GetTickCount
-#include "otherstructs.h"               // Needed for Requested_Block_Struct
-#include "types.h"                      // Needed for uint32
+#include "KnownFile.h"                      // Needed for CKnownFile
+#include "otherfunctions.h"                 // Needed for GetTickCount
+
+#include <wx/thread.h>                      // Needed for wxMutex
+
+class CFile;
+class CMemFile;
+class CSearchFile;
+class CUpDownClient;
+class wxMemoryDC;
+class wxRect;
+
+struct Gap_Struct;
+struct Requested_Block_Struct;
 
 #define	PS_READY			0
 #define	PS_EMPTY			1
@@ -47,17 +57,13 @@
 #define SRV_PR_NORMAL		0
 #define SRV_PR_HIGH			1
 
-//#define BUFFER_SIZE_LIMIT	500000 // Max bytes before forcing a flush
 #define BUFFER_TIME_LIMIT	5000   // Max milliseconds before forcing a flush
 
-class CSearchFile;
-class CUpDownClient;
-
 struct PartFileBufferedData
 {
-	BYTE *data;						// Barry - This is the data to be written
-	uint32 start;					// Barry - This is the start offset of the data
-	uint32 end;						// Barry - This is the end offset of the data
+	wxByte *data;						// Barry - This is the data to be written
+	wxUint32 start;					// Barry - This is the start offset of the data
+	wxUint32 end;						// Barry - This is the end offset of the data
 	Requested_Block_Struct *block;	// Barry - This is the requested block that this data relates to
 };
 
@@ -70,39 +76,39 @@ public:
 	void InitializeFromLink(CED2KFileLink* fileLink);
 	virtual ~CPartFile();
 	
-	void 	SetPartFileStatus(uint8 newstatus);
+	void 	SetPartFileStatus(wxUint8 newstatus);
 	bool	CreateFromFile(char* directory,char* filename)	{return false;}// not supported in this class
 	bool	LoadFromFile(FILE* file)						{return false;}
 	bool	WriteToFile(FILE* file)							{return false;}
 	bool	IsPartFile()									{return !(status == PS_COMPLETE);}
-	uint32	Process(uint32 reducedownload);
+	wxUint32	Process(wxUint32 reducedownload);
 	bool	LoadPartFile(char* in_directory, char* filename); //filename = *.part.met
 	bool	SavePartFile(bool Initial=false);
 	void	PartFileHashFinished(CKnownFile* result);
-	bool	HashSinglePart(uint16 partnumber); // true = ok , false = corrupted	
+	bool	HashSinglePart(wxUint16 partnumber); // true = ok , false = corrupted	
 
-	void	AddGap(uint32 start, uint32 end);
-	void	FillGap(uint32 start, uint32 end);
+	void	AddGap(wxUint32 start, wxUint32 end);
+	void	FillGap(wxUint32 start, wxUint32 end);
 	void	DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool bFlat);
 	void	DrawShareStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect, bool bFlat);
-	bool	IsComplete(uint32 start, uint32 end);
-	bool	IsPureGap(uint32 start, uint32 end);
-	bool	IsCorruptedPart(uint16 partnumber);
+	bool	IsComplete(wxUint32 start, wxUint32 end);
+	bool	IsPureGap(wxUint32 start, wxUint32 end);
+	bool	IsCorruptedPart(wxUint16 partnumber);
 	void	UpdateCompletedInfos();
         
-	bool	GetNextRequestedBlock(CUpDownClient* sender,Requested_Block_Struct** newblocks,uint16* count);
+	bool	GetNextRequestedBlock(CUpDownClient* sender,Requested_Block_Struct** newblocks,wxUint16* count);
 	void	WritePartStatus(CMemFile* file);
-	void	AddSources(CMemFile* sources,uint32 serverip, uint16 serverport);
-	uint8	GetStatus(bool ignorepause = false);
+	void	AddSources(CMemFile* sources,wxUint32 serverip, wxUint16 serverport);
+	wxUint8	GetStatus(bool ignorepause = false);
 	void	NewSrcPartsInfo();
 	char*	GetPartMetFileName()							{return partmetfilename;}
-	uint32	GetTransfered()									{return transfered;}
+	wxUint32	GetTransfered()									{return transfered;}
 	char*	GetFullName()									{return fullname;}
-	uint16	GetSourceCount();
-	uint16	GetTransferingSrcCount()						{return transferingsrc;}
-	uint32	GetDatarate()									{return datarate;}
+	wxUint16	GetSourceCount();
+	wxUint16	GetTransferingSrcCount()						{return transferingsrc;}
+	wxUint32	GetDatarate()									{return datarate;}
 	float	GetPercentCompleted()							{return percentcompleted;}
-	uint16  GetNotCurrentSourcesCount();
+	wxUint16  GetNotCurrentSourcesCount();
 	int		GetValidSourcesCount();
 	bool	IsMovie();
 	bool	IsSound();
@@ -113,13 +119,13 @@ public:
 	
 	
 	CString getPartfileStatus(); //<<--9/21/02
-	sint32	getTimeRemaining(); //<<--9/21/02
+	wxInt32	getTimeRemaining(); //<<--9/21/02
 	time_t	lastseencomplete;
 	int		getPartfileStatusRang();
         CString GetDownloadFileInfo();
 
 	// Barry - Added as replacement for BlockReceived to buffer data before writing to disk
-	uint32	WriteToBuffer(uint32 transize, BYTE *data, uint32 start, uint32 end, Requested_Block_Struct *block);
+	wxUint32	WriteToBuffer(wxUint32 transize, wxByte *data, wxUint32 start, wxUint32 end, Requested_Block_Struct *block);
 	void	FlushBuffer(void);
 	// Barry - This will invert the gap list, up to caller to delete gaps when done
 	// 'Gaps' returned are really the filled areas, and guaranteed to be in order
@@ -131,7 +137,7 @@ public:
 	// Barry - Added to prevent list containing deleted blocks on shutdown
 	void	RemoveAllRequestedBlocks(void);
 
-	void	RemoveBlockFromList(uint32 start,uint32 end);
+	void	RemoveBlockFromList(wxUint32 start,wxUint32 end);
 	void	RemoveAllSources(bool bTryToSwap);
 	void	DeleteFile();
 	void	StopFile();
@@ -139,20 +145,20 @@ public:
 	void	ResumeFile();
 
 	virtual	Packet* CreateSrcInfoPacket(CUpDownClient* forClient);
-	void	AddClientSources(CMemFile* sources,uint8 sourceexchangeversion);
+	void	AddClientSources(CMemFile* sources,wxUint8 sourceexchangeversion);
 
 	void	PreviewFile();
 	bool	PreviewAvailable();
-	uint8   GetAvailablePartCount()			{return availablePartsCount;}
+	wxUint8   GetAvailablePartCount()			{return availablePartsCount;}
 	void	UpdateAvailablePartsCount();
 
-	uint32	GetLastAnsweredTime()			{ return m_ClientSrcAnswered; }
+	wxUint32	GetLastAnsweredTime()			{ return m_ClientSrcAnswered; }
 	void	SetLastAnsweredTime()			{ m_ClientSrcAnswered = ::GetTickCount(); }
 	void	SetLastAnsweredTimeTimeout()		{ m_ClientSrcAnswered = 2 * CONNECTION_LATENCY +
 											                        ::GetTickCount() - SOURCECLIENTREASK; }
-	uint64	GetLostDueToCorruption()		{return m_iLostDueToCorruption;}
-	uint64	GetGainDueToCompression()		{return m_iGainDueToCompression;}
-	uint32	TotalPacketsSavedDueToICH()		{return m_iTotalPacketsSavedDueToICH;}
+	wxUint64	GetLostDueToCorruption()		{return m_iLostDueToCorruption;}
+	wxUint64	GetGainDueToCompression()		{return m_iGainDueToCompression;}
+	wxUint32	TotalPacketsSavedDueToICH()		{return m_iTotalPacketsSavedDueToICH;}
 	bool	IsStopped() 				{return stopped;}
 	bool	HasComment()				{return hasComment;}
 	bool	HasRating()				{return hasRating;}
@@ -161,89 +167,89 @@ public:
 	void	SetHasRating(bool in)			{hasRating=in;}
 	void	UpdateFileRatingCommentAvail();
 
-        wxString GetProgressString(uint16 size);
+        wxString GetProgressString(wxUint16 size);
 
 	int		GetCommonFilePenalty();
 	void	UpdateDisplayedInfo(bool force=false);
 	time_t	GetLastChangeDatetime(bool forcecheck=false);
-	uint8	GetCategory();
-	void	SetCategory(uint8 cat)			{m_category=cat;SavePartFile();}
+	wxUint8	GetCategory();
+	void	SetCategory(wxUint8 cat)			{m_category=cat;SavePartFile();}
 
-	CFile	m_hpartfile;	//permanent opened handle to avoid write conflicts
+	CFile*	m_hpartfile;	//permanent opened handle to avoid write conflicts
 	volatile bool m_bPreviewing;
-	void	SetDownPriority(uint8 newDownPriority);
+	void	SetDownPriority(wxUint8 newDownPriority);
 	bool	IsAutoDownPriority()	{ return m_bAutoDownPriority; }
 	void	SetAutoDownPriority(bool flag) { m_bAutoDownPriority = flag; }
 	void	UpdateAutoDownPriority();
-	uint8	GetDownPriority()	{ return m_iDownPriority; }
+	wxUint8	GetDownPriority()	{ return m_iDownPriority; }
         // Acess to Flag for SourceSharing
         bool    GetDisableXS()          { return m_DisableXS; }
         void    SetDisableXS(bool in)   { m_DisableXS = in; }
 protected:
-	bool	GetNextEmptyBlockInPart(uint16 partnumber,Requested_Block_Struct* result);
-	bool	IsAlreadyRequested(uint32 start, uint32 end);
+	bool	GetNextEmptyBlockInPart(wxUint16 partnumber,Requested_Block_Struct* result);
+	bool	IsAlreadyRequested(wxUint32 start, wxUint32 end);
 	void	CompleteFile(bool hashingdone);
 	void	CreatePartFile();
 	void	Init();
 	wxMutex 	m_FileCompleteMutex;  // Lord KiRon - Mutex for file completion
 private:
-	uint16	count;
-	uint16	transferingsrc;
-	uint32  completedsize;
-	uint64	m_iLostDueToCorruption;
-	uint64	m_iGainDueToCompression;
-	uint32  m_iTotalPacketsSavedDueToICH;
-	uint32	datarate;
+	wxUint16	count;
+	wxUint16	transferingsrc;
+	wxUint32  completedsize;
+	wxUint64	m_iLostDueToCorruption;
+	wxUint64	m_iGainDueToCompression;
+	wxUint32  m_iTotalPacketsSavedDueToICH;
+	wxUint32	datarate;
 	char*	fullname;
 	char*	partmetfilename;
-	uint32	transfered;
+	wxUint32	transfered;
 	bool	paused;
 	bool	stopped;
         bool    m_DisableXS;                  // Flag for SourceSharing
-	uint8	m_iDownPriority;
+	wxUint8	m_iDownPriority;
 	bool	m_bAutoDownPriority;
-	uint8	status;
+	wxUint8	status;
 	bool	newdate;	             // indicates if there was a writeaccess to the .part file
-	uint32	lastsearchtime;
-	uint32	lastpurgetime;
-	uint32	m_LastNoNeededCheck;
+	wxUint32	lastsearchtime;
+	wxUint32	lastpurgetime;
+	wxUint32	m_LastNoNeededCheck;
 	CTypedPtrList<CPtrList, Gap_Struct*> gaplist;
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> requestedblocks_list;
-	CArray<uint16,uint16> m_SrcpartFrequency;
+	CArray<wxUint16,wxUint16> m_SrcpartFrequency;
 	float	percentcompleted;
-	CList<uint16,uint16>	corrupted_list;
-	uint8	availablePartsCount;
-	uint32	m_ClientSrcAnswered;
-	uint32	m_nSavedReduceDownload;
+	CList<wxUint16,wxUint16>	corrupted_list;
+	wxUint8	availablePartsCount;
+	wxUint32	m_ClientSrcAnswered;
+	wxUint32	m_nSavedReduceDownload;
 	bool	m_bPercentUpdated;
 	static	CBarShader s_LoadBar; 
 	static	CBarShader s_ChunkBar; 
 	bool	hasRating;
 	bool	hasComment;
-	BOOL 	PerformFileComplete(); // Lord KiRon
-	static UINT CompleteThreadProc(CPartFile* pFile); // Lord KiRon - Used as separate thread to complete file
+	bool 	PerformFileComplete(); // Lord KiRon
+	static wxUint16 CompleteThreadProc(CPartFile* pFile); // Lord KiRon - Used as separate thread to complete file
 	void    CharFillRange(wxString* buffer,float start, float end, char color);
 
-	DWORD	m_lastRefreshedDLDisplay;
-	DWORD   m_lastdatetimecheck;
+	wxUint32	m_lastRefreshedDLDisplay;
+	wxUint32   m_lastdatetimecheck;
 	time_t	m_lastdatecheckvalue;
 
 	// Barry - Buffered data to be written
 	CTypedPtrList<CPtrList, PartFileBufferedData*> m_BufferedData_list;
-	uint32 m_nTotalBufferData;
-	uint32 m_nLastBufferFlushTime;
-	uint8	m_category;
+	wxUint32 m_nTotalBufferData;
+	wxUint32 m_nLastBufferFlushTime;
+	wxUint8	m_category;
 	
-	DWORD	m_LastSourceDropTime;
+	wxUint32	m_LastSourceDropTime;
 
 public:
 	CTypedPtrList<CPtrList, CUpDownClient*> srclists[SOURCESSLOTS];
 	bool	srcarevisible;		// used for downloadlistctrl
 	bool	m_bShowOnlyDownloading;	// used for downloadlistctrl
 	bool	hashsetneeded;
-	uint16	GetMaxSourcesPerFile() { return m_MaxSourcesPerFile; }
-	void	SetMaxSourcesPerFile(uint16 in) { m_MaxSourcesPerFile=in; }
-	uint32  GetCompletedSize()   {return completedsize;}
+	wxUint16	GetMaxSourcesPerFile() { return m_MaxSourcesPerFile; }
+	void	SetMaxSourcesPerFile(wxUint16 in) { m_MaxSourcesPerFile=in; }
+	wxUint32  GetCompletedSize()   {return completedsize;}
 	
 	   /* Razor 1a - Modif by MikaelB */
 
@@ -287,7 +293,7 @@ public:
 
           /* A4AF Auto attribute */
           bool m_IsA4AFAuto;
-	  uint16 	m_MaxSourcesPerFile;
+	  wxUint16 	m_MaxSourcesPerFile;
 
 /* End modif */
  
