@@ -21,63 +21,47 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif // HAVE_CONFIG_H
+#ifdef PRECOMP
+    #include "xmule-headers.h"
+#endif
 
-// Test if we have _GNU_SOURCE before the next step will mess up
-// setting __USE_GNU
-// (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
-#include "wx/setup.h"
+#include "Preferences.h"                    // Needed for this Interface's Prototype
+
+#include "ini2.h"                           // Needed for CIni
+#include "opcodes.h"                        // Needed for MAXCONPER5SEC
+#include "otherfunctions.h"                 // Needed for md4cpy
+#include "xmule.h"                          // Needed for theApp
+
+#include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
+
+#ifdef HAVE_CONFIG_H
+    #include "config.h"                     // Needed for PACKAGE_NAME
+#endif
 
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
 #if defined(HAVE_SYS_PARAM_H)
-#include <sys/param.h>
+    #include <sys/param.h>                  // Needed for *BSD systems, apparently.
 #endif
 
-#ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "wintypes.h"
-#	include "Preferences.h"
-#	include "opcodes.h"
-#include "otherfunctions.h"             // Needed for md4cpy
-#	include "ini2.h"
-#	include "stdlib.h"
-#	include "stdio.h"
-#	include "resource.h"
-#endif
-
-#include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
-
-#include <time.h>
-#include <stdlib.h>
-#include <locale.h>
-#include <wx/filename.h>
+#include <wx/filename.h>                    // Needed for wxFileName
 
 #define ELEMENT_COUNT(X) (sizeof(X) / sizeof(X[0]))
 #define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
 
-#include <sys/stat.h>
-#include <sys/types.h>
-
-
 #ifndef MAX_PATH
-// *BSD compatibility
-#if (defined(BSD) && (BSD >= 199103))
-#define MAX_PATH MAXPATHLEN
-#else
-#define MAX_PATH 2048
-#endif
+    // *BSD compatibility
+    #if (defined(BSD) && (BSD >= 199103))
+        #define MAX_PATH MAXPATHLEN
+    #else
+        #define MAX_PATH 2048
+    #endif
 #endif
 
 #ifdef __FreeBSD__
-extern long long atoll(char *s);
+    extern long long atoll(char *s);
 #endif /* __FreeBSD__ */
 
-
-
 CPreferences::CPreferences()
 {
     // we need random numbers sometimes:
@@ -90,7 +74,10 @@ CPreferences::CPreferences()
     // Use home directory to save preferences
     char buffer[490];
     snprintf(buffer, 400, "%s/." PACKAGE_NAME, getenv("HOME"));
-    mkdir(buffer, 0777);
+    if (!wxDirExists(buffer))
+    {
+        wxMkdir(buffer, 0777);
+    }
     strncat(buffer, "/", 1);
     SetAppDir(CString(buffer)); 
 
@@ -222,25 +209,28 @@ void CPreferences::CreateUserHash()
 
 int CPreferences::GetRecommendedMaxConnections()
 {
+#if defined(__WIN32__)
     int iRealMax =::GetMaxConnections();
-    if (iRealMax == - 1 || iRealMax > 520)
-    return 500;
-    if (iRealMax < 20)
-    return iRealMax;
-    if (iRealMax <= 256)
-    return iRealMax - 10;
-    return iRealMax - 20;
-}
-
-WORD CPreferences::GetWindowsVersion()
-{
-    static bool bWinVerAlreadyDetected = false;
-    if (!bWinVerAlreadyDetected)
+    
+    if (iRealMax == -1 || iRealMax > 520)
     {
-        bWinVerAlreadyDetected = true;
-        m_wWinVer = DetectWinVersion();
+        return 500;
     }
-    return m_wWinVer;
+    
+    if (iRealMax < 20)
+    {
+        return iRealMax;
+    }
+
+    if (iRealMax <= 256)
+    {
+        return iRealMax - 10;
+    }
+    
+    return iRealMax - 20;
+#else
+    return 500;
+#endif
 }
 
 uint16 CPreferences::GetDefaultMaxConperFive()
@@ -647,7 +637,7 @@ bool CPreferences::LoadPreferences(void)
     sprintf(prefs->proxy.password, "%s", ini.GetString("ProxyPassword", buffer, "Proxy") .GetData());
     sprintf(prefs->proxy.user, "%s", ini.GetString("ProxyUser", buffer, "Proxy") .GetData());
     prefs->proxy.port = ini.GetInt("ProxyPort", 1080, "Proxy");
-    prefs->proxy.type = ini.GetInt("ProxyType", PROXYTYPE_NOPROXY, "Proxy");
+    prefs->proxy.type = ini.GetInt("ProxyType", 0, "Proxy");
     for (int i = 0 ; i < 13 ; i++)
     {
          buffer2.Format("StatColor%i", i);
@@ -822,34 +812,35 @@ bool CPreferences::LoadCats(void)
     category_fd = fopen(catinif, "r");
     if (category_fd != NULL)
     {
-	   fscanf(category_fd, "%d ", &max);
-           for (int i = 1 ; i <= max ; i++)
-           {
-                  Category_Struct *newcat = new Category_Struct;
-  	          fgets(buffer, 66, category_fd);
-                  sprintf(newcat->title, "");
-                  strncat(newcat->title, buffer, strlen(buffer) - 1);          
-                  fgets(buffer, 2050, category_fd);                                  
-                  sprintf(newcat->incomingpath, "");
-                  strncat(newcat->incomingpath, buffer, strlen(buffer) - 1);
-                  fgets(buffer, 258, category_fd);
-                  sprintf(newcat->comment, "");
-                  strncat(newcat->comment, buffer, strlen(buffer) - 1);
-                  fgets(buffer, 15, category_fd);
-                  newcat->color = (uint32)strtoul(buffer, &dummy, 0);
-                  fgets(buffer, 5, category_fd);
-                  newcat->prio = (uint8) atoi(buffer) - 1;
-                  AddCat(newcat);
-                  if (!wxFileName::DirExists(newcat->incomingpath)) 
-                  {
-                      mkdir(newcat->incomingpath, 0777);
-		  }
-           }
+        fscanf(category_fd, "%d ", &max);
+       for (int i = 1 ; i <= max ; i++)
+       {
+            Category_Struct *newcat = new Category_Struct;
+            fgets(buffer, 66, category_fd);
+            sprintf(newcat->title, "");
+            strncat(newcat->title, buffer, strlen(buffer) - 1);          
+            fgets(buffer, 2050, category_fd);                                  
+            sprintf(newcat->incomingpath, "");
+            strncat(newcat->incomingpath, buffer, strlen(buffer) - 1);
+            fgets(buffer, 258, category_fd);
+            sprintf(newcat->comment, "");
+            strncat(newcat->comment, buffer, strlen(buffer) - 1);
+            fgets(buffer, 15, category_fd);
+            newcat->color = (uint32)strtoul(buffer, &dummy, 0);
+            fgets(buffer, 5, category_fd);
+            newcat->prio = (uint8) atoi(buffer) - 1;
+            AddCat(newcat);
+
+            if (!wxFileName::DirExists(newcat->incomingpath)) 
+            {
+                wxMkdir(newcat->incomingpath, 0777);
+            }
+       }
            fclose(category_fd);
     } 
     else
     {
-	   error = true;
+        error = true;
     }
     return error;
 }
@@ -973,7 +964,7 @@ void CPreferences::SetColumnSortAscending(Table t, bool sortAscending)
     }
 }
 
-int CPreferences::GetColumnWidth(Table t, int index) const
+int CPreferences::GetColumnWidth(const short int t, int index) const
 {
     switch (t)
     {
@@ -996,7 +987,7 @@ int CPreferences::GetColumnWidth(Table t, int index) const
 
 }
 
-void CPreferences::SetColumnWidth(Table t, int index, int width)
+void CPreferences::SetColumnWidth(const short int t, int index, int width)
 {
     switch (t)
     {
@@ -1024,57 +1015,7 @@ void CPreferences::SetColumnWidth(Table t, int index, int width)
     }
 }
 
-BOOL CPreferences::GetColumnHidden(Table t, int index) const
-{
-    switch (t)
-    {
-    case tableDownload:
-        return prefs->downloadColumnHidden[index];
-    case tableUpload:
-        return prefs->uploadColumnHidden[index];
-    case tableQueue:
-        return prefs->queueColumnHidden[index];
-    case tableSearch:
-        return prefs->searchColumnHidden[index];
-    case tableShared:
-        return prefs->sharedColumnHidden[index];
-    case tableServer:
-        return prefs->serverColumnHidden[index];
-    case tableClientList:
-        return prefs->clientListColumnHidden[index];
-    }
-    return FALSE;
-}
-
-void CPreferences::SetColumnHidden(Table t, int index, BOOL bHidden)
-{
-    switch (t)
-    {
-    case tableDownload:
-        prefs->downloadColumnHidden[index] = bHidden;
-        break;
-    case tableUpload:
-        prefs->uploadColumnHidden[index] = bHidden;
-        break;
-    case tableQueue:
-        prefs->queueColumnHidden[index] = bHidden;
-        break;
-    case tableSearch:
-        prefs->searchColumnHidden[index] = bHidden;
-        break;
-    case tableShared:
-        prefs->sharedColumnHidden[index] = bHidden;
-        break;
-    case tableServer:
-        prefs->serverColumnHidden[index] = bHidden;
-        break;
-    case tableClientList:
-        prefs->clientListColumnHidden[index] = bHidden;
-        break;
-    }
-}
-
-int CPreferences::GetColumnOrder(Table t, int index) const
+int CPreferences::GetColumnOrder(const short int t, int index) const
 {
     switch (t)
     {
@@ -1096,7 +1037,7 @@ int CPreferences::GetColumnOrder(Table t, int index) const
     return 0;
 }
 
-void CPreferences::SetColumnOrder(Table t, INT *piOrder)
+void CPreferences::SetColumnOrder(const short int t, INT *piOrder)
 {
     switch (t)
     {
