@@ -22,27 +22,22 @@
 #ifndef PREVIEW_H
 #define PREVIEW_H
 
-#include "PartFile.h"                   // Needed for CPartFile
+#include <wx/thread.h>                      // Needed for wxThread
+
+class CPartFile;
 
 class CPreviewThread : public wxThread
 {
-  //	DECLARE_DYNCREATE(CPreviewThread)
-
- public:
+public:
 	CPreviewThread();           // protected constructor used by dynamic creation
 	virtual ~CPreviewThread();
-	//DECLARE_MESSAGE_MAP()
 public:
-	virtual	BOOL	InitInstance() {return true;}
-	//virtual int		Run();
+	virtual	bool	InitInstance() {return true;}
 	virtual void* Entry();
 	void	SetValues(CPartFile* pPartFile);
 
 private:
 	CPartFile* m_pPartfile;
-
 };
 
-
-
 #endif
