@@ -19,30 +19,28 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// QueueListCtrl.cpp : implementation file
-
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "QueueListCtrl.h"
-#include "PartFile.h"                   // Needed for PR_VERYHIGH
-#	include "ChatWnd.h"
-#include "ClientCredits.h"                  // Needed for CClientCredits
-#	include "ClientDetailDialog.h"
-#	include "FriendList.h"
-#	include "KnownFile.h"
-#	include "muuli_wdr.h"
-#	include "otherfunctions.h"
-#	include "opcodes.h"
-#	include "SharedFileList.h"
-#	include "TransferWnd.h"
-#	include "UploadQueue.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/menu.h>                    // Needed for wxMenu
+#include "QueueListCtrl.h"                  // Needed for this Interface's Prototype
+ 
+#include "ChatWnd.h"                        // Needed for CChatWnd
+#include "ClientCredits.h"                  // Needed for CClientCredits
+#include "ClientDetailDialog.h"             // Needed for CClientDetailDialog
+#include "FriendList.h"                     // Needed for CFriendList
+#include "muuli_wdr.h"                      // Needed for ID_QUEUELIST
+#include "PartFile.h"                       // Needed for PR_VERYHIGH
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "TransferWnd.h"                    // Needed for CTransferWnd
+#include "updownclient.h"                   // Needed for CUpDownClient
+#include "UploadQueue.h"                    // Needed for CUploadQueue
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for CxmuleDlg
+
+#include <wx/dcmemory.h>                    // Needed for wxMemoryDC
+#include <wx/menu.h>                        // Needed for wxMenu
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
@@ -128,42 +126,6 @@ void CQueueListCtrl::Init()
     InsertColumn(7, GetResString(IDS_ENTERQUEUE), LVCFMT_LEFT, 110);
     InsertColumn(8, GetResString(IDS_BANNED), LVCFMT_LEFT, 60);
     InsertColumn(9, GetResString(IDS_UPSTATUS), LVCFMT_LEFT, 100);
-#if 0
-    // something that can't be done here and now. moved to InitSort()
-    // Barry - Use preferred sort order from preferences
-    int sortItem = theApp.glob_prefs->GetColumnSortItem(CPreferences::tableQueue);
-    bool sortAscending = theApp.glob_prefs->GetColumnSortAscending(CPreferences::tableQueue);
-    SetSortArrow(sortItem, sortAscending);
-    SortItems(SortProc, sortItem + (sortAscending ? 0: 10));
-#endif
-#if 0
-    SetExtendedStyle(LVS_EX_FULLROWSELECT);
-    InsertColumn(0, GetResString(IDS_QL_USERNAME), LVCFMT_LEFT, 150, 0);
-    InsertColumn(1, GetResString(IDS_FILE), LVCFMT_LEFT, 275, 1);
-    InsertColumn(2, GetResString(IDS_FILEPRIO), LVCFMT_LEFT, 110, 2);
-    InsertColumn(3, GetResString(IDS_QL_RATING), LVCFMT_LEFT, 60, 3);
-    InsertColumn(4, GetResString(IDS_SCORE), LVCFMT_LEFT, 60, 4);
-    InsertColumn(5, GetResString(IDS_ASKED), LVCFMT_LEFT, 60, 5);
-    InsertColumn(6, GetResString(IDS_LASTSEEN), LVCFMT_LEFT, 110, 6);
-    InsertColumn(7, GetResString(IDS_ENTERQUEUE), LVCFMT_LEFT, 110, 7);
-    InsertColumn(8, GetResString(IDS_BANNED), LVCFMT_LEFT, 60, 8);
-    imagelist.Create(16, 16, ILC_COLOR32 |ILC_MASK, 0, 10);
-    imagelist.SetBkColor(RGB(255, 255, 255));
-    imagelist.Add(theApp.LoadIcon(IDI_USER0));
-    imagelist.Add(theApp.LoadIcon(IDI_COMPPROT));
-    imagelist.Add(theApp.LoadIcon(IDI_PLUS));
-    imagelist.Add(theApp.LoadIcon(IDI_PLUSCOMPROT));
-    SetImageList( &imagelist, LVSIL_SMALL);
-    m_ClientMenu.CreatePopupMenu();
-    m_ClientMenu.AddMenuTitle(GetResString(IDS_CLIENTS));
-    m_ClientMenu.AppendMenu(MF_STRING, MP_DETAIL, GetResString(IDS_SHOWDETAILS));
-    m_ClientMenu.AppendMenu(MF_STRING, MP_MESSAGE, GetResString(IDS_SEND_MSG));
-    m_ClientMenu.AppendMenu(MF_STRING, MP_UNBAN, GetResString(IDS_UNBAN));
-    m_ClientMenu.AppendMenu(MF_SEPARATOR);
-    m_ClientMenu.AppendMenu(MF_STRING, MP_SWITCHCTRL, GetResString(IDS_VIEWUPLOADS));
-    SetMenu( &m_ClientMenu);
-    LoadSettings(CPreferences::tableQueue);
-#endif
 }
 
 CQueueListCtrl::~CQueueListCtrl()
@@ -206,51 +168,6 @@ void CQueueListCtrl::OnNMRclick(wxMouseEvent &evt)
 
 void CQueueListCtrl::Localize()
 {
-#if 0
-    CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-    HDITEM hdi;
-    hdi.mask = HDI_TEXT;
-    if (pHeaderCtrl->GetItemCount() != 0)
-    {
-        CString strRes;
-        strRes = GetResString(IDS_QL_USERNAME);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(0, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_FILE);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(1, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_FILEPRIO);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(2, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_QL_RATING);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(3, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_SCORE);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(4, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_ASKED);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(5, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_LASTSEEN);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(6, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_ENTERQUEUE);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(7, &hdi);
-        strRes.ReleaseBuffer();
-        strRes = GetResString(IDS_BANNED);
-        hdi.pszText = strRes.GetBuffer();
-        pHeaderCtrl->SetItem(8, &hdi);
-        strRes.ReleaseBuffer();
-    }
-#endif
 }
 
 void CQueueListCtrl::AddClient(CUpDownClient *client)
@@ -346,7 +263,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
     cur_rec.top = rect.y;
     cur_rec.right = rect.x + rect.width;
     cur_rec.bottom = rect.y + rect.height;
-    CString Sbuffer;
+    wxString Sbuffer;
     //	char buffer[100];
     CKnownFile *file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
@@ -415,7 +332,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                                         };
                     //imagelist.Draw(dc,image, point, ILD_NORMAL);
                     imagelist.Draw(image, *dc, cur_rec.left, cur_rec.top + 1, wxIMAGELIST_DRAW_TRANSPARENT);
-                    Sbuffer.Format("%s", client->GetUserName());
+                    Sbuffer = client->GetUserName();
                     cur_rec.left += 20;
                     dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
                     cur_rec.left -= 20;
@@ -423,7 +340,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                 }
             case 1:
                 if (file)
-                Sbuffer.Format("%s", file->GetFileName());
+                Sbuffer = file->GetFileName();
                 else
                 Sbuffer = "?";
                 break;
@@ -433,19 +350,19 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                     switch (file->GetUpPriority())
                     {
                     case PR_VERYHIGH:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIORELEASE) .GetData());
+                        Sbuffer = GetResString(IDS_PRIORELEASE);
                         break;
                     case PR_HIGH:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIOHIGH) .GetData());
+                        Sbuffer = GetResString(IDS_PRIOHIGH);
                         break;
                     case PR_LOW:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIOLOW) .GetData());
+                        Sbuffer = GetResString(IDS_PRIOLOW);
                         break;
                     case PR_VERYLOW:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIOVERYLOW) .GetData());
+                        Sbuffer = GetResString(IDS_PRIOVERYLOW);
                         break;
                     default:
-                        Sbuffer.Format("%s", GetResString(IDS_PRIONORMAL) .GetData());
+                        Sbuffer = GetResString(IDS_PRIONORMAL);
                         break;
                     }
                 }
@@ -453,25 +370,29 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
                 Sbuffer = "?";
                 break;
             case 3:
-                Sbuffer.Format("%.1f", (float) client->GetScore(false, false, true));
+                Sbuffer.Printf("%.1f", (float)client->GetScore(false, false, true));
                 break;
             case 4:
-                Sbuffer.Format("%i", client->GetScore(false));
+                Sbuffer.Printf("%i", client->GetScore(false));
                 break;
             case 5:
-                Sbuffer.Format("%i", client->GetAskedCount());
+                Sbuffer.Printf("%i", client->GetAskedCount());
                 break;
             case 6:
-                Sbuffer.Format("%s", CastSecondsToHM((::GetTickCount() - client->GetLastUpRequest()) /1000) .GetData());
+                Sbuffer = CastSecondsToHM((::GetTickCount() - client->GetLastUpRequest()) / 1000);
                 break;
             case 7:
-                Sbuffer.Format("%s", CastSecondsToHM((::GetTickCount() - client->GetWaitStartTime()) /1000) .GetData());
+                Sbuffer = CastSecondsToHM((::GetTickCount() - client->GetWaitStartTime()) / 1000);
                 break;
             case 8:
                 if (client->IsBanned())
-                Sbuffer.Format("%s", GetResString(IDS_YES) .GetData());
+                {
+                    Sbuffer = GetResString(IDS_YES);
+                }
                 else
-                Sbuffer.Format("%s", GetResString(IDS_NO) .GetData());
+                {
+                    Sbuffer = GetResString(IDS_NO);
+                }
                 break;
             case 9:
                 if (client->GetUpPartCount())
@@ -504,26 +425,7 @@ void CQueueListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const wx
     }
 }
 
-#if 0
-BEGIN_MESSAGE_MAP(CQueueListCtrl, CMuleListCtrl)
-ON_NOTIFY_REFLECT(NM_RCLICK, OnNMRclick)
-ON_NOTIFY_REFLECT(LVN_COLUMNCLICK, OnColumnClick)
-END_MESSAGE_MAP()
-#endif
-
-#if 0
-// CQueueListCtrl message handlers
-void CQueueListCtrl::OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult)
-{
-    POINT point;
-    ::GetCursorPos( &point);
-    m_ClientMenu.TrackPopupMenu(TPM_LEFTALIGN |TPM_RIGHTBUTTON, point.x, point.y, this);
-    *pResult = 0;
-}
-
-#endif
-
-bool CQueueListCtrl::ProcessEvent(wxEvent &evt)
+bool CQueueListCtrl::ProcessEvent(wxEvent& evt)
 {
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
     return CMuleListCtrl::ProcessEvent(evt);
