@@ -20,17 +20,14 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "wintypes.h"
-#	include "SafeFile.h"
+    #include "xmule-headers.h"
 #endif
 
+#include "SafeFile.h"                       // Needed for this Interface's Prototype
+
 CSafeFile::CSafeFile(LPCSTR lpszFileName, UINT nOpenFlags)
 : CFile(lpszFileName, (CFile::OpenMode) nOpenFlags)
-//:CFile(lpszFileName,nOpenFlags)
 {
-    // Nothing to do here
 }
 
 CSafeFile::CSafeFile(): CFile()
