@@ -22,62 +22,44 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-//#define 	__AMULE0__
-//#define	__XMULE2__
-
-#ifndef __AMULE0__
-#include <wx/settings.h>
-#include <wx/sizer.h>
-#include <wx/settings.h>
-#include <wx/sizer.h>
-#include <wx/tokenzr.h>
-#include "listctrl.h"
-#include <wx/splitter.h>	//Splitterwindow
-#include "wx/xrc/xmlres.h"
-#include "xmuleDlg.h"           // Needed for CxmuleDlg
-#endif
-
 #if defined(WIN32)
-#include <wx/msw/winundef.h>      // THIS IS NEEDED OR ERRORS RESULT!!
+    #include <wx/msw/winundef.h>            // THIS IS NEEDED OR ERRORS RESULT!!
 #endif
-#include <wx/wx.h>
 
-#ifndef __XMULE2__                // FOR XMULE 1.8
-
-#include "SearchDlg.h"            // Interface declarations.
-#include "SearchList.h"           // Interface declarations.
-#include "xmule.h"                      // Needed for theApp
-#include "ED2KLink.h"             // Needed for CED2KLink
-#include "UploadQueue.h"          // Needed for CUploadQueue
-#include "DownloadQueue.h"        // Needed for CDownloadQueue
-#include "otherfunctions.h"       // Needed for URLEncode
-#include "packets.h"              // Needed for Packet
-#include "server.h"               // Needed for CServer
-#include "ServerList.h"           // Needed for CServerList
-#include "sockets.h"              // Needed for CServerConnect
-
-#else                             // FOR XMULE 2.0
+//#include <wx/wx.h>
 
 #ifdef PRECOMP
-#include "pch.h"                  // For precompiled releases
+    #include "xmule-headers.h"
 #endif
 
-#include "sys.h"                  // Needed for platform-specific code
-#include "SearchDlg.h"            // Interface declarations.
-#include "xmuleDlg.h"             // Needed for CxmuleDlg
-#include "ED2KLink.h"             // Needed for CED2KLink
-#include "UploadQueue.h"          // Needed for CUploadQueue
-#include "SearchList.h"           // Needed for CSearchList
-#include "DownloadQueue.h"        // Needed for CDownloadQueue
-#include "otherfunctions.h"       // Needed for URLEncode
-#include "packets.h"              // Needed for Packet
-#include "server.h"               // Needed for CServer
-#include "ServerList.h"           // Needed for CServerList
-#include "sockets.h"              // Needed for CServerConnect
-#include "CxmuleAppBase.h"        // Needed for theApp
-#include "muuli_wdr.h"            // Needed for IDC_STARTS
+#include "SearchDlg.h"                      // Needed for this Interface's Prototype
 
-#endif
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "ED2KLink.h"                       // Needed for CED2KLink
+#include "listctrl.h"                       // Needed for wxODListCtrl
+#include "otherfunctions.h"                 // Needed for URLEncode
+#include "packets.h"                        // Needed for Packet
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_SEARCH_ANY
+#include "SearchList.h"                     // Needed for CSearchFile
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "sockets.h"                        // Needed for CServerConnect
+#include "UploadQueue.h"                    // Needed for CUploadQueue
+#include "xmule.h"                          // Needed for theApp
+
+#include <wx/button.h>                      // Needed for wxButton
+#include <wx/choice.h>                      // Needed for wxChoice
+#include <wx/filedlg.h>                     // Needed for wxFileDialog
+#include <wx/gauge.h>                       // Needed for wxGauge
+
+#include <wx/menu.h>                        // Needed for wxMenu
+#include <wx/msgdlg.h>                      // Needed for wxMessageDialog
+#include <wx/sizer.h>                       // Needed for wxBoxSizer
+#include <wx/splitter.h>                    // Needed for Splitterwindow
+#include <wx/statbox.h>                     // Needed for wxStaticBox
+#include <wx/stattext.h>                    // Needed for wxStaticText
+#include <wx/textctrl.h>                    // Needed for wxTextCtrl
 
 #include "pixmaps/close.xpm"
 #include "pixmaps/close_hi.xpm"
@@ -141,7 +123,7 @@ wxString specialtag_type_name[7] =
 #define	SDRES		GetResString
 #define SDLISTEVT 	(wxObjectEventFunction) (wxEventFunction) (wxListEventFunction) &CSearchDlg
 #define SDMOUSEEVT 	(wxObjectEventFunction) (wxEventFunction) (wxMouseEventFunction) &CSearchDlg
-#define SDCMDEVT 	(wxObjectEventFunction) (wxEventFunction) (wxCommandEventFunction) &CSearchDlg
+#define SDCMDEVT 	(wxObjectEventFunction) (wxEventFunction) (wxCommandEvent unction) &CSearchDlg
 
 wxBoxSizer *row1;
 
@@ -443,7 +425,7 @@ void CSearchDlg::ButtonStart(wxCommandEvent &event)
         }
         if (!smaskcurrent)
         {
-            m_timer.Stop();
+            m_timer->Stop();
             sdbutton[0]->Enable(true);
             sdbutton[2]->Enable(false);
             sdgauge[0]->SetValue(0);
@@ -588,7 +570,7 @@ void CSearchDlg::ButtonStart(wxCommandEvent &event)
                         smaskresults[smaskcurrent] = 0;
                         smasknext[smaskcurrent] = 0;
                         if (smaskcurrent == smaskhighest)--smaskhighest;
-                        m_timer.Stop();
+                        m_timer->Stop();
                         sdbutton[0]->Enable(true);
                         sdbutton[2]->Enable(false);
                         sdgauge[0]->SetValue(0);
@@ -673,7 +655,7 @@ printf("glspacket2\n");
                 wxOK |wxCENTRE |wxICON_INFORMATION);
                 dlg->ShowModal();
                 delete dlg;
-                m_timer.Stop();
+                m_timer->Stop();
                 sdbutton[0]->Enable(true);
                 sdbutton[2]->Enable(false);
                 sdgauge[0]->SetValue(0);
@@ -750,7 +732,7 @@ void CSearchDlg::ButtonCancel(wxCommandEvent &event)
         delete glspacket;
         glspacket = NULL;
     }
-    m_timer.Stop();
+    m_timer->Stop();
     sdbutton[0]->Enable(true);
     sdbutton[2]->Enable(false);
     sdgauge[0]->SetValue(0);
@@ -1344,9 +1326,11 @@ void CSearchDlg::PopupSearchMasks(wxMouseEvent &event)
     PopupMenu(pop_smasks, event.GetPosition());
 }
 
-CSearchDlg::CSearchDlg(wxWindow *pParent): wxPanel(pParent, CSearchDlg::IDD), m_timer(this, ID_SEARCHTIMER)
+CSearchDlg::CSearchDlg(wxWindow *pParent): wxPanel(pParent, CSearchDlg::IDD)
 {
     int column;
+    m_timer = new wxTimer(this, ID_SEARCHTIMER);
+
     // Color for the Buttons
     wxColour *button_bgcolour = new wxColour(0xd1, 0xc7, 0xff);
     // Differnt Colors for Searchresults depending on Availibility
@@ -1367,12 +1351,7 @@ CSearchDlg::CSearchDlg(wxWindow *pParent): wxPanel(pParent, CSearchDlg::IDD), m_
     pop_sresults->Append(17004, "Close this result-list");
     pop_sresults->Append(17005, "Close all result-lists");
     pop_sresults->AppendSeparator();
-#if 0
-    pop_sresults->Append(17011, "Copy ED2k-link to clipboard");
-    pop_sresults->Append(17012, "Copy ED2k-link to clipboard (HTML)");
-    pop_sresults->Append(17013, "Check Fake");
-    pop_sresults->AppendSeparator();
-#endif
+
     pop_sresults->Append(17097, "Save tables");
     pop_sresults->Append(17098, "Load tables");
     pop_sresults->Append(17099, "Clear all");
@@ -1551,11 +1530,7 @@ CSearchDlg::CSearchDlg(wxWindow *pParent): wxPanel(pParent, CSearchDlg::IDD), m_
     // <-- huh ?
     // Colums of the Search Results List Box
     column = 0;
-#if 0
-    ic1.m_text = _("No.");
-    lsresults->InsertColumn(column, ic1);
-    lsresults->SetColumnWidth(column, 40);
-#endif
+
     ic1.m_text = _("Filename");
     lsresults->InsertColumn(column, ic1);
     lsresults->SetColumnWidth(column, 250);
@@ -1660,17 +1635,11 @@ CSearchDlg::CSearchDlg(wxWindow *pParent): wxPanel(pParent, CSearchDlg::IDD), m_
     row4->Add(sdgauge[0], 2, wxGROW, 0);
     wxBoxSizer *root = new wxBoxSizer(wxVERTICAL);
     root->Add(row1, 0, wxALL |wxGROW, 4);
-#if 0
-    wxALL = border(4), wxGROW = horizonal stretchable:
-#endif
+
     root->Add(row2, 0, wxALL |wxGROW, 4);
-#if 0
-    (f2 = 1) = horizontal stretchable, (f2 = 2) = vertical stretchable:
-#endif
+
     root->Add(row3, 3, wxALL |wxGROW, 4);
-#if 0
-    (f2 = 1) = horizontal stretchable, (f2 = 2) = vertical stretchable:
-#endif
+
     root->Add(row4, 0, wxGROW, 0);
     this->SetAutoLayout(TRUE);
     this->SetSizer(root);
@@ -1686,9 +1655,7 @@ CSearchDlg::CSearchDlg(wxWindow *pParent): wxPanel(pParent, CSearchDlg::IDD), m_
     this->Connect(11003, wxEVT_COMMAND_TEXT_ENTER, (wxObjectEventFunction) &CSearchDlg::InputMaxSize);
     this->Connect(11006, wxEVT_COMMAND_TEXT_ENTER, (wxObjectEventFunction) &CSearchDlg::InputAvailability);
     this->Connect(11007, wxEVT_COMMAND_TEXT_ENTER, (wxObjectEventFunction) &CSearchDlg::InputExtension);
-#if 0
-    this->Connect(11008, wxEVT_COMMAND_TEXT_ENTER, (wxObjectEventFunction) &CSearchDlg::InputED2K);
-#endif
+
     this->Connect(12001, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction) &CSearchDlg::ButtonStart);
     this->Connect(12002, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction) &CSearchDlg::ButtonMore);
     this->Connect(12003, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction) &CSearchDlg::ButtonCancel);
@@ -1698,12 +1665,7 @@ CSearchDlg::CSearchDlg(wxWindow *pParent): wxPanel(pParent, CSearchDlg::IDD), m_
     this->Connect(12007, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction) &CSearchDlg::ButtonClearAll);
     this->Connect(12008, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction) &CSearchDlg::ButtonReset);
     this->Connect(12009, wxEVT_COMMAND_BUTTON_CLICKED, (wxObjectEventFunction) &CSearchDlg::ButtonStartLink);
-#if 0
-    this->Connect(13001, wxEVT_COMMAND_CHOICE_SELECTED, (wxObjectEventFunction) &CSearchDlg::ChoiceType);
-    this->Connect(13002, wxEVT_COMMAND_CHOICE_SELECTED, (wxObjectEventFunction) &CSearchDlg::ChoiceMethod);
-    this->Connect(13001, wxEVT_COMMAND_CHOICE_SELECTED, (wxObjectEventFunction) NULL);
-    this->Connect(13002, wxEVT_COMMAND_CHOICE_SELECTED, (wxObjectEventFunction) NULL);
-#endif
+
     this->Connect(14001, wxEVT_COMMAND_LIST_COL_CLICK, SDLISTEVT::ListSortSearchResults);
     this->Connect(14001, wxEVT_COMMAND_LIST_ITEM_ACTIVATED, (wxObjectEventFunction) &CSearchDlg::ButtonDownload);
     this->Connect(14002, wxEVT_COMMAND_LIST_ITEM_SELECTED, SDLISTEVT::ListSelectedSearchMask);
@@ -2575,27 +2537,7 @@ void CSearchDlg::SearchEnd(char *packet, wxUint32 packetsize, wxUint32 nServerIP
                 slistentry += "|";
                 slistentry += wxString::Format("%d", file_udpserverport);
                 slistentry += "|";
-#if 0
-                //creation of a clean ed2k-fileitem - test for ftp&http-protokoll
-                file_tagc = 2;
-                slp = 0;
-                put_tag(sed2kentry, slp, 6);
-                //file_id
-                put_tag(sed2kentry, slp, 0);
-                //file_clientip
-                put_tag(sed2kentry, slp, 1);
-                //file_clientport
-                put_tag(sed2kentry, slp, 99);
-                //file_tagc
-                put_tag(sed2kentry, slp, 2);
-                //file_name
-                put_tag(sed2kentry, slp, 3);
-                //file_size
-                put_tag(sed2kentry, slp, 4);
-                //file_availability
-                p.dump("original", (unsigned char *) pcklast, (long) pck - (long) pcklast);
-                p.dump("put_tag", (unsigned char *) sed2kentry, slp);
-#endif
+
                 if (!sdchoice[0]->GetSelection() || (sdchoice[0]->GetSelection() == (int) file_type))
                 {
                     // For Type-Selected-Search
@@ -2624,7 +2566,7 @@ void CSearchDlg::SearchEnd(char *packet, wxUint32 packetsize, wxUint32 nServerIP
         lsmasks->SetItem(smaskindex[smaskcurrent], 0, linebuffer);
         if (!globsearch)
         {
-            m_timer.Stop();
+            m_timer->Stop();
             sdbutton[0]->Enable(true);
             sdbutton[2]->Enable(false);
             sdgauge[0]->SetValue(0);
@@ -2634,7 +2576,7 @@ void CSearchDlg::SearchEnd(char *packet, wxUint32 packetsize, wxUint32 nServerIP
         }
         else
         {
-            m_timer.Start(750);
+            m_timer->Start(750);
             global_search_timer = (unsigned int *) 1;
         }
     }
@@ -2668,15 +2610,7 @@ wxString CSearchDlg::CreateWebQuery()
     default:
         break;
     }
-#if 0
-    //CString tosearch;
-    GetDlgItem(IDC_SWEB)->GetWindowText(tosearch);
-    tosearch = CString(URLEncode(tosearch) .GetData());
-    tosearch.Replace("%20", "+");
-    query += "&pattern=";
-    query += tosearch;
-    query += "&action=search&name=FD-Search&op=modload&file=index&requestby=amule";
-#endif
+
     return query;
 }
 
