@@ -22,24 +22,22 @@
 #ifndef SEARCHDLG_H
 #define SEARCHDLG_H
 
-#include <wx/panel.h>                   // Needed for wxPanel
-#include <wx/combobox.h>                // Needed for wxComboBox
-#include <wx/imaglist.h>                // Needed for wxImageList
-#include <wx/timer.h>                   // Needed for wxTimer and wxTimerEvent
-#include <wx/statbmp.h>                 // Needed for wxStaticBitmap
-#include <wx/listbase.h>                // Needed for wxListEvent
+#include <wx/panel.h>                       // Needed for wxPanel
+#include <wx/statbmp.h>                     // Needed for wxStaticBitmap
 
 class Packet;
+class wxComboBox;
+class wxImageList;
+class wxListEvent;
+class wxTimer;
+class wxTimerEvent;
 
-class CSearchDlg : public wxPanel {
+class CSearchDlg: public wxPanel 
+{
     DECLARE_DYNAMIC_CLASS(CSearchDlg)
-    public:
-    CSearchDlg() {
-    // dummy constructor:
-    };
-    // standard constructor:
+public:
+    CSearchDlg() { }
     CSearchDlg(wxWindow* pParent);
-    // destructor:
     virtual ~CSearchDlg();
     bool CheckTabNameExists(wxString searchString);
     void CreateNewTab(wxString searchString,wxUint32 nSearchID);
@@ -88,7 +86,7 @@ private:
     void SearchResultsCloseAllRL(wxCommandEvent& evt);
     void SearchResultsCloseThisSM(wxCommandEvent& evt);
     void SearchResultsCloseAllSM(wxCommandEvent& evt);
-    void OnTimer(wxTimerEvent&evt);
+    void OnTimer(wxTimerEvent& evt);
     // private methods
     void ExecuteLinkED2K();
     void ShowSearchMasks();
@@ -97,18 +95,14 @@ private:
     // private member variables
     int srtab_deep,srtab_lock;
     int smaskhighest,smaskcurrent;
-    wxComboBox typebox;
-    wxComboBox Stypebox;
-    wxImageList *ImageList;
-    wxTimer m_timer;
+
+    wxImageList* ImageList;
+    wxTimer* m_timer;
     wxStaticBitmap m_ctrlSearchFrm;
     wxStaticBitmap m_ctrlWebSearchFrm;
     wxStaticBitmap m_ctrlDirectDlFrm;
-    //wxListCtrl*	lsmasks;
-    //wxListCtrl*	lsresults;
 };
 
-// ESearchType
 enum ESearchType {
     //NOTE: The numbers are *equal* to the entries in the comboxbox->TODO: use item data
     SearchTypeServer = 0,
@@ -118,7 +112,6 @@ enum ESearchType {
     SearchTypeFileDonkey
 };
 
-// SSearchParams
 struct SSearchParams {
     SSearchParams(void) : dwSearchID((wxUint32)-1), eType(SearchTypeServer),
     ulMinSize(0), ulMaxSize(0), iAvailability(-1) {
@@ -130,5 +123,5 @@ struct SSearchParams {
     int iAvailability;
     bool bMatchKeywords;
 };
-#endif // SEARCHDLG_H
 
+#endif // SEARCHDLG_H
