@@ -22,12 +22,12 @@
 #ifndef SEARCHLIST_H
 #define SEARCHLIST_H
 
-#include "KnownFile.h"                  // Needed for CAbstractFile
+#include "KnownFile.h"                      // Needed for CAbstractFile
+#include "wintypes.h"                       // Needed for LPCTSTR
 
 class CSearchFile : public CAbstractFile {
 	friend class CPartFile;
 public:
-	//CSearchFile() {};
 	CSearchFile(char* data, wxUint32 nSearchID);
 	CSearchFile(CFile* in_data, wxUint32 nSearchID, wxUint32 nServerIP=0, uint16 nServerPort=0, LPCTSTR pszDirectory = NULL);
 	CSearchFile(wxUint32 nSearchID, const uchar* pucFileHash, wxUint32 uFileSize, char *pszFileName, int iFileType, int iAvailability);
@@ -102,7 +102,6 @@ private:
 	uint16	 m_list_childcount;
 	CSearchFile* m_list_parent;
 	bool		 m_bPreviewPossible;
-	//CArray<CxImage*,CxImage*> m_listImages;
 	char *m_pszDirectory;
 };
 #endif
