@@ -19,35 +19,38 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-#include "config.h"
+#ifdef PRECOMP
+    #include "xmule-headers.h"
+#endif
 
-// Test if we have _GNU_SOURCE before the next step will mess up
-// setting __USE_GNU
-// (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
-#include <wx/setup.h>
+#include "ServerList.h"                     // Needed for this Interface's Prototype
+
+#include "ldaemon.h"                        // Needed for CLDaemon
+#include "ListenSocket.h"                   // Needed for TooManySockets
+#include "otherfunctions.h"                 // Needed for GetTickCount
+#include "PartFile.h"                       // Needed for SRV_PR_HIGH
+#include "Preferences.h"                    // Needed for CPreferences
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "HTTPDownloadDlg.h"                // Needed for CHTTPDownloadDlg
+#include "otherstructs.h"                   // Needed for ServerMet_Struct
+#include "packets.h"                        // Needed for CTag
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "server.h"                         // Needed for CServer
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
+#include "ServerWnd.h"                      // Needed for CServerWnd
+#include "sockets.h"                        // Needed for CServerConnect
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for xmuleDlg
 
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
 #if defined(HAVE_SYS_PARAM_H)
-#include <sys/param.h>
+    #include <sys/param.h>
 #endif
 
-#include "ServerList.h"                     // Needed for this Interface's Prototype
-#include "ldaemon.h"                        // Needed for LDAEMON_H
-#include "ListenSocket.h"                   // Needed for TooManySockets
-#include "otherfunctions.h"                 // Needed for GetTickCount
-#include "PartFile.h"                       // Needed for SRV_PR_HIGH
-#include "DownloadQueue.h"
-#include "HTTPDownloadDlg.h"
-#include "SafeFile.h"
-#include "ServerWnd.h"
-#include "xmule.h"
-#include "xmuleDlg.h"
-
-#include <wx/msgdlg.h>
-
-#include <wx/listimpl.cpp>
-//WX_DEFINE_LIST(CServerListList);
+#include <wx/filename.h>                    // Needed for wxFileName
+#include <wx/menu.h>                        // Needed for wxMenu
+#include <wx/msgdlg.h>                      // Needed for wxMessageBox
 
 CServerList::CServerList(CPreferences *in_prefs):
 list(wxKEY_NONE)
@@ -64,6 +67,16 @@ list(wxKEY_NONE)
     m_nLastSaved =::GetTickCount();
 }
 
+CServer* CServerList::GetServerAt(wxUint32 pos)
+{
+    return list.GetAt(list.FindIndex(pos));
+}
+
+wxUint32 CServerList::GetServerCount()
+{
+    return list.GetCount();
+}
+
 void CServerList::AutoUpdate()
 {
     if (app_prefs->adresses_list.IsEmpty())
@@ -155,8 +168,7 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
         theApp.xmuledlg->AddLogLine(false, _("Failed to load server.met!"));
         return false;
     }
-    if ((1 != servermet.Read( &version, 1)) ||
-    (version != 0xE0 &&version != MET_HEADER))
+    if ((1 != servermet.Read( &version, 1)) || (version != 0xE0 && version != MET_HEADER))
     {
         servermet.Close();
         theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_BADSERVERMETVERSION), version);
@@ -164,20 +176,20 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
     }
     try
     {
-        uint32 fservercount;
+        wxUint32 fservercount;
         if (4 != servermet.Read( &fservercount, 4))
         throw CInvalidPacket();
         ServerMet_Struct sbuffer;
-        uint32 iAddCount = 0;
+        wxUint32 iAddCount = 0;
         theApp.xmuledlg->serverwnd->serverlistctrl->Freeze();
-        for (uint32 j = 0 ; j < fservercount ; j++)
+        for (wxUint32 j = 0 ; j < fservercount ; j++)
         {
             // get server
             if (sizeof(ServerMet_Struct) != servermet.Read( &sbuffer, sizeof(ServerMet_Struct)))
             throw CInvalidPacket();
             CServer *newserver = new CServer( &sbuffer);
             //add tags
-            for (uint32 i = 0 ; i < sbuffer.tagcount ; i++)
+            for (wxUint32 i = 0 ; i < sbuffer.tagcount ; i++)
             newserver->AddTagFromFile( &servermet);
             // set listname for server
             if (!newserver->GetListName())
@@ -220,21 +232,6 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
         return false;
     }
     servermet.Close();
-#if 0
-    catch(CFileException *error)
-    {
-        if (error->m_cause == CFileException::endOfFile)
-        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_BADSERVERLIST));
-        else
-        {
-            char buffer[150];
-            error->GetErrorMessage(buffer, 150);
-            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FILEERROR_SERVERMET), buffer);
-        }
-        //memleak fix:
-        error->Delete();
-    }
-#endif
     return true;
 }
 
@@ -276,7 +273,7 @@ void CServerList::ServerStats()
         }
         Packet *packet = new Packet(OP_GLOBSERVSTATREQ, 4);
         srand((unsigned) time(NULL));
-        uint32 time = 0x55AA0000 + (uint16) rand();
+        wxUint32 time = 0x55AA0000 + (wxUint16) rand();
         ping_server->SetChallenge(time);
         memcpy(packet->pBuffer, &time, 4);
         ping_server->SetLastPinged(::GetTickCount());
@@ -349,7 +346,7 @@ void CServerList::RemoveAllServers()
     }
 }
 
-void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32 &file, uint32 &tuser, uint32 &tfile, float &occ)
+void CServerList::GetStatus(wxUint32 &total, wxUint32 &failed, wxUint32 &user, wxUint32 &file, wxUint32 &tuser, wxUint32 &tfile, float &occ)
 {
     total = list.GetCount();
     failed = 0;
@@ -358,8 +355,8 @@ void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32
     tuser = 0;
     tfile = 0;
     occ = 0;
-    uint32 maxusers = 0;
-    uint32 tuserk = 0;
+    wxUint32 maxusers = 0;
+    wxUint32 tuserk = 0;
     CServer *curr;
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
@@ -385,7 +382,7 @@ void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32
     if (maxusers > 0) occ = (float)(tuserk *100) /maxusers;
 }
 
-void CServerList::GetUserFileStatus(uint32 &user, uint32 &file)
+void CServerList::GetUserFileStatus(wxUint32 &user, wxUint32 &file)
 {
     user = 0;
     file = 0;
@@ -439,10 +436,6 @@ void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserve
     if (!stream.Ok())
     return;
     wxTextInputStream f(stream);
-#if 0
-    if (!f.Open(strFilename, "r"))
-    return;
-#endif
     while (strLine = f.ReadLine())
     {
         // stop iteration if end of file is met..:
@@ -521,7 +514,7 @@ void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserve
 void CServerList::MoveServerDown(CServer *aServer)
 {
     POSITION pos1, pos2;
-    uint16 i = 0;
+    wxUint16 i = 0;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         list.GetNext(pos1);
@@ -541,7 +534,7 @@ void CServerList::MoveServerDown(CServer *aServer)
 void CServerList::Sort()
 {
     POSITION pos1, pos2;
-    uint16 i = 0;
+    wxUint16 i = 0;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         list.GetNext(pos1);
@@ -565,8 +558,8 @@ void CServerList::Sort()
 CServer *CServerList::GetNextServer()
 {
     CServer *nextserver = 0;
-    uint32 i = 0;
-    if (serverpos >= ((uint32) list.GetCount())) return 0;
+    wxUint32 i = 0;
+    if (serverpos >= ((wxUint32) list.GetCount())) return 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(serverpos);
@@ -591,7 +584,7 @@ CServer *CServerList::GetNextServer()
 CServer *CServerList::GetNextSearchServer()
 {
     CServer *nextserver = 0;
-    uint32 i = 0;
+    wxUint32 i = 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(searchserverpos);
@@ -613,7 +606,7 @@ CServer *CServerList::GetNextSearchServer()
 CServer *CServerList::GetNextStatServer()
 {
     CServer *nextserver = 0;
-    uint32 i = 0;
+    wxUint32 i = 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(statserverpos);
@@ -682,14 +675,6 @@ void CServerList::CancelUDPBroadcast()
     }
 }
 
-#if 0
-void CALLBACK CServerList::UDPTimerProc(HWND hwnd, UINT uMsg, UINT_PTR idEvent, DWORD dwTime)
-{
-    theApp.serverlist->SendNextPacket();
-}
-
-#endif
-
 CServer *CServerList::GetNextServer(CServer *lastserver)
 {
     if (list.IsEmpty())
@@ -729,7 +714,7 @@ CServer *CServerList::GetServerByIP(wxUint32 nIP, wxUint16 nPort)
     return NULL;
 }
 
-CServer *CServerList::GetServerByAddress(char *address, uint16 port)
+CServer *CServerList::GetServerByAddress(char *address, wxUint16 port)
 {
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
@@ -759,16 +744,16 @@ bool CServerList::SaveServermetToFile()
         }
         version = 0xE0;
         fwrite( &version, 1, 1, servermet);
-        uint32 fservercount = list.GetCount();
+        wxUint32 fservercount = list.GetCount();
         fwrite( &fservercount, 4, 1, servermet);
         ServerMet_Struct sbuffer;
         CServer *nextserver;
-        for (uint32 j = 0 ; j != fservercount ; j++)
+        for (wxUint32 j = 0 ; j != fservercount ; j++)
         {
             nextserver = this->GetServerAt(j);
             sbuffer.ip = nextserver->GetIP();
             sbuffer.port = nextserver->GetPort();
-            uint16 tagcount = 11;
+            wxUint16 tagcount = 11;
             if (nextserver->GetListName())
             tagcount++;
             if (nextserver->GetDynIP())
@@ -826,17 +811,6 @@ bool CServerList::SaveServermetToFile()
         delete[] oldservermet;
         delete[] curservermet;
     }
-#if 0
-    catch(CFileException *error)
-    {
-        OUTPUT_DEBUG_TRACE();
-        theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_SAVESERVERMET2));
-        //mf:
-        delete[] newservermet;
-        error->Delete();
-        return false;
-    }
-#endif
     delete[] newservermet;
     return true;
 }
