@@ -20,37 +20,33 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#include "PartFile.h"                   // Needed for SRV_PR_LOW
-#	include "DownloadQueue.h"
-#	include "muuli_wdr.h"
-#	include "otherfunctions.h"
-#	include "ServerListCtrl.h"
-#	include "ServerWnd.h"
-#	include "sockets.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/event.h>
-#include <wx/menu.h>                    // Needed for wxMenu
-#include <wx/stattext.h>                // Needed for wxStaticText
+#include "ServerListCtrl.h"                 // Needed for this Interface's Prototype
+
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "muuli_wdr.h"                      // Needed for ID_SERVERLIST
+#include "PartFile.h"                       // Needed for SRV_PR_LOW
+#include "Preferences.h"                    // Needed for CPreferences
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerWnd.h"                      // Needed for CServerWnd
+#include "sockets.h"                        // Needed for CServerConnect
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <wx/menu.h>                        // Needed for wxMenu
+#include <wx/stattext.h>                    // Needed for wxStaticText
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
 BEGIN_EVENT_TABLE(CServerListCtrl, CMuleListCtrl)
-EVT_LIST_ITEM_RIGHT_CLICK(ID_SERVERLIST, CServerListCtrl::OnRclickServlist)
-EVT_LIST_COL_CLICK(ID_SERVERLIST, CServerListCtrl::OnLvnColumnclickServlist)
-EVT_LEFT_DCLICK(CServerListCtrl::OnLDclick)
+    EVT_LIST_ITEM_RIGHT_CLICK(ID_SERVERLIST, CServerListCtrl::OnRclickServlist)
+    EVT_LIST_COL_CLICK(ID_SERVERLIST, CServerListCtrl::OnLvnColumnclickServlist)
+    EVT_LEFT_DCLICK(CServerListCtrl::OnLDclick)
 END_EVENT_TABLE()
 
-// implemented by processevent():
-//  EVT_MENU(MP_CONNECTTO,CServerListCtrl::OnConnectTo)
-//EVT_MENU(MP_REMOVE,CServerListCtrl::OnRemove)
-//EVT_MENU(MP_GETED2KLINK,CServerListCtrl::OnCopyLink)
-
-//IMPLEMENT_DYNAMIC(CServerListCtrl, CMuleListCtrl/*CTreeCtrl*/)
 CServerListCtrl::CServerListCtrl()
 {
     memset( &asc_sort, 0, 8);
@@ -179,7 +175,7 @@ void CServerListCtrl::OnConnectTo(wxCommandEvent &event)
     theApp.xmuledlg->ShowConnectionState(false);
 }
 
-void CServerListCtrl::OnRemove(wxEvent &event)
+void CServerListCtrl::OnRemove(wxCommandEvent&event)
 {
     long item = - 1;
     if (this->GetSelectedItemCount() > 1)
@@ -252,32 +248,6 @@ bool CServerListCtrl::Init(CServerList *in_list)
     asc_sort[7] = true;
     // perhaps not yet
     //LoadSettings(CPreferences::tableServer);
-#if 0
-    this->ModifyStyle(0, TVS_HASLINES |TVS_LINESATROOT |TVS_HASBUTTONS);
-    // Set Imagelist
-    server_list = in_list;
-    imagelist.Create(16, 16, ILC_COLOR |ILC_MASK, 0, 10);
-    imagelist.SetBkColor(RGB(255, 255, 255));
-    imagelist.Add(theApp.LoadIcon(IDI_ICON1));
-    //TVSIL_NORMAL);:
-    this->SetImageList( &imagelist, LVSIL_SMALL);
-    //here the CListCtrl is set to report-style:
-    this->ModifyStyle(LVS_SINGLESEL |LVS_LIST |LVS_ICON |LVS_SMALLICON, LVS_REPORT);
-    InsertColumn(0, GetResString(IDS_SL_SERVERNAME), LVCFMT_LEFT, 150);
-    InsertColumn(1, GetResString(IDS_IP), LVCFMT_LEFT, 140);
-    InsertColumn(2, GetResString(IDS_DESCRIPTION), LVCFMT_LEFT, 150);
-    InsertColumn(3, GetResString(IDS_PING), LVCFMT_LEFT, 50);
-    InsertColumn(4, GetResString(IDS_UUSERS), LVCFMT_LEFT, 50);
-    InsertColumn(5, GetResString(IDS_PW_FILES), LVCFMT_LEFT, 50);
-    InsertColumn(6, GetResString(IDS_PREFERENCE), LVCFMT_LEFT, 60);
-    InsertColumn(7, GetResString(IDS_UFAILED), LVCFMT_LEFT, 50);
-    InsertColumn(8, GetResString(IDS_STATICSERVER), LVCFMT_LEFT, 50);
-    asc_sort[3] = true;
-    asc_sort[4] = true;
-    asc_sort[5] = true;
-    asc_sort[7] = true;
-    LoadSettings(CPreferences::tableServer);
-#endif
     return true;
 }
 
@@ -287,63 +257,8 @@ CServerListCtrl::~CServerListCtrl()
 
 void CServerListCtrl::Localize()
 {
-#if 0
-    CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-    HDITEM hdi;
-    hdi.mask = HDI_TEXT;
-    CString strRes;
-    strRes = GetResString(IDS_SL_SERVERNAME);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(0, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_IP);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(1, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_DESCRIPTION);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(2, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_PING);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(3, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_UUSERS);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(4, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_PW_FILES);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(5, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_PREFERENCE);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(6, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_UFAILED);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(7, &hdi);
-    strRes.ReleaseBuffer();
-    strRes = GetResString(IDS_STATICSERVER);
-    hdi.pszText = strRes.GetBuffer();
-    pHeaderCtrl->SetItem(8, &hdi);
-    strRes.ReleaseBuffer();
-#endif
 }
 
- /*void CServerListCtrl::ShowServers(){
- DeleteAllItems();
- int i=0;
- CString temp;
- for(POSITION pos = server_list->list.GetHeadPosition(); pos != NULL;server_list->list.GetNext(pos)) {
- CServer* cur_server = server_list->list.GetAt(pos);
- InsertItem(LVIF_TEXT|LVIF_PARAM,i,cur_server->GetListName(),0,0,0,(LPARAM)cur_server);
- RefreshServer( cur_server );
- i++;
- }
- }
-    */
-
 void CServerListCtrl::RemoveServer(CServer *todel, bool bDelToList)
 {
     //LVFINDINFO find;
@@ -478,62 +393,7 @@ void CServerListCtrl::RefreshServer(CServer *server)
     else SetItem(itemnr, 8, _("No"));
 }
 
-#if 0
-    BEGIN_MESSAGE_MAP(CServerListCtrl, CMuleListCtrl/*CTreeCtrl*/
-
-)
-ON_NOTIFY_REFLECT(NM_RCLICK, OnNMRclickServlist)
-ON_NOTIFY_REFLECT(LVN_COLUMNCLICK, OnLvnColumnclickServlist)
-//<-- mod bb 27.09.02:
-ON_NOTIFY_REFLECT(NM_DBLCLK, OnNMLdblclk)
-END_MESSAGE_MAP()
-
-// CServerListCtrl message handlers
-
-void CServerListCtrl::OnNMRclickServlist(NMHDR *pNMHDR, LRESULT *pResult)
-{
-    POINT point;
-    ::GetCursorPos( &point);
-    // tecxx 0609 2002
-    // fix - on right click, we also want to change the current selection like the left click does
-    CPoint p = point;
-    ScreenToClient( &p);
-    int it = HitTest(p);
-    if (it != - 1)
-    // display selection mark correctly!:
-    SetSelectionMark(it);
-    // fix end
-    // Create up-to-date popupmenu
-    UINT flags;
-    CTitleMenu m_ServerMenu;
-    CMenu m_ServerPrioMenu;
-    // set state of selection-dependent menuitems
-    flags = MF_STRING || MF_DISABLED;
-    if (this->GetSelectionMark() != - 1) if(((CServer *) GetItemData(GetSelectionMark())) != NULL) flags = MF_STRING;
-    // add priority switcher
-    m_ServerPrioMenu.CreateMenu();
-    m_ServerPrioMenu.AppendMenu(MF_STRING, MP_PRIOLOW, GetResString(IDS_PRIOLOW));
-    m_ServerPrioMenu.AppendMenu(MF_STRING, MP_PRIONORMAL, GetResString(IDS_PRIONORMAL));
-    m_ServerPrioMenu.AppendMenu(MF_STRING, MP_PRIOHIGH, GetResString(IDS_PRIOHIGH));
-    m_ServerMenu.CreatePopupMenu();
-    m_ServerMenu.AddMenuTitle(GetResString(IDS_EM_SERVER));
-    m_ServerMenu.AppendMenu(flags, MP_CONNECTTO, GetResString(IDS_CONNECTTHIS));
-    m_ServerMenu.AppendMenu(flags |MF_POPUP, (UINT_PTR) m_ServerPrioMenu.m_hMenu, GetResString(IDS_PRIORITY));
-    m_ServerMenu.AppendMenu(flags, MP_ADDTOSTATIC, GetResString(IDS_ADDTOSTATIC));
-    m_ServerMenu.AppendMenu(MF_STRING |MF_SEPARATOR);
-    m_ServerMenu.AppendMenu(flags, MP_REMOVE, GetResString(IDS_REMOVETHIS));
-    m_ServerMenu.AppendMenu(MF_STRING, MP_REMOVEALL, GetResString(IDS_REMOVEALL));
-    m_ServerMenu.AppendMenu(MF_SEPARATOR);
-    m_ServerMenu.AppendMenu(MF_STRING, MP_GETED2KLINK, GetResString(IDS_DL_LINK1));
-    m_ServerMenu.SetDefaultItem(MP_CONNECTTO);
-    m_ServerMenu.TrackPopupMenu(TPM_LEFTALIGN |TPM_RIGHTBUTTON, point.x, point.y, this);
-    m_ServerMenu.DestroyMenu();
-    *pResult = 0;
-}
-
-#endif
-
-bool CServerListCtrl::ProcessEvent(wxEvent &evt)
+bool CServerListCtrl::ProcessEvent(wxEvent& evt)
 {
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
     return CMuleListCtrl::ProcessEvent(evt);
@@ -703,49 +563,12 @@ bool CServerListCtrl::ProcessEvent(wxEvent &evt)
                     theApp.CopyTextToClipboard(link);
                     break;
                 }
-#if 0
-            case Irc_SetSendLink:
-                {
-                    POSITION pos = this->GetFirstSelectedItemPosition();
-                    CString buffer, link;
-                    while (pos != NULL)
-                    {
-                        CServer *change = (CServer *) this->GetItemData(this->GetNextSelectedItem(pos));
-                        buffer.Format("ed2k://|server|%s|%d|/", change->GetFullIP(), change->GetPort());
-                        if (link.GetLength() > 0) buffer = "\n" + buffer;
-                        link += buffer;
-                        POSITION pos = this->GetFirstSelectedItemPosition();
-                    }
-                    theApp.xmuledlg->ircwnd.SetSendFileString(link);
-                    break;
-                }
-#endif
             }
         }
     }
     return CMuleListCtrl::ProcessEvent(evt);
 }
 
-#if 0
-void CServerListCtrl::OnNMLdblclk(NMHDR *pNMHDR, LRESULT *pResult)
-{
-    // mod bb 27.09.02
-    if (GetSelectionMark() != ( - 1))
-    {
-        theApp.serverconnect->ConnectToServer((CServer *) GetItemData(GetSelectionMark()));
-        theApp.xmuledlg->ShowConnectionState(false);
-    }
-}
-
-bool CServerListCtrl::AddServermetToList(CString strFile)
-{
-    bool flag = server_list->AddServermetToList(strFile);
-    RemoveDeadServer();
-    return flag;
-}
-
-#endif
-
 bool CServerListCtrl::AddServermetToList(wxString strFile)
 {
     Freeze();
@@ -816,18 +639,6 @@ int CServerListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
                         return item1->GetPort() - item2->GetPort();
                     }
                 }
-#if 0
-                for (int i = 0 ; iTemp == 0 ; i++)
-                {
-                    sTemp1 = sIP1.Tokenize(".", counter1);
-                    sTemp2 = sIP2.Tokenize(".", counter2);
-                    iTemp = atoi(sTemp2) - atoi(sTemp1);
-                    if (i > 2)
-                    {
-                        return item1->GetPort() - item2->GetPort();
-                    }
-                }
-#endif
                 return iTemp;
             }
         }
@@ -857,18 +668,6 @@ int CServerListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
                         return item2->GetPort() - item1->GetPort();
                     }
                 }
-#if 0
-                for (int i = 0 ; iTemp == 0 ; i++)
-                {
-                    s2Temp1 = s2IP1.Tokenize(".", counter1);
-                    s2Temp2 = s2IP2.Tokenize(".", counter2);
-                    iTemp = atoi(s2Temp1) - atoi(s2Temp2);
-                    if (i > 2)
-                    {
-                        return item2->GetPort() - item1->GetPort();
-                    }
-                }
-#endif
                 return iTemp;
             }
         }
