@@ -20,39 +20,34 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#include "PartFile.h"                   // Needed for CPartFile::GetStatus
-#	include "ClientList.h"
-#	include "DownloadQueue.h"
-#	include "KnownFile.h"
-#	include "ListenSocket.h"
-#	include "NewFunctions.h"
-#	include "opcodes.h"
-#	include "SearchDlg.h"
-#	include "SearchList.h"
-#	include "ServerSocket.h"
-#	include "ServerWnd.h"
-#	include "SharedFileList.h"
-#	include "updownclient.h"
-#	include "UploadQueue.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <time.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
- /*
- BEGIN_EVENT_TABLE(CServerSocket,wxSocketClient);
- END_EVENT_TABLE()
-    */
+#include "ServerSocket.h"                   // Needed for this Interface's Prototype
+
+#include "PartFile.h"                       // Needed for CPartFile::GetStatus
+#include "ClientList.h"                     // Needed for CClientList
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "ListenSocket.h"                   // Needed for CListenSocket
+#include "otherstructs.h"                   // Needed for LoginAnswer_Struct
+#include "packets.h"                        // Needed for Packets
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "SearchDlg.h"                      // Needed for CSearchDlg
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
+#include "ServerWnd.h"                      // Needed for CServerWnd
+#include "sockets.h"                        // Needed for CServerConnect
+#include "updownclient.h"                   // Needed for CUpDownClient
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <arpa/inet.h>                      // Needed for sockaddr_in
 
 IMPLEMENT_DYNAMIC_CLASS(CServerSocket, CEMSocket)
 
-CServerSocket::CServerSocket(CServerConnect *in_serverconnect)
+CServerSocket::CServerSocket(CServerConnect* in_serverconnect)
 {
     //printf("Serversocket: size %d\n",sizeof(CServerSocket));
     serverconnect = in_serverconnect;
