@@ -24,11 +24,12 @@
 #ifndef SERVERSOCKET_H
 #define SERVERSOCKET_H
 
-#include "server.h"                     // Needed for CServer
-#include "EMSocket.h"                   // Needed for CEMSocket
+#include "EMSocket.h"                       // Needed for CEMSocket
+
+class CServer;
 
 #ifndef ID_SOKETTI
-#define ID_SOKETTI 7772
+    #define ID_SOKETTI 7772
 #endif
 
 class CServerSocket : public CEMSocket
@@ -63,8 +64,6 @@ private:
 	int32	sizereceived;
 	char*	rbuffer;
 	bool	m_bIsDeleting;//true: socket is already in deletion phase, don't destroy it in ::StopConnectionTry
-
-	//DECLARE_EVENT_TABLE()
 };
 
 #endif
