@@ -20,23 +20,25 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "ClientList.h"
-#	include "DownloadQueue.h"
-#	include "IPFilter.h"
-#	include "KnownFile.h"
-#	include "ServerSocket4661.h"
-#	include "NewSockets.h"
-#	include "opcodes.h"
-#	include "SharedFileList.h"
-#	include "UploadQueue.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#	include "PartFile.h"
+    #include "xmule-headers.h"
 #endif
 
+#include "ServerSocket4661.h"                // Needed for this Interface's Prototype
+
+
+#include "ClientList.h"
+#include "DownloadQueue.h"
+#include "IPFilter.h"
+#include "KnownFile.h"
+#include "NewSockets.h"
+#include "opcodes.h"
+#include "SharedFileList.h"
+#include "UploadQueue.h"
+#include "wintypes.h"
+#include "xmule.h"
+#include "xmuleDlg.h"
+#include "PartFile.h"
+
 #ifndef ID_SOKETTI
 #define ID_SOKETTI 7772
 #endif
