@@ -19,20 +19,15 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-
 #ifndef SERVERWND_H
 #define SERVERWND_H
 
-#include "ServerListCtrl.h"             // Needed for CServerListCtrl
-#include "ServerList.h"                 // Needed for SaveServermetToFile
-#include <wx/textctrl.h>                // Needed for wxTextCtrl
-#include <wx/statbmp.h>                 // Needed for wxStaticBitmap
-#include <wx/html/htmlwin.h>            // Needed for wxHtmlWindow
-#include <wx/panel.h>                   // Needed for wxPanel
+#include <wx/panel.h>                       // Needed for wxPanel
+
+class CServerListCtrl;
 
 class CServerWnd : public wxPanel
 {
-  //DECLARE_DYNAMIC(CServerWnd)
   DECLARE_DYNAMIC_CLASS(CServerWnd)
     
     CServerWnd() {};
@@ -44,7 +39,6 @@ public:
 	void UpdateServerMetFromURL(wxString strURL);
 	void UpdateMyInfo();
 
-	//wxSizer* Create(wxWindow* parent);
 // Dialog Data
 	enum
         {
@@ -52,22 +46,12 @@ public:
         };
 	CServerListCtrl* serverlistctrl;
 protected:
-	//virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-	//virtual BOOL OnInitDialog();
-	//DECLARE_MESSAGE_MAP()
 public:
-	//CHyperTextCtrl servermsgbox;
-	wxHtmlWindow servermsgbox;
-	wxTextCtrl logbox;
-	void OnBnClickedAddserver(wxEvent& evt);
-	void OnBnClickedUpdateservermetfromurl(wxEvent& evt);
-	//afx_msg void OnBnClickedAddserver();
-	//afx_msg void OnBnClickedUpdateservermetfromurl();
-	void OnBnClickedResetLog(wxEvent& evt);
+	void OnBnClickedAddserver(wxCommandEvent & evt);
+	void OnBnClickedUpdateservermetfromurl(wxCommandEvent & evt);
+	void OnBnClickedResetLog(wxCommandEvent & evt);
 private:
-	wxStaticBitmap m_ctrlNewServerFrm;
-	wxStaticBitmap m_ctrlUpdateServerFrm;
-
 	DECLARE_EVENT_TABLE()
 };
+
 #endif
