@@ -19,65 +19,32 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-
 #ifndef _SHAREDFILESLIST_H
 #define _SHAREDFILESLIST_H
 
-#include "MapKey.h"                     // Needed for CCKey
-#include "NewFunctions.h"               // Needed for MAP
-#include <map>                          // Needed for std::map
-#include "sockets.h"                    // Needed for CServerConnect
-#include "KnownFileList.h"              // Needed for CKnownFileList
+#include "MapKey.h"                         // Needed for CCKey
+#include "mfc.h"                            // Needed for CTypedPtrList
+
+#include <map>                              // Needed for std::map
+#include <wx/thread.h>                      // Needed for wxMutex
+
+class MAP;
 
 extern MAP *listof_SharedFiles;
 
 struct UnknownFile_Struct;
 
-class CKnownFileList;
 class CAddFileThread;
-
-#if 0
-WX_DECLARE_LIST(UnknownFileStruct,UnknownList);
-
-class CFilePtrList : public UnknownList
-{
-public:
-  CFilePtrList() : UnknownList()
-    { };
-  virtual ~CFilePtrList() 
-    { };
-  
-  int GetCount()	{ int nResult;
-  wxMutexLocker locker(m_lockFilePtrList);
-  nResult = UnknownList::GetCount();
-  return nResult; };
-  
-  bool IsEmpty()		{ bool bResult;
-  wxMutexLocker locker(m_lockFilePtrList);
-  bResult = UnknownList::IsEmpty();
-  return bResult; };
-  
-  UnknownList::Node* AddTail(UnknownFileStruct* pNewElement) 
-    { UnknownList::Node* pos;
-    wxMutexLocker locker(m_lockFilePtrList);
-    pos = UnknownList::Append(pNewElement);
-    return pos; };
-  
-  UnknownFileStruct* RemoveHead() 
-    { UnknownFileStruct* pFile;
-    wxMutexLocker locker(m_lockFilePtrList);
-    pFile = UnknownList::GetFirst()->GetData();
-    UnknownList::DeleteNode(UnknownList::GetFirst());
-    return pFile; };
-  
-  //CRITICAL_SECTION 	m_lockFilePtrList;
-  wxMutex m_lockFilePtrList;
-};
-#endif
+class CKnownFile;
+class CKnownFileList;
+class CMemFile;
+class CPreferences;
+class CServerConnect;
 
 typedef std::map<CCKey,CKnownFile*> CKnownFileMap;
 
-class CSharedFileList{
+class CSharedFileList
+{
 	friend class CSharedFilesCtrl;
 	friend class CClientReqSocket;
 public:
@@ -104,7 +71,6 @@ public:
 private:
 	void	FindSharedFiles();
 
-	//CKnownFileMap		m_Files_map;
 	CPreferences*		app_prefs;
 	CServerConnect*		server;
 	CSharedFilesCtrl*	output;
