@@ -20,20 +20,24 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#include "PartFile.h"                   // Needed for PR_NORMAL
-#	include "CommentDialog.h"
-#	include "muuli_wdr.h"
-#	include "otherfunctions.h"
-#	include "SharedFilesCtrl.h"
-#	include "SharedFilesWnd.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/msgdlg.h>                  // Needed for wxMessageBox
-#include <wx/stattext.h>                // Needed for wxStaticText
+#include "SharedFilesCtrl.h"                // Needed for this Interface's Prototype
+
+#include "CommentDialog.h"                  // Needed for CCommentDialog
+#include "muuli_wdr.h"                      // Needed for ID_SHFILELIST
+#include "NewFunctions.h"                   // Needed for MAP
+#include "PartFile.h"                       // Needed for PR_NORMAL
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SharedFileList.h"                 // Needed for CKnownFileMap
+#include "SharedFilesWnd.h"                 // Needed for CSharedFilesWnd
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <wx/dcmemory.h>                    // Needed for wxMemoryDC
+#include <wx/msgdlg.h>                      // Needed for wxMessageBox
+#include <wx/stattext.h>                    // Needed for wxStaticText
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
@@ -44,9 +48,7 @@ END_EVENT_TABLE()
 
 CSharedFilesCtrl::CSharedFilesCtrl()
 {
-    // i_a:
     sflist = 0;
-    // i_a:
     memset( & sortstat, 0, sizeof(sortstat));
 }
 
@@ -57,9 +59,7 @@ CSharedFilesCtrl::~ CSharedFilesCtrl()
 CSharedFilesCtrl::CSharedFilesCtrl(wxWindow *& parent, int id, const wxPoint & pos, wxSize siz, int flags)
 : CMuleListCtrl(parent, id, pos, siz, flags | wxLC_OWNERDRAW)
 {
-    // i_a:
     sflist = 0;
-    // i_a:
     memset( & sortstat, 0, sizeof(sortstat));
     m_SharedFilesMenu = NULL;
     Init();
@@ -89,43 +89,6 @@ void CSharedFilesCtrl::Init()
     InsertColumn(7, GetResString(IDS_SF_ACCEPTS), LVCFMT_LEFT, 100);
     InsertColumn(8, GetResString(IDS_SF_TRANSFERRED), LVCFMT_LEFT, 120);
     InsertColumn(9, GetResString(IDS_UPSTATUS), LVCFMT_LEFT, 120);
-#if 0
-    SetExtendedStyle(LVS_EX_FULLROWSELECT);
-    ModifyStyle(LVS_SINGLESEL, 0);
-    InsertColumn(0, GetResString(IDS_DL_FILENAME), LVCFMT_LEFT, 250, 0);
-    InsertColumn(1, GetResString(IDS_DL_SIZE), LVCFMT_LEFT, 100, 1);
-    InsertColumn(2, GetResString(IDS_TYPE), LVCFMT_LEFT, 50, 2);
-    InsertColumn(3, GetResString(IDS_PRIORITY), LVCFMT_LEFT, 70, 3);
-    InsertColumn(4, GetResString(IDS_PERMISSION), LVCFMT_LEFT, 100, 4);
-    InsertColumn(5, GetResString(IDS_FILEID), LVCFMT_LEFT, 220, 5);
-    InsertColumn(6, GetResString(IDS_SF_REQUESTS), LVCFMT_LEFT, 100, 5);
-    InsertColumn(7, GetResString(IDS_SF_ACCEPTS), LVCFMT_LEFT, 100, 5);
-    InsertColumn(8, GetResString(IDS_SF_TRANSFERRED), LVCFMT_LEFT, 120, 5);
-    m_SharedFilesMenu.CreatePopupMenu();
-    m_SharedFilesMenu.AddMenuTitle(GetResString(IDS_SHAREDFILES));
-    // add priority switcher
-    m_PrioMenu.CreateMenu();
-    m_PrioMenu.AppendMenu(MF_STRING, MP_PRIOVERYLOW, GetResString(IDS_PRIOVERYLOW));
-    m_PrioMenu.AppendMenu(MF_STRING, MP_PRIOLOW, GetResString(IDS_PRIOLOW));
-    m_PrioMenu.AppendMenu(MF_STRING, MP_PRIONORMAL, GetResString(IDS_PRIONORMAL));
-    m_PrioMenu.AppendMenu(MF_STRING, MP_PRIOHIGH, GetResString(IDS_PRIOHIGH));
-    m_PrioMenu.AppendMenu(MF_STRING, MP_PRIOVERYHIGH, GetResString(IDS_PRIORELEASE));
-    // add permission switcher
-    m_PermMenu.CreateMenu();
-    m_PermMenu.AppendMenu(MF_STRING, MP_PERMNONE, GetResString(IDS_FSTATUS_LOCKED));
-    m_PermMenu.AppendMenu(MF_STRING, MP_PERMFRIENDS, GetResString(IDS_FSTATUS_FRIENDSONLY));
-    m_PermMenu.AppendMenu(MF_STRING, MP_PERMALL, GetResString(IDS_FSTATUS_PUBLIC));
-    // todo enable when it works
-    m_SharedFilesMenu.AppendMenu(MF_STRING | MF_POPUP, (UINT_PTR) m_PrioMenu.m_hMenu, GetResString(IDS_PRIORITY));
-    //m_SharedFilesMenu.AppendMenu(MF_STRING|MF_POPUP,(UINT_PTR)m_PermMenu.m_hMenu, (LPCTSTR)"Permissions");
-    m_SharedFilesMenu.AppendMenu(MF_STRING | MF_SEPARATOR);
-    m_SharedFilesMenu.AppendMenu(MF_STRING, MP_OPEN, GetResString(IDS_OPENFILE));
-    m_SharedFilesMenu.AppendMenu(MF_STRING, MP_GETED2KLINK, GetResString(IDS_DL_LINK1));
-    m_SharedFilesMenu.AppendMenu(MF_STRING, MP_GETHTMLED2KLINK, GetResString(IDS_DL_LINK2));
-    m_SharedFilesMenu.AppendMenu(MF_STRING, 123456789, GetResString(IDS_IRC_ADDLINKTOIRC));
-    //This menu option is is for testing..
-    LoadSettings(CPreferences::tableShared);
-#endif
 }
 
 void CSharedFilesCtrl::OnNMRclick(wxListEvent & evt)
@@ -203,7 +166,7 @@ void CSharedFilesCtrl::RemoveFile(CKnownFile * toRemove)
     ShowFilesCount();
 }
 
-void CSharedFilesCtrl::UpdateFile(CKnownFile * file, uint32 itemnr)
+void CSharedFilesCtrl::UpdateFile(CKnownFile * file, wxUint32 itemnr)
 {
     wxString buffer;
     SetItemData(itemnr, (long) file);
@@ -279,9 +242,8 @@ void CSharedFilesCtrl::ShowFile(CKnownFile * file)
     ShowFile(file, GetItemCount());
 }
 
-void CSharedFilesCtrl::ShowFile(CKnownFile * file, uint32 itemnr)
+void CSharedFilesCtrl::ShowFile(CKnownFile* file, wxUint32 itemnr)
 {
-    //InsertItem(LVIF_TEXT|LVIF_PARAM,itemnr,file->GetFileName(),0,0,0,(LPARAM)file);
     int newitem = InsertItem(itemnr, file->GetFileName());
     SetItemData(newitem, (long) file);
     // set background...
@@ -293,14 +255,12 @@ void CSharedFilesCtrl::ShowFile(CKnownFile * file, uint32 itemnr)
     ShowFilesCount();
 }
 
-//BOOL CSharedFilesCtrl::OnCommand(WPARAM wParam, LPARAM lParam)
-bool CSharedFilesCtrl::ProcessEvent(wxEvent & evt)
+bool CSharedFilesCtrl::ProcessEvent(wxEvent& evt)
 {
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
     return CMuleListCtrl::ProcessEvent(evt);
     wxCommandEvent & event = (wxCommandEvent &) evt;
     UINT selectedCount = this->GetSelectedItemCount();
-    //GetSelectionMark();:
     int iSel = GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
     if (iSel != ( - 1))
     {
@@ -309,7 +269,6 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent & evt)
         {
         case 123456789:
             {
-                //theApp.xmuledlg->ircwnd.SetSendFileString(theApp.CreateED2kLink(file));
                 printf("todo: ircwnd\n");
                 break;
             }
@@ -362,9 +321,8 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent & evt)
             //For Comments
         case MP_CMT:
             {
-                CCommentDialog dialog(this, file);
-                //dialog.DoModal();
-                dialog.ShowModal();
+                CCommentDialog* dialog = new CCommentDialog(this, file);
+                dialog->ShowModal();
                 break;
             }
         case MP_PRIOVERYLOW:
@@ -374,12 +332,10 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent & evt)
         case MP_PRIOVERYHIGH:
         case MP_PRIOAUTO:
             {
-                //POSITION pos = this->GetFirstSelectedItemPosition();
                 bool no_partfile_selected = false;
                 long pos = GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
                 while (pos != ( - 1))
                 {
-                    //this->GetNextSelectedItem(pos);:
                     int iSel = pos;
                     file = (CKnownFile *) this->GetItemData(iSel);
                     switch (event.GetId())
@@ -443,7 +399,6 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent & evt)
             {
                 printf("FIX: ei tue multi-select\n");
                 if (((CPartFile *) file)->IsPartFile())
-                //AfxMessageBox(GetResString(IDS_ERR_NOPRIMCHANGE));
                 wxMessageBox(GetResString(IDS_ERR_NOPRIMCHANGE));
                 else
                 {
@@ -455,7 +410,6 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent & evt)
         case MP_PERMFRIENDS:
             {
                 if (((CPartFile *) file)->IsPartFile())
-                //AfxMessageBox(GetResString(IDS_ERR_NOPRIMCHANGE));
                 wxMessageBox(GetResString(IDS_ERR_NOPRIMCHANGE));
                 else
                 {
@@ -475,10 +429,8 @@ bool CSharedFilesCtrl::ProcessEvent(wxEvent & evt)
     return CMuleListCtrl::ProcessEvent(evt);
 }
 
-//void CSharedFilesCtrl::OnColumnClick( NMHDR* pNMHDR, LRESULT* pResult){
 void CSharedFilesCtrl::OnColumnClick(wxListEvent & evt)
 {
-    //NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;
     // Barry - Store sort order in preferences
     // Determine ascending based on whether already sorted on this column
     int sortItem = theApp.glob_prefs->GetColumnSortItem(CPreferences::tableShared);
@@ -500,7 +452,6 @@ void CSharedFilesCtrl::OnColumnClick(wxListEvent & evt)
     if (adder == 0)
     SetSortArrow(sortItem, sortAscending);
     else
-    // ? arrowDoubleUp : arrowDoubleDown);:
     SetSortArrow(sortItem, sortAscending);
     SortItems(SortProc, sortItem + adder + (sortAscending ? 0: 20));
 }
@@ -606,14 +557,11 @@ int CSharedFilesCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
 
 void CSharedFilesCtrl::UpdateItem(CKnownFile * toupdate)
 {
-    //LVFINDINFO find;
-    //find.flags = LVFI_PARAM;
-    //find.lParam = (LPARAM)toupdate;
     sint16 result = FindItem( - 1, (long) toupdate);
     if (result != - 1)
     {
         UpdateFile(toupdate, result);
-        //Update(result) ;   // Added by Tarod to real time refresh - DonGato - 11/11/2002
+        Update(result) ;   // Added by Tarod to real time refresh - DonGato - 11/11/2002
         theApp.xmuledlg->sharedfileswnd->Check4StatUpdate(toupdate);
     }
 }
@@ -624,7 +572,7 @@ void CSharedFilesCtrl::ShowFilesCount()
     wxStaticCast(FindWindowByName(wxT("sharedFilesLabel")), wxStaticText)->SetLabel(fmtstr);
 }
 
-void CSharedFilesCtrl::OnDrawItem(int item, wxDC * dc, const wxRect & rect, const wxRect & rectHL, bool highlighted)
+void CSharedFilesCtrl::OnDrawItem(int item, wxDC* dc, const wxRect& rect, const wxRect& rectHL, bool highlighted)
 {
     CKnownFile * file = (CKnownFile *) GetItemData(item);
     assert(file != NULL);
