@@ -23,49 +23,46 @@
 #ifndef _SHAREDFILESTRL_H
 #define _SHAREDFILESTRL_H
 
-#include "MuleListCtrl.h"               // Needed for CMuleListCtrl
-#include "SharedFileList.h"             // Needed for CKnownFileMap
-#include <wx/menu.h>                    // Needed for wxMenu
+#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl
 
+#include <wx/menu.h>                        // Needed for wxMenu
+
+class CKnownFile;
 class CSharedFileList;
+class wxMemoryDC;
+
 class CSharedFilesCtrl : public CMuleListCtrl
 {
-  //	DECLARE_DYNAMIC(CSharedFilesCtrl)
-
 public:
 	CSharedFilesCtrl();
-	CSharedFilesCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags);
+	CSharedFilesCtrl(wxWindow*& parent, int id, const wxPoint& pos, wxSize siz, int flags);
 	virtual ~CSharedFilesCtrl();
 	void	Init();
 	void InitSort();
 	void	ShowFileList(CSharedFileList* in_sflist);
 	void	ShowFile(CKnownFile* file);
-	void	ShowFile(CKnownFile* file,uint32 itemnr);
+	void	ShowFile(CKnownFile* file, wxUint32 itemnr);
 	void	RemoveFile(CKnownFile* toremove);
-	void	UpdateFile(CKnownFile* file,uint32 pos);
+	void	UpdateFile(CKnownFile* file, wxUint32 pos);
 	void	UpdateItem(CKnownFile* toupdate);
 	void	Localize();
 	void	ShowFilesCount();
 protected:
-	virtual void OnDrawItem(int item,wxDC* dc,const wxRect& rect,const wxRect& rectHL,bool highlighted);
+	virtual void OnDrawItem(int item, wxDC* dc, const wxRect& rect, const wxRect& rectHL, bool highlighted);
 	static int  SortProc(long lParam1, long lParam2, long lParamSort);
-	//afx_msg	void OnColumnClick( NMHDR* pNMHDR, LRESULT* pResult);
 	void OnColumnClick(wxListEvent& evt);
-	//DECLARE_MESSAGE_MAP()
 	void OnNMRclick(wxListEvent& evt);
 	DECLARE_EVENT_TABLE()
 
 	virtual bool ProcessEvent(wxEvent& evt);
 private:
-	//CTitleMenu	   m_SharedFilesMenu;
 	wxMenu* m_SharedFilesMenu;
 	wxMenu		   m_PrioMenu;
 	wxMenu		   m_PermMenu;
 	CSharedFileList* sflist;
 	bool		   sortstat[3];
 public:
-	//afx_msg void OnContextMenu(CWnd* pWnd, CPoint point);
 protected:
-	//virtual BOOL OnCommand(WPARAM wParam, LPARAM lParam);
 };
+
 #endif
