@@ -20,23 +20,29 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "StatisticsDlg.h"
-#include "resource.h"                   // Needed for IDS_SELECT_TEMPDIR
-#	include "ClientList.h"
-#	include "ColorFrameCtrl.h"
-#	include "DownloadQueue.h"
-#	include "muuli_wdr.h"
-#	include "StatisticsDlg.h"
-#	include "UploadQueue.h"
-//#	include "WebServer.h"
-#	include "xmule.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/settings.h>
-#include <wx/sizer.h>                   // Needed for wxSizer::Show
-#include <wx/stattext.h>                // Needed for wxStaticText
+#include "StatisticsDlg.h"                  // Needed for 
+
+#include "ClientList.h"                     // Needed for CClientList
+#include "ColorFrameCtrl.h"                 // Needed for CColorFrameCtrl
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "ListenSocket.h"                   // Needed for CListenSocket
+#include "muuli_wdr.h"                      // Needed for statsDlg
+#include "NewFunctions.h"                   // Needed for MAP
+#include "OScopeCtrl.h"                     // Needed for COScopeCtrl
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_KBYTESEC
+#include "ServerList.h"                     // Needed for CServerList
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServerConnect
+#include "UploadQueue.h"                    // Needed for CUploadQueue
+#include "xmule.h"                          // Needed for theApp
+
+#include <wx/sizer.h>                       // Needed for wxSizer::Show
+#include <wx/stattext.h>                    // Needed for wxStaticText
 
 #define ID_EXPORT_HTML 20001
 
@@ -54,20 +60,6 @@ CStatisticsDlg::CStatisticsDlg(wxWindow *pParent):
     m_UploadOMeter = (COScopeCtrl *) FindWindowByName("uloadScope");
     m_Statistics = (COScopeCtrl *) FindWindowByName("otherScope");
     stattree = wxStaticCast(FindWindowByName("statTree"), wxTreeCtrl);
-#if 0
-    COScopeCtrl * tmp = new COScopeCtrl(3, this);
-    testSizer->Add(tmp, 1, wxGROW | wxALL | wxALIGN_CENTRE | wxLEFT, 5);
-    testSizer->Layout();
-    m_DownloadOMeter = * tmp;
-#endif
-#if 0
-    // let's play around a bit
-    // can't. preferences are created later
-    tmp->SetRange(0, theApp.glob_prefs->GetMaxGraphDownloadRate() + 4, 0);
-    tmp->SetRange(0, theApp.glob_prefs->GetMaxGraphDownloadRate() + 4, 1);
-    tmp->SetRange(0, theApp.glob_prefs->GetMaxGraphDownloadRate() + 4, 2);
-    tmp->SetYUnits(GetResString(IDS_KBYTESEC));
-#endif
 }
 
 CStatisticsDlg::~ CStatisticsDlg()
@@ -150,7 +142,6 @@ void CStatisticsDlg::Init()
     cli_versions[2] = stattree->AppendItem(cli1, GetResString(IDS_FSTAT_WAITING));
     cli_versions[3] = stattree->AppendItem(cli1, GetResString(IDS_FSTAT_WAITING));
     cli8 = stattree->AppendItem(h_clients, GetResString(IDS_FSTAT_WAITING));
-    //  cli10= stattree->AppendItem(h_clients,GetResString(IDS_FSTAT_WAITING));
     cli2 = stattree->AppendItem(h_clients, GetResString(IDS_FSTAT_WAITING));
     cli_versions[4] = stattree->AppendItem(cli2, GetResString(IDS_FSTAT_WAITING));
     cli_versions[5] = stattree->AppendItem(cli2, GetResString(IDS_FSTAT_WAITING));
@@ -182,19 +173,12 @@ void CStatisticsDlg::Init()
     shar3 = stattree->AppendItem(h_shared, GetResString(IDS_FSTAT_WAITING));
     stattree->Expand(root);
     stattree->Expand(h_uptime);
-    //,TVE_EXPAND);:
     stattree->Expand(h_transfer);
-    //,TVE_EXPAND);:
     stattree->Expand(h_connection);
-    //,TVE_EXPAND);:
     stattree->Expand(h_clients);
-    //,TVE_EXPAND);:
     stattree->Expand(h_servers);
-    // ,TVE_EXPAND);:
     stattree->Expand(h_shared);
-    //,TVE_EXPAND);:
     stattree->Expand(h_upload);
-    //,TVE_EXPAND);:
     stattree->Expand(h_download);
     RepaintMeters();
     m_ilastMaxConnReached = 0;
@@ -221,7 +205,7 @@ void CStatisticsDlg::RepaintMeters()
     m_Statistics->SetGridColor(theApp.glob_prefs->GetStatsColor(1));
     m_Statistics->SetPlotColor(theApp.glob_prefs->GetStatsColor(10), 0);
     m_Statistics->SetPlotColor(theApp.glob_prefs->GetStatsColor(8), 1);
-    //m_Statistics.SetPlotColor( theApp.glob_prefs->GetStatsColor(10),2) ;
+    m_Statistics->SetPlotColor( theApp.glob_prefs->GetStatsColor(10),2) ;
     m_Statistics->SetPlotColor(theApp.glob_prefs->GetStatsColor(9), 3);
     SetupLegend(IDC_C0_2, 0, 1);
     SetupLegend(IDC_C0_3, 1, 1);
@@ -231,15 +215,11 @@ void CStatisticsDlg::RepaintMeters()
     SetupLegend(IDC_C1, 2, 2);
     SetupLegend(IDC_S0, 1, 3);
     SetupLegend(IDC_S1, 0, 3);
-    //SetupLegend( IDC_S2, 2 ,3);
     SetupLegend(IDC_S3, 3, 3);
 }
 
 void CStatisticsDlg::SetupLegend(int ResIdx, int ElmtIdx, int legendNr)
 {
-    //CRect Rect;
-    //GetDlgItem( ResIdx )->GetWindowRect( Rect );
-    //ScreenToClient( Rect );
     CColorFrameCtrl * ctrl = (CColorFrameCtrl *) FindWindow(ResIdx);
     if (ctrl == NULL)
     {
@@ -248,25 +228,16 @@ void CStatisticsDlg::SetupLegend(int ResIdx, int ElmtIdx, int legendNr)
     }
     if (legendNr == 1)
     {
-        //m_Led1[ ElmtIdx ].Create( WS_VISIBLE | WS_CHILD, Rect, this );
-        //m_Led1[ ElmtIdx ].SetBackgroundColor( m_DownloadOMeter.GetPlotColor( ElmtIdx ) );
-        //m_Led1[ ElmtIdx ].SetFrameColor( RGB( 0x00, 0x00, 0x00 ) );
         ctrl->SetBackgroundColor((COLORREF) m_DownloadOMeter->GetPlotColor(ElmtIdx));
         ctrl->SetFrameColor((COLORREF) RGB(0, 0, 0));
     }
     else if(legendNr == 2)
     {
-        //m_Led2[ ElmtIdx ].Create( WS_VISIBLE | WS_CHILD, Rect, this );
-        //m_Led2[ ElmtIdx ].SetBackgroundColor( m_UploadOMeter.GetPlotColor( ElmtIdx ) );
-        //m_Led2[ ElmtIdx ].SetFrameColor( RGB( 0x00, 0x00, 0x00 ) );
         ctrl->SetBackgroundColor((COLORREF) m_UploadOMeter->GetPlotColor(ElmtIdx));
         ctrl->SetFrameColor((COLORREF) RGB(0, 0, 0));
     }
     else if(legendNr == 3)
     {
-        //m_Led3[ ElmtIdx ].Create( WS_VISIBLE | WS_CHILD, Rect, this );
-        //m_Led3[ ElmtIdx ].SetBackgroundColor( m_Statistics.GetPlotColor( ElmtIdx ) );
-        //m_Led3[ ElmtIdx ].SetFrameColor( RGB( 0x00, 0x00, 0x00 ) );
         ctrl->SetBackgroundColor((COLORREF) m_Statistics->GetPlotColor(ElmtIdx));
         ctrl->SetFrameColor((COLORREF) RGB(0, 0, 0));
     }
@@ -306,11 +277,6 @@ void CStatisticsDlg::SetCurrentRate(float uploadrate, float downloadrate)
     m_dPlotDataDown[2] = downloadrate;
     m_dPlotDataUp[2] = uploadrate;
     if (maxDown < downloadrate) maxDown = downloadrate;
-/*    // Websever [kuchin]
-    UpDown * updown = new UpDown();
-    updown->upload = uploadrate;
-    updown->download = downloadrate;
-    theApp.webserver->AddStatsLine(updown);*/
     // averages
     m_dPlotDataDown[0] = GetAvgDownloadRate(AVG_SESSION);
     m_dPlotDataUp[0] = GetAvgUploadRate(AVG_SESSION);
@@ -323,13 +289,9 @@ void CStatisticsDlg::SetCurrentRate(float uploadrate, float downloadrate)
     activeconnections = theApp.listensocket->GetOpenSockets();
     theApp.downloadqueue->GetDownloadStats(myStats);
     m_dPlotDataMore[0] = theApp.uploadqueue->GetUploadQueueLength();
-    //myStats[0];:
     m_dPlotDataMore[1] = activeconnections;
-    //theApp.uploadqueue->GetWaitingUserCount();:
     m_dPlotDataMore[2] = 0;
     m_dPlotDataMore[3] = myStats[1];
-    //for (int i=0;i<4;i++) if (m_dPlotDataMore[i]>theApp.glob_prefs->GetStatsMax()) {resize=true;theApp.glob_prefs->GetStatsMax()=(int)m_dPlotDataMore[i];}
-    //if (resize) m_Statistics.SetRanges(0, theApp.glob_prefs->GetStatsMax()+15) ;
     m_Statistics->AppendPoints(m_dPlotDataMore);
 }
 
@@ -516,7 +478,6 @@ void CStatisticsDlg::ShowStatistics()
     stattree->SetItemText(cli6, cbuffer);
     cbuffer.Format(GetResString(IDS_STATS_FILTEREDCLIENTS) .GetData(), theApp.stat_filteredclients);
     stattree->SetItemText(cli7, cbuffer);
-    //if (stattree->GetItemState(cli3, TVIS_EXPANDED)&&TVIS_EXPANDED == TVIS_EXPANDED ) {
     if (stattree->IsExpanded(cli3))
     {
         uint32 totcnt = myStats[1];
@@ -558,7 +519,7 @@ void CStatisticsDlg::ShowStatistics()
             stattree->SetItemText(cli_versions[i + 8], cbuffer);
         }
     }
-    //if (stattree->GetItemState(cli2, TVIS_EXPANDED)&&TVIS_EXPANDED == TVIS_EXPANDED ) {
+
     if (stattree->IsExpanded(cli2))
     {
         uint32 totcnt = myStats[4];
@@ -600,7 +561,7 @@ void CStatisticsDlg::ShowStatistics()
             stattree->SetItemText(cli_versions[i + 4], cbuffer);
         }
     }
-    //if (stattree->GetItemState(cli1, TVIS_EXPANDED)&&TVIS_EXPANDED == TVIS_EXPANDED ) {
+
     if (stattree->IsExpanded(cli1))
     {
         uint32 totcnt = myStats[2];
@@ -676,8 +637,6 @@ void CStatisticsDlg::ShowStatistics()
     if (m_itemp != m_ilastMaxConnReached)
     {
         char osDate[60];
-        //_strtime( osTime );
-        //_strdate( osDate );
         time_t mytime = time(NULL);
         struct tm * now = localtime( & mytime);
         strftime(osDate, sizeof(osDate) - 1, "%d.%m.%Y %H:%M:%S", now);
@@ -740,25 +699,6 @@ float CStatisticsDlg::GetAvgUploadRate(int averageType)
     }
 }
 
-#if 0
-void CStatisticsDlg::OnShowWindow(BOOL bShow, UINT nStatus)
-{
-}
-
-void CStatisticsDlg::OnSize(UINT nType, int cx, int cy)
-{
-    CResizableDialog::OnSize(nType, cx, cy);
-    // TODO: Add your message handler code here
-    //this will cause COScopeCtrl::OnSizeCall
-    CRect rc;
-    GetDlgItem(IDC_UPLOAD)->GetWindowRect( & rc);
-    ScreenToClient( & rc);
-    m_DownloadOMeter.MoveWindow( & rc);
-    //OnSize:
-}
-
-#endif
-
 void CStatisticsDlg::ShowInterval()
 {
     //EnableWindow( FALSE );
@@ -775,8 +715,6 @@ void CStatisticsDlg::ShowInterval()
         m_UploadOMeter->SetXUnits(tmpstr);
         m_DownloadOMeter->SetXUnits(tmpstr);
     }
-    //UpdateData(FALSE);
-    //EnableWindow( TRUE );
 }
 
 void CStatisticsDlg::SetARange(bool SetDownload, int maxValue)
@@ -795,27 +733,6 @@ void CStatisticsDlg::SetARange(bool SetDownload, int maxValue)
     }
 }
 
-#if 0
-void CStatisticsDlg::Localize()
-{
-    GetDlgItem(IDC_STATIC_D3)->SetWindowText(GetResString(IDS_ST_DOWNLOAD));
-    GetDlgItem(IDC_STATIC_U)->SetWindowText(GetResString(IDS_ST_UPLOAD));
-    GetDlgItem(IDC_STATIC_D)->SetWindowText(GetResString(IDS_ST_CURRENT));
-    GetDlgItem(IDC_STATIC_U2)->SetWindowText(GetResString(IDS_ST_CURRENT));
-    GetDlgItem(IDC_STATIC_D2)->SetWindowText(GetResString(IDS_ST_SESSION));
-    GetDlgItem(IDC_STATIC_U3)->SetWindowText(GetResString(IDS_ST_SESSION));
-    GetDlgItem(IDC_STATIC_S2)->SetWindowText(GetResString(IDS_ST_ACTIVED));
-    GetDlgItem(IDC_STATIC_S0)->SetWindowText(GetResString(IDS_ST_ACTIVEC));
-    GetDlgItem(IDC_STATIC_S1)->SetWindowText(GetResString(IDS_ST_ACTIVEU));
-    GetDlgItem(IDC_STATIC_S3)->SetWindowText(GetResString(IDS_ST_WAITINGU));
-    CString value;
-    value.Format(" (%u mins)", theApp.glob_prefs->GetStatsAverageMinutes());
-    GetDlgItem(IDC_TIMEAVG1)->SetWindowText(GetResString(IDS_AVG) + value);
-    GetDlgItem(IDC_TIMEAVG2)->SetWindowText(GetResString(IDS_AVG) + value);
-}
-
-#endif
-
 // the idea: we must dispatch this request to the main thread as web thread
 // can't touch the GUI controls. Only allowed function is wxPostEvent which
 // unfortunately just passes the event, so we must implement a wxCondition
@@ -840,7 +757,7 @@ wxString CStatisticsDlg::ExportHTML()
     return exportString;
 }
 
-void CStatisticsDlg::ExportHTMLEvent(wxEvent & evt)
+void CStatisticsDlg::ExportHTMLEvent(wxCommandEvent& evt)
 {
     int8 ix;
     wxString temp;
