@@ -22,16 +22,18 @@
 #ifndef STAT_DLG_H
 #define STAT_DLG_H
 
-#include "OScopeCtrl.h"                 // Needed for COScopeCtrl
-#include "types.h"                      // Needed for uint32
-#include <list>                         // Needed for std::list
-#include <wx/treectrl.h>                // Needed for wxTreeItemId
+#include "types.h"                          // Needed for uint32
+
+#include <list>                             // Needed for std::list
+#include <wx/setup.h>                       // Needed for wxTreeItemId
+#include <wx/treectrl.h>                    // Needed for wxTreeItemId
+
+class COScopeCtrl;
 
 typedef wxTreeItemId HTREEITEM;
 
 class CStatisticsDlg : public wxPanel
 {
-  //DECLARE_DYNAMIC(CStatisticsDlg)
 public:
     CStatisticsDlg(wxWindow* pParent = NULL);   // standard constructor
     ~CStatisticsDlg();
@@ -57,7 +59,7 @@ public:
     // so it is splitted in two parts   
     wxString ExportHTML();
  private:
-    void ExportHTMLEvent(wxEvent& evt);
+    void ExportHTMLEvent(wxCommandEvent & evt);
     wxString exportString;
     wxMutex exportMutex;
     wxCondition* exportCondition;
@@ -65,10 +67,6 @@ public:
 
 private:
     COScopeCtrl* m_DownloadOMeter,*m_UploadOMeter,*m_Statistics;
-    //CColorFrameCtrl m_Led1[ 3 ];
-    //CColorFrameCtrl m_Led2[ 3 ];
-    //CColorFrameCtrl m_Led3[ 4 ];
-
     wxTreeCtrl* stattree;
 
     int dl_users,dl_active;
@@ -104,11 +102,6 @@ private:
     uint32 activeconnections;
 protected:
     DECLARE_EVENT_TABLE()
-    //virtual void OnSize(UINT nType,int cx,int cy);
-    //virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support    
-    //DECLARE_MESSAGE_MAP()
-    //virtual BOOL OnInitDialog(); 
-    //void  OnShowWindow(BOOL bShow,UINT nStatus);
 };
 #endif
 
