@@ -19,43 +19,42 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+#ifndef __SYSTRAY_DISABLED__
+
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "SysTray.h"
-#	include "Preferences.h"
-#	include "SharedFileList.h"
-#	include "UploadQueue.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <net/if.h>                     // Needed for ifreq
-#include <netinet/in.h>                 // Needed for sockaddr_in
-#include <libintl.h>
-#include "pixmaps/mule_Tr_grey.ico.xpm"
-#include <gtk/gtk.h>
-#include <gdk/gdk.h>
-#include <gdk/gdkx.h>
-#include <glib.h>
-#include <X11/Xatom.h>
+#include "SysTray.h"                        // Needed for this Interface's Prototype
 
-#include <locale.h>
-#include <config.h>
-#include <sys/ioctl.h>
+#include "config.h"                         // Needed for VERSION
+#include "eggtrayicon.h"                    // Needed for egg_tray_icon_new
+#include "NewFunctions.h"                   // Needed for MAP
+#include "opcodes.h"                        // Needed for UNLIMITED
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "resource.h"                       // Needed for IDS_CONNECTING
+#include "server.h"                         // Needed for CServer
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServerConnect
+#include "UploadQueue.h"                    // Needed for CUploadQueue
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
 
-#include <arpa/inet.h>
-#include <netdb.h>
-
-#include <unistd.h>
-#include "eggtrayicon.h"
+#include <arpa/inet.h>                      // Needed for inet_ntoa
+#include <gtk/gtk.h>                        // Needed for gtk_menu_new
+#include <libintl.h>                        // Needed for bindtextdomain
+#include <net/if.h>                         // Needed for ifreq
+#include <netinet/in.h>                     // Needed for sockaddr_in
+#include <sys/ioctl.h>                      // Needed for SIOCGIFADDR
+#include <X11/Xatom.h>                      // Needed for XA_WINDOW
 
 #ifdef __WXMAC__
-#	include <sys/types.h>
-#	include <sys/socket.h>
+    #include <sys/types.h>
+    #include <sys/socket.h>
 #endif
 
-#ifndef __SYSTRAY_DISABLED__
+#include "pixmaps/mule_Tr_grey.ico.xpm"
 
 #ifdef __SAFE_TRAY__
 gchar *getIP()
@@ -280,7 +279,7 @@ static gboolean tray_menu(GtkWidget *widget, GdkEventButton *event, gpointer dat
     {
         max_up_speed = 100;
     }
-    label = "xMule " + wxString(VERSION) + "\nActual Speed Limits:\nDL: " + dl_speed + " kb/s " + "UP:" + upl_speed + " kb/s";
+    label = "xMule " + wxString(PACKAGE_VERSION) + "\nActual Speed Limits:\nDL: " + dl_speed + " kb/s " + "UP:" + upl_speed + " kb/s";
     // Info menu
     info_menu = gtk_menu_new();
     gtk_menu_set_title(GTK_MENU(info_menu), "xMule TrayMenu Info");
@@ -580,8 +579,8 @@ CSysTray::CSysTray(wxWindow *_parent, int _desktopMode, const wxString &title)
         return;
     }
     setlocale(LC_ALL, "");
-    bindtextdomain(PACKAGE, LOCALEDIR);
-    textdomain(PACKAGE);
+    bindtextdomain(PACKAGE_NAME, LOCALEDIR);
+    textdomain(PACKAGE_NAME);
     bool use_legacy = false;
     // Case 2 and 3 are KDE/other legacy system
     if (desktopMode == 1 || desktopMode == 2)
