@@ -9,8 +9,8 @@
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
+//
+// This program is distributed in the hope that it will be useful, 
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
@@ -22,63 +22,57 @@
 #ifndef _TRANSFERWND_H
 #define _TRANSFERWND_H
 
-#include "UploadListCtrl.h"             // Needed for CUploadListCtrl
-#include "DownloadListCtrl.h"           // Needed for CDownloadListCtrl
-#include "SplitterControl.h"            // Needed for CSplitterControl
-#include "QueueListCtrl.h"              // Needed for CQueueListCtrl
-#include <wx/notebook.h>                // Needed for wxNotebookEvent
-#include <wx/listctrl.h>                // Needed for wxListCtrl
+#include <wx/panel.h>                       // Needed for wxPanel
 
+class CatMenuHandler;
+class CDownloadListCtrl;
 class CMuleNotebook;
+class CQueueListCtrl;
+class CString;
+class CUploadListCtrl;
+class wxListCtrl;
+class wxMouseEvent;
+class wxNotebookEvent;
+class wxSplitterEvent;
+
 class CTransferWnd : public wxPanel
 {
-  //DECLARE_DYNAMIC(CTransferWnd)
+friend class CatMenuHandler;
   DECLARE_DYNAMIC_CLASS(CTransferWnd)
 
 public:
 	CTransferWnd(wxWindow* pParent = NULL);   // standard constructor
 	virtual ~CTransferWnd();
-	void	ShowQueueCount(uint32 number);
+	void	ShowQueueCount(wxUint32 number);
 	void	SwitchUploadList(wxCommandEvent& evt);
 	void	Localize();
-	BOOL	OnInitDialog();
+	bool	OnInitDialog();
 // Dialog Data
 	enum { IDD };
 	CUploadListCtrl*		uploadlistctrl;
 	CDownloadListCtrl*	downloadlistctrl;
 	CQueueListCtrl*		queuelistctrl;
-	//wxToolTip		m_ttip;
 	bool			windowtransferstate;
+	DECLARE_EVENT_TABLE()
+
 protected:
 	void DoResize(int delta);
 	void UpdateSplitterRange();
 	void SetInitLayout();
-	virtual bool ProcessEvent(wxEvent& evt);
-	/*
-	virtual BOOL PreTranslateMessage(MSG* pMsg);
-	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
-	virtual BOOL OnInitDialog();
-	virtual LRESULT DefWindowProc(UINT message, WPARAM wParam, LPARAM lParam);
-	afx_msg BOOL OnToolTipNotify(UINT id, NMHDR *pNMH, LRESULT *pResult);
-	*/
 
 	void DoSplitResize(int delta);
 	void UpdateToolTips(void);
 	int GetItemUnderMouse(wxListCtrl* ctrl);
-	void OnSelchangeDltab(wxNotebookEvent& evt);
-	void OnNMRclickDLtab(wxMouseEvent& evt);
-    void OnSashPositionChanged();
+    void OnSelchangeDltab(wxNotebookEvent& evt);
+    void OnNMRclickDLtab(wxMouseEvent& evt);
+    void OnSashPositionChanged(wxSplitterEvent& event);
 
-	int AddCategorie(CString newtitle,CString newincoming,CString newcomment,bool addTab);
-	void EditCatTabLabel(int index,CString newlabel);
 
-	CSplitterControl m_wndSplitter;
+	int AddCategorie(CString newtitle, CString newincoming, CString newcomment, bool addTab);
+	void EditCatTabLabel(int index, CString newlabel);
+
 	CMuleNotebook* m_dlTab;
 
-	DECLARE_EVENT_TABLE()
-
-	//DECLARE_MESSAGE_MAP()
-
 private:
 	wxString m_strToolTip;
 	int m_iOldToolTipItemDown;
