@@ -20,27 +20,28 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "UDPSocket.h"
-#include "NewSockets.h"                 // Needed for NewSocket_DebugPP
-#include "PartFile.h"                   // Needed for CPartFile::AddSources
-#	include "DownloadQueue.h"
-#	include "SearchDlg.h"
-#	include "SearchList.h"
-#	include "ServerList.h"
-#	include "ServerWnd.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
+#include "UDPSocket.h"                      // Needed for this Interface's Prototype
+
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "NewSockets.h"                     // Needed for NewSocket_DebugPP
+#include "packets.h"                        // Needed for Packet
+#include "PartFile.h"                       // Needed for CPartFile::AddSources
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "SearchDlg.h"                      // Needed for CSearchDlg
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
+#include "ServerWnd.h"                      // Needed for CServerWnd
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
 #include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
 
-#include <netdb.h>
-#include <pthread.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
+#include <arpa/inet.h>                      // Needed for inet_addr
+#include <netdb.h>                          // Needed for hostent
 
 //=PTHREAD_CREATE_DETACHED;:
 static pthread_attr_t attr;
@@ -205,25 +206,6 @@ wxThread::ExitCode AsyncDNS::Entry()
     }
 }
 
-#if 0
-CUDPSocketWnd::CUDPSocketWnd()
-{
-}
-
-BEGIN_MESSAGE_MAP(CUDPSocketWnd, CWnd)
-ON_MESSAGE(WM_DNSLOOKUPDONE, OnDNSLookupDone)
-END_MESSAGE_MAP()
-
-LRESULT CUDPSocketWnd::OnDNSLookupDone(WPARAM wParam, LPARAM lParam)
-{
-    m_pOwner->DnsLookupDone(wParam, lParam);
-    return true;
-}
-
-;
-
-#endif
-
 IMPLEMENT_DYNAMIC_CLASS(CUDPSocket, wxDatagramSocket)
 
 static wxIPV4address tmpaddress;
@@ -233,7 +215,6 @@ static wxIPV4address tmpaddress;
 CUDPSocket::CUDPSocket(CServerConnect *in_serverconnect, wxIPV4address &address)
 : wxDatagramSocket(address, wxSOCKET_NOWAIT)
 {
-    //m_hWndResolveMessage = NULL;
     sendbuffer = 0;
     cur_server = 0;
     serverconnect = in_serverconnect;
@@ -241,7 +222,6 @@ CUDPSocket::CUDPSocket(CServerConnect *in_serverconnect, wxIPV4address &address)
     SetEventHandler( *theApp.xmuledlg, ID_SOKETTI);
     SetNotify(wxSOCKET_INPUT_FLAG);
     Notify(TRUE);
-    //DnsTaskHandle = 0;
 }
 
 CUDPSocket::~CUDPSocket()
@@ -252,7 +232,6 @@ CUDPSocket::~CUDPSocket()
     delete cur_server;
     if (sendbuffer)
     delete[] sendbuffer;
-    //m_udpwnd.DestroyWindow();
 }
 
 void CUDPSocket::OnReceive(int nErrorCode)
@@ -379,7 +358,6 @@ wxUint32 hostip, wxUint16 port)
                 update->SetMaxUsers(cur_maxusers);
                 update->SetSoftFiles(cur_softfiles);
                 update->SetHardFiles(cur_hardfiles);
-                //printf("->> reading Stats from server, flags are %i\n",uUDPFlags);
                 update->SetUDPFlags(uUDPFlags);
                 theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(update);
             }
@@ -426,21 +404,6 @@ bool CUDPSocket::ProcessExtPacket(unsigned char *packet, wxUint16 size, wxUint8
 	NewSocket_DebugPP(NULL,opcode,size,packet);
         switch (opcode)
         {
- /*
- case OP_UDPVERIFYUPREQ:{
- wxASSERT (size == 6);
- if (size == 6){
- uint32 checkclientip = 0;
- uint16 checkclientport = 0;
- memcpy(&checkclientip,packet,4);
- memcpy(&checkclientport,packet,2);
- if (theApp.clientlist->VerifyUpload(checkclientip,checkclientport)){
- Packet answer(OP_UDPVERIFYUPA,0,OP_EMULEPROT);
- SendTo(answer.GetUDPHeader(),2,port,hostip);
- }
- }
- break;
-    }*/
         case OP_UDPVERIFYUPA:
             {
                 theApp.downloadqueue->AddDownDataOverheadOther(size);
@@ -458,7 +421,6 @@ void CUDPSocket::DnsLookupDone(struct sockaddr_in *inaddr)
     /* An asynchronous database routine completed. */
     if (inaddr == NULL)
     {
-    /*WSAGETASYNCERROR(lp) != 0){*/
         if (sendbuffer)
         delete[] sendbuffer;
         sendbuffer = 0;
