@@ -22,14 +22,15 @@
 #ifndef _UDPSOCKET_H
 #define _UDPSOCKET_H
 
-#include <netinet/in.h>                 // Needed for sockaddr_in
+#include "types.h"                          // Needed for uint32
+#include "wintypes.h"                       // Needed for LPCTSTR
 
-#include <wx/socket.h>                  // Needed for wxDatagramSocket
+#include <netinet/in.h>                     // Needed for sockaddr_in
+#include <wx/socket.h>                      // Needed for wxDatagramSocket
 
-#include "packets.h"                    // Needed for Packet
-#include "server.h"                     // Needed for CServer
+class CServer;
+class Packet;
 
-#define WM_DNSLOOKUPDONE WM_USER+280
 // Client to Server communication
 class CServerConnect;
 
@@ -42,23 +43,17 @@ class CUDPSocket : public wxDatagramSocket //CAsyncSocket
 public:
 	CUDPSocket(CServerConnect* in_serverconnect,wxIPV4address& addr);
 	~CUDPSocket();
-	//bool	Create();
 	void	SendPacket(Packet* packet,CServer* host);
 	void DnsLookupDone(struct sockaddr_in* addr);
-	//void	DnsLookupDone(WPARAM wp, LPARAM lp);
 protected:
 	void	AsyncResolveDNS(LPCTSTR lpszHostAddress, UINT nHostPort);
-	//HANDLE	DnsTaskHandle;					// dns lookup handle
 	
  public:
 	virtual void OnReceive(int nErrorCode);
 private:
 	LPCTSTR m_lpszHostAddress;
 	UINT m_nHostPort;
-	//HWND m_hWndResolveMessage;	// where to send WM_DNSRESOLVED
-	//SOCKADDR_IN m_SaveAddr;
 	struct sockaddr_in m_SaveAddr;
-	//CUDPSocketWnd m_udpwnd;
 
 	void SendBuffer();
 	void SendBuffer_NEW(wxUint32 hostip,wxUint16 port);
