@@ -20,43 +20,43 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#include "PartFile.h"                   // Needed for PR_VERYHIGH
-#include "ClientCredits.h"                  // Needed for CClientCredits
-#	include "ClientUDPSocket.h"
-#	include "KnownFile.h"
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#	include "otherstructs.h"
-#	include "packets.h"
-#	include "SharedFileList.h"
-#	include "TransferWnd.h"
-#	include "updownclient.h"
-#	include "UploadQueue.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
-#	include "NewSockets.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <zlib.h>
+#include "updownclient.h"                   // Needed for this Interface's Prototype
+
+#include "BarShader.h"                      // Needed for CBarShader
+#include "ClientCredits.h"                  // Needed for CClientCredits
+#include "ListenSocket.h"                   // Needed for CClientReqServer
+#include "NewSockets.h"                     // Needed for NewSocket_SendPacket
+#include "otherstructs.h"                   // Needed for Requested_Block_Struct
+#include "packets.h"                        // Needed for Packet
+#include "PartFile.h"                       // Needed for PR_VERYHIGH
+#include "Preferences.h"                    // Needed for CPreferences
+#include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
+#include "SafeFile.h"                       // Needed for CSafeFile
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServerConnect
+#include "TransferWnd.h"                    // Needed for CTransferWnd
+#include "UploadListCtrl.h"                 // Needed for CUploadListCtrl
+#include "UploadQueue.h"                    // Needed for CUploadQueue
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <wx/dc.h>                          // Needed for wxDC
 
 //	members of CUpDownClient
 //	which are mainly used for uploading functions
 
 CBarShader CUpDownClient::s_UpStatusBar(16);
 
-void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
+void CUpDownClient::DrawUpStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
     RECT gaprect;
     gaprect.top = rect.y + 2;
     gaprect.bottom = (rect.y + rect.height) - 2;
-    //rect->left;:
     gaprect.left = rect.x;
-    //rect->right;:
     gaprect.right = (rect.x + rect.width);
-    //dc->FillRect(&gaprect,&CBrush(RGB(220,220,220)));
     wxBrush suti(wxColour(220, 220, 220), wxSOLID);
     dc->SetPen( *wxTRANSPARENT_PEN);
     dc->SetBrush(suti);
@@ -78,7 +78,6 @@ void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyre
         {
             gaprect.right = rect.x + (uint32)(((float) PARTSIZE *i/1024) *blockpixel);
             gaprect.left = rect.x + (uint32)((float)((float) PARTSIZE * (i + 1) /1024) *blockpixel);
-            //dc->FillRect(&gaprect,&CBrush(RGB(0,0,0)));
             dc->SetBrush( *wxBLACK_BRUSH);
             mygaprect.x = gaprect.left;
             mygaprect.y = gaprect.top;
@@ -89,50 +88,30 @@ void CUpDownClient::DrawUpStatusBar(wxMemoryDC *dc, wxRect rect, bool onlygreyre
     }
 }
 
- /*
- COLORREF crBoth;
- COLORREF crNeither;
- COLORREF crClientOnly;
- COLORREF crPending;
- COLORREF crNextPending;
- if(bFlat) {
- crBoth = RGB(0, 150, 0);
- crNeither = RGB(224, 224, 224);
- crClientOnly = RGB(0, 0, 0);
- crPending = RGB(255,208,0);
- crNextPending = RGB(255,255,100);
- } else {
- crBoth = RGB(0, 192, 0);
- crNeither = RGB(240, 240, 240);
- crClientOnly = RGB(104, 104, 104);
- crPending = RGB(255, 208, 0);
- crNextPending = RGB(255,255,100);
- }
- s_UpStatusBar.SetFileSize(PARTSIZE*(m_nUpPartCount));
- s_UpStatusBar.SetHeight(rect->bottom - rect->top);
- s_UpStatusBar.SetWidth(rect->right - rect->left);
- s_UpStatusBar.Fill(crNeither);
- if (!onlygreyrect && m_abyUpPartStatus) {
- for (uint32 i = 0;i != m_nUpPartCount;i++){
- if (m_abyUpPartStatus[i]){
- s_StatusBar.FillRange(PARTSIZE*(i), PARTSIZE*(i+1), crClientOnly);
- }
- }
- }
- s_StatusBar.Draw(dc, rect->left, rect->top, bFlat);
- }
-    */
-
 uint32 CUpDownClient::GetScore(bool sysvalue, bool isdownloading, bool onlybasevalue)
 {
     //TODO: complete this (friends, uploadspeed, xmuleuser etc etc)
     if (!m_pszUsername)
-    return 0;
+    {
+        return 0;
+    }
+
+    if (SpecialPerson == true)
+    {
+        return 0x0FFFFFFF;
+    }
+
     // friend slot
-    if (IsFriend() &&GetFriendSlot())
-    return 0x0FFFFFFF;
+    if (IsFriend() && GetFriendSlot())
+    {
+        return 0x0FFFFFFF;
+    }
+    
     if (IsBanned())
-    return 0;
+    {
+        return 0;
+    }
+    
     if (sysvalue &&HasLowID() && ! (socket &&socket->IsConnected()))
     {
         return 0;
@@ -311,7 +290,6 @@ bool CUpDownClient::CreateNextBlockPackage()
             throw GetResString(IDS_ERR_LARGEREQBLOCK);
             if (!srcfile->IsPartFile())
             {
-                //CFile::modeRead|CFile::osSequentialScan|CFile::shareDenyNone)):
                 if (!file.Open(fullname, CFile::read))
                 throw GetResString(IDS_ERR_OPEN);
                 delete[] fullname;
@@ -330,12 +308,12 @@ bool CUpDownClient::CreateNextBlockPackage()
                 CPartFile *partfile = (CPartFile *) srcfile;
                 delete[] fullname;
                 fullname = 0;
-                partfile->m_hpartfile.Seek(currentblock->StartOffset);
+                partfile->m_hpartfile->Seek(currentblock->StartOffset);
                 filedata = new byte[togo + 500];
-                if (uint32 done = partfile->m_hpartfile.Read(filedata, togo) != togo)
+                if (uint32 done = partfile->m_hpartfile->Read(filedata, togo) != togo)
                 {
-                    partfile->m_hpartfile.Seek(0);
-                    partfile->m_hpartfile.Read(filedata + done, togo - done);
+                    partfile->m_hpartfile->Seek(0);
+                    partfile->m_hpartfile->Read(filedata + done, togo - done);
                 }
             }
             SetUploadFileID(currentblock->FileID);
