@@ -20,31 +20,33 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "UploadListCtrl.h"
-#	include "ChatWnd.h"
-#include "ClientCredits.h"                  // Needed for CClientCredits
-#	include "ClientDetailDialog.h"
-#	include "FriendList.h"
-#	include "KnownFile.h"
-#	include "muuli_wdr.h"
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#	include "SharedFileList.h"
-#	include "TransferWnd.h"
-#	include "wintypes.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/menu.h>                    // Needed for wxMenu
+#include "UploadListCtrl.h"                 // Needed for this Interface's Prototype
+
+#include "ChatWnd.h"                        // Needed for CChatWnd
+#include "ClientCredits.h"                  // Needed for CClientCredits
+#include "ClientDetailDialog.h"             // Needed for CClientDetailDialog
+#include "FriendList.h"                     // Needed for CFriendList
+#include "KnownFile.h"                      // Needed for CKnownFile
+#include "muuli_wdr.h"                      // Needed for ID_UPLOADLIST
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "TransferWnd.h"                    // Needed for CTransferWnd
+#include "updownclient.h"                   // Needed for CUpDownClient
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <wx/dcmemory.h>                    // Needed for wxMemoryDC
+#include <wx/menu.h>                        // Needed for wxMenu
 
 #define SYSCOLOR(x) (wxSystemSettings::GetColour(x))
 
 BEGIN_EVENT_TABLE(CUploadListCtrl, CMuleListCtrl)
-EVT_RIGHT_DOWN(CUploadListCtrl::OnNMRclick)
-EVT_LIST_COL_CLICK(ID_UPLOADLIST, CUploadListCtrl::OnColumnClick)
+    EVT_RIGHT_DOWN(CUploadListCtrl::OnNMRclick)
+    EVT_LIST_COL_CLICK(ID_UPLOADLIST, CUploadListCtrl::OnColumnClick)
 END_EVENT_TABLE()
 
 // images
@@ -59,7 +61,6 @@ END_EVENT_TABLE()
 #include "pixmaps/pluseDonkeyHybrid.ico.xpm"
 #include "pixmaps/thief.ico.xpm"
 
-//IMPLEMENT_DYNAMIC(CUploadListCtrl, CMuleListCtrl)
 CUploadListCtrl::CUploadListCtrl()
 {
 }
@@ -95,23 +96,16 @@ CUploadListCtrl::CUploadListCtrl(wxWindow *&parent, int id, const wxPoint &pos,
 
 void CUploadListCtrl::Init()
 {
-    //,0);:
     InsertColumn(0, GetResString(IDS_QL_USERNAME), wxLIST_FORMAT_LEFT, 150);
-    //,1);:
     InsertColumn(1, GetResString(IDS_FILE), wxLIST_FORMAT_LEFT, 275);
-    //,2);:
     InsertColumn(2, GetResString(IDS_DL_SPEED), wxLIST_FORMAT_LEFT, 60);
-    //,3);:
     InsertColumn(3, GetResString(IDS_DL_TRANSF), wxLIST_FORMAT_LEFT, 65);
-    //,4);:
     InsertColumn(4, GetResString(IDS_WAITED), wxLIST_FORMAT_LEFT, 60);
-    //,6);:
     InsertColumn(5, GetResString(IDS_UPLOADTIME), wxLIST_FORMAT_LEFT, 60);
-    //,5);:
     InsertColumn(6, GetResString(IDS_STATUS), wxLIST_FORMAT_LEFT, 110);
     InsertColumn(7, GetResString(IDS_UPSTATUS), wxLIST_FORMAT_LEFT, 100);
     // not here.. no preferences yet
-    //LoadSettings(CPreferences::tableUpload);
+    // LoadSettings(CPreferences::tableUpload);
 }
 
 void CUploadListCtrl::InitSort()
@@ -168,7 +162,6 @@ void CUploadListCtrl::AddClient(CUpDownClient *client)
 {
     uint32 itemnr = GetItemCount();
     char buffer[100];
-    //itemnr = InsertItem(LVIF_TEXT|LVIF_PARAM,itemnr,client->GetUserName(),0,0,1,(LPARAM)client);
     itemnr = InsertItem(itemnr, client->GetUserName());
     SetItemData(itemnr, (long) client);
     wxListItem myitem;
@@ -181,10 +174,6 @@ void CUploadListCtrl::AddClient(CUpDownClient *client)
 
 void CUploadListCtrl::RemoveClient(CUpDownClient *client)
 {
-    //LVFINDINFO find;
-    //find.flags = LVFI_PARAM;
-    //find.lParam = (LPARAM)client;
-    //sint32 result = FindItem(&find);
     sint32 result = FindItem( - 1, (long) client);
     if (result != ( - 1))
     DeleteItem(result);
@@ -192,11 +181,6 @@ void CUploadListCtrl::RemoveClient(CUpDownClient *client)
 
 void CUploadListCtrl::RefreshClient(CUpDownClient *client)
 {
-    //LVFINDINFO find;
-    //find.flags = LVFI_PARAM;
-    //find.lParam = (LPARAM)client;
-    //sint32 itemnr = FindItem(&find);
-
     if (theApp.nowindow)
 	return;
     sint32 itemnr = FindItem( - 1, (long) client);
@@ -217,8 +201,6 @@ void CUploadListCtrl::RefreshClient(CUpDownClient *client)
         else
         image = 0;
     }
-    // no images yet
-    //SetItem(itemnr,0,LVIF_IMAGE,0,image,0,0,0,0);
     char buffer[100];
     CKnownFile *file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     if (file)
@@ -248,7 +230,7 @@ void CUploadListCtrl::RefreshClient(CUpDownClient *client)
     SetItem(itemnr, 7, "Bar is missing :)");
 }
 
-bool CUploadListCtrl::ProcessEvent(wxEvent &evt)
+bool CUploadListCtrl::ProcessEvent(wxEvent& evt)
 {
     if (evt.GetEventType() != wxEVT_COMMAND_MENU_SELECTED)
     return CMuleListCtrl::ProcessEvent(evt);
@@ -269,11 +251,7 @@ bool CUploadListCtrl::ProcessEvent(wxEvent &evt)
             }
         case MP_ADDFRIEND:
             {
-                //      int pos;
-                //      while (pos!=-1) {
                 theApp.friendlist->AddFriend(client);
-                //	pos=GetNextItem(pos,wxLIST_NEXT_ALL,wxLIST_STATE_SELECTED);
-                //      }
                 break;
             }
         case MP_DETAIL:
@@ -290,7 +268,6 @@ bool CUploadListCtrl::ProcessEvent(wxEvent &evt)
     {
     case MP_SWITCHCTRL:
         {
-            //((CTransferWnd*)GetParent())->SwitchUploadList(event);
             theApp.xmuledlg->transferwnd->SwitchUploadList(event);
         }
     }
@@ -299,8 +276,6 @@ bool CUploadListCtrl::ProcessEvent(wxEvent &evt)
 
 void CUploadListCtrl::OnColumnClick(wxListEvent &evt)
 {
-    //NMHDR* pNMHDR, LRESULT* pResult){
-    //NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;
     // if it's a second click on the same column then reverse the sort order,
     // Barry - Store sort order in preferences
     // Determine ascending based on whether already sorted on this column
@@ -316,7 +291,6 @@ void CUploadListCtrl::OnColumnClick(wxListEvent &evt)
     SetSortArrow(sortItem, sortAscending);
     SortItems(SortProc, sortItem + (sortAscending ? 0: 100));
     // otherwise sort the new column in ascending order.
-    //*pResult = 0;
 }
 
 int CUploadListCtrl::SortProc(long lParam1, long lParam2, long lParamSort)
@@ -419,14 +393,8 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
     dc->DrawRectangle(rectHL);
     dc->SetPen( *wxTRANSPARENT_PEN);
     // then stuff from original xmule
-    //lpDrawItemStruct->itemData;:
     CUpDownClient *client = (CUpDownClient *) GetItemData(item);
-    //CMemDC dc(CDC::FromHandle(lpDrawItemStruct->hDC),&CRect(lpDrawItemStruct->rcItem));
-    //dc.SelectObject(GetFont());
-    //COLORREF crOldTextColor = dc->GetTextColor();
-    //COLORREF crOldBkColor = dc->GetBkColor();
     RECT cur_rec;
-    //memcpy(&cur_rec,&lpDrawItemStruct->rcItem,sizeof(RECT));
     cur_rec.left = rect.x;
     cur_rec.top = rect.y;
     cur_rec.right = rect.x + rect.width;
@@ -436,14 +404,11 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
     // end lagloose
     CString Sbuffer;
     CKnownFile *file = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
-    //CHeaderCtrl *pHeaderCtrl = GetHeaderCtrl();
-    //pHeaderCtrl->GetItemCount();:
     int iCount = GetColumnCount();
     cur_rec.right = cur_rec.left - 8;
     cur_rec.left += 4;
     for (int iCurrent = 0 ; iCurrent < iCount ; iCurrent++)
     {
-        //pHeaderCtrl->OrderToIndex(iCurrent);:
         int iColumn = iCurrent;
         if (1)
         {
@@ -501,10 +466,8 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                         cur_rec.left, cur_rec.top + 1
                                         };
                     imagelist.Draw(image, *dc, cur_rec.left, cur_rec.top + 1, wxIMAGELIST_DRAW_TRANSPARENT);
-                    //imagelist.Draw(dc,image, point, ILD_NORMAL);
                     Sbuffer.Format("%s", client->GetUserName());
                     cur_rec.left += 20;
-                    //dc->DrawText(Sbuffer,Sbuffer.GetLength(),&cur_rec,DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS);
                     dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
                     cur_rec.left -= 20;
                     break;
@@ -558,7 +521,6 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
                     {
                         Sbuffer.Append(" -->");
                     }
-                    // Sbuffer = GetResString(IDS_TRANSFERRING);
                     // end lagloose
                     break;
                 default:
@@ -595,10 +557,8 @@ void CUploadListCtrl::OnDrawItem(int item, wxDC *dc, const wxRect &rect, const w
             }
             if (iColumn != 7 &&iColumn != 0)
             {
-                //dc->DrawText(Sbuffer,Sbuffer.GetLength(),&cur_rec,DT_LEFT|DT_SINGLELINE|DT_VCENTER|DT_NOPREFIX|DT_END_ELLIPSIS);
                 dc->DrawText(Sbuffer, cur_rec.left, cur_rec.top + 3);
             }
-            //GetColumnWidth(iColumn);:
             cur_rec.left += cx;
             delete clipper;
         }
