@@ -22,7 +22,7 @@
 #ifndef _UPLOADLISTCTRL_H
 #define _UPLOADLISTCTRL_H
 
-#include "MuleListCtrl.h"               // Needed for CMuleListCtrl
+#include "MuleListCtrl.h"                   // Needed for CMuleListCtrl
 
 class CUpDownClient;
 
@@ -31,8 +31,6 @@ class CUpDownClient;
 
 class CUploadListCtrl : public CMuleListCtrl
 {
-  //DECLARE_DYNAMIC(CUploadListCtrl)
-
 public:
 	CUploadListCtrl();
 	CUploadListCtrl(wxWindow*& parent,int id,const wxPoint& pos,wxSize siz,int flags);
@@ -46,15 +44,7 @@ public:
 	void	Hide() {/*ShowWindow(SW_HIDE);*/}
 	void	Visable() {/*ShowWindow(SW_SHOW);*/}
 	void	Localize();
-	//virtual BOOL OnCommand(WPARAM wParam,LPARAM lParam );
 protected:
-	/*
-	static int CALLBACK SortProc(LPARAM lParam1, LPARAM lParam2, LPARAM lParamSort);
-	afx_msg	void OnColumnClick( NMHDR* pNMHDR, LRESULT* pResult);
-	afx_msg void OnNMRclick(NMHDR *pNMHDR, LRESULT *pResult);
-	DECLARE_MESSAGE_MAP()
-	*/
-	
 	static int SortProc(long lp1,long lp2,long lpSort);
 
 	void OnColumnClick(wxListEvent& evt);
