@@ -22,13 +22,17 @@
 #ifndef _UPLOADQUEUE_H
 #define _UPLOADQUEUE_H
 
-#include <wx/timer.h>                   // Needed for wxTimer
-#include "updownclient.h"               // Needed for CUpDownClient
-#include "Preferences.h"                // Needed for CPreferences
+#include "mfc.h"                            // Needed for POSITION
+#include "types.h"                          // Needed for uint16
+
+class CPreferences;
+class CUpDownClient;
+class wxTimer;
 
 // Helper class holding a copy of a filehash
 // The CCKey class is similiar but not useable here.
-class CFileHash {
+class CFileHash
+{
 public:
 	CFileHash()			{ memset(m_hash, 0, 16); }
 	CFileHash(const unsigned char* k) { memcpy(m_hash, k, 16); }
@@ -43,7 +47,8 @@ private:
 	unsigned char m_hash[16];
 };
 
-class CUploadQueue{
+class CUploadQueue
+{
 public:
 	CUploadQueue(CPreferences* in_prefs);
 	~CUploadQueue();
@@ -109,7 +114,6 @@ waitinglist.GetHeadPosition();}
 protected:
 	void	RemoveFromWaitingQueue(POSITION pos, bool updatewindow);
 	POSITION	GetWaitingClient(CUpDownClient* client);
-//	POSITION	GetWaitingClientByID(CUpDownClient* client);
 	POSITION	GetDownloadingClient(CUpDownClient* client);
 	bool		AcceptNewClient();
 	void		AddUpNextClient(CUpDownClient* directadd = 0);
