@@ -20,31 +20,28 @@
 // Wizard.cpp : implementation file
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "muuli_wdr.h"
-#	include "otherfunctions.h"
-#	include "Preferences.h"
-#	include "PreferencesDlg.h"
-#	include "StatisticsDlg.h"
-#	include "wintypes.h"
-#	include "Wizard.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <wx/listctrl.h>
-#include <wx/sizer.h>                   // Needed for wxSizer
-#include <wx/textctrl.h>                // Needed for wxTextCtrl
-// Wizard dialog
+#include "Wizard.h"                         // Needed for this Interface's Prototype
 
-//IMPLEMENT_DYNAMIC(Wizard, CDialog)
-    Wizard::Wizard(wxWindow *pParent /*=NULL*/
+#include "muuli_wdr.h"                      // Needed for connWizDlg
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "PPgConnection.h"                  // Needed for CPPgConnection
+#include "PPgTweaks.h"                      // Needed for CPPgTweaks
+#include "Preferences.h"                    // Needed for CPreferences
+#include "PreferencesDlg.h"                 // Needed for CPreferencesDlg
+#include "resource.h"                       // Needed for IDS_PW_CONNECTION
+#include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
 
-)
-//: CDialog(Wizard::IDD, pParent)
-: wxDialog(pParent, Wizard::IDD, _("Wizard"), wxDefaultPosition, wxDefaultSize,
-wxDEFAULT_DIALOG_STYLE |wxSYSTEM_MENU)
+#include <wx/listctrl.h>                    // Needed for wxListCtrl
+#include <wx/sizer.h>                       // Needed for wxSizer
+#include <wx/textctrl.h>                    // Needed for wxTextCtrl
+
+Wizard::Wizard(wxWindow* pParent)
+: wxDialog(pParent, Wizard::IDD, _("Wizard"), wxDefaultPosition, wxDefaultSize, wxDEFAULT_DIALOG_STYLE | wxSYSTEM_MENU)
 {
     m_iOS = 0;
     m_iTotalDownload = 0;
@@ -73,7 +70,7 @@ END_EVENT_TABLE()
 #define GetDlgItem(a,b) wxStaticCast(FindWindowById((a)),b)
 #define IsDlgButtonChecked(a) GetDlgItem(a,wxRadioButton)->GetValue()
 
-void Wizard::OnBnClickedApply(wxEvent &evt)
+void Wizard::OnBnClickedApply(wxCommandEvent&evt)
 {
     char buffer[510];
     int upload, download;
@@ -216,42 +213,40 @@ void Wizard::OnBnClickedApply(wxEvent &evt)
     }
     theApp.xmuledlg->preferenceswnd->m_wndConnection->LoadSettings();
     theApp.xmuledlg->preferenceswnd->m_wndTweaks->LoadSettings();
-    printf("TODO: TWEAKS missing \n");
-    //CDialog::OnOK();
     EndModal(0);
 }
 
-void Wizard::OnBnClickedCancel(wxEvent &evt)
+void Wizard::OnBnClickedCancel(wxCommandEvent&evt)
 {
     EndModal(1);
 }
 
-void Wizard::OnBnClickedWizRadioOsNtxp(wxEvent &evt)
+void Wizard::OnBnClickedWizRadioOsNtxp(wxCommandEvent&evt)
 {
     m_iOS = 0;
 }
 
-void Wizard::OnBnClickedWizRadioUs98me(wxEvent &evt)
+void Wizard::OnBnClickedWizRadioUs98me(wxCommandEvent&evt)
 {
     m_iOS = 1;
 }
 
-void Wizard::OnBnClickedWizLowdownloadRadio(wxEvent &evt)
+void Wizard::OnBnClickedWizLowdownloadRadio(wxCommandEvent&evt)
 {
     m_iTotalDownload = 0;
 }
 
-void Wizard::OnBnClickedWizMediumdownloadRadio(wxEvent &evt)
+void Wizard::OnBnClickedWizMediumdownloadRadio(wxCommandEvent&evt)
 {
     m_iTotalDownload = 1;
 }
 
-void Wizard::OnBnClickedWizHighdownloadRadio(wxEvent &evt)
+void Wizard::OnBnClickedWizHighdownloadRadio(wxCommandEvent&evt)
 {
     m_iTotalDownload = 2;
 }
 
-void Wizard::OnBnClickedWizResetButton(wxEvent &evt)
+void Wizard::OnBnClickedWizResetButton(wxCommandEvent&evt)
 {
     CString strBuffer;
     strBuffer.Format("%i", 0);
@@ -261,16 +256,11 @@ void Wizard::OnBnClickedWizResetButton(wxEvent &evt)
 
 #define CheckDlgButton(a,b) GetDlgItem(a,wxRadioButton)->SetValue(b)
 
-BOOL Wizard::OnInitDialog()
+bool Wizard::OnInitDialog()
 {
-    //CheckDlgButton(IDC_WIZ_XP_RADIO,1);
-    //CheckDlgButton(ID_LOWDOWN, 1);
-    //CheckDlgButton(ID_KBITS, 1);
     CString temp;
     temp.Format("%u", app_prefs->prefs->maxGraphDownloadRate *8);
-    //GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(temp);
     temp.Format("%u", app_prefs->prefs->maxGraphUploadRate *8);
-    //GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(temp);
     m_provider->InsertColumn(0, GetResString(IDS_PW_CONNECTION), wxLIST_FORMAT_LEFT, 160);
     m_provider->InsertColumn(1, GetResString(IDS_WIZ_DOWN), wxLIST_FORMAT_LEFT, 90);
     m_provider->InsertColumn(2, GetResString(IDS_WIZ_UP), wxLIST_FORMAT_LEFT, 90);
@@ -334,7 +324,7 @@ BOOL Wizard::OnInitDialog()
 
 void Wizard::SetCustomItemsActivation()
 {
-    BOOL active = (m_provider->GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED) < 1);
+    bool active = (m_provider->GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED) < 1);
     GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->Enable(active);
     GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->Enable(active);
     GetDlgItem(ID_KBITS, wxRadioButton)->Enable(active);
@@ -343,7 +333,6 @@ void Wizard::SetCustomItemsActivation()
 
 void Wizard::OnNMClickProviders(wxListEvent &evt)
 {
-    //LPNMLISTVIEW pNMLV = reinterpret_cast<LPNMLISTVIEW>(pNMHDR);
     SetCustomItemsActivation();
     uint16 up, down;
     int cursel = m_provider->GetNextItem( - 1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
@@ -404,11 +393,6 @@ void Wizard::OnNMClickProviders(wxListEvent &evt)
     }
     CString temp;
     temp.Format("%u", down);
-    //GetDlgItem(ID_TRUEDOWNLOAD, wxTextCtrl)->SetValue(temp);
     temp.Format("%u", up);
-    //GetDlgItem(ID_TRUEUPLOAD, wxTextCtrl)->SetValue(temp);
-    //CheckDlgButton(ID_KBITS, 1);
-    //CheckDlgButton(ID_KBYTES, 0);
-    //*pResult = 0;
 }
 
