@@ -1,7 +1,7 @@
 // This file is a part of the xMule Project.
 //
-// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://xmule.hopto.org/)
-// RSA-1024 Fingerprint: 4145 9DFD 5338 4FCC 1636  86E5 2E5A 42D8 BA13 460B
+// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -17,35 +17,21 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-// XBMDraw.cpp: implementation of the XBMDraw class.
-//
-//////////////////////////////////////////////////////////////////////
-
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "wintypes.h"
-#	include "XBMDraw.h"
+    #include "xmule-headers.h"
 #endif
 
-#ifdef _DEBUG
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
+#include "XBMDraw.h"                        // Needed for this Interface's Prototype
 
-#define new DEBUG_NEW
-#endif
+#include "wintypes.h"                       // Needed for BYTE
 
-//////////////////////////////////////////////////////////////////////
-// Construction/Destruction
-//////////////////////////////////////////////////////////////////////
-
-XBMDraw:: XBMDraw()
+XBMDraw::XBMDraw()
 {
     m_nWidth = m_nHeight = 0;
     m_pImage = NULL;
 }
 
-XBMDraw:: ~XBMDraw()
+XBMDraw::~XBMDraw()
 {
     try
     {
@@ -57,7 +43,7 @@ XBMDraw:: ~XBMDraw()
     }
 }
 
-bool XBMDraw:: CreateImage(CString sName, int nWidth, int nHeight, BYTE bBackground)
+bool XBMDraw::CreateImage(CString sName, int nWidth, int nHeight, BYTE bBackground)
 {
     try
     {
@@ -76,7 +62,7 @@ bool XBMDraw:: CreateImage(CString sName, int nWidth, int nHeight, BYTE bBackgro
     return false;
 }
 
-bool XBMDraw:: GetImage(CString &sImage)
+bool XBMDraw::GetImage(CString &sImage)
 {
     try
     {
@@ -118,7 +104,7 @@ bool XBMDraw:: GetImage(CString &sImage)
     return false;
 }
 
-bool XBMDraw:: Plot(int x, int y, bool bXOR)
+bool XBMDraw::Plot(int x, int y, bool bXOR)
 {
     try
     {
@@ -145,7 +131,7 @@ bool XBMDraw:: Plot(int x, int y, bool bXOR)
     return false;
 }
 
-CString XBMDraw:: GetImageTag()
+CString XBMDraw::GetImageTag()
 {
     try
     {
@@ -159,7 +145,7 @@ CString XBMDraw:: GetImageTag()
     return "";
 }
 
-bool XBMDraw:: Line(int x1, int y1, int x2, int y2, bool bXOR)
+bool XBMDraw::Line(int x1, int y1, int x2, int y2, bool bXOR)
 {
     try
     {
