@@ -204,249 +204,6 @@ static struct GSocketGUIFunctionsTable *gs_gui_functions;
 #define _GSocket_Uninstall_Callback(socket, event) \
     if (gs_gui_functions) gs_gui_functions->Uninstall_Callback(socket, event)
 
-static struct GSocketBaseFunctionsTable gs_base_functions =
-{
-    _GSocket_Detected_Read,
-    _GSocket_Detected_Write
-};
-
-/* Global initialisers */
-
-void GSocket_SetGUIFunctions(struct GSocketGUIFunctionsTable *guifunc)
-{
-  gs_gui_functions = guifunc;
-}
-         
-int GSocket_Init(void)
-{
-  if (gs_gui_functions)
-  {
-      if ( !gs_gui_functions->GUI_Init() )
-        return 0;
-  }
-  return 1;
-}
-
-void GSocket_Cleanup(void)
-{
-  if (gs_gui_functions)
-  {
-      gs_gui_functions->GUI_Cleanup();
-  }
-}
-
-/* Constructors / Destructors for GSocket */
-
-GSocket *GSocket_new(void)
-{
-  int i, success;
-  GSocket *socket;
-
-  socket = (GSocket *)malloc(sizeof(GSocket));
-
-  if (socket == NULL)
-    return NULL;
-
-  socket->m_fd                  = INVALID_SOCKET;
-  for (i=0;i<GSOCK_MAX_EVENT;i++)
-  {
-    socket->m_cbacks[i]         = NULL;
-  }
-  socket->m_detected            = 0;
-  socket->m_local               = NULL;
-  socket->m_peer                = NULL;
-  socket->m_error               = GSOCK_NOERROR;
-  socket->m_server              = FALSE;
-  socket->m_stream              = TRUE;
-  socket->m_gui_dependent       = NULL;
-  socket->m_non_blocking        = FALSE;
-  socket->m_timeout             = 10*60*1000;
-                                /* 10 minutes * 60 sec * 1000 millisec */
-  socket->m_establishing        = FALSE;
-
-  socket->m_functions           = &gs_base_functions;
-
-  /* Per-socket GUI-specific initialization */
-  success = _GSocket_GUI_Init_Socket(socket);
-  if (!success)
-  {
-    free(socket);
-    return NULL;
-  }
-
-  return socket;
-}
-
-void GSocket_close(GSocket *socket)
-{
-    _GSocket_Disable_Events(socket);
-    close(socket->m_fd);
-    socket->m_fd = INVALID_SOCKET;
-}
-
-void GSocket_destroy(GSocket *socket)
-{
-  assert(socket != NULL);
-
-  /* Check that the socket is really shutdowned */
-  if (socket->m_fd != INVALID_SOCKET)
-    GSocket_Shutdown(socket);
-
-  /* Per-socket GUI-specific cleanup */
-  _GSocket_GUI_Destroy_Socket(socket);
-
-  /* Destroy private addresses */
-  if (socket->m_local)
-    GAddress_destroy(socket->m_local);
-
-  if (socket->m_peer)
-    GAddress_destroy(socket->m_peer);
-
-  /* Destroy the socket itself */
-  free(socket);
-}
-
-/* GSocket_Shutdown:
- *  Disallow further read/write operations on this socket, close
- *  the fd and disable all callbacks.
- */
-void GSocket_Shutdown(GSocket *socket)
-{
-  int evt;
-
-  assert(socket != NULL);
-
-  /* If socket has been created, shutdown it */
-  if (socket->m_fd != INVALID_SOCKET)
-  {
-    shutdown(socket->m_fd, 2);
-    GSocket_close(socket);
-  }
-
-  /* Disable GUI callbacks */
-  for (evt = 0; evt < GSOCK_MAX_EVENT; evt++)
-    socket->m_cbacks[evt] = NULL;
-
-  socket->m_detected = GSOCK_LOST_FLAG;
-}
-
-/* Address handling */
-
-/* GSocket_SetLocal:
- * GSocket_GetLocal:
- * GSocket_SetPeer:
- * GSocket_GetPeer:
- *  Set or get the local or peer address for this socket. The 'set'
- *  functions return GSOCK_NOERROR on success, an error code otherwise.
- *  The 'get' functions return a pointer to a GAddress object on success,
- *  or NULL otherwise, in which case they set the error code of the
- *  corresponding GSocket.
- *
- *  Error codes:
- *    GSOCK_INVSOCK - the socket is not valid.
- *    GSOCK_INVADDR - the address is not valid.
- */
-GSocketError GSocket_SetLocal(GSocket *socket, GAddress *address)
-{
-  assert(socket != NULL);
-
-  /* the socket must be initialized, or it must be a server */
-  if ((socket->m_fd != INVALID_SOCKET && !socket->m_server))
-  {
-    socket->m_error = GSOCK_INVSOCK;
-    return GSOCK_INVSOCK;
-  }
-
-  /* check address */
-  if (address == NULL || address->m_family == GSOCK_NOFAMILY)
-  {
-    socket->m_error = GSOCK_INVADDR;
-    return GSOCK_INVADDR;
-  }
-
-  if (socket->m_local)
-    GAddress_destroy(socket->m_local);
-
-  socket->m_local = GAddress_copy(address);
-
-  return GSOCK_NOERROR;
-}
-
-GSocketError GSocket_SetPeer(GSocket *socket, GAddress *address)
-{
-  assert(socket != NULL);
-
-  /* check address */
-  if (address == NULL || address->m_family == GSOCK_NOFAMILY)
-  {
-    socket->m_error = GSOCK_INVADDR;
-    return GSOCK_INVADDR;
-  }
-
-  if (socket->m_peer)
-    GAddress_destroy(socket->m_peer);
-
-  socket->m_peer = GAddress_copy(address);
-
-  return GSOCK_NOERROR;
-}
-
-GAddress *GSocket_GetLocal(GSocket *socket)
-{
-  GAddress *address;
-  struct sockaddr addr;
-  SOCKLEN_T size = sizeof(addr);
-  GSocketError err;
-
-  assert(socket != NULL);
-
-  /* try to get it from the m_local var first */
-  if (socket->m_local)
-    return GAddress_copy(socket->m_local);
-
-  /* else, if the socket is initialized, try getsockname */
-  if (socket->m_fd == INVALID_SOCKET)
-  {
-    socket->m_error = GSOCK_INVSOCK;
-    return NULL;
-  }
-
-  if (getsockname(socket->m_fd, &addr, (SOCKLEN_T *) &size) < 0)
-  {
-    socket->m_error = GSOCK_IOERR;
-    return NULL;
-  }
-
-  /* got a valid address from getsockname, create a GAddress object */
-  address = GAddress_new();
-  if (address == NULL)
-  {
-    socket->m_error = GSOCK_MEMERR;
-    return NULL;
-  }
-
-  err = _GAddress_translate_from(address, &addr, size);
-  if (err != GSOCK_NOERROR)
-  {
-    GAddress_destroy(address);
-    socket->m_error = err;
-    return NULL;
-  }
-
-  return address;
-}
-
-GAddress *GSocket_GetPeer(GSocket *socket)
-{
-  assert(socket != NULL);
-
-  /* try to get it from the m_peer var */
-  if (socket->m_peer)
-    return GAddress_copy(socket->m_peer);
-
-  return NULL;
-}
-
 /* Server specific parts */
 
 /* GSocket_SetServer:
@@ -1818,5 +1575,5 @@ GSocketError GAddress_UNIX_GetPath(GAddress *address, char *path, size_t sbuf)
 
   return GSOCK_NOERROR;
 }
-#endif  /* !defined(__VISAGECPP__) */
+#endif
 #endif  /* wxUSE_SOCKETS || defined(__GSOCKET_STANDALONE__) */
