@@ -24,7 +24,7 @@
  *          Guillermo Rodriguez Garcia <guille@iies.es> (maintainer)
  * Purpose: GSocket main Unix file
  * Licence: The wxWindows licence
- * CVSID:   $Id: gsocket.c,v 1.13 2004/08/13 15:51:08 HopeSeekr Exp $
+ * CVSID:   $Id: gsocket.c,v 1.15 2004/08/26 07:23:48 HopeSeekr Exp $
  * -------------------------------------------------------------------------
  */
 
@@ -32,6 +32,15 @@
  * PLEASE don't put C++ comments here - this is a C source file.
  */
 
+#include <wx/version.h>                     // Needed for wxCHECK_VERSION
+
+#if defined(__WXUNIVERSAL__)
+#elif wxCHECK_VERSION(2, 5, 0)
+
+#include "gsocket-2.5.c"
+
+#else
+
 #ifndef __GSOCKET_STANDALONE__
 #include "wx/setup.h"
 #endif
@@ -1719,4 +1728,4 @@ GSocketError GAddress_UNIX_GetPath(GAddress *address, char *path, size_t sbuf)
 }
 
 #endif  /* wxUSE_SOCKETS || defined(__GSOCKET_STANDALONE__) */
-
+#endif  /* wxCHECK_VERSION(2, 5, 0) */
