@@ -1,3 +1,22 @@
+// This file is a part of the xMule Project.
+//
+// Copyright (c) 2004 Theodore R. Smith (donate@xmule.org / http://www.xmule.org/)
+// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
+//
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation; either
+// version 2 of the License, or (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
 /* GTK - The GIMP Toolkit
  * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
  *
@@ -37,7 +56,6 @@
 
 static void            gtk_plug_xembed_class_init            (GtkPlugXEmbedClass *klass);
 static void            gtk_plug_xembed_init                  (GtkPlugXEmbed      *plug);
-static void            gtk_plug_xembed_finalize              (GtkObject          *object);
 static void            gtk_plug_xembed_realize               (GtkWidget          *widget);
 static void            gtk_plug_xembed_unrealize             (GtkWidget          *widget);
 static void            gtk_plug_xembed_show                  (GtkWidget          *widget);
@@ -649,8 +667,10 @@ gtk_plug_xembed_set_focus (GtkWindow *window,
    */
 #ifdef __GTK2__
   if (focus && !window->has_focus)
-#else
+#elif GTK_CHECK_VERSION(1,2,9)
   if (focus && !window->window_has_focus)
+#else
+  if (focus)
 #endif
     {
       send_xembed_message (plug, XEMBED_REQUEST_FOCUS, 0, 0, 0,
