@@ -52,38 +52,6 @@ static char THIS_FILE[] = __FILE__;
 
 )
 {
-#if 0
-    char drive[_MAX_DRIVE];
-    char dir[_MAX_DIR];
-    char fname[_MAX_FNAME];
-    char ext[_MAX_EXT];
-    _splitpath(strFileName, drive, dir, fname, ext);
-    if (! drive[0])
-    {
-        //PathCanonicalize(..) doesn't work with for all Plattforms !
-        wxString strModule;
-        if (bModulPath)
-        {
-            GetModuleFileName(NULL, strModule.GetBuffer(MAX_INI_BUFFER), MAX_INI_BUFFER);
-            strModule.ReleaseBuffer();
-        }
-        else
-        {
-            GetCurrentDirectory(MAX_INI_BUFFER, strModule.GetBuffer(MAX_INI_BUFFER));
-            strModule.ReleaseBuffer();
-            // fix by "cpp@world-online.no"
-            strModule.TrimRight('\\');
-            strModule.TrimRight('/');
-            strModule += "\\";
-        }
-        strModule.ReleaseBuffer();
-        _splitpath(strModule, drive, dir, fname, ext);
-        strModule = drive;
-        strModule += dir;
-        strModule += strFileName;
-        strFileName = strModule;
-    }
-#endif
 }
 
     /*static*/
@@ -100,37 +68,6 @@ wxString CIni::GetDefaultSection()
 
 )
 {
-#if 0
-    char drive[_MAX_DRIVE];
-    char dir[_MAX_DIR];
-    char fname[_MAX_FNAME];
-    char ext[_MAX_EXT];
-    wxString strTemp;
-    wxString strApplName;
-    GetModuleFileName(NULL, strTemp.GetBuffer(MAX_INI_BUFFER), MAX_INI_BUFFER);
-    strTemp.ReleaseBuffer();
-    _splitpath(strTemp, drive, dir, fname, ext);
-    //"ApplName":
-    strTemp = fname;
-    //"ApplName.ini":
-    strTemp += ".ini";
-    if (bModulPath)
-    {
-        strApplName = drive;
-        strApplName += dir;
-        strApplName += strTemp;
-    }
-    else
-    {
-        GetCurrentDirectory(MAX_INI_BUFFER, strApplName.GetBuffer(MAX_INI_BUFFER));
-        strApplName.ReleaseBuffer();
-        strApplName.TrimRight('\\');
-        strApplName.TrimRight('/');
-        strApplName += "\\";
-        strApplName += strTemp;
-    }
-    return strApplName;
-#endif
     return "perse";
 }
 
@@ -316,20 +253,6 @@ wxPoint CIni::GetPoint(wxString strEntry, wxPoint ptDefault, LPCSTR strSection)
 
 wxRect CIni::GetRect(wxString strEntry, wxRect rectDefault, LPCSTR strSection)
 {
-#if 0
-    wxRect rectReturn = rectDefault;
-    wxString strDefault;
-    //old version :strDefault.Format("(%d,%d,%d,%d)",rectDefault.top,rectDefault.left,rectDefault.bottom,rectDefault.right);
-    strDefault.Format("%d,%d,%d,%d", rectDefault.left, rectDefault.top, rectDefault.right, rectDefault.bottom);
-    wxString strRect = GetString(strEntry, strDefault);
-    int nRead = 0;
-    //new Version found
-    if (4 == sscanf(strRect, "%d,%d,%d,%d", &rectDefault.left, &rectDefault.top, &rectDefault.right, &rectDefault.bottom))
-    return rectReturn;
-    //old Version found
-    sscanf(strRect, "(%d,%d,%d,%d)", &rectReturn.top, &rectReturn.left, &rectReturn.bottom, &rectReturn.right);
-    return rectReturn;
-#endif
     return wxRect(0, 0, 0, 0);
 }
 
@@ -459,18 +382,6 @@ wxChar *CIni::GetLPCSTR(wxString strEntry, const wxChar *strSection, const wxCha
     cb->Flush();
     memcpy(m_chBuffer, stringu.GetData(), stringu.Length() + 1);
     return m_chBuffer;
-#if 0
-    // evtl Section neu setzen
-    if (strSection != NULL)
-    m_strSection = strSection;
-    wxString temp;
-    if (strDefault == NULL)
-    temp = Read(m_strFileName, m_strSection, strEntry, wxString());
-    else
-    temp = Read(m_strFileName, m_strSection, strEntry, strDefault);
-    // '+1' damit die Null am Ende mit kopiert wird:
-    return(wxChar *) memcpy(m_chBuffer, (LPCTSTR) temp.GetData(), temp.Length() + 1);
-#endif
 }
 
 void CIni::SerGetString(BOOL bGet, wxString &str, wxString strEntry, LPCSTR strSection, LPCSTR strDefault)
