@@ -23,7 +23,7 @@
 // Author:      Vadim Zeitlin
 // Modified by:
 // Created:     04.12.99
-// RCS-ID:      $Id: listbase.h,v 1.11 2004/08/13 15:51:08 HopeSeekr Exp $
+// RCS-ID:      $Id: listbase.h,v 1.12 2004/08/23 05:53:30 HopeSeekr Exp $
 // Copyright:   (c) wxWindows team
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -37,6 +37,9 @@
 
 #if wxUSE_LISTCTRL
 
+#include <wx/colour.h>
+#include <wx/font.h>
+
 // ----------------------------------------------------------------------------
 // types
 // ----------------------------------------------------------------------------
@@ -399,7 +402,7 @@ public:
     int GetCode() const { return GetKeyCode(); }
 #endif // WXWIN_COMPATIBILITY_2_2
 
-    virtual wxEvent *Clone() const { return new wxListEvent(*this); }
+    virtual wxCommandEvent *Clone() const { return new wxListEvent(*this); }
 
 //protected: -- not for backwards compatibility
     int           m_code;
@@ -437,7 +440,7 @@ BEGIN_DECLARE_EVENT_TYPES()
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_ITEM_ACTIVATED, 715)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_CACHE_HINT, 716)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_RIGHT_CLICK, 717)
-	DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_MIDDLE_CLICK, 718)
+        DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_MIDDLE_CLICK, 718)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_BEGIN_DRAG, 719)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_DRAGGING, 720)
     DECLARE_EVENT_TYPE(wxEVT_COMMAND_LIST_COL_END_DRAG, 721)
