@@ -18,11 +18,12 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "mfc.h"
+    #include "xmule-headers.h"
 #endif
-#include <wx/listimpl.cpp>              // Needed for WX_DEFINE_LIST
+
+#include "mfc.h"                            // Needed for this Interface's Prototype
+
+#include <wx/listimpl.cpp>                  // Needed for WX_DEFINE_LIST
 
 WX_DEFINE_LIST(stringList)
 
