@@ -22,9 +22,9 @@
 // wrappers for required MFC classes
 // makes life a bit less annoying
 
-#include <wx/list.h>                    // Needed for WX_DECLARE_LIST
-#include <wx/hashmap.h>                 // Needed for WX_DECLARE_HASH_MAP
-#include <wx/dynarray.h>                // Needed for WX_DEFINE_ARRAY
+#include <wx/list.h>                        // Needed for WX_DECLARE_LIST
+#include <wx/hashmap.h>                     // Needed for WX_DECLARE_HASH_MAP
+#include <wx/dynarray.h>                    // Needed for WX_DEFINE_ARRAY
 
 WX_DEFINE_ARRAY(void *, VoidArray);
 WX_DECLARE_LIST(void, VoidList);
@@ -33,15 +33,10 @@ WX_DECLARE_HASH_MAP(unsigned int, void *, wxIntegerHash, wxIntegerEqual, VoidHas
 typedef struct
 {
     VoidHash::iterator it;
-    VoidList::Node *node;
 } _POSITION;
 
 typedef _POSITION *POSITION;
 
-//typedef void* POSITION;
-#ifndef __NOGTK__
-#include <glib.h>
-#endif
 // basic list
 // ok, own implementation. you can't do the reasonaby otherwise
 template < class TYPE, class ARG_TYPE >
@@ -54,7 +49,6 @@ class CList: public wxObject
     }
     MYNODE;
     protected:
-    //VoidList internalList;
     MYNODE *internalList;
     MYNODE *tail;
     int count;
@@ -85,19 +79,16 @@ class CList: public wxObject
     int GetCount() const
     {
         return count;
-        //g_list_length(internalList);
     }
     ;
     int GetSize() const
     {
         return count;
-        //g_list_length(internalList);
     }
     ;
     bool IsEmpty() const
     {
         return count == 0;
-        //g_list_length(internalList)==0;
     }
     ;
     TYPE &GetHead()
@@ -492,7 +483,7 @@ class CStringList: public stringList
     { }
     POSITION GetHeadPosition()
     {
-        return(POSITION) GetFirst();
+        return (POSITION)GetFirst();
     }
     CString GetNext(POSITION &pos)
     {
@@ -509,13 +500,6 @@ class CStringList: public stringList
     }
 };
 
-// default hasher
-template <class ARG_KEY>
-unsigned int HashKey(ARG_KEY key)
-{
-    return((unsigned int)(void *)(unsigned long) key);
-}
-
 template < class KEY, class ARG_KEY, class VALUE, class ARG_VALUE >
 class CMap: public wxObject
 {
