@@ -20,21 +20,17 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "otherfunctions.h"
-#	include "PartFile.h"
-#	include "Preferences.h"
-#	include "resource.h"
-#	include "types.h"
-#	include "wintypes.h"
-#	include "xmule.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <map>                              // Needed for std::map
+#include "otherfunctions.h"                 // Needed for this Interface's Prototype
 
-#include <wx/utils.h>
-#include <wx/file.h>                    // Needed for wxFile
+#include "PartFile.h"                       // Needed for CPartFile
+#include "Preferences.h"                    // Needed for CPreferences
+#include "xmule.h"                          // Needed for theApp
+
+#include <map>                              // Needed for std::map
+#include <wx/file.h>                        // Needed for wxFile
 
 #define itemsof(x) (sizeof(x)/sizeof(x[0]))
 
@@ -44,7 +40,8 @@ wxString GetResString(unsigned int uStringID)
 
     if (msgs.empty())
     {
-#include "strings.en"
+#include "resource.h"                       // Needed for strings' IDs
+#include "strings.en"                       // Needed for strings
         for (unsigned int a = 0; a < itemsof(_resStrings); ++a)
         {
             msgs[_resStrings[a].id] = wxString(_resStrings[a].resstr, *wxConvCurrent);
@@ -54,196 +51,126 @@ wxString GetResString(unsigned int uStringID)
 }
 
 // Base chars for encode an decode functions
-static BYTE base16Chars[17] = "0123456789ABCDEF";
+static wxByte base16Chars[17] = "0123456789ABCDEF";
 
-static BYTE base32Chars[33] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567";
+static wxByte base32Chars[33] = "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567";
 
 #define BASE16_LOOKUP_MAX 23
-static BYTE base16Lookup[BASE16_LOOKUP_MAX][2] =
+static wxByte base16Lookup[BASE16_LOOKUP_MAX][2] =
 {
-    {
-        '0', 0x0
-    }
-    ,
-    {
-        '1', 0x1
-    }
-    ,
-    {
-        '2', 0x2
-    }
-    ,
-    {
-        '3', 0x3
-    }
-    ,
-    {
-        '4', 0x4
-    }
-    ,
-    {
-        '5', 0x5
-    }
-    ,
-    {
-        '6', 0x6
-    }
-    ,
-    {
-        '7', 0x7
-    }
-    ,
-    {
-        '8', 0x8
-    }
-    ,
-    {
-        '9', 0x9
-    }
-    ,
-    {
-        ':', 0x9
-    }
-    ,
-    {
-        ';', 0x9
-    }
-    ,
-    {
-        '<', 0x9
-    }
-    ,
-    {
-        '=', 0x9
-    }
-    ,
-    {
-        '>', 0x9
-    }
-    ,
-    {
-        '?', 0x9
-    }
-    ,
-    {
-        '@', 0x9
-    }
-    ,
-    {
-        'A', 0xA
-    }
-    ,
-    {
-        'B', 0xB
-    }
-    ,
-    {
-        'C', 0xC
-    }
-    ,
-    {
-        'D', 0xD
-    }
-    ,
-    {
-        'E', 0xE
-    }
-    ,
-    {
-        'F', 0xF
-    }
-}
+    { '0', 0x0 },
+    { '1', 0x1 },
+    { '2', 0x2 },
+    { '3', 0x3 },
+    { '4', 0x4 },
+    { '5', 0x5 },
+    { '6', 0x6 },
+    { '7', 0x7 },
+    { '8', 0x8 },
+    { '9', 0x9 },
+    { ':', 0x9 },
+    { ';', 0x9 },
+    { '<', 0x9 },
+    { '=', 0x9 },
+    { '>', 0x9 },
+    { '?', 0x9 },
+    { '@', 0x9 },
+    { 'A', 0xA },
+    { 'B', 0xB },
+    { 'C', 0xC },
+    { 'D', 0xD },
+    { 'E', 0xE },
+    { 'F', 0xF }
+};
 
-;
-
-CString CastItoXBytes(uint64 count)
+wxString CastItoXBytes(wxUint64 count)
 {
-    CString buffer;
+    wxString buffer;
     if (count < 1024)
     {
-        buffer.Format("%.0f %s", (float) count, GetResString(IDS_BYTES) .GetData());
+        buffer.Printf("%.0f %s", (float) count, GetResString(IDS_BYTES) .GetData());
     }
     else if(count < 1048576)
     {
-        buffer.Format("%.0f %s", (float) count/1024, GetResString(IDS_KBYTES) .GetData());
+        buffer.Printf("%.0f %s", (float) count/1024, GetResString(IDS_KBYTES) .GetData());
     }
     else if(count < 1073741824)
     {
-        buffer.Format("%.2f %s", (float) count/1048576, GetResString(IDS_MBYTES) .GetData());
+        buffer.Printf("%.2f %s", (float) count/1048576, GetResString(IDS_MBYTES) .GetData());
     }
     else if (count < 1099511627776LL)
     {
-        buffer.Format("%.2f %s", (float) count/1073741824, GetResString(IDS_GBYTES) .GetData());
+        buffer.Printf("%.2f %s", (float) count/1073741824, GetResString(IDS_GBYTES) .GetData());
     }
     else
     {
-        buffer.Format("%.3f %s", (float) count/1099511627776LL, GetResString(IDS_TBYTES) .GetData());
+        buffer.Printf("%.3f %s", (float) count/1099511627776LL, GetResString(IDS_TBYTES) .GetData());
     }
     return buffer;
 }
 
-CString CastItoIShort(uint64 count)
+wxString CastItoIShort(wxUint64 count)
 {
-    CString output;
+    wxString output;
     if (count < 1000)
     {
-        output.Format("%i", count);
+        output.Printf("%i", count);
     }
     else if(count < 1000000)
     {
-        output.Format("%.0f%s", (float) count/1000, GetResString(IDS_KILO) .GetData());
+        output.Printf("%.0f%s", (float) count/1000, GetResString(IDS_KILO) .GetData());
     }
     else if(count < 1000000000)
     {
-        output.Format("%.2f%s", (float) count/1000000, GetResString(IDS_MEGA) .GetData());
+        output.Printf("%.2f%s", (float) count/1000000, GetResString(IDS_MEGA) .GetData());
     }
     else if(count < 1000000000000LL)
     {
-        output.Format("%.2f%s", (float) count/1000000000LL, GetResString(IDS_GIGA) .GetData());
+        output.Printf("%.2f%s", (float) count/1000000000LL, GetResString(IDS_GIGA) .GetData());
     }
     else if(count < 1000000000000000LL)
     {
-        output.Format("%.2f%s", (float) count/1000000000000LL, GetResString(IDS_TERRA) .GetData());
+        output.Printf("%.2f%s", (float) count/1000000000000LL, GetResString(IDS_TERRA) .GetData());
     }
     return output;
 }
 
-CString CastSecondsToHM(sint32 count)
+wxString CastSecondsToHM(wxInt32 count)
 {
-    CString buffer;
+    wxString buffer;
     if (count < 0)
     {
         buffer = "?";
     }
     else if(count < 60)
     {
-        buffer.Format("%i %s", count, GetResString(IDS_SECS) .GetData());
+        buffer.Printf("%i %s", count, GetResString(IDS_SECS) .GetData());
     }
     else if(count < 3600)
     {
-        buffer.Format("%i:%s %s", count/60, LeadingZero(count - (count/60) *60) .GetData(), GetResString(IDS_MINS) .GetData());
+        buffer.Printf("%i:%s %s", count/60, LeadingZero(count - (count/60) *60) .GetData(), GetResString(IDS_MINS) .GetData());
     }
     else if(count < 86400)
     {
-        buffer.Format("%i:%s %s", count/3600, LeadingZero((count - (count/3600) *3600) /60) .GetData(), GetResString(IDS_HOURS) .GetData());
+        buffer.Printf("%i:%s %s", count/3600, LeadingZero((count - (count/3600) *3600) /60) .GetData(), GetResString(IDS_HOURS) .GetData());
     }
     else
     {
-        buffer.Format("%i %s %i %s", count/86400, GetResString(IDS_DAYS) .GetData(), (count - (count/86400) *86400) /3600, GetResString(IDS_HOURS) .GetData());
+        buffer.Printf("%i %s %i %s", count/86400, GetResString(IDS_DAYS) .GetData(), (count - (count/86400) *86400) /3600, GetResString(IDS_HOURS) .GetData());
     }
     return buffer;
 }
 
-CString LeadingZero(uint32 units)
+wxString LeadingZero(wxUint32 units)
 {
-    CString temp;
+    wxString temp;
     if (units < 10)
     {
-        temp.Format("0%i", units);
+        temp.Printf("0%i", units);
     }
     else
     {
-        temp.Format("%i", units);
+        temp.Printf("%i", units);
     }
     return temp;
 }
@@ -300,7 +227,7 @@ void URLDecode(wxString &result, const char *buff)
         if (buff[x] == '%' &&x + 2 < buflen &&IsHexDigit(buff[x + 1]) &&IsHexDigit(buff[x + 2]))
         {
             char hexstr[3];
-            // Copy the two BYTEs following the %
+            // Copy the two wxBytes following the %
             strncpy(hexstr, &buff[x + 1], 2);
             // Skip over the hex
             x = x + 2;
@@ -321,14 +248,14 @@ wxString URLEncode(wxString sIn)
 {
     wxString sOut;
     const int nLen = sIn.Length() + 1;
-    register LPBYTE pOutTmp = NULL;
-    LPBYTE pOutBuf = NULL;
-    register LPBYTE pInTmp = NULL;
+    register wxByte* pOutTmp = NULL;
+    wxByte* pOutBuf = NULL;
+    register wxByte* pInTmp = NULL;
     //GetData(); //GetBuffer(nLen);:
-    LPBYTE pInBuf = (LPBYTE) sIn.GetWriteBuf(nLen);
+    wxByte* pInBuf = (wxByte*) sIn.GetWriteBuf(nLen);
     //alloc out buffer
-    //GetData(); //GetBuffer(nLen  * 3 - 2);//new BYTE [nLen  * 3];:
-    pOutBuf = (LPBYTE) sOut.GetWriteBuf(nLen *3 - 2);
+    //GetData(); //GetBuffer(nLen  * 3 - 2);//new wxByte [nLen  * 3];:
+    pOutBuf = (wxByte*) sOut.GetWriteBuf(nLen *3 - 2);
     if (pOutBuf)
     {
         pInTmp = pInBuf;
@@ -360,11 +287,6 @@ wxString URLEncode(wxString sIn)
     return sOut;
 }
 
-inline BYTE toHex(const BYTE &x)
-{
-    return x > 9 ? x + 55: x + 48;
-}
-
 int GetFTIDbyName(wxString infile)
 {
     int i;
@@ -428,10 +350,6 @@ int GetFTIDbyName(wxString infile)
 wxString GetFiletypeByName(wxString infile)
 {
     wxString ext;
-    // For what was this ???  PLK
-#if 0
-    if (infile.ReverseFind('.') == - 1) return GetResString(IDS_SEARCH_ANY);
-#endif
     // For what is this ??? PLK
     if (infile.Find('.', TRUE) == - 1) return GetResString(IDS_SEARCH_ANY);
     // ext == extension of the filename (Search Result) PLK
@@ -478,101 +396,10 @@ wxString MakeStringEscaped(wxString in)
 
 bool Ask4RegFix(bool checkOnly)
 {
-#if 0
-    // check registry if ed2k links is assigned to xmule
-    CRegKey regkey;
-    regkey.Create(HKEY_CLASSES_ROOT, "ed2k\\shell\\open\\command");
-    ULONG maxsize = 500;
-    TCHAR rbuffer[500];
-    char modbuffer[490];
-    char regbuffer[520];
-    regkey.QueryStringValue(0, rbuffer, &maxsize);
-    ::GetModuleFileName(0, modbuffer, 490);
-    sprintf(regbuffer, "\"%s\" \"%%1\"", modbuffer);
-    if (strcmp(rbuffer, regbuffer))
-    {
-        if (checkOnly) return true;
-        if (MessageBox(0, GetResString(IDS_ASSIGNED2K), GetResString(IDS_ED2KLINKFIX), MB_ICONQUESTION |MB_YESNO) == IDYES)
-        {
-            regkey.SetStringValue(0, regbuffer);
-            // Added Shrink:
-            regkey.Create(HKEY_CLASSES_ROOT, "ed2k\\DefaultIcon");
-            regkey.SetStringValue(0, modbuffer);
-            regkey.Create(HKEY_CLASSES_ROOT, "ed2k");
-            regkey.SetStringValue(0, "URL: ed2k Protocol");
-            regkey.SetStringValue("URL Protocol", "");
-        }
-    }
-    regkey.Close();
-    return false;
-#endif
     return true;
 }
 
-int GetMaxConnections()
-{
-#if 0
-    OSVERSIONINFOEX osvi;
-    ZeroMemory( &osvi, sizeof(OSVERSIONINFOEX));
-    osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEX);
-    if (!GetVersionEx((OSVERSIONINFO *) &osvi))
-    {
-        //if OSVERSIONINFOEX doesn't work, try OSVERSIONINFO
-        osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
-        if (!GetVersionEx((OSVERSIONINFO *) &osvi))
-        //shouldn't ever happen:
-        return - 1;
-    }
-    // Windows NT product family:
-    if (osvi.dwPlatformId == VER_PLATFORM_WIN32_NT)
-    //no limits:
-    return - 1;
-    if (osvi.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS)
-    {
-        // Windows 95 product family
-        if (osvi.dwMajorVersion == 4 &&osvi.dwMinorVersion == 0)
-        {
-            //old school 95
-            HKEY hKey;
-            DWORD dwValue;
-            DWORD dwLength = sizeof(dwValue);
-            LONG lResult;
-            RegOpenKeyEx(HKEY_LOCAL_MACHINE, "System\\CurrentControlSet\\Services\\VxD\\MSTCP",
-            0, KEY_QUERY_VALUE, &hKey);
-            lResult = RegQueryValueEx(hKey, TEXT("MaxConnections"), NULL, NULL,
-            (LPBYTE) &dwValue, &dwLength);
-            RegCloseKey(hKey);
-            if (lResult != ERROR_SUCCESS || lResult < 1)
-            //the default for 95 is 100:
-            return 100;
-            return dwValue;
-        }
-        else
-        {
-            //98 or ME
-            HKEY hKey;
-            TCHAR szValue[32];
-            DWORD dwLength = sizeof(szValue);
-            LONG lResult;
-            RegOpenKeyEx(HKEY_LOCAL_MACHINE, "System\\CurrentControlSet\\Services\\VxD\\MSTCP",
-            0, KEY_QUERY_VALUE, &hKey);
-            lResult = RegQueryValueEx(hKey, TEXT("MaxConnections"), NULL, NULL,
-            (LPBYTE) szValue, &dwLength);
-            RegCloseKey(hKey);
-            LONG lMaxConnections;
-            if (lResult != ERROR_SUCCESS || (lMaxConnections = atoi(szValue)) < 1)
-            //the default for 98/ME is 100:
-            return 100;
-            return lMaxConnections;
-        }
-    }
-    //give the user the benefit of the doubt, most use NT+ anyway:
-    return - 1;
-#endif
-    return - 1;
-}
-
-CString GetRateString(uint16 rate)
+wxString GetRateString(wxUint16 rate)
 {
     switch (rate)
     {
@@ -598,28 +425,22 @@ CString GetRateString(uint16 rate)
     return GetResString(IDS_CMT_NOTRATED);
 }
 
-WORD DetectWinVersion()
-{
-    // we are at least this good
-    return _WINVER_XP_;
-}
-
-// Returns a BASE32 encoded BYTE array
+// Returns a BASE32 encoded wxByte array
 //
 // [In]
-//   buffer: Pointer to BYTE array
+//   buffer: Pointer to wxByte array
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   CString object with BASE32 encoded BYTE array
-CString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
+//   wxString object with BASE32 encoded wxByte array
+wxString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
 {
-    CString Base32Buff;
+    wxString Base32Buff;
     unsigned int i, index;
     unsigned char word;
     for (i = 0, index = 0 ; i < bufLen ;)
     {
-        // Is the current word going to span a BYTE boundary?
+        // Is the current word going to span a wxByte boundary?
         if (index > 3)
         {
             word = (buffer[i] & (0xFF >> index));
@@ -641,17 +462,17 @@ CString EncodeBase32(const unsigned char *buffer, unsigned int bufLen)
     return Base32Buff;
 }
 
-// Returns a BASE16 encoded BYTE array
+// Returns a BASE16 encoded wxByte array
 //
 // [In]
-//   buffer: Pointer to BYTE array
+//   buffer: Pointer to wxByte array
 //   bufLen: Lenght of buffer array
 //
 // [Return]
-//   CString object with BASE16 encoded BYTE array
-CString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
+//   wxString object with BASE16 encoded wxByte array
+wxString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
 {
-    CString Base16Buff;
+    wxString Base16Buff;
     for (unsigned int i = 0 ; i < bufLen ; i++)
     {
         Base16Buff += base16Chars[buffer[i] >> 4];
@@ -660,22 +481,22 @@ CString EncodeBase16(const unsigned char *buffer, unsigned int bufLen)
     return Base16Buff;
 }
 
-// Decodes a BASE16 string into a BYTE array
+// Decodes a BASE16 string into a wxByte array
 //
 // [In]
 //   base16Buffer: String containing BASE16
 //   base16BufLen: Lenght BASE16 coded string's length
 //
 // [Out]
-//   buffer: BYTE array containing decoded string
-void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, BYTE *buffer)
+//   buffer: wxByte array containing decoded string
+void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, wxByte *buffer)
 {
     memset(buffer, 0, DecodeLengthBase16(base16BufLen));
     for (unsigned int i = 0 ; i < base16BufLen ; i++)
     {
         int lookup = toupper(base16Buffer[i]) - '0';
         // Check to make sure that the given word falls inside a valid range
-        BYTE word = 0;
+        wxByte word = 0;
         if (lookup < 0 || lookup >= BASE16_LOOKUP_MAX)
         word = 0xFF;
         else
@@ -697,61 +518,13 @@ void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, BYTE *buf
 //   base16Length: Actual length of BASE16 string
 //
 // [Return]
-//   New length of BYTE array decoded
+//   New length of wxByte array decoded
 int DecodeLengthBase16(int base16Length)
 {
     return base16Length / 2;
 }
 
-#if 0
-void UpdateURLMenu(CMenu &menu, int &counter)
-{
-    counter = 0;
-    theApp.webservices.RemoveAll();
-    CString name, url, sbuffer;
-    char buffer[1024];
-    int lenBuf = 1024;
-    FILE *readFile = fopen(CString(theApp.glob_prefs->GetAppDir()) + "webservices.dat", "r");
-    if (readFile != NULL)
-    {
-        while (!feof(readFile))
-        {
-            if (fgets(buffer, lenBuf, readFile) == 0) break;
-            sbuffer = buffer;
-            // ignore comments & too short lines
-            if (sbuffer.GetAt(0) == '#' || sbuffer.GetAt(0) == '/' || sbuffer.GetLength() < 5)
-            continue;
-            int pos = sbuffer.Find(',');
-            if (pos > 0)
-            {
-                counter++;
-                menu.AppendMenu(MF_STRING, MP_WEBURL + (counter - 1), sbuffer.Left(pos) .Trim());
-                theApp.webservices.Add(sbuffer.Right(sbuffer.GetLength() - pos - 1) .Trim());
-            }
-        }
-        fclose(readFile);
-    }
-}
-
-#endif
-
-void RunURL(CAbstractFile *file, CString urlpattern)
-{
-#if 0
-    // Convert hash to hexadecimal text and add it to the URL
-    urlpattern.Replace("#hashid", EncodeBase16(file->GetFileHash(), 16));
-    // Add file size to the URL
-    CString temp;
-    temp.Format("%u", file->GetFileSize());
-    urlpattern.Replace("#filesize", temp);
-    // add filename to the url
-    urlpattern.Replace("#filename", URLEncode(file->GetFileName()));
-    // Open URL
-    ShellExecute(NULL, NULL, urlpattern, NULL, theApp.glob_prefs->GetAppDir(), SW_SHOWDEFAULT);
-#endif
-}
-
-CString GetCatTitle(int catid)
+wxString GetCatTitle(int catid)
 {
     switch (catid)
     {
@@ -771,7 +544,7 @@ CString GetCatTitle(int catid)
     case 13: return GetResString(IDS_SEARCH_PICS);
     case 14: return GetResString(IDS_TEXT);
     }
-    return CString("?");
+    return wxString("?");
 }
 
 bool CheckShowItemInGivenCat(CPartFile *file, int inCategory)
@@ -857,14 +630,6 @@ bool CheckShowItemInGivenCat(CPartFile *file, int inCategory)
     return(IsNotFiltered &&IsInCat);
 }
 
-#ifdef __FreeBSD__
-long long atoll(char *s)
-{
-    return strtoll(s, (char **) NULL, 10);
-}
-
-#endif /* __FreeBSD__ */
-
 void MakeFoldername(char *path)
 {
     wxString string(path);
@@ -875,14 +640,14 @@ void MakeFoldername(char *path)
 void HexDump(const void *buffer, unsigned long buflen)
 {
 #if defined(__DEBUG__)
-    const uint8 *cbuf = (const uint8 *) buffer;
+    const wxUint8 *cbuf = (const wxUint8 *) buffer;
     for (unsigned long ofs = 0 ; ofs < buflen ; /* no increment here */
     )
     {
         printf("%08lx", ofs);
         for (unsigned long i = 0 ; (i < 8) && (ofs < buflen) ; i++, ofs++)
         {
-            printf(" %02x", (int) cbuf[ofs]);
+            printf(" %02x", (int)cbuf[ofs]);
         }
         printf("\n");
     }
@@ -913,13 +678,16 @@ bool BackupFile(const wxString &filename, const wxString &appendix)
 bool SafeCopyFile(const wxString &file1, const wxString &file2)
 {
     wxFile fileIn(file1, wxFile::read);
+
     if (!fileIn.IsOpened())
     {
-        //		return FALSE;// for copying it the file could be open too!!
+        // for copying it the file could be open too!!
+        return FALSE;
     }
     wxFile fileOut(file2, wxFile::write);
     char buf[4096];
     size_t count;
+
     while (true)
     {
         count = fileIn.Read(buf, WXSIZEOF(buf));
@@ -936,10 +704,12 @@ bool SafeCopyFile(const wxString &file1, const wxString &file2)
             return FALSE;
         }
     }
+
     if (!fileIn.Close() || !fileOut.Close())
     {
         return FALSE;
     }
+
     return TRUE;
 }
 
