@@ -22,112 +22,116 @@
 #ifndef OTHERFUNS_H
 #define OTHERFUNS_H
 
-#include "mfc.h"                        // Needed for CString
-#include "types.h"                      // Needed for uint64
-#include "wintypes.h"                   // Needed for WORD
-#include <sys/time.h>                   // Needed for gettimeofday
+#include <sys/time.h>                       // Needed for gettimeofday
+#include <wx/string.h>                      // Needed for wxString
 
-#define ROUND(x) (floor((float)x+0.5f))
+#define ROUND(x) (std::floor((float)x + 0.5f))
 
-#define _WINVER_NT4_	0x0004
-#define _WINVER_95_		0x0004
-#define _WINVER_98_		0x0A04
-#define _WINVER_ME_		0x5A04
-#define _WINVER_2K_		0x0005
-#define _WINVER_XP_		0x0105
+class CPartFile;
 
-CString CastItoXBytes(uint64 count);
-CString CastItoIShort(uint64 number);
-CString CastSecondsToHM(sint32 seconds); //<<--9/21/02
-CString LeadingZero(uint32 units);
-void ShellOpenFile(CString name); //<<--9/21/02
+wxString CastItoXBytes(wxUint64 count);
+wxString CastItoIShort(wxUint64 number);
+wxString CastSecondsToHM(wxInt32 seconds); //<<--9/21/02
+wxString LeadingZero(wxUint32 units);
+void ShellOpenFile(wxString name); //<<--9/21/02
 wxString GetResString(unsigned int uStringID);//<<--10/01/02
 void MakeFoldername(char* path);
 
 void URLDecode(wxString& result, const char* buff);// Make a malloc'd decoded strnig from an URL encoded string (with escaped spaces '%20' and  the like
 wxString URLEncode(wxString sIn);
-inline BYTE toHex(const BYTE &x);
+
+inline wxByte toHex(const wxByte& x)
+{
+    return x > 9 ? x + 55: x + 48;
+}
+
 int GetFTIDbyName(wxString infile);
 wxString GetFiletypeByName(wxString infile);
 bool Ask4RegFix(bool checkOnly, bool dontAsk = false); // Barry - Allow forced update without prompt
 void BackupReg(void); // Barry - Store previous values
 void RevertReg(void); // Barry - Restore previous values
-int GetMaxConnections();
 wxString MakeStringEscaped(wxString in);
-//void RunURL(CAbstractFile* file,CString urlpattern);
+
 void HexDump(const void *buffer, unsigned long buflen);
 bool BackupFile(const wxString& filename, const wxString& appendix);
 
-class CPartFile;
-CString GetCatTitle(int catid);
+wxString GetCatTitle(int catid);
 bool CheckShowItemInGivenCat(CPartFile* file,int inCategory);
 
-WORD	DetectWinVersion();
-//_int64	GetFreeDiskSpaceX(PCHAR pDirectory);
-//For Rate File 
-CString GetRateString(uint16 rate);
-//void	UpdateURLMenu(CMenu &menu, int &counter);
+wxString GetRateString(wxUint16 rate);
 
 // From Gnucleus project [found by Tarod]
-CString EncodeBase32(const unsigned char* buffer, unsigned int bufLen);
-CString EncodeBase16(const unsigned char* buffer, unsigned int bufLen);
-int	DecodeLengthBase16(int base16Length);
+wxString EncodeBase32(const unsigned char* buffer, unsigned int bufLen);
+wxString EncodeBase16(const unsigned char* buffer, unsigned int bufLen);
+int DecodeLengthBase16(int base16Length);
 void DecodeBase16(const char *base16Buffer, unsigned int base16BufLen, unsigned char *buffer);
 
-__inline char* nstrdup(const char* src)
+inline char* nstrdup(const char* src)
 {
-	int len = (src ? strlen(src) : 0) + 1;
-	char *res = new char[len];
-	if ( src ) strcpy(res, src);
-	res[len-1] = 0;
-	return res;
+    int len = (src ? strlen(src) : 0) + 1;
+    char* res = new char[len];
+
+    if (src)
+    {
+        strcpy(res, src);
+    }
+    res[len - 1] = 0;
+
+    return res;
 }
 
 // md4cmp -- replacement for memcmp(hash1,hash2,16)
 // Like 'memcmp' this function returns 0, if hash1==hash2, and !0, if hash1!=hash2.
 // NOTE: Do *NOT* use that function for determining if hash1<hash2 or hash1>hash2.
-__inline int md4cmp(const void* hash1, const void* hash2) {
-	return !(((uint32*)hash1)[0] == ((uint32*)hash2)[0] &&
-		     ((uint32*)hash1)[1] == ((uint32*)hash2)[1] &&
-		     ((uint32*)hash1)[2] == ((uint32*)hash2)[2] &&
-		     ((uint32*)hash1)[3] == ((uint32*)hash2)[3]);
+inline int md4cmp(const void* hash1, const void* hash2)
+{
+    return !(((wxUint32*)hash1)[0] == ((wxUint32*)hash2)[0] &&
+             ((wxUint32*)hash1)[1] == ((wxUint32*)hash2)[1] &&
+             ((wxUint32*)hash1)[2] == ((wxUint32*)hash2)[2] &&
+             ((wxUint32*)hash1)[3] == ((wxUint32*)hash2)[3]);
 }
 
 // md4clr -- replacement for memset(hash,0,16)
-__inline void md4clr(const void* hash) {
-	((uint32*)hash)[0] = ((uint32*)hash)[1] = ((uint32*)hash)[2] = ((uint32*)hash)[3] = 0;
+inline void md4clr(const void* hash) {
+    ((wxUint32*)hash)[0] = ((wxUint32*)hash)[1] = ((wxUint32*)hash)[2] = ((wxUint32*)hash)[3] = 0;
 }
 
 // md4cpy -- replacement for memcpy(dst,src,16)
-__inline void md4cpy(const void* dst, const void* src) {
-	((uint32*)dst)[0] = ((uint32*)src)[0];
-	((uint32*)dst)[1] = ((uint32*)src)[1];
-	((uint32*)dst)[2] = ((uint32*)src)[2];
-	((uint32*)dst)[3] = ((uint32*)src)[3];
+inline void md4cpy(const void* dst, const void* src)
+{
+    ((wxUint32*)dst)[0] = ((wxUint32*)src)[0];
+    ((wxUint32*)dst)[1] = ((wxUint32*)src)[1];
+    ((wxUint32*)dst)[2] = ((wxUint32*)src)[2];
+    ((wxUint32*)dst)[3] = ((wxUint32*)src)[3];
 }
 
-#define	MAX_HASHSTR_SIZE (16*2+1)
-CString md4str(const uchar* hash);
-void md4str(const uchar* hash, char* pszHash);
+#define MAX_HASHSTR_SIZE (16*2+1)
 
-__inline int CompareUnsigned(uint32 uSize1, uint32 uSize2)
+inline int CompareUnsigned(wxUint32 uSize1, wxUint32 uSize2)
 {
-	if (uSize1 < uSize2)
-		return -1;
-	if (uSize1 > uSize2)
-		return 1;
-	return 0;
+    if (uSize1 < uSize2)
+    {
+        return -1;
+    }
+    else if (uSize1 > uSize2)
+    {
+        return 1;
+    }
+    return 0;
 }
 
 inline long GetTickCount()
-{	
-  struct timeval aika;
-  gettimeofday(&aika,NULL);
-  unsigned long secs=aika.tv_sec*1000;
-  secs+=(aika.tv_usec/1000);
-  return secs;
+{
+  struct timeval temp;
+  gettimeofday(&temp, NULL);
+  return (temp.tv_sec * 1000) + (temp.tv_usec / 1000);
 }
 
 bool SafeCopyFile(const wxString& file1, const wxString& file2);
 
+inline unsigned int form_version(unsigned int major, unsigned int minor, unsigned int release)
+{
+    return (major * 100000) + (minor * 1000) + (release * 100);
+}
+
 #endif
