@@ -20,18 +20,15 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "packets.h"
-#	include "NewFunctions.h"
+    #include "xmule-headers.h"
 #endif
 
-#include "otherstructs.h"               // Needed for Header_Struct
-#include "otherfunctions.h"             // Needed for nstrdup
+#include "packets.h"                        // Needed for this Interface's Prototype
 
-#ifdef _DEBUG
-#define new DEBUG_NEW
-#endif
+#include "CMemFile.h"                       // Needed for CMemFile
+#include "NewFunctions.h"                   // Needed for ascprintf
+#include "otherfunctions.h"                 // Needed for nstrdup
+#include "otherstructs.h"                   // Needed for Header_Struct
 
 void pckfilter(wxUint8 opcode, void * pbuffer, int length)
 {
@@ -55,7 +52,7 @@ void pckfilter(wxUint8 opcode, void * pbuffer, int length)
     }
 }
 
-Packet::Packet(uint8 protocol)
+Packet::Packet(wxUint8 protocol)
 {
     m_bSplitted = false;
     m_bLastSplitted = false;
@@ -82,7 +79,7 @@ Packet::Packet(unsigned char * header)
 }
 
 // -khaos--+++> Slightly modified for our stats uses...
-Packet::Packet(char * type, char * pPacketPart, uint32 nSize, bool bLast, bool bFromPF)
+Packet::Packet(char * type, char * pPacketPart, wxUint32 nSize, bool bLast, bool bFromPF)
 {
     // only used for splitted packets!
     m_bFromPF = bFromPF;
@@ -98,7 +95,7 @@ Packet::Packet(char * type, char * pPacketPart, uint32 nSize, bool bLast, bool b
 // -khaos--+++> Slightly modified for our stats uses...
 //				If m_bFromPF = true then packet was formed from a partfile
 //				If m_bFromPF = false then this packet was formed from a complete shared file.
-Packet::Packet(char * type, int8 in_opcode, uint32 in_size, uint8 protocol, bool bFromPF)
+Packet::Packet(char * type, wxInt8 in_opcode, wxInt32 in_size, wxUint8 protocol, bool bFromPF)
 {
     m_bFromPF = bFromPF;
     // <-----khaos-
@@ -122,7 +119,7 @@ Packet::Packet(char * type, int8 in_opcode, uint32 in_size, uint8 protocol, bool
     prot = protocol;
 }
 
-Packet::Packet(char * pPacketPart, uint32 nSize, bool bLast)
+Packet::Packet(char * pPacketPart, wxUint32 nSize, bool bLast)
 {
     // only used for splitted packets!
     m_bSplitted = true;
@@ -134,7 +131,7 @@ Packet::Packet(char * pPacketPart, uint32 nSize, bool bLast)
     size = nSize - 6;
 }
 
-Packet::Packet(int8 in_opcode, uint32 in_size, uint8 protocol, unsigned char * buffer)
+Packet::Packet(wxInt8 in_opcode, wxInt32 in_size, wxUint8 protocol, unsigned char * buffer)
 {
     m_bSplitted = false;
     m_bPacked = false;
@@ -156,7 +153,7 @@ Packet::Packet(int8 in_opcode, uint32 in_size, uint8 protocol, unsigned char * b
     prot = protocol;
 }
 
-Packet::Packet(int8 in_opcode, uint32 in_size, uint8 protocol)
+Packet::Packet(wxInt8 in_opcode, wxInt32 in_size, wxUint8 protocol)
 {
     m_bSplitted = false;
     m_bPacked = false;
@@ -178,7 +175,7 @@ Packet::Packet(int8 in_opcode, uint32 in_size, uint8 protocol)
     prot = protocol;
 }
 
-Packet::Packet(CMemFile * datafile, uint8 protocol)
+Packet::Packet(CMemFile * datafile, wxUint8 protocol)
 {
     m_bSplitted = false;
     m_bPacked = false;
@@ -288,7 +285,7 @@ void Packet::PackPacket()
 bool Packet::UnPackPacket(unsigned int uMaxDecompressedSize)
 {
     assert(prot == OP_PACKEDPROT);
-    uint32 nNewSize = size * 10 + 300;
+    wxUint32 nNewSize = size * 10 + 300;
     if (nNewSize > uMaxDecompressedSize)
     nNewSize = uMaxDecompressedSize;
     BYTE * unpack = new BYTE[nNewSize];
@@ -308,7 +305,7 @@ bool Packet::UnPackPacket(unsigned int uMaxDecompressedSize)
     return false;
 }
 
-CTag::CTag(char * name, uint32 intvalue)
+CTag::CTag(char * name, wxUint32 intvalue)
 {
     tag = new Tag_Struct;
     memset(tag, 0, sizeof(Tag_Struct));
@@ -317,7 +314,7 @@ CTag::CTag(char * name, uint32 intvalue)
     tag->intvalue = intvalue;
 }
 
-CTag::CTag(int8 special, uint32 intvalue)
+CTag::CTag(wxInt8 special, wxUint32 intvalue)
 {
     tag = new Tag_Struct;
     memset(tag, 0, sizeof(Tag_Struct));
@@ -335,7 +332,7 @@ CTag::CTag(char * name, char * strvalue)
     tag->stringvalue = nstrdup(strvalue);
 }
 
-CTag::CTag(int8 special, char * strvalue)
+CTag::CTag(wxInt8 special, char * strvalue)
 {
     tag = new Tag_Struct;
     memset(tag, 0, sizeof(Tag_Struct));
