@@ -23,40 +23,43 @@
 #ifndef PACKETS_H
 #define PACKETS_H
 
-#include "opcodes.h"                    // Needed for OP_EDONKEYPROT
-#include "types.h"                      // Needed for uint8
-#include "SafeFile.h"                   // Needed for CSafeFile
-#include <exception>                    // Needed for std::exception
+#include "opcodes.h"                        // Needed for OP_EDONKEYPROT
 
-extern void pckfilter(wxUint8 opcode,void *pbuffer,int length);
+#include <exception>                        // Needed for std::exception
+#include <wx/defs.h>                        // Needed for wxUint8
+
+class CFile;
+class CMemFile;
+class CSafeFile;
+
+extern void pckfilter(wxUint8 opcode, void *pbuffer, int length);
 
 //			PACKET CLASS
 // TODO some parts could need some work to make it more efficient
 class Packet {
 public:
-	Packet(uint8 protocol = OP_EDONKEYPROT);
+	Packet(wxUint8 protocol = OP_EDONKEYPROT);
 	Packet(unsigned char* header); // only used for receiving packets
-	Packet(char* pPacketPart,uint32 nSize,bool bLast); // only used for splitted packets!
-	Packet(CMemFile* datafile,uint8 protocol = OP_EDONKEYPROT);
-	//Packet(int8 in_opcode,CMemFile* datafile,uint8 protocol = OP_EDONKEYPROT);
-	Packet(int8 in_opcode,int32 in_size,uint8 protocol = OP_EDONKEYPROT);
-	Packet(int8 in_opcode,int32 in_size,uint8 protocol, unsigned char *buffer);
-	Packet(char* type,int8 in_opcode,int32 in_size,uint8 protocol = OP_EDONKEYPROT,bool bFromPF = true);
-	Packet(char* type,char* pPacketPart,uint32 nSize,bool bLast,bool bFromPF = true);//only used for spl. packets!
+	Packet(char* pPacketPart,wxUint32 nSize,bool bLast); // only used for splitted packets!
+	Packet(CMemFile* datafile,wxUint8 protocol = OP_EDONKEYPROT);
+	Packet(wxInt8 in_opcode,wxInt32 in_size,wxUint8 protocol = OP_EDONKEYPROT);
+	Packet(wxInt8 in_opcode,wxInt32 in_size,wxUint8 protocol, unsigned char *buffer);
+	Packet(char* type,wxInt8 in_opcode,wxInt32 in_size,wxUint8 protocol = OP_EDONKEYPROT,bool bFromPF = true);
+	Packet(char* type,char* pPacketPart,wxUint32 nSize,bool bLast,bool bFromPF = true);//only used for spl. packets!
 	~Packet();
 	char*	GetHeader();
 	char*	GetUDPHeader();
 	char*	GetPacket();
 	char*	DetachPacket();
-	uint32	GetRealPacketSize()		{return size+6;}
+	wxUint32	GetRealPacketSize()		{return size+6;}
 	bool	IsSplitted()			{return m_bSplitted;}
 	bool	IsLastSplitted()		{return m_bLastSplitted;}
 	void	PackPacket();
 	bool	UnPackPacket(unsigned int uMaxDecompressedSize = 50000);
 	char*	pBuffer;
-	uint32	size;
-	uint8	opcode;
-	uint8	prot;
+	wxUint32	size;
+	wxUint8	opcode;
+	wxUint8	prot;
 	// -khaos--+++> Returns either -1, 0 or 1.  -1 is unset, 0 is from complete file, 1 is from part file
 	bool	IsFromPF()				{return m_bFromPF;}
 	// <-----khaos-
@@ -70,11 +73,11 @@ private:
 	int	m_bFromPF;
 };
 struct Tag_Struct{
-	int8	type;
+	wxInt8	type;
 	char*	tagname;
 	char*	stringvalue;
-	uint32	intvalue;
-	int8	specialtag;
+	wxUint32	intvalue;
+	wxInt8	specialtag;
 	
 };
 
@@ -105,10 +108,10 @@ enum TTagType
 
 class CTag {
 public:
-	CTag(char* name,uint32 intvalue);
-	CTag(int8 special, uint32 intvalue);
+	CTag(char* name,wxUint32 intvalue);
+	CTag(wxInt8 special, wxUint32 intvalue);
 	CTag(char* name,char* strvalue);
-	CTag(int8 special, char* strvalue);
+	CTag(wxInt8 special, char* strvalue);
 	CTag(Tag_Struct* in_tag);
 	CTag(CFile* in_data);
 	CTag(CMemFile* in_data);
