@@ -19,7 +19,7 @@
 //{{NO_DEPENDENCIES}}
 // Microsoft Visual C++ generated include file.
 // Used by xmule.rc
-//
+
 #define IDR_MANIFEST                    1
 #define IDC_BUTTONRENAME                2
 #define IDC_BUTTONSTRIP                 3
@@ -1086,7 +1086,6 @@
 #define IDC_LIST2                       2011
 #define IDC_DOWNLOADLIST                2011
 #define IDC_SBUTTON1                    2011
-//#define IDC_RELOADSHAREDFILES           2011
 #define IDC_BN_DOWNLOADS                2011
 #define IDC_MAXCON2                     2011
 #define IDC_TOOLTIPDELAY                2011
@@ -1098,7 +1097,6 @@
 #define IDC_ADD                         2011
 #define IDC_COLOR_BUTTON                2011
 #define IDC_EDITADR                     2011
-#define IDC_BROWSE                      2011
 #define IDC_RELOADFILTER                2011
 #define IDC_HOTMENU                     2011
 #define IDC_WSRELOADTMPL                2011
@@ -1244,23 +1242,17 @@
 #define IDC_DNAME                       2074
 #define IDC_FSTATIC7                    2074
 #define IDC_DSOFT                       2075
-//#define IDC_SREQUESTED                  2075
 #define IDC_FSTATIC10                   2075
 #define IDC_NAME21                      2075
 #define IDC_DIP                         2076
-//#define IDC_SACCEPTED                   2076
 #define IDC_DSIP                        2077
-//#define IDC_STRANSFERED                 2077
 #define IDC_DHASH                       2078
 #define IDC_FSTATIC8                    2078
 #define IDC_DVERSION                    2079
 #define IDC_FSTATIC9                    2079
 #define IDC_DID                         2080
-//#define IDC_SREQUESTED2                 2080
 #define IDC_DSNAME                      2081
-//#define IDC_SACCEPTED2                  2081
 #define IDC_DDOWNLOADING                2082
-//#define IDC_STRANSFERED2                2082
 #define IDC_DDOWN                       2083
 #define IDC_DAVDR                       2084
 #define IDC_DDUP                        2085
@@ -1292,25 +1284,18 @@
 #define IDC_SLIDER                      2102
 #define IDC_FD_XI13                     2102
 #define IDC_BN_SEARCH                   2103
-//#define IDC_C1                          2103
 #define IDC_FD_XI6                      2103
 #define IDC_STATIC_LINE                 2104
 #define IDC_FD_XI8                      2104
 #define IDC_SLIDER_VALUE                2105
 #define IDC_FD_XI10                     2105
-//#define IDC_C0                          2106
 #define IDC_FD_XI12                     2106
 #define IDC_STATIC_D                    2107
 #define IDC_STATIC_U                    2108
 #define IDC_STATISTICS                  2109
 #define IDC_STATS                       2110
 #define IDC_STATSSCOPE                  2110
-//#define IDC_S0                          2111
-//#define IDC_S1                          2112
-//#define IDC_S3                          2113
-//#define IDC_S2                          2114
 #define IDC_STATIC7                     2115
-//#define IDC_C0_2                        2115
 #define IDC_STATIC_S0                   2116
 #define IDD_SPLASH                      2116
 #define IDC_STATIC_S1                   2117
@@ -1325,13 +1310,10 @@
 #define IDC_STATIC_U2                   2123
 #define IDC_STATIC_U3                   2124
 #define IDC_EXIT                        2124
-//#define IDC_C2                          2125
-//#define IDC_C1_2                        2125
 #define IDC_SPIN1                       2125
 #define IDC_SPLASHON                    2125
 #define IDC_FRAME2                      2126
 #define IDC_PUBLICSHARED                2126
-//#define IDC_C0_3                        2126
 #define IDC_FRAME1                      2127
 #define IDC_STATIC_D4                   2127
 #define IDC_TIMEAVG1                    2127
@@ -1341,7 +1323,6 @@
 #define IDC_TIMEAVG2                    2130
 #define IDC_CHECK2                      2131
 #define IDC_FILTER                      2131
-//#define IDC_C1_3                        2131
 #define IDC_IRC_USECHANFILTER           2131
 #define IDC_UDPDISABLE                  2131
 #define IDC_VERBOSE                     2131
@@ -1386,7 +1367,6 @@
 #define IDC_S_TITLE                     2167
 #define IDC_IRC_MISC_FRM                2168
 #define IDC_UDPPORTLABEL                2169
-#define IDC_CMSTATUS                    2170
 #define IDC_LANG                        2171
 #define IDC_LANG_FRM                    2172
 #define IDC_CONNTITLE                   2173
@@ -1537,22 +1517,18 @@
 #define IDC_WIZ_TRUEUPLOAD_BOX          2280
 #define IDC_UDPPORT                     2280
 #define IDC_USERNAME                    2280
-#define IDC_CMT_TEXT                    2280
 #define IDC_MAXSRCPERFILESOFT           2280
 #define IDC_MAXSRCEPERFILESOFT          2280
 #define IDC_DEBUG_LOG                   2280
-#define IDC_TITLE                       2280
 #define IDC_FILTERLEVEL                 2280
 #define IDC_TEXT                        2280
 #define IDC_WSPORT                      2280
 #define IDC_WIZARD                      2281
 #define IDC_USERHASH                    2281
-#define IDC_INCOMING                    2281
 #define IDC_WSPASS                      2281
 #define IDC_OS_FRAME                    2282
 #define IDC_IP                          2282
 #define IDC_INCOMING2                   2282
-#define IDC_COMMENT                     2282
 #define IDC_WSPASS2                     2282
 #define IDC_WSPASSLOW                   2282
 #define IDC_HOTBUTTON_FRAME             2283
@@ -1578,7 +1554,6 @@
 #define IDC_KBITS                       2303
 #define IDC_KBYTES                      2304
 #define IDC_FILEINFO                    2305
-//#define IDC_FILESIZE                    2306
 #define IDC_UNIT                        2307
 #define IDC_CTINFO                      2308
 #define IDC_MAXCONLABEL                 2310
@@ -1587,11 +1562,6 @@
 #define IDC_PWT_NETWORK                 2313
 #define IDC_INFO1                       2314
 #define IDC_INFO2                       2315
-#define IDCOK                           2316
-#define IDCCANCEL                       2317
-#define IDC_CMT_LQUEST                  2318
-#define IDC_CMT_LAIDE                   2319
-#define IDCREF                          2319
 #define IDC_RATEQUEST                   2320
 #define IDC_LST                         2320
 #define IDC_RATEHELP                    2321
@@ -1628,7 +1598,6 @@
 #define IDC_CLIENTLIST                  2354
 #define IDC_STATIC_FILTERLEVEL2         2354
 #define IDC_EDITFILTER                  2355
-#define IDC_CATCOLOR                    2356
 #define IDC_FILTERCOMMENTSLABEL         2357
 #define IDC_WATCHCB                     2358
 #define IDC_STATIC_COLOR                2359
@@ -1706,7 +1675,6 @@
 #define IDD_PPG_SECURITY                2431
 #define IDC_IRC_EMULEPROTO_INFOMESSAGE  2432
 #define IDC_STATIC_PRIO                 2433
-#define IDC_PRIOCOMBO                   2434
 #define IDR_WIZ1_WATERMARK              2435
 #define IDR_WIZ1_HEADER                 2436
 #define IDC_STARTNEXTFILECAT            2437
