@@ -20,21 +20,23 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "server.h"
-#	include "opcodes.h"
-#	include "otherfunctions.h"
-#	include "xmule.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <netinet/in.h>
-#include <arpa/inet.h>
+#include "server.h"                         // Needed for this Interface's Prototype
+
+#include "otherfunctions.h"                 // Needed for nstrdup
+#include "otherstructs.h"                   // Needed for ServerMet_Struct
+#include "packets.h"                        // Needed for CTag
+#include "SafeFile.h"                       // Needed for CSafeFile
+
+#include <arpa/inet.h>                      // Needed for in_addr
+#include <wx/listimpl.cpp>                  // Needed for WX_DEFINE_LIST
+#include <wx/treectrl.h>                    // Needed for wxTreeCtrl
 
-#include <wx/listimpl.cpp>
 WX_DEFINE_LIST(TagList)
 
-CServer::CServer(ServerMet_Struct *in_data)
+CServer::CServer(ServerMet_Struct* in_data)
 {
     //taglist = new CTypedPtrList<CPtrList, CTag*>;
     taglist = new TagList;
@@ -238,6 +240,11 @@ bool CServer::AddTagFromFile(CSafeFile *servermet)
     return true;
 }
 
+void CServer::AddTag(CTag* in_tag)
+{
+    taglist->Append(in_tag);
+}
+
 void CServer::SetListName(char *newname)
 {
     if (listname)
@@ -254,49 +261,6 @@ void CServer::SetDescription(char *newname)
 
 void CServer::FillWindowTags(wxTreeCtrl *wnd, wxTreeItemId rootitem)
 {
-#if 0
-    POSITION pos;
-    char buffer[255];
-    if (description)
-    {
-        sprintf(buffer, GetResString(IDS_DESC), description);
-        wnd->InsertItem(buffer, - 1, - 1, rootitem);
-    }
-    sprintf(buffer, GetResString(IDS_IP) + ": %s", ipfull);
-    wnd->InsertItem(buffer, - 1, - 1, rootitem);
-    sprintf(buffer, GetResString(IDS_PORT) + ": %i", port);
-    wnd->InsertItem(buffer, - 1, - 1, rootitem);
-    if (ping)
-    {
-        sprintf(buffer, GetResString(IDS_PING) + ": %i", ping);
-        wnd->InsertItem(buffer, - 1, - 1, rootitem);
-    }
-    if (users)
-    {
-        sprintf(buffer, GetResString(IDS_USERS), users);
-        wnd->InsertItem(buffer, - 1, - 1, rootitem);
-    }
-    if (files)
-    {
-        sprintf(buffer, GetResString(IDS_FILES) + ": %i", files);
-        wnd->InsertItem(buffer, - 1, - 1, rootitem);
-    }
-    CTag *cur_tag;
-    for (int i = 0 ; i != taglist->GetCount() ; i++)
-    {
-        pos = taglist->FindIndex(i);
-        cur_tag = taglist->GetAt(pos);
-        if (cur_tag->tag->specialtag)
-        continue;
-        if (cur_tag->tag->type == 2)
-        sprintf(buffer, "%s: %s", cur_tag->tag->tagname, cur_tag->tag->stringvalue);
-        else if(cur_tag->tag->type == 3)
-        sprintf(buffer, "%s: %i", cur_tag->tag->tagname, cur_tag->tag->intvalue);
-        else
-        continue;
-        wnd->InsertItem(buffer, - 1, - 1, rootitem);
-    }
-#endif
     printf("todo. fill window tags\n");
 }
 
