@@ -23,11 +23,19 @@
 #ifndef SERVER_H
 #define SERVER_H
 
-#include "packets.h"                    // Needed for CTag
-#include "otherstructs.h"               // Needed for ServerMet_Struct
-#include <wx/treectrl.h>                // Needed for wxTreeCtrl
+#include "types.h"                          // Needed for uint16
+#include "wintypes.h"                       // Needed for LPCTSTR
 
-WX_DECLARE_LIST(CTag,TagList);
+#include <wx/list.h>                        // Needed for WX_DECLARE_LIST
+#include <wx/string.h>                      // Needed for wxString
+
+class CSafeFile;
+class CTag;
+class wxTreeCtrl;
+class wxTreeItemId;
+
+struct ServerMet_Struct;
+WX_DECLARE_LIST(CTag, TagList);
 
 #define		SRV_TCPFLG_COMPRESSION			0x00000001
 
@@ -40,12 +48,12 @@ public:
 	CServer(uint16 in_port, char* i_addr);
 	CServer(CServer* pOld);
 	~CServer();
-	void	AddTag(CTag* in_tag)			{taglist->Append(in_tag);}
+    void AddTag(CTag* in_tag);
 	char*	GetListName()					{return listname;}
 	char*	GetFullIP()						{return ipfull;}
 	char*	GetAddress();
 	uint16	GetPort()						{return port;}
-	void	FillWindowTags(wxTreeCtrl* wnd,wxTreeItemId rootitem);
+	void	FillWindowTags(wxTreeCtrl* wnd, wxTreeItemId rootitem);
 	bool	AddTagFromFile(CSafeFile* servermet);
 	void	SetListName(char* newname);
 	void	SetDescription(char* newdescription);
@@ -102,7 +110,6 @@ private:
 	uint16		port;
 	uint32		failedcount; 
 	TagList* taglist;
-	//CTypedPtrList<CPtrList, CTag*>*	taglist;
 	uint8		staticservermember;
 	uint32		softfiles;
 	uint32		hardfiles;
