@@ -20,29 +20,30 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-#	include "xmule-headers.h"
-#else
-#	include "sockets.h"
-#include "otherfunctions.h"             // Needed for GetResString
-#	include "ListenSocket.h"
-#	include "opcodes.h"
-#	include "packets.h"
-#	include "SearchDlg.h"
-#	include "SearchList.h"
-#	include "ServerSocket.h"
-#	include "ServerWnd.h"
-#	include "SharedFileList.h"
-#	include "SysTray.h"
-#	include "UDPSocket.h"
-#	include "xmule.h"
-#	include "xmuleDlg.h"
+    #include "xmule-headers.h"
 #endif
 
-#include <time.h>
-#include <sys/ioctl.h>                  // Needed for SIOCGIFADDR
-#include <net/if.h>                     // Needed for ifreq
+#include "sockets.h"                        // Needed for this Interface's Prototype
 
-// CServerConnect
+#include "CMemFile.h"                       // Needed for CMemFile
+#include "ListenSocket.h"                   // Needed for CListenSocket
+#include "otherfunctions.h"                 // Needed for GetResString
+#include "packets.h"                        // Needed for Packet
+#include "Preferences.h"                    // Needed for CPreferences
+#include "SearchDlg.h"                      // Needed for CSearchDlg
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
+#include "ServerSocket.h"                   // Needed for CServerSocket
+#include "ServerWnd.h"                      // Needed for CServerWnd
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "SysTray.h"                        // Needed for TBN_IMPORTANTEVENT
+#include "UDPSocket.h"                      // Needed for CUDPSocket
+#include "xmule.h"                          // Needed for theApp
+#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
+
+#include <net/if.h>                         // Needed for ifreq
+#include <sys/ioctl.h>                      // Needed for SIOCGIFADDR
 
 void CServerConnect::TryAnotherConnectionrequest()
 {
@@ -75,7 +76,7 @@ void CServerConnect::TryAnotherConnectionrequest()
     }
 }
 
-void CServerConnect::ConnectToAnyServer(uint32 startAt, bool prioSort, bool isAuto)
+void CServerConnect::ConnectToAnyServer(wxUint32 startAt, bool prioSort, bool isAuto)
 {
     lastStartAt = startAt;
     StopConnectionTry();
@@ -129,7 +130,7 @@ void CServerConnect::ConnectToServer(CServer *server, bool multiconnect)
     m_lstOpenSockets.AddTail((void *&) newsocket);
     //newsocket->Create(0,SOCK_STREAM,FD_READ|FD_WRITE|FD_CLOSE|FD_CONNECT,NULL);
     newsocket->ConnectToServer(server);
-    ULONG x = GetTickCount();
+    unsigned long x = GetTickCount();
     connectionattemps.SetAt(x, newsocket);
 }
 
@@ -173,11 +174,11 @@ void CServerConnect::ConnectionEstablished(CServerSocket *sender)
         }
         CMemFile *data = new CMemFile();
         data->Write(theApp.glob_prefs->GetUserHash(), 16);
-        uint32 clientid = GetClientID();
+        wxUint32 clientid = GetClientID();
         data->Write( &clientid, 4);
-        uint16 port = app_prefs->GetPort();
+        wxUint16 port = app_prefs->GetPort();
         data->Write( &port, 2);
-        uint32 tagcount = 4;
+        wxUint32 tagcount = 4;
         data->Write( &tagcount, 4);
         CTag tagName(CT_NAME, app_prefs->GetUserNick());
         tagName.WriteTagToFile(data);
@@ -386,7 +387,6 @@ bool CServerConnect::Disconnect()
         connected = false;
         theApp.xmuledlg->ShowConnectionState(false, "");
         theApp.stat_serverConnectTime = 0;
-        //theApp.xmuledlg->serverwnd->servermsgbox.AppendText(CString("\n\n\n\n"));
         return true;
     }
     else
@@ -408,7 +408,6 @@ CServerConnect::CServerConnect(CServerList *in_serverlist, CPreferences *in_pref
     tmp.Service(theApp.glob_prefs->GetPort() + 10);
     // initalize socket for udp packets:
     udpsocket = new CUDPSocket(this, tmp);
-    //udpsocket->Create();
     m_idRetryTimer.SetOwner(theApp.xmuledlg, 4333);
     lastStartAt = 0;
     InitLocalIP();
@@ -437,7 +436,7 @@ CServer *CServerConnect::GetCurrentServer()
     }
 }
 
-void CServerConnect::SetClientID(uint32 newid)
+void CServerConnect::SetClientID(wxUint32 newid)
 {
     clientid = newid;
     theApp.xmuledlg->ShowConnectionState(IsConnected(), GetCurrentServer()->GetListName());
@@ -494,7 +493,7 @@ void CServerConnect::InitLocalIP()
     }
 }
 
-bool CServerConnect::IsLocalServer(uint32 dwIP, uint16 nPort)
+bool CServerConnect::IsLocalServer(wxUint32 dwIP, wxUint16 nPort)
 {
     if (IsConnected())
     {
