@@ -24,8 +24,9 @@
 #ifndef _SOCKETS_H
 #define _SOCKETS_H
 
-#include "server.h"                     // Needed for CServer
-#include "ServerList.h"                 // Needed for CServerList
+#include "mfc.h"                            // Needed for CTypedPtrList
+
+#include <wx/timer.h>                       // Needed for wxTimer
 
 #define CS_FATALERROR	-5
 #define CS_DISCONNECTED	-4
@@ -38,11 +39,15 @@
 #define	CS_WAITFORLOGIN	3
 #define CS_RETRYCONNECTTIME  30 // seconds
 
-
 class CUDPSocket;
+class Packet;
+class CPreferences;
+class CServer;
+class CServerList;
 class CServerSocket;
 
-class CServerConnect{
+class CServerConnect
+{
 public:
 	CServerConnect(CServerList* in_serverlist, CPreferences* in_prefs);
 	~CServerConnect();
@@ -50,10 +55,9 @@ public:
 	void	ConnectionEstablished(CServerSocket* sender);
 	
 	void	ConnectToAnyServer() {ConnectToAnyServer(0,true,true);}
-	void	ConnectToAnyServer(uint32 startAt,bool prioSort=false,bool isAuto=true);
+	void	ConnectToAnyServer(wxUint32 startAt,bool prioSort=false,bool isAuto=true);
 	void	ConnectToServer(CServer* toconnect, bool multiconnect=false);
 	void	StopConnectionTry();
-	//static  VOID CALLBACK RetryConnectCallback(HWND hWnd, UINT nMsg, UINT nId, DWORD dwTime);
 
 	void	CheckForTimeout();
 	void	DestroySocket(CServerSocket* pSck);	// safe socket closure and destruction
@@ -64,11 +68,11 @@ public:
 	bool	IsConnected()	{return connected;}
 	wxUint32	GetClientID()		{return clientid;}
 	CServer*	GetCurrentServer();
-	uint32	clientid;
-	uint8	pendingConnects;
+	wxUint32	clientid;
+	wxUint8	pendingConnects;
 	bool	IsLowID()		{return (clientid < 16777216);}
-	void	SetClientID(uint32 newid);
-	bool	IsLocalServer(uint32 dwIP, uint16 nPort);
+	void	SetClientID(wxUint32 newid);
+	bool	IsLocalServer(wxUint32 dwIP, wxUint16 nPort);
 	void	TryAnotherConnectionrequest();
 	bool	IsSingleConnect()	{return singleconnecting;}
 	void	InitLocalIP();
@@ -78,18 +82,17 @@ private:
 	bool	connecting;
 	bool	singleconnecting;
 	bool	connected;
-	int8	max_simcons;
-	uint32 lastStartAt;
+	wxInt8	max_simcons;
+	wxUint32 lastStartAt;
 	CPreferences*	app_prefs;
 	CServerSocket*	connectedsocket;
 	CServerList*	used_list;
 	CUDPSocket*		udpsocket;
 	CTypedPtrList<CPtrList,void*>		m_lstOpenSockets;	// list of currently opened sockets
-	//UINT			m_idRetryTimer;
 	wxTimer m_idRetryTimer;
 	wxUint32 	m_nLocalIP;
 
-	CMap<ULONG ,ULONG&,CServerSocket*,CServerSocket*> connectionattemps;
+	CMap<unsigned long, unsigned long&, CServerSocket*, CServerSocket*> connectionattemps;
 // Added by sivka [Tarod: Tries after a LowID connection]
 public: 
 	void	ResetLowIDTries() {m_lowid_tries = 0;}
