@@ -23,7 +23,7 @@
 // Author:      Robert Roebling
 // Created:     01/02/97
 // Modified:    22/10/98 - almost total rewrite, simpler interface (VZ)
-// Id:          $Id: treectlc.cpp,v 1.30 2004/08/13 15:51:11 HopeSeekr Exp $
+// Id:          $Id: treectlc.cpp,v 1.31 2004/09/09 22:40:17 HopeSeekr Exp $
 // Copyright:   (c) 1998 Robert Roebling, Julian Smart and Markus Holzem
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -1656,14 +1656,6 @@ void wxGenericCTreeCtrl::Collapse(const wxCTreeItemId &itemId)
         return;
     }
     item->Collapse();
-#if 0  // TODO why should items be collapsed recursively?
-    wxArrayGenericCTreeItems &children = item->GetChildren();
-    size_t count = children.Count();
-    for (size_t n = 0 ; n < count ; n++)
-    {
-        Collapse(children[n]);
-    }
-#endif
     CalculatePositions();
     RefreshSubtree(item);
     event.SetEventType(wxEVT_COMMAND_CTREE_ITEM_COLLAPSED);
