@@ -29,21 +29,28 @@
 #ifndef _UPDOWNCLIENT_H
 #define _UPDOWNCLIENT_H
 
-#include "otherstructs.h"               // Needed for Requested_Block_Struct
-#include "EMSocket.h"
-#include "ListenSocket.h"               // Needed for CClientReqServer
-//#include "ClientCredits.h"              // Needed for CClientCredits
-class CClientCredits;
-#include "otherfunctions.h"             // Needed for GetTickCount
-#include <wx/dcmemory.h>                // Needed for wxMemoryDC
+#include "mfc.h"                            // Needed for CTypedPtrList
+#include "wintypes.h"                       // Needed for DWORD
+
+#include <wx/gdicmn.h>                      // Needed for wxRect
 
 class CBarShader;
-class CPartFile;
+class CClientCredits;
+class CClientReqServer;
 class CKnownFile;
+class CMemFile;
+class CPartFile;
+class CString;
+class Packet;
+struct Pending_Block_Struct;
+struct Requested_Block_Struct;
+struct Requested_File_Struct;
+class wxDC;
+class wxPaintDC;
+
 typedef unsigned char byte;
 extern inline long GetTickCount();
 
-
 // uploadstate
 #define	US_UPLOADING		0
 #define	US_ONUPLOADQUEUE	1
@@ -75,18 +82,20 @@ extern inline long GetTickCount();
 #define	MS_CONNECTING		2
 #define	MS_UNABLETOCONNECT	3
 
-enum EClientSoftware {
-	SO_EMULE			= 0,
-	SO_CDONKEY			= 1,
-	SO_XMULE			= 2,
-	SO_AMULE			= 3,
-	SO_SHAREAZA			= 4,
-	SO_EDONKEYHYBRID		= 50,
-	SO_EDONKEY			= 51,
-	SO_MLDONKEY			= 52,
-	SO_OLDEMULE			= 53,
-	SO_UNKNOWN			= 54,
-	SO_NEW_MLDONKEY			= 152
+enum EClientSoftware
+{
+    SO_EMULE            = 0,
+    SO_CDONKEY          = 1,
+    SO_XMULE            = 2,
+    SO_AMULE            = 3,
+    SO_SHAREAZA         = 4,
+    SO_MLDONKEY         = 10,
+    SO_LPHANT           = 20,
+    SO_EDONKEYHYBRID    = 50,
+    SO_EDONKEY,
+    SO_OLDEMULE,
+    SO_UNKNOWN,
+    SO_NEW_MLDONKEY     = 152
 };
 
 enum ESecureIdentState {
@@ -112,32 +121,32 @@ class CUpDownClient
 public:
 	//base
 	CUpDownClient(CClientReqSocket* sender = 0);
-	CUpDownClient(uint16 in_port, uint32 in_userid, uint32 in_serverup, uint16 in_serverport,CPartFile* in_reqfile);
+	CUpDownClient(wxUint16 in_port, wxUint32 in_userid, wxUint32 in_serverup, wxUint16 in_serverport,CPartFile* in_reqfile);
 	~CUpDownClient();
 	void			Destroy();
 	void			Disconnected();
 	bool			TryToConnect(bool bIgnoreMaxCon = false);
 	void			ConnectionEstablished();
-	uint32			GetUserID()					{return m_nUserID;}
+	wxUint32			GetUserID()					{return m_nUserID;}
 	void			SetUserID(wxUint32 nUserID)			{ m_nUserID=nUserID; }
 	char*			GetUserName()				{return m_pszUsername;}
-	uint32			GetIP()						{return m_dwUserIP;}
+	wxUint32			GetIP()						{return m_dwUserIP;}
 	bool			HasLowID()					{return (m_nUserID < 16777216);}
 	char*			GetFullIP()					{return m_szFullUserIP;}
-	uint32			GetUserPort()				{return m_nUserPort;}
-	uint32			GetTransferedUp()			{return m_nTransferedUp;}
-	uint32			GetTransferedDown()			{return m_nTransferedDown;}
-	uint32			GetServerIP()				{return m_dwServerIP;}
+	wxUint32			GetUserPort()				{return m_nUserPort;}
+	wxUint32			GetTransferedUp()			{return m_nTransferedUp;}
+	wxUint32			GetTransferedDown()			{return m_nTransferedDown;}
+	wxUint32			GetServerIP()				{return m_dwServerIP;}
 	void			SetServerIP(wxUint32 nIP)		{ m_dwServerIP=nIP; }
-	uint16			GetServerPort()				{return m_nServerPort;}
+	wxUint16			GetServerPort()				{return m_nServerPort;}
 	void			SetServerPort(wxUint16 nPort)		{ m_nServerPort=nPort; }
-	uchar*			GetUserHash()				{return (uchar*)m_achUserHash;}
-	void			SetUserHash(uchar* achUserHash);
+	byte*			GetUserHash()				{return (byte*)m_achUserHash;}
+	void			SetUserHash(byte* achUserHash);
 	bool			HasValidHash()				{return ((int*)m_achUserHash)[0] != 0 || ((int*)m_achUserHash)[1] != 0 ||
 												        ((int*)m_achUserHash)[2] != 0 || ((int*)m_achUserHash)[3] != 0; }
 	int			GetHashType();
-	uint32			GetVersion()				{return m_nClientVersion;}
-	uint8			GetMuleVersion()			{if(m_byEmuleVersion==0x99) return 0x42; else return m_byEmuleVersion;}
+	wxUint32			GetVersion()				{return m_nClientVersion;}
+	wxUint8			GetMuleVersion()			{ return m_byEmuleVersion; }
 	bool			ExtProtocolAvailable()		{return m_bEmuleProtocol;}
 	bool			IsEmuleClient()				{return m_byEmuleVersion;}
 	CClientCredits* 	Credits()					{return credits;}
@@ -145,51 +154,51 @@ public:
 	char*			GetClientFilename()			{return m_pszClientFilename;}
 	wxString		GetClientFilename_NEW() const		{return m_strClientFilename;}
 	bool			SupportsUDP()				{return m_byUDPVer != 0 && m_nUDPPort != 0;}
-	uint16			GetUDPPort()				{return m_nUDPPort;}
-	void			SetUDPPort(uint16 nPort)	{ m_nUDPPort = nPort; }
-	uint8			GetUDPVersion()				{return m_byUDPVer;}
-	uint8			GetExtendedRequestsVersion(){return m_byExtendedRequestsVer;}
+	wxUint16			GetUDPPort()				{return m_nUDPPort;}
+	void			SetUDPPort(wxUint16 nPort)	{ m_nUDPPort = nPort; }
+	wxUint8			GetUDPVersion()				{return m_byUDPVer;}
+	wxUint8			GetExtendedRequestsVersion(){return m_byExtendedRequestsVer;}
 	bool			IsFriend()					{return m_Friend != NULL;}
 	float			GetCompression()	{return (float)compressiongain/notcompressed*100.0f;} // Add rod show compression
 	void			ResetCompressionGain() {compressiongain = 0; notcompressed=1;} // Add show compression
 
 	void			RequestSharedFileList();
-	void			ProcessSharedFileList(char* pachPacket, uint32 nSize);
+	void			ProcessSharedFileList(char* pachPacket, wxUint32 nSize);
 	
         wxString                 GetUploadFileInfo();
 
 	void			SetUserName(char* pszNewName);
 	EClientSoftware		GetClientSoft()				{return m_clientSoft;}
 	void			ReGetClientSoft();
-	bool			ProcessHelloAnswer(char* pachPacket, uint32 nSize);
-	bool			ProcessHelloPacket(char* pachPacket, uint32 nSize);
+	bool			ProcessHelloAnswer(char* pachPacket, wxUint32 nSize);
+	bool			ProcessHelloPacket(char* pachPacket, wxUint32 nSize);
 	void			SendHelloAnswer();
 	void			SendHelloPacket();
 	void			SendMuleInfoPacket(bool bAnswer);
-	void			ProcessMuleInfoPacket(char* pachPacket, uint32 nSize);
-	void			ProcessMuleCommentPacket(char* pachPacket, uint32 nSize);
+	void			ProcessMuleInfoPacket(char* pachPacket, wxUint32 nSize);
+	void			ProcessMuleCommentPacket(char* pachPacket, wxUint32 nSize);
 	bool			Compare(CUpDownClient* tocomp);
 	void			SetLastStateChange()	{m_dwLastStateChange = ::GetTickCount();}
 	void			SetLastSrcReqTime()		{m_dwLastSourceRequest = ::GetTickCount();}
 	void			SetLastSrcAnswerTime()		{m_dwLastSourceAnswer = ::GetTickCount();}
 	void			SetLastAskedForSources()	{m_dwLastAskedForSources = ::GetTickCount();}
-	uint32			GetLastStateChange()	{return m_dwLastStateChange;}
-	uint32			GetLastSrcReqTime()			{return m_dwLastSourceRequest;}
-	uint32			GetLastSrcAnswerTime()		{return m_dwLastSourceAnswer;}
-	uint32			GetLastAskedForSources()	{ return m_dwLastAskedForSources;}
+	wxUint32			GetLastStateChange()	{return m_dwLastStateChange;}
+	wxUint32			GetLastSrcReqTime()			{return m_dwLastSourceRequest;}
+	wxUint32			GetLastSrcAnswerTime()		{return m_dwLastSourceAnswer;}
+	wxUint32			GetLastAskedForSources()	{ return m_dwLastAskedForSources;}
 	bool			GetFriendSlot()				{return m_bFriendSlot;}
 	void			SetFriendSlot(bool bNV)		{m_bFriendSlot = bNV;}
 	void			SetCommentDirty(bool bDirty = true) {m_bCommentDirty = bDirty;}
-	uint8			GetSourceExchangeVersion()	{return m_bySourceExchangeVer;}
+	wxUint8			GetSourceExchangeVersion()	{return m_bySourceExchangeVer;}
 
 	void			SendPublicKeyPacket();
 	void			SendSignaturePacket();
-	void			ProcessPublicKeyPacket(uchar* pachPacket, uint32 nSize);
-	void			ProcessSignaturePacket(uchar* pachPacket, uint32 nSize);
-	uint8			GetSecureIdentState()		{return m_SecureIdentState;}
+	void			ProcessPublicKeyPacket(byte* pachPacket, wxUint32 nSize);
+	void			ProcessSignaturePacket(byte* pachPacket, wxUint32 nSize);
+	wxUint8			GetSecureIdentState()		{return m_SecureIdentState;}
 	void			SendSecIdentStatePacket();
 	void			ProcessSecIdentStatePacket(unsigned char* pachPacket,wxUint32 nSize);
-	uint8			GetInfoPacketsReceived() const { return m_byInfopacketsReceived; }
+	wxUint8			GetInfoPacketsReceived() const { return m_byInfopacketsReceived; }
 	void			InfoPacketsReceived();
 	void			ResetFileStatusInfo();
 
@@ -199,111 +208,111 @@ public:
 	CClientReqSocket*	socket;
 	CClientCredits*		credits;
 	CFriend*			m_Friend;
+    bool SpecialPerson;
 	//upload
-	uint32	compressiongain; /// Add show compression
-	uint32  notcompressed; // Add show compression
-	uint8			GetUploadState()			{return m_byUploadState;}
-	void			SetUploadState(uint8 news)	{m_byUploadState = news;}
-	uint32			GetWaitStartTime()			{return m_dwWaitTime;}
-	uint32			GetWaitTime()				{return m_dwUploadTime-m_dwWaitTime;}
+	wxUint32	compressiongain; /// Add show compression
+	wxUint32  notcompressed; // Add show compression
+	wxUint8			GetUploadState()			{return m_byUploadState;}
+	void			SetUploadState(wxUint8 news)	{m_byUploadState = news;}
+	wxUint32			GetWaitStartTime()			{return m_dwWaitTime;}
+	wxUint32			GetWaitTime()				{return m_dwUploadTime-m_dwWaitTime;}
 	bool			IsDownloading()				{return (m_byUploadState == US_UPLOADING);}
 	bool			HasBlocks()					{return !(m_BlockSend_queue.IsEmpty() && m_BlockRequests_queue.IsEmpty());}
-	uint32			GetDatarate()				{return m_nUpDatarate;}	
-	uint32			GetScore(bool sysvalue, bool isdownloading = false, bool onlybasevalue = false);
+	wxUint32			GetDatarate()				{return m_nUpDatarate;}	
+	wxUint32			GetScore(bool sysvalue, bool isdownloading = false, bool onlybasevalue = false);
 	void			AddReqBlock(Requested_Block_Struct* reqblock);
 	bool			CreateNextBlockPackage();
-	void			SetUpStartTime(uint32 dwTime = 0);
-	uint32			GetUpStartTimeDelay()		{return ::GetTickCount() - m_dwUploadTime;}
-	void			SetWaitStartTime(uint32 dwTime = 0);
+	void			SetUpStartTime(wxUint32 dwTime = 0);
+	wxUint32			GetUpStartTimeDelay()		{return ::GetTickCount() - m_dwUploadTime;}
+	void			SetWaitStartTime(wxUint32 dwTime = 0);
 	void			SendHashsetPacket(char* forfileid);
-	void			SetUploadFileID(uchar* tempreqfileid);
-	uchar*			GetUploadFileID()	{return requpfileid;}
+	void			SetUploadFileID(byte* tempreqfileid);
+	byte*			GetUploadFileID()	{return requpfileid;}
 	CPartFile*		GetDownloadFile()	{return reqfile;}
 	void			SetDownloadFile(CPartFile*);
-	uint32			SendBlockData(uint32 maxammount);
+	wxUint32			SendBlockData(wxUint32 maxammount);
 	void			ClearUploadBlockRequests();
 	void			SendRankingInfo();
 	void			SendCommentInfo(CKnownFile *file);
-	uint32			GetLastAskedDelay();
-	void			AddRequestCount(uchar* fileid);
+	wxUint32			GetLastAskedDelay();
+	void			AddRequestCount(byte* fileid);
 	bool 			IsDifferentPartBlock();
 	void			UnBan();
 	void			Ban();
-	uint32			GetBanTime()				{return m_dwBanTime;}
-	uint32			GetAskedCount()				{return m_cAsked;}
+	wxUint32			GetBanTime()				{return m_dwBanTime;}
+	wxUint32			GetAskedCount()				{return m_cAsked;}
 	void			AddAskedCount()				{m_cAsked++;}
-	void			SetAskedCount( uint32 m_cInAsked)				{m_cAsked = m_cInAsked;}
+	void			SetAskedCount( wxUint32 m_cInAsked)				{m_cAsked = m_cInAsked;}
 	void			FlushSendBlocks();			// call this when you stop upload, or the socket might be not able to send
 	void			SetLastUpRequest()			{m_dwLastUpRequest = ::GetTickCount();}
-	uint32			GetLastUpRequest()			{return m_dwLastUpRequest;}
+	wxUint32			GetLastUpRequest()			{return m_dwLastUpRequest;}
 	void			UDPFileReasked();
-	uint32			GetSessionUp()			{return m_nTransferedUp - m_nCurSessionUp;}
+	wxUint32			GetSessionUp()			{return m_nTransferedUp - m_nCurSessionUp;}
 	void			ResetSessionUp()		{m_nCurSessionUp = m_nTransferedUp;} 
-	void			ProcessUpFileStatus(char* packet,uint32 size);
-	uint16			GetUpPartCount()			{return m_nUpPartCount;}
-	void			DrawUpStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat);
+	void			ProcessUpFileStatus(char* packet,wxUint32 size);
+	wxUint16			GetUpPartCount()			{return m_nUpPartCount;}
+	void			DrawUpStatusBar(wxDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat);
 
 	//download
-	uint32			GetAskedCountDown()				{return m_cDownAsked;} //<<--
+	wxUint32			GetAskedCountDown()				{return m_cDownAsked;} //<<--
 	void			AddAskedCountDown()				{m_cDownAsked++;}
-	void			SetAskedCountDown( uint32 m_cInDownAsked)				{m_cDownAsked = m_cInDownAsked;}
-	uint8			GetDownloadState()			{return m_nDownloadState;}
-	void			SetDownloadState(uint8 byNewState);
-	uint32			GetLastAskedTime()			{return m_dwLastAskedTime;}
-	inline bool			IsPartAvailable(uint16 iPart)	{return	( (iPart >= m_nPartCount) || (!m_abyPartStatus) )? 0:m_abyPartStatus[iPart];}
-	bool			IsUpPartAvailable(uint16 iPart) {return ( (iPart
+	void			SetAskedCountDown( wxUint32 m_cInDownAsked)				{m_cDownAsked = m_cInDownAsked;}
+	wxUint8			GetDownloadState()			{return m_nDownloadState;}
+	void			SetDownloadState(wxUint8 byNewState);
+	wxUint32			GetLastAskedTime()			{return m_dwLastAskedTime;}
+	inline bool			IsPartAvailable(wxUint16 iPart)	{return	( (iPart >= m_nPartCount) || (!m_abyPartStatus) )? 0:m_abyPartStatus[iPart];}
+	bool			IsUpPartAvailable(wxUint16 iPart) {return ( (iPart
  >= m_nUpPartCount) || (!m_abyUpPartStatus) )? 0:m_abyUpPartStatus[iPart];}
-	uint8*			GetPartStatus()				{return m_abyPartStatus;}
-	uint32			GetDownloadDatarate()		{ return m_nDownDatarate; }
-	uint16			GetRemoteQueueRank()		{ return m_nRemoteQueueRank; }
+	wxUint8*			GetPartStatus()				{return m_abyPartStatus;}
+	wxUint32			GetDownloadDatarate()		{ return m_nDownDatarate; }
+	wxUint16			GetRemoteQueueRank()		{ return m_nRemoteQueueRank; }
 	void			SetRemoteQueueFull( bool flag )	{m_bRemoteQueueFull = flag;}
 	bool			IsRemoteQueueFull()			{return m_bRemoteQueueFull;}
-	void			SetRemoteQueueRank(uint16 nr);
-	void			DrawStatusBar(wxMemoryDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat);
+	void			SetRemoteQueueRank(wxUint16 nr);
+	void			DrawStatusBar(wxDC* dc, wxRect rect, bool onlygreyrect, bool  bFlat);
 	void			AskForDownload();
 	void			SendFileRequest_HOPE();
 	void			SendFileRequest();
-	void			ProcessFileInfo(char* packet,uint32 size);
-	void			ProcessFileStatus(char* packet,uint32 size);
-	void			ProcessHashSet(unsigned char* packet,uint32 size);
+	void			ProcessFileInfo(char* packet,wxUint32 size);
+	void			ProcessFileStatus(char* packet,wxUint32 size);
+	void			ProcessHashSet(unsigned char* packet,wxUint32 size);
 	bool			AddRequestForAnotherFile(CPartFile* file);
 	void			SendBlockRequests();
-	void			ProcessBlockPacket(char* packet, uint32 size, bool packed = false);
-	uint32			CalculateDownloadRate();
-	uint16			GetAvailablePartCount();
-	//			SwapToAnotherFile(bool bIgnoreNoNeeded = false);   Razor 1a - Modif by MikaelB 
+	void			ProcessBlockPacket(char* packet, wxUint32 size, bool packed = false);
+	wxUint32			CalculateDownloadRate();
+	wxUint16			GetAvailablePartCount();
 
-	void			UDPReaskACK(uint16 nNewQR);
+	void			UDPReaskACK(wxUint16 nNewQR);
 	void			UDPReaskFNF();
 	void			UDPReaskForDownload();
 	bool			IsSourceRequestAllowed();
 
-	uint16 GetUpCompleteSourcesCount() { return m_nUpCompleteSourcesCount; }
-	void SetUpCompleteSourcesCount(uint16 n) { m_nUpCompleteSourcesCount = n; }
+	wxUint16 GetUpCompleteSourcesCount() { return m_nUpCompleteSourcesCount; }
+	void SetUpCompleteSourcesCount(wxUint16 n) { m_nUpCompleteSourcesCount = n; }
 	
 	int				sourcesslot;
 
 	//chat
-	uint8			GetChatState()				{return m_byChatstate;}
-	void			SetChatState(uint8 nNewS)	{m_byChatstate = nNewS;}
+	wxUint8			GetChatState()				{return m_byChatstate;}
+	void			SetChatState(wxUint8 nNewS)	{m_byChatstate = nNewS;}
 	bool			m_bIsSpammer;
-	uint8			m_cMessagesReceived; //Count of chatmessages he sent to me
-	uint8			m_cMessagesSend; //Count of chatmessages i sent to him
+	wxUint8			m_cMessagesReceived; //Count of chatmessages he sent to me
+	wxUint8			m_cMessagesSend; //Count of chatmessages i sent to him
 
 	//File Comment 
     CString			GetFileComment()			{return m_strComment;} 
     void			SetFileComment(char *desc)	{m_strComment.Format("%s",desc);}
-    uint8			GetFileRate()				{return m_iRate;}
-    void			SetFileRate(int8 iNewRate)	{m_iRate=iNewRate;}
+    wxUint8			GetFileRate()				{return m_iRate;}
+    void			SetFileRate(wxInt8 iNewRate)	{m_iRate=iNewRate;}
 
 	// Barry - Process zip file as it arrives, don't need to wait until end of block
-	int unzip(Pending_Block_Struct *block, BYTE *zipped, uint32 lenZipped, BYTE **unzipped, uint32 *lenUnzipped, bool recursive = false);
+	int unzip(Pending_Block_Struct *block, byte *zipped, wxUint32 lenZipped, byte **unzipped, wxUint32 *lenUnzipped, bool recursive = false);
 	// Barry - Sets string to show parts downloading, eg NNNYNNNNYYNYN
 	void ShowDownloadingParts(wxString &partsYN);
 	void UpdateDisplayedInfo(bool force=false);
 	int  GetFileListRequested() { return m_iFileListRequested; }
 	void SetFileListRequested(int iFileListRequested) { m_iFileListRequested = iFileListRequested; }
-	uint8	m_cFailed;
+	wxUint8	m_cFailed;
 
 private:
 	CPartFile*		reqfile;
@@ -313,32 +322,31 @@ private:
 	bool	ProcessHelloTypePacket(CMemFile* data);
 	void	SendHelloTypePacket(CMemFile* data);
 	bool	m_bIsBotuser;
-//	bool	isfriend;
-	uint32	m_dwUserIP;
-	uint32	m_dwServerIP;
-	uint32	m_nUserID;
-	int16	m_nUserPort;
-	int16	m_nServerPort;
-	uint32	m_nClientVersion;
-	uint32	m_nUpDatarate;
-	uint32	dataratems;
-	uint32	m_cSendblock;
-	uint8	m_byEmuleVersion;
-	uint8	m_byDataCompVer;
+	wxUint32	m_dwUserIP;
+	wxUint32	m_dwServerIP;
+	wxUint32	m_nUserID;
+	wxInt16	m_nUserPort;
+	wxInt16	m_nServerPort;
+	wxUint32	m_nClientVersion;
+	wxUint32	m_nUpDatarate;
+	wxUint32	dataratems;
+	wxUint32	m_cSendblock;
+	wxUint8	m_byEmuleVersion;
+	wxUint8	m_byDataCompVer;
 	bool	m_bEmuleProtocol;
 	char*	m_pszUsername;
 	char	m_szFullUserIP[21];
 	char	m_achUserHash[16];
-	uint16	m_nUDPPort;
-	uint8	m_byUDPVer;
-	uint8	m_bySourceExchangeVer;
-	uint8	m_byAcceptCommentVer;
-	uint8	m_byExtendedRequestsVer;
+	wxUint16	m_nUDPPort;
+	wxUint8	m_byUDPVer;
+	wxUint8	m_bySourceExchangeVer;
+	wxUint8	m_byAcceptCommentVer;
+	wxUint8	m_byExtendedRequestsVer;
 	EClientSoftware	m_clientSoft;
-	uint32	m_dwLastSourceRequest;
-	uint32	m_dwLastSourceAnswer;
-	uint32  m_dwLastAskedForSources;
-	uint32  m_dwLastStateChange;
+	wxUint32	m_dwLastSourceRequest;
+	wxUint32	m_dwLastSourceAnswer;
+	wxUint32  m_dwLastAskedForSources;
+	wxUint32  m_dwLastStateChange;
 	int	m_iFileListRequested;
 	bool	m_bFriendSlot;
 	bool	m_bCommentDirty;
@@ -347,44 +355,44 @@ private:
 	bool	m_bGPLEvildoer;
 	bool	m_bPreviewReqPending;
 	bool	m_bPreviewAnsPending;
-	uint16	m_nKadPort;
+	wxUint16	m_nKadPort;
 	bool	m_bMultiPacket;
 
 	ESecureIdentState	m_SecureIdentState;
-	uint8	m_byInfopacketsReceived;
-	uint32	m_dwLastSignatureIP;
-	uint8	m_bySupportSecIdent;
+	wxUint8	m_byInfopacketsReceived;
+	wxUint32	m_dwLastSignatureIP;
+	wxUint8	m_bySupportSecIdent;
 	bool	m_bySupportsPreview;
 	
-	uint32	m_byCompatibleClient;
+	wxUint32	m_byCompatibleClient;
 	CTypedPtrList<CPtrList, Packet*>				 m_WaitingPackets_list;
 	DWORD	m_lastRefreshedDLDisplay;
 
 	//upload
-	void CreateStandartPackets(byte* data,uint32 togo, Requested_Block_Struct* currentblock);
-	void CreatePackedPackets(byte* data,uint32 togo, Requested_Block_Struct* currentblock);
+	void CreateStandartPackets(byte* data,wxUint32 togo, Requested_Block_Struct* currentblock);
+	void CreatePackedPackets(byte* data,wxUint32 togo, Requested_Block_Struct* currentblock);
 	bool		m_bBanned;
-	uint32		m_nTransferedUp;
-	uint8		m_byUploadState;
-	uint32		m_dwWaitTime;
-	uint32		m_dwUploadTime;
-	uint32		m_nMaxSendAllowed;
-	uint32		m_nAvUpDatarate;
-	uint32		m_cAsked;
-	uint32		m_dwLastUpRequest;
-	uint32		m_dwBanTime;
+	wxUint32		m_nTransferedUp;
+	wxUint8		m_byUploadState;
+	wxUint32		m_dwWaitTime;
+	wxUint32		m_dwUploadTime;
+	wxUint32		m_nMaxSendAllowed;
+	wxUint32		m_nAvUpDatarate;
+	wxUint32		m_cAsked;
+	wxUint32		m_dwLastUpRequest;
+	wxUint32		m_dwBanTime;
 	bool		m_bUsedComprUp;	//only used for interface output
-	uint32		m_nCurSessionUp;
-	uint16		m_nUpPartCount;
+	wxUint32		m_nCurSessionUp;
+	wxUint16		m_nUpPartCount;
 	static		CBarShader s_UpStatusBar;
-	uchar		requpfileid[16];
-	uint16 m_nUpCompleteSourcesCount;
+	byte		requpfileid[16];
+	wxUint16 m_nUpCompleteSourcesCount;
 	public:
-	uint8*		m_abyUpPartStatus;
-	uint16		m_lastPartAsked;
+	wxUint8*		m_abyUpPartStatus;
+	wxUint16		m_lastPartAsked;
 	DWORD		m_dwEnteredConnectedState;
 	CString		m_strModVersion;
-	uint32		m_nSumForAvgUpDataRate;
+	wxUint32		m_nSumForAvgUpDataRate;
 
 	private:
 	CList<int,int>	 m_AvarageUDR_list;
@@ -396,43 +404,42 @@ private:
 	//download
 	bool		m_bRemoteQueueFull;
 	bool		usedcompressiondown; //only used for interface output
-	uint8		m_nDownloadState;
-	uint16		m_nPartCount;
-	uint32		m_cDownAsked;
-	uint8*		m_abyPartStatus;
-	uint32		m_dwLastAskedTime;
+	wxUint8		m_nDownloadState;
+	wxUint16		m_nPartCount;
+	wxUint32		m_cDownAsked;
+	wxUint8*		m_abyPartStatus;
+	wxUint32		m_dwLastAskedTime;
 	wxString	m_strClientFilename;
 	char*		m_pszClientFilename;
-	uint32		m_nTransferedDown;
-	uint32      m_nLastBlockOffset;   // Patch for show parts that you download [Cax2]
-	uint32		m_nDownDatarate;
-	uint32		m_nDownDataRateMS;
-	uint32		m_nAvDownDatarate;
-	uint16		m_cShowDR;
-	uint32		m_dwLastBlockReceived;
-	uint16		m_nRemoteQueueRank;
+	wxUint32		m_nTransferedDown;
+	wxUint32      m_nLastBlockOffset;   // Patch for show parts that you download [Cax2]
+	wxUint32		m_nDownDatarate;
+	wxUint32		m_nDownDataRateMS;
+	wxUint32		m_nAvDownDatarate;
+	wxUint16		m_cShowDR;
+	wxUint32		m_dwLastBlockReceived;
+	wxUint16		m_nRemoteQueueRank;
 	bool		m_bCompleteSource;
 	bool		m_bReaskPending;
 	bool		m_bUDPPending;
-	uint32		m_nSumForAvgDownDataRate;
+	wxUint32		m_nSumForAvgDownDataRate;
 	bool		m_bHashsetRequested;
 	bool		m_bSharedDirectories;
  	bool		m_bNoViewSharedFiles;
 	bool		m_bSupportsPreview;
 
 	CList<int,int>	 m_AvarageDDR_list;
-	sint32		sumavgDDR;
-	sint32		sumavgUDR;
+	wxInt32		sumavgDDR;
+	wxInt32		sumavgUDR;
 	CTypedPtrList<CPtrList, Pending_Block_Struct*>	 m_PendingBlocks_list;
- // CTypedPtrList<CPtrList, CPartFile*>	 m_OtherRequests_list;    ---> See Razor 1a modif  : becomes public
 	CTypedPtrList<CPtrList, Requested_Block_Struct*> m_DownloadBlocks_list;
 	CTypedPtrList<CPtrList, CPartFile*>				 m_OtherNoNeeded_list;
 
 	static CBarShader s_StatusBar;
 	// chat
-	uint8 m_byChatstate;
+	wxUint8 m_byChatstate;
 	CString m_strComment;
-	int8 m_iRate;
+	wxInt8 m_iRate;
 
   /* Razor 1a - Modif by MikaelB */
   
@@ -487,14 +494,13 @@ private:
   public:
 
 	bool			thief;  // is a thief ?
-	uint64	getUID() 
+	wxUint64	getUID() 
  	{
-			uint64 ip = ((uint64) m_dwUserIP) << 32;
-			uint64 port = ((uint64) m_nUserPort) << 16;
-			uint64 uid = ip + port;
+			wxUint64 ip = ((wxUint64) m_dwUserIP) << 32;
+			wxUint64 port = ((wxUint64) m_nUserPort) << 16;
+			wxUint64 uid = ip + port;
 			return uid;
 	}		
-		//return ((uint64)m_dwUserIP<<32)+((uint64)m_nUserPort<<16); }
 	int				leechertype;  // what kind of leecher is it ?
   
 };
