@@ -64,11 +64,9 @@
     #pragma interface "wxTreeMultiCtrl.cpp"
 #endif
 
-#ifndef WX_PRECOMP
-    #include "wx/wx.h"
-#endif
-
-#include <wx/dynarray.h>
+#include <wx/event.h>                       // Needed for wxNotifyEvent
+#include <wx/scrolwin.h>                    // Needed for wxScrolledWindow
+//#include <wx/dynarray.h>
 
 
 // classes for internal tree structure
@@ -309,7 +307,7 @@ public:
     {
     }
 
-    virtual wxEvent *Clone() const { return new wxTreeMultiEvent(*this); }
+    virtual wxCommandEvent *Clone() const { return new wxTreeMultiEvent(*this); }
 
     wxTreeMultiItem GetItem() const
     {
