@@ -18,40 +18,62 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#include <iostream>                         // Needed for std::cout
-#include <mcheck.h>
-#include <gtk/gtk.h>                        // Needed for GTK_WINDOW_TOPLEVEL
-#include <sys/stat.h>                       // Needed for mkdir
 
-#include <wx/clipbrd.h>                     // Needed for wxTheClipboard
-#include <wx/msgdlg.h>                      // Needed for wxMessageBox
-#include <wx/splash.h>                      // Needed for wxSplashScreen
-#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
+#ifdef PRECOMP
+    #include "xmule-headers.h"
+#endif
 
 #include "xmule.h"                          // Needed for this Interface's Prototype
 
+#include "CFile.h"                          // Needed for CFile
 #include "ChatWnd.h"                        // Needed for CChatWnd
 #include "ClientCredits.h"                  // Needed for CClientCredits
 #include "ClientList.h"                     // Needed for CClientList
 #include "config.h"                         // Needed for HAVE_SYS_RESOURCE_H
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
 #include "DownloadQueue.h"                  // Needed for CDownloadQueue
-#include "NewSockets.h"                     // Needed for NewSocket_Start
 #include "ED2KLink.h"                       // Needed for CED2KLink
 #include "FlowChart.h"                      // Needed for CFlowChart
 #include "FriendList.h"                     // Needed for CFriendList
 #include "IPFilter.h"                       // Needed for CIPFilter
+#include "KnownFile.h"                      // Needed for CKnownFile
+#include "KnownFileList.h"                  // Needed for CKnownFileList
 #include "ldaemon.h"                        // Needed for CLDaemon
+#include "ListenSocket.h"                   // Needed for CListenSocket
 #include "muuli_wdr.h"                      // Needed for ID_FRIENDLIST
+#include "NewFunctions.h"                   // Needed for MAP
+#include "NewSockets.h"                     // Needed for NewSocket_Start
+#include "otherfunctions.h"                 // Needed for CastItoXBytes
+#include "Preferences.h"                    // Needed for CPreferences
 #include "PreferencesDlg.h"                 // Needed for CPreferencesDlg
+#include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
 #include "ServerWnd.h"                      // Needed for CServerWnd
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "SharedFilesCtrl.h"                // Needed for CSharedFilesCtrl
 #include "SharedFilesWnd.h"                 // Needed for CSharedFilesWnd
+#include "sockets.h"                        // Needed for CServerConnect
 #include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
 #include "TransferWnd.h"                    // Needed for CTransferWnd
+#include "updownclient.h"                   // Needed for CUpDownClient
+#include "UploadListCtrl.h"                 // Needed for CUploadListCtrl
 #include "UploadQueue.h"                    // Needed for CUploadQueue
 #include "xmuleDlg.h"                       // Needed for CxmuleDlg
 
 #include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
 
+#include <iostream>                         // Needed for std::cout
+#include <gtk/gtk.h>                        // Needed for GTK_WINDOW_TOPLEVEL
+#include <mcheck.h>
+
+#include <wx/clipbrd.h>                     // Needed for wxTheClipboard
+#include <wx/msgdlg.h>                      // Needed for wxMessageBox
+#include <wx/splash.h>                      // Needed for wxSplashScreen
+
+#include <wx/xrc/xmlres.h>                  // Needed for wxXmlResource
+
 using std::cout;
 using std::endl;
 
@@ -104,8 +126,6 @@ int CxmuleApp::OnExit()
     return wxApp::OnExit();
 }
 
-//CxmuleApp theApp;
-
 extern void InitXmlResource();
 
 bool CxmuleApp::OnInit()
@@ -127,26 +147,21 @@ bool CxmuleApp::OnInit()
         }
     }
 
-//    dyn_prefs = new DynamicPrefs;
-    MapData_Init(listof_UpDownClients);
-    // catch fatal exceptions
     wxHandleFatalExceptions(true);
-    //putenv("LANG=en_US");
     SetResourceLimits();
     // for resources
     wxXmlResource::Get()->InitAllHandlers();
     InitXmlResource();
     printf("Initialising xMule\n");
     close(0);
-    //if(ProcessCommandLine())
-    //  return FALSE;
-    //SetTopWindow(dlg);
     SetVendorName("TikuWarez");
+
     // Do NOT change this string to xMule nor anything else, it WILL fuck you up.
     SetAppName("eMule");
     m_locale.Init(wxLANGUAGE_DEFAULT);
     m_locale.AddCatalogLookupPathPrefix(LOCALEDIR);
-    m_locale.AddCatalog(PACKAGE);
+    m_locale.AddCatalog(PACKAGE_NAME);
+
     // Madcat - Check if prefs can be found at ~/.lmule and rename as neccesery.
     wxString OldPrefDir = getenv("HOME") + wxString("/.lmule");
     wxString NewPrefDir = getenv("HOME") + wxString("/.xMule");
@@ -157,15 +172,15 @@ bool CxmuleApp::OnInit()
     }
     if (!wxDirExists(NewPrefDir))
     {
-        mkdir(NewPrefDir, 0777);
+        wxMkdir(NewPrefDir, 0777);
     }
     if (!wxDirExists(NewPrefDir + wxString("/Incoming")))
     {
-        mkdir(NewPrefDir + wxString("/Incoming"), 0777);
+        wxMkdir(NewPrefDir + wxString("/Incoming"), 0777);
     }
     if (!wxDirExists(NewPrefDir + wxString("/Temp")))
     {
-        mkdir(NewPrefDir + wxString("/Temp"), 0777);
+        wxMkdir(NewPrefDir + wxString("/Temp"), 0777);
     }
     wxString filename = NewPrefDir + wxString("/server.met");
     if (!wxFileExists(filename))
@@ -189,13 +204,30 @@ bool CxmuleApp::OnInit()
     xmuledlg->flowchartwnd = new CFlowChart(xmuledlg);
     xmuledlg->flowchartwnd->Show(false);
     LoadCompatiblePrefs();
-
     xmuledlg->preferenceswnd->SetPrefs(glob_prefs);
+/*
+-----BEGIN PGP MESSAGE-----
+Charset: UTF-8
+Version: GnuPG v1.2.2
+Comment: This is a special comment that is never compiled.
+
+hQHOA2jcsHQEewHzEAcAjkfYTfMXMLjXwl/H92G6YV9ioEGOTK+mzQnkOUpk1Uht oyf5P4iz7bQc4UK71D+s3CFNMKirEa1Ho5+MXeFczHdqMAyUYiWyB5dMaTSTwOdp
+XI+/oMTo4imftEmak+h0SGBzagAVjRr5jY7EDSky/9EA3WWI7hN5b7k+nKZu+W4O s62KEwp8pEkqYxNH4GWGjA0xXgP3E/i6NNfaKQgo895fvHsPYLXTmMgVXf+W0TUN
+NvcxuysflrHb2eqpiu4K2TUcq8O8qr59Dnb2h4zgy7BCNe8IxKu2Ws7pqryrhDsG /3RSzus+HO4dD1yl74p7nYjLTKYoMwgSTg4qoVRGBhVjGanxJ58/VFqIc3rYWjgq
+q09U1amZaD0D64VzfZVe2VuN7KUlcQTK/BiAs16uuHLDbhuID6CUUTPSmnp0hL57 Lkg8MfRzI/HLSFzXlauK3hP1nNBdoFCnxaCkkXTBHVYViIbR0umBCCcTqFN3Gesr
+le/x5AQfdJUBy9vJqojC9UydwWR7fZDaP2kq0ddk9ZQePmcyMTmspXmZqN3yHAhz 3Z5GYEuATi9iVbYlLC0mKB/VhYnwD+lQeodaxluX/FFs0sCHAefz63ge/Y7oQ0JO
+8hX+FfdnPWZ1RGtDkXK7nvpfg03wPTpTpMPNEvFzwOir7FGpqyapTXwq8BuOWEyn FDw2gpmdkGSANTP9seVj++JZr631D6xIn/xqyvY0Tg8CSZLam6iAZ/45P7KsvWnA
+WZ8k6XmfsLqx5hOxTin1AJilmFnQDDwpT9Ut6DUo66yFdVdpc88yDutKvFFFnp4N 2Kfg2u3BNmaxNuyxyRJL5AqQAgLz47P3vn58f+IStOL9HoHemnaE+368AMzmGUAf
+xgDi99qMpDDUabceIP22Vwwxeuyqmn5FkPNVS3Tf+YnxYimVr846SUAumaYL74bz yd9fg0AQZs1ptlDZZqTBvOnQaJjIDRqPpoqczqthAfFs+byQSbXEndh3UU0zDzWU
+hu+JvF+Z2knW4lRM7VrainKZOdpEvT3EKEBI
+=BUaZ
+-----END PGP MESSAGE-----
+*/
     if (daemon == false)
     {
         xmuledlg->createSystray(wxString::Format(wxT("%s v%s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
     }
-    // splashscreen
+
     if (daemon == false && theApp.glob_prefs->UseSplashScreen() && !theApp.glob_prefs->GetStartMinimized())
     {
         InitSplashXRC();
@@ -219,21 +251,18 @@ bool CxmuleApp::OnInit()
     myaddr.AnyAddress();
     myaddr.Service(glob_prefs->GetPort());
     NewSocket_Start(1, 0, glob_prefs->GetUDPPort());
-//    xmuledlg->flowchartwnd->Sync(1, 1, serverconnect->GetLocalIP(), glob_prefs->GetUDPPort(), NULL);    
+
     // bugfix - do this before creating the uploadqueue:
     downloadqueue = new CDownloadQueue(glob_prefs, sharedfiles);
     uploadqueue = new CUploadQueue(glob_prefs);
     ipfilter = new CIPFilter();
     clientcredits = new CClientCreditsList(glob_prefs);
 //    webserver = new CWebServer();
-    //INT_PTR nResponse = dlg.DoModal();
-    // init statistics stuff, better do it asap
     xmuledlg->statisticswnd->Init();
     xmuledlg->statisticswnd->ShowInterval();
     // must do initialisations here..
     xmuledlg->serverwnd->serverlistctrl->Init(serverlist);
     serverlist->Init();
-    // ini. downloadqueue
     theApp.downloadqueue->Init();
     xmuledlg->AddLogLine(true, PACKAGE_STRING);
     //
@@ -283,7 +312,8 @@ bool CxmuleApp::OnInit()
     // pretty much ready now. start autoconnect if
     if (theApp.glob_prefs->DoAutoConnect())
     {
-        theApp.xmuledlg->OnBnConnect();
+        wxCommandEvent event;
+        theApp.xmuledlg->OnBnConnect(event);
     }
     return TRUE;
 }
@@ -299,7 +329,6 @@ void CxmuleApp::ProcessCommand()
     if ((lda->Command.Left (8)) == wxString ("connect "))
     {
         St1=lda->Command.AfterFirst (32);
-//        num=serverlist->GetServerCount ();
         notunderstood = false;
 
         CServer* cur_file;
@@ -486,7 +515,7 @@ bool CxmuleApp::CopyTextToClipboard(wxString strText)
 {
     if (wxTheClipboard->Open())
     {
-        wxTheClipboard->UsePrimarySelection(FALSE);
+        wxTheClipboard->UsePrimarySelection(TRUE);
         wxTheClipboard->SetData(new wxTextDataObject(strText));
         wxTheClipboard->Close();
     }
@@ -626,11 +655,11 @@ bool CxmuleApp::CopyTextToClipboard(wxString strText)
 void CxmuleApp::OnFatalException()
 {
     // Close sockets first.
-/*    if (theApp.listensocket)
+    if (theApp.listensocket)
     {
         theApp.listensocket->Destroy();
         NewSocket_Stop(1);
-    }*/
+    }
 
 // (stkn) create backtrace
 #if defined(__linux__)
@@ -875,10 +904,15 @@ void CxmuleApp::SetCompatiblePrefs()
     oldprefs->startMinimized = dynprefs->Get<bool>("start-minimized");
 
 // Connection Settings
-    oldprefs->maxupload = dynprefs->Get<long>("limits-upload");
-    oldprefs->maxdownload = dynprefs->Get<long>("limits-download");
-    oldprefs->maxGraphDownloadRate = dynprefs->Get<long>("capacities-download");
-    oldprefs->maxGraphUploadRate = dynprefs->Get<long>("capacities-upload");
+    long temp;
+    temp = dynprefs->Get<long>("capacities-download");
+    oldprefs->maxGraphDownloadRate = (temp == 0 ? 65535 : temp);
+    temp = dynprefs->Get<long>("capacities-upload");
+    oldprefs->maxGraphUploadRate = (temp == 0 ? 65535 : temp);
+    temp = dynprefs->Get<long>("limits-upload");
+    oldprefs->maxupload = (temp == 0 ? 65535 : temp);
+    temp = dynprefs->Get<long>("limits-download");
+    oldprefs->maxdownload = (temp == 0 ? 65535 : temp);
     oldprefs->port = dynprefs->Get<long>("tcp-port");
     oldprefs->udpport = dynprefs->Get<long>("udp-port");
     oldprefs->maxsourceperfile = dynprefs->Get<long>("max-sources");
