@@ -18,70 +18,69 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#include "xmuleDlg.h"
-#include "AddFileThread.h"
-#include "ChatWnd.h"
+
+#ifdef PRECOMP
+    #include "xmule-headers.h"
+#endif
+
+#include "xmuleDlg.h"                       // Needed for this Interface's Prototype
+
+#include "AddFileThread.h"                  // Needed for CAddFileThread
+#include "ChatWnd.h"                        // Needed for CChatWnd
 #include "ClientCredits.h"                  // Needed for CClientCredits
-#include "ClientList.h"
-#include "ClientUDPSocket.h"
-#include "config.h"
-#include "DownloadQueue.h"
-#include "ED2KLink.h"
-#include "FlowChart.h"
-#include "FriendList.h"
-#include "KnownFile.h"
-#include "KnownFileList.h"
+#include "ClientList.h"                     // Needed for CClientList
+#include "ClientUDPSocket.h"                // Needed for CClientUDPSocket
+#include "config.h"                         // Needed for PACKAGE_NAME
+#include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
+#include "DownloadQueue.h"                  // Needed for CDownloadQueue
+#include "FriendList.h"                     // Needed for CFriendList
+#include "KnownFileList.h"                  // Needed for CKnownFileList
 #include "ldaemon.h"                        // Needed for CLDaemon
-#include "ListenSocket.h"
-#include "muuli_wdr.h"
-#include "NewSockets.h"
-#include "opcodes.h"
-#include "PartFile.h"
+#include "ListenSocket.h"                   // Needed for CListenSocket
+#include "muuli_wdr.h"                      // Needed for ID_BUTTONCONNECT
+#include "NewSockets.h"                     // Needed for NewSocket_Stop
+#include "PartFile.h"                       // Needed for CPartFile
 #include "Preferences.h"                    // Needed for CPreferences
-#include "PreferencesDlg.h"
-#include "resource.h"
-#include "SearchDlg.h"
-#include "ServerList.h"
-#include "ServerSocket.h"
-#include "ServerWnd.h"
-#include "SharedFileList.h"
-#include "SharedFilesWnd.h"
-#include "sockets.h"
-#include "StatisticsDlg.h"
-#include "SysTray.h"
-#include "TransferWnd.h"
-#include "UDPSocket.h"
-#include "UploadQueue.h"
-#include "xmule.h"
+#include "PreferencesDlg.h"                 // Needed for CPreferencesDlg
+#include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
+#include "SearchDlg.h"                      // Needed for CSearchDlg
+#include "server.h"                         // Needed for CServer
+#include "ServerList.h"                     // Needed for CServerList
+#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
+#include "ServerSocket.h"                   // Needed for CServerSocket
+#include "ServerWnd.h"                      // Needed for CServerWnd
+#include "SharedFileList.h"                 // Needed for CSharedFileList
+#include "SharedFilesCtrl.h"                // Needed for CSharedFilesCtrl
+#include "SharedFilesWnd.h"                 // Needed for CSharedFilesWnd
+#include "sockets.h"                        // Needed for CServerConnect
+#include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
+#include "SysTray.h"                        // Needed for CSysTray
+#include "TransferWnd.h"                    // Needed for CTransferWnd
+#include "UDPSocket.h"                      // Needed for CUDPSocket
+#include "UploadListCtrl.h"                 // Needed for CUploadListCtrl
+#include "UploadQueue.h"                    // Needed for CUploadQueue
+#include "xmule.h"                          // Needed for theApp
 
 #include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
 
-#include <errno.h>
-#include <math.h>
-#include <signal.h>
-#include <arpa/inet.h>                  // Needed for inet_addr
+#include <cerrno>                           // Needed for errno
+#include <cmath>                            // Needed for ceil
+#include <signal.h>                         // Needed for SIGPIPE
+#include <arpa/inet.h>                      // Needed for inet_addr
 
-#include <wx/msgdlg.h>                  // Needed for wxMessageBox
-#include <wx/sizer.h>                   // Needed for wxSizer::Show
-#include <wx/socket.h>
-#include <wx/splash.h>
-#include <wx/splitter.h>                // Needed for wxSplitterWindow
-#include <wx/toolbar.h>
-#include <wx/utils.h>
-#include <wx/radiobut.h>
-
-//#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+#include <wx/config.h>                      // Needed for wxConfigBase
+#include <wx/msgdlg.h>                      // Needed for wxMessageBox
+#include <wx/radiobut.h>                    // Needed for wxRadioButton
+#include <wx/sizer.h>                       // Needed for wxSizer::Show
+#include <wx/splitter.h>                    // Needed for wxSplitterWindow
+#include <wx/stattext.h>                    // Needed for wxStaticText
+#include <wx/textctrl.h>                    // Needed for wxTextCtrl
 
+// connection images
 #include "pixmaps/mule_TrayIcon.ico.xpm"
 #include "pixmaps/mule_Tr_yellow.ico.xpm"
 #include "pixmaps/mule_Tr_grey.ico.xpm"
 
-// connection images
-
-#ifdef _DEBUG
-#define new DEBUG_NEW
-#endif
-
 #if wxMINOR_VERSION > 4
 #	define CLOSEBOX wxCLOSE_BOX
 #else
@@ -170,7 +169,7 @@ void muleDefaultToolbar(wxToolBar * parent)
 // CxmuleDlg Dialog
 
 CxmuleDlg::CxmuleDlg(wxWindow * pParent, wxString title)
-: wxFrame(pParent, CxmuleDlg::IDD, title, wxDefaultPosition, wxSize(800, 520),
+: wxFrame(pParent, -1, title, wxDefaultPosition, wxSize(800, 520),
 wxCAPTION | wxRESIZE_BORDER | wxSYSTEM_MENU | wxDIALOG_NO_PARENT | wxTHICK_FRAME | wxMINIMIZE_BOX | wxMAXIMIZE_BOX | CLOSEBOX)
 {
     theApp.xmuledlg = this;
@@ -259,7 +258,7 @@ class QueryDlg: public wxDialog
         Centre();
         };
     protected:
-    void OnOk(wxEvent & evt)
+    void OnOk(wxCommandEvent& evt)
     {
         EndModal(0);
         };
@@ -312,7 +311,9 @@ void CxmuleDlg::OnUQTimer(wxTimerEvent & evt)
 {
     // call timerproc
     if (!IsRunning())
-    return;
+    {
+        return;
+    }
     TimerProc();
 }
 
@@ -332,7 +333,8 @@ void CxmuleDlg::OnToolClick(wxCommandEvent& event)
 
     if (id == ID_BUTTONCONNECT)
     {
-        OnBnConnect();
+        wxCommandEvent temp_event;
+        OnBnConnect(temp_event);
     }
     else if (id == ID_BUTTONPREFERENCES)
     {
@@ -355,14 +357,14 @@ void CxmuleDlg::OnToolClick(wxCommandEvent& event)
         case ID_BUTTONSHARED: SetActiveDialog(sharedfileswnd); m_nActiveDialog = 4; break;
         case ID_BUTTONMESSAGES: SetActiveDialog(chatwnd); m_nActiveDialog = 5; break;
         case ID_BUTTONSTATISTICS: SetActiveDialog(statisticswnd); m_nActiveDialog = 6; break;
-        case ID_BUTTONFLOWCHART: SetActiveDialog(flowchartwnd); m_nActiveDialog = 7; break;
+        case ID_BUTTONFLOWCHART: SetActiveDialog((wxWindow *)flowchartwnd); m_nActiveDialog = 7; break;
         default: break;
     };
     theApp.SetCompatiblePrefs();    
     // UpdateBar();
 }
 
-void CxmuleDlg::btnPreferences(wxEvent & ev)
+void CxmuleDlg::btnPreferences(wxCommandEvent& ev)
 {
     theApp.SetCompatiblePrefs();
     // do preferences
@@ -595,7 +597,7 @@ void CxmuleDlg::ShutDown()
 
 // CxmuleDlg eventhandler
 
-void CxmuleDlg::OnBnConnect()
+void CxmuleDlg::OnBnConnect(wxCommandEvent& event)
 {
     if (!theApp.serverconnect->IsConnected())
     //connect if not currently connected
@@ -630,7 +632,6 @@ void CxmuleDlg::ResetDebugLog()
 {
     logtext = "";
     //SetWindowText(logtext);:
-    serverwnd->logbox.Clear();
 }
 
 void CxmuleDlg::AddLogLine(bool addtostatusbar, const wxChar * line, ...)
@@ -841,26 +842,37 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll)
 
     lastuprate = theApp.uploadqueue->GetDatarate();
     lastdownrate = theApp.downloadqueue->GetDatarate();
+    
     int lastuprateoverhead = theApp.uploadqueue->GetUpDatarateOverhead();
     int lastdownrateoverhead = theApp.downloadqueue->GetDownDatarateOverhead();
+
     if (theApp.glob_prefs->ShowOverhead())
-    sprintf(buffer, GetResString(IDS_UPDOWN), (float) lastuprate/ 1024, (float) lastuprateoverhead/ 1024, (float) lastdownrate/ 1024, (float) lastdownrateoverhead/ 1024);
-    else
-    sprintf(buffer, GetResString(IDS_UPDOWNSMALL), (float) lastuprate/ 1024, (float) lastdownrate/ 1024);
-    //statusbar.SetStatusText(buffer,2); //,0);
-    ((wxStaticText *) FindWindowByName("speedLabel"))->SetLabel(buffer);
-    Layout();
-    if (theApp.serverconnect->IsConnected())
     {
-	sprintf(buffer2, wxString(_("xMule (%s | ") + GetResString(IDS_CONNECTED) + ")") .GetData(), buffer);
-	server = theApp.serverconnect->GetCurrentServer ();
-	if (server)
-	    ConnState = GetResString(IDS_CONNECTED) + wxString (" ") + server->GetListName();
+        sprintf(buffer, GetResString(IDS_UPDOWN), (float) lastuprate/ 1024, (float) lastuprateoverhead/ 1024, (float) lastdownrate/ 1024, (float) lastdownrateoverhead/ 1024);
     }
     else
     {
-	sprintf(buffer2, wxString(_("xMule (%s | ") + GetResString(IDS_DISCONNECTED) + ")") .GetData(), buffer);
-	ConnState = GetResString(IDS_DISCONNECTED);
+        sprintf(buffer, GetResString(IDS_UPDOWNSMALL), (float) lastuprate/ 1024, (float) lastdownrate/ 1024);
+    }
+
+    //statusbar.SetStatusText(buffer,2); //,0);
+    ((wxStaticText *) FindWindowByName("speedLabel"))->SetLabel(buffer);
+    //Layout();
+    
+    if (theApp.serverconnect->IsConnected())
+    {
+        sprintf(buffer2, wxString(_("xMule (%s | ") + GetResString(IDS_CONNECTED) + ")") .GetData(), buffer);
+        server = theApp.serverconnect->GetCurrentServer ();
+    
+        if (server)
+        {
+            ConnState = GetResString(IDS_CONNECTED) + wxString (" ") + server->GetListName();
+        }
+    }
+    else
+    {
+        sprintf(buffer2, wxString(_("xMule (%s | ") + GetResString(IDS_DISCONNECTED) + ")") .GetData(), buffer);
+        ConnState = GetResString(IDS_DISCONNECTED);
     }
 
     if (!theApp.daemon)
@@ -873,22 +885,33 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll)
         m_wndTaskbarNotifier->TraySetToolTip(buffer2);
     }
 
-    wxStaticBitmap * bmp = (wxStaticBitmap *) FindWindowByName("transferImg");
+    wxStaticBitmap* bmp = (wxStaticBitmap *)FindWindowByName("transferImg");
+    
     if (lastuprate && lastdownrate)
-    bmp->SetBitmap(transicons[3]);
-    else if(lastuprate)
-    bmp->SetBitmap(transicons[2]);
-    else if(lastdownrate)
-    bmp->SetBitmap(transicons[1]);
+    {
+        bmp->SetBitmap(transicons[3]);
+    }
+    else if (lastuprate)
+    {
+        bmp->SetBitmap(transicons[2]);
+    }
+    else if (lastdownrate)
+    {
+        bmp->SetBitmap(transicons[1]);
+    }
     else
-    bmp->SetBitmap(transicons[0]);
+    {
+        bmp->SetBitmap(transicons[0]);
+    }
+
     //PLK Show-Rates on title
     if (theApp.glob_prefs->ShowRatesOnTitle())
     {
         if (theApp.daemon)
         {
-            theApp.lda->Print (wxString::Format(wxT("%s v%s --- %s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION), buffer,ConnState.GetData()),LD_STATUS,true);
+            theApp.lda->Print(wxString::Format(wxT("%s v%s --- %s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION), buffer,ConnState.GetData()),LD_STATUS,true);
         }
+
         if (!theApp.nowindow)
         {
             theApp.xmuledlg->SetTitle(wxString::Format(wxT("%s v%s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION), buffer));
@@ -900,9 +923,10 @@ void CxmuleDlg::ShowTransferRate(bool foreceAll)
         {
             theApp.lda->Print (wxString::Format(wxT("%s v%s --- %s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION),ConnState.GetData()),LD_STATUS,true);
         }
+        
         if (!theApp.nowindow)
         {
-              theApp.xmuledlg->SetTitle(wxString::Format(wxT("%s v%s                                         "), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
+              theApp.xmuledlg->SetTitle(wxString::Format(wxT("%s v%s"), wxT(PACKAGE_NAME), wxT(PACKAGE_VERSION)));
         }
     }
 }
