@@ -36,8 +36,19 @@
 
 #include "DynPrefs.h"
 
+#include <wx/button.h>                      // Needed for wxButton
+#include <wx/checkbox.h>                    // Needed for wxCheckBox
+#include <wx/combobox.h>                    // Needed for wxComboBox
+#include <wx/dirdlg.h>                      // Needed for wxDirDialog
 #include <wx/filesys.h>                     // Needed for wxFileSystem
+#include <wx/intl.h>                        // Needed for _
+#include <wx/msgdlg.h>                      // Needed for wxMessageBox
+#include <wx/sizer.h>                       // Needed for wxBoxSizer
+#include <wx/slider.h>                      // Needed for wxSlider
 #include <wx/statline.h>                    // Needed for wxStaticLine
+#include <wx/stattext.h>                    // Needed for wxStaticText
+#include <wx/textctrl.h>                    // Needed for EVT_TEXT
+#include <wx/valtext.h>                     // Needed for wxFILTER_NUMERIC
 
 const wxEventType wxEVT_PREFS_CHANGED = wxNewEventType();
 short int E_BROWSE1 = 6660;
@@ -90,7 +101,7 @@ BEGIN_EVENT_TABLE(DynamicPreferencesCtrl, wxTreeMultiCtrl)
     EVT_ROOT_EXPANDED(-1, DynamicPreferencesCtrl::OnExpandNode)
 //    EVT_SCROLL(DynamicPreferencesCtrl::OnSlider)
 END_EVENT_TABLE()
-
+  
 class SmartSlider: public wxSlider
 {
 public:
@@ -136,33 +147,33 @@ void DynamicPreferencesCtrl::OnExpandNode(wxTreeMultiEvent* event)
     OnChangedPrefs(event);
 }
 
-void DynamicPreferencesCtrl::OnCheckBox(wxCommandEvent* event)
+void DynamicPreferencesCtrl::OnCheckBox(wxCommandEvent& event)
 {
-    dynprefs->Add(ControlName(this->FindWindowById(event->GetId())->GetName()), event->IsChecked());
+    dynprefs->Add(ControlName(this->FindWindowById(event.GetId())->GetName()), event.IsChecked());
 }
 
-void DynamicPreferencesCtrl::OnTextChange(wxCommandEvent* event)
+void DynamicPreferencesCtrl::OnTextChange(wxCommandEvent& event)
 {
-    wxChar first_char = this->FindWindowById(event->GetId())->GetName().GetChar(0);
+    wxChar first_char = this->FindWindowById(event.GetId())->GetName().GetChar(0);
     if (first_char == wxT('c'))
     {
-        dynprefs->Add(ControlName(this->FindWindowById(event->GetId())->GetName()), event->GetInt());
+      dynprefs->Add(ControlName(this->FindWindowById(event.GetId())->GetName()), event.GetInt());
     }
     else if (first_char == wxT('l'))
     {
         long number;
-        event->GetString().ToLong(&number);
-        dynprefs->Add(ControlName(this->FindWindowById(event->GetId())->GetName()), number);
+        event.GetString().ToLong(&number);
+        dynprefs->Add(ControlName(this->FindWindowById(event.GetId())->GetName()), number);
     }
     else if (first_char == wxT('f'))
     {
         double number;
-        event->GetString().ToDouble(&number);
-        dynprefs->Add(ControlName(this->FindWindowById(event->GetId())->GetName()), number);
+        event.GetString().ToDouble(&number);
+        dynprefs->Add(ControlName(this->FindWindowById(event.GetId())->GetName()), number);
     }
     else
     {
-        dynprefs->Add(ControlName(this->FindWindowById(event->GetId())->GetName()), event->GetString());
+        dynprefs->Add(ControlName(this->FindWindowById(event.GetId())->GetName()), event.GetString());
     }
 }
 
