@@ -3,7 +3,7 @@
 // Purpose:     XML resources
 // Author:      Vaclav Slavik
 // Created:     2000/03/05
-// RCS-ID:      $Id: xmlres.h,v 1.1 2004/03/13 04:01:18 hopeseekr Exp $
+// RCS-ID:      $Id: xmlres.h,v 1.2 2004/08/28 02:37:39 HopeSeekr Exp $
 // Copyright:   (c) 2000 Vaclav Slavik
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -15,11 +15,13 @@
 #pragma interface "xmlres.h"
 #endif
 
+#include <list>                             // Needed for std::list
+#include <vector>                           // Needed for std::vector
+
 #include "wx/defs.h"
 #include "wx/string.h"
 #include "wx/dynarray.h"
 #include "wx/datetime.h"
-#include "wx/list.h"
 #include "wx/gdicmn.h"
 #include "wx/filesys.h"
 #include "wx/bitmap.h"
@@ -28,17 +30,17 @@
 
 #include "wx/xrc/xml.h"
 
-class WXDLLEXPORT wxMenu;
-class WXDLLEXPORT wxMenuBar;
-class WXDLLEXPORT wxDialog;
-class WXDLLEXPORT wxPanel;
-class WXDLLEXPORT wxWindow;
-class WXDLLEXPORT wxFrame;
-class WXDLLEXPORT wxToolBar;
+class wxMenu;
+class wxMenuBar;
+class wxDialog;
+class wxPanel;
+class wxWindow;
+class wxFrame;
+class wxToolBar;
 
-class WXXMLDLLEXPORT wxXmlResourceHandler;
-class WXXMLDLLEXPORT wxXmlSubclassFactory;
-class WXXMLDLLEXPORT wxXmlSubclassFactoriesList;
+class wxXmlResourceHandler;
+class wxXmlSubclassFactory;
+typedef std::list<wxXmlSubclassFactory *> wxXmlSubclassFactoriesList;
 class wxXmlResourceModule;
 
 
@@ -66,7 +68,7 @@ class wxXmlResourceModule;
                  WX_XMLRES_CURRENT_VERSION_RELEASE * 256 + \
                  WX_XMLRES_CURRENT_VERSION_REVISION)
 
-class WXXMLDLLEXPORT wxXmlResourceDataRecord
+class wxXmlResourceDataRecord
 {
 public:
     wxXmlResourceDataRecord() : Doc(NULL), Time(wxDateTime::Now()) {}
@@ -78,12 +80,6 @@ public:
 };
 
 
-#ifdef WXXMLISDLL
-WX_DECLARE_EXPORTED_OBJARRAY(wxXmlResourceDataRecord, wxXmlResourceDataRecords);
-#else
-WX_DECLARE_OBJARRAY(wxXmlResourceDataRecord, wxXmlResourceDataRecords);
-#endif
-
 enum wxXmlResourceFlags
 {
     wxXRC_USE_LOCALE     = 1,
@@ -93,7 +89,7 @@ enum wxXmlResourceFlags
 // This class holds XML resources from one or more .xml files
 // (or derived forms, either binary or zipped -- see manual for
 // details).
-class WXXMLDLLEXPORT wxXmlResource : public wxObject
+class wxXmlResource : public wxObject
 {
 public:
     // Constructor.
@@ -102,7 +98,8 @@ public:
     //        wxXRC_NO_SUBCLASSING
     //              subclass property of object nodes will be ignored
     //              (useful for previews in XRC editors)
-    wxXmlResource(int flags = wxXRC_USE_LOCALE);
+    wxXmlResource();
+    wxXmlResource(int flags);
 
     // Constructor.
     // Flags: wxXRC_USE_LOCALE
@@ -256,8 +253,8 @@ private:
     long m_version;
 
     int m_flags;
-    wxList m_handlers;
-    wxXmlResourceDataRecords m_data;
+    std::list<wxXmlResourceHandler *> m_handlers;
+    std::vector<wxXmlResourceDataRecord *> m_data;
 #if wxUSE_FILESYSTEM
     wxFileSystem m_curFileSystem;
     wxFileSystem& GetCurFileSystem() { return m_curFileSystem; }
@@ -307,14 +304,14 @@ private:
 // wxXmlResourceHandler is an abstract base class for resource handlers
 // capable of creating a control from an XML node.
 
-class WXXMLDLLEXPORT wxXmlResourceHandler : public wxObject
+class wxXmlResourceHandler : public wxObject
 {
 public:
     // Constructor.
     wxXmlResourceHandler();
 
     // Destructor.
-    virtual ~wxXmlResourceHandler() {}
+    virtual ~wxXmlResourceHandler();
 
     // Creates an object (menu, dialog, control, ...) from an XML node.
     // Should check for validity.
@@ -466,7 +463,7 @@ void wxXmlInitResourceModule();
 // register your subclasses via wxWindows' RTTI mechanism. This class is useful
 // only for language bindings developer who need a way to implement subclassing
 // in wxWindows ports that don't support wxRTTI (e.g. wxPython).
-class WXXMLDLLEXPORT wxXmlSubclassFactory
+class wxXmlSubclassFactory
 {
 public:
     // Try to create instance of given class and return it, return NULL on failure:
