@@ -3,7 +3,7 @@
 // Purpose:     XRC resource for panels
 // Author:      Vaclav Slavik
 // Created:     2000/03/05
-// RCS-ID:      $Id: xh_panel.cpp,v 1.1 2004/03/13 04:01:17 hopeseekr Exp $
+// RCS-ID:      $Id: xh_panel.cpp,v 1.2 2004/08/23 05:53:32 HopeSeekr Exp $
 // Copyright:   (c) 2000 Vaclav Slavik
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -25,7 +25,7 @@
 
 wxPanelXmlHandler::wxPanelXmlHandler() : wxXmlResourceHandler()
 {
-    XRC_ADD_STYLE(wxNO_3D);
+  //    XRC_ADD_STYLE(wxNO_3D);
     XRC_ADD_STYLE(wxTAB_TRAVERSAL);
     XRC_ADD_STYLE(wxWS_EX_VALIDATE_RECURSIVELY);
     XRC_ADD_STYLE(wxCLIP_CHILDREN);
