@@ -3,7 +3,7 @@
 // Purpose:     wxXmlDocument - XML parser & data holder class
 // Author:      Vaclav Slavik
 // Created:     2000/03/05
-// RCS-ID:      $Id: xml.cpp,v 1.2 2004/08/15 04:04:15 HopeSeekr Exp $
+// RCS-ID:      $Id: xml.cpp,v 1.4 2004/08/28 02:37:38 HopeSeekr Exp $
 // Copyright:   (c) 2000 Vaclav Slavik
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,13 +12,14 @@
 #pragma implementation "xml.h"
 #endif
 
-// For compilers that support precompilation, includes "wx.h".
-#include "wx/wxprec.h"
+#include <wx/version.h>                     // Needed for wxCHECK_VERSION
 
-#ifdef __BORLANDC__
-    #pragma hdrstop
-#endif
+#if wxCHECK_VERSION(2, 5, 0)
+    #include "wx/xml/xml.h"
+#else
+    #include "wx/xrc/xml.h"
 
+#if wxUSE_XML
 
 #include "wx/wfstream.h"
 #include "wx/datstrm.h"
@@ -27,9 +28,14 @@
 #include "wx/intl.h"
 #include "wx/strconv.h"
 
-#include "wx/xrc/xml.h"
+#include "expat.h" // from Expat
 
-#include "xmlparse.h" // from Expat
+// DLL options compatibility check:
+#include "wx/app.h"
+
+#if wxCHECK_VERSION(2, 5, 0)
+    WX_CHECK_BUILD_OPTIONS("wxXML")
+#endif
 
 //-----------------------------------------------------------------------------
 //  wxXmlNode
@@ -151,8 +157,8 @@ wxString wxXmlNode::GetPropVal(const wxString& propName, const wxString& default
     wxString tmp;
     if (GetPropVal(propName, &tmp))
         return tmp;
-    else
-        return defaultVal;
+
+    return defaultVal;
 }
 
 void wxXmlNode::AddChild(wxXmlNode *child)
@@ -320,13 +326,9 @@ void wxXmlDocument::DoCopy(const wxXmlDocument& doc)
     m_fileEncoding = doc.m_fileEncoding;
     m_root = new wxXmlNode(*doc.m_root);
 }
-#include <iostream>
-using namespace std;
-
 
 bool wxXmlDocument::Load(const wxString& filename, const wxString& encoding)
 {
-    cout << "Filename: " << filename << endl;
     wxFileInputStream stream(filename);
     return Load(stream, encoding);
 }
@@ -359,7 +361,7 @@ inline static wxString CharToString(wxMBConv *conv,
     if ( conv )
     {
         size_t nLen = (len != wxSTRING_MAXLEN) ? len :
-                          nLen = wxConvUTF8.MB2WC((wchar_t*) NULL, s, 0);
+                          wxConvUTF8.MB2WC((wchar_t*) NULL, s, 0);
 
         wchar_t *buf = new wchar_t[nLen+1];
         wxConvUTF8.MB2WC(buf, s, nLen);
@@ -369,7 +371,7 @@ inline static wxString CharToString(wxMBConv *conv,
         return str;
     }
     else
-        return wxString(s, len);
+        return wxString(s, len != wxSTRING_MAXLEN ? len : strlen(s));
 #endif
 }
 
@@ -535,27 +537,35 @@ bool wxXmlDocument::Load(wxInputStream& stream, const wxString& encoding)
     XML_SetDefaultHandler(parser, DefaultHnd);
     XML_SetUnknownEncodingHandler(parser, UnknownEncodingHnd, NULL);
 
-    bool ok = TRUE;
+    bool ok = true;
     do
     {
         size_t len = stream.Read(buf, BUFSIZE).LastRead();
         done = (len < BUFSIZE);
         if (!XML_Parse(parser, buf, len, done))
         {
+            wxString error(XML_ErrorString(XML_GetErrorCode(parser)),
+                           *wxConvCurrent);
             wxLogError(_("XML parsing error: '%s' at line %d"),
-                       XML_ErrorString(XML_GetErrorCode(parser)),
+                       error.c_str(),
                        XML_GetCurrentLineNumber(parser));
-            ok = FALSE;
+            ok = false;
             break;
         }
     } while (!done);
 
     if (ok)
     {
-        SetVersion(ctx.version);
-        SetFileEncoding(ctx.encoding);
+        if (!ctx.version.IsEmpty())
+            SetVersion(ctx.version);
+        if (!ctx.encoding.IsEmpty())
+            SetFileEncoding(ctx.encoding);
         SetRoot(ctx.root);
     }
+    else
+    {
+        delete ctx.root;
+    }
 
     XML_ParserFree(parser);
 #if !wxUSE_UNICODE
@@ -575,11 +585,16 @@ bool wxXmlDocument::Load(wxInputStream& stream, const wxString& encoding)
 
 // write string to output:
 inline static void OutputString(wxOutputStream& stream, const wxString& str,
-                                wxMBConv *convMem, wxMBConv *convFile)
+#if wxUSE_UNICODE
+    wxMBConv * WXUNUSED(convMem),
+#else
+    wxMBConv *convMem,
+#endif
+    wxMBConv *convFile)
 {
     if (str.IsEmpty()) return;
 #if wxUSE_UNICODE
-    const wxWX2MBbuf buf(str.mb_str(convFile ? *convFile : wxConvUTF8));
+    const wxWX2MBbuf buf(str.mb_str(*(convFile ? convFile : &wxConvUTF8)));
     stream.Write((const char*)buf, strlen((const char*)buf));
 #else
     if ( convFile == NULL )
@@ -595,7 +610,8 @@ inline static void OutputString(wxOutputStream& stream, const wxString& str,
 // Same as above, but create entities first.
 // Translates '<' to "&lt;", '>' to "&gt;" and '&' to "&amp;"
 static void OutputStringEnt(wxOutputStream& stream, const wxString& str,
-                            wxMBConv *convMem, wxMBConv *convFile)
+                            wxMBConv *convMem, wxMBConv *convFile,
+                            bool escapeQuotes = false)
 {
     wxString buf;
     size_t i, last, len;
@@ -607,7 +623,8 @@ static void OutputStringEnt(wxOutputStream& stream, const wxString& str,
     {
         c = str.GetChar(i);
         if (c == wxT('<') || c == wxT('>') ||
-            (c == wxT('&') && str.Mid(i+1, 4) != wxT("amp;")))
+            (c == wxT('&') && str.Mid(i+1, 4) != wxT("amp;")) ||
+            (escapeQuotes && c == wxT('"')))
         {
             OutputString(stream, str.Mid(last, i - last), convMem, convFile);
             switch (c)
@@ -621,6 +638,9 @@ static void OutputStringEnt(wxOutputStream& stream, const wxString& str,
                 case wxT('&'):
                     OutputString(stream, wxT("&amp;"), NULL, NULL);
                     break;
+                case wxT('"'):
+                    OutputString(stream, wxT("&quot;"), NULL, NULL);
+                    break;
                 default: break;
             }
             last = i + 1;
@@ -656,10 +676,11 @@ static void OutputNode(wxOutputStream& stream, wxXmlNode *node, int indent,
             prop = node->GetProperties();
             while (prop)
             {
-                OutputString(stream, wxT(" ") + prop->GetName() +
-                             wxT("=\"") + prop->GetValue() + wxT("\""),
+                OutputString(stream, wxT(" ") + prop->GetName() +  wxT("=\""),
                              NULL, NULL);
-                // FIXME - what if prop contains '"'?
+                OutputStringEnt(stream, prop->GetValue(), NULL, NULL,
+                                true/*escapeQuotes*/);
+                OutputString(stream, wxT("\""), NULL, NULL);
                 prop = prop->GetNext();
             }
 
@@ -729,3 +750,6 @@ bool wxXmlDocument::Save(wxOutputStream& stream) const
 
     return TRUE;
 }
+
+#endif // wxUSE_XML
+#endif
