@@ -3,7 +3,7 @@
 // Purpose:     XRC resources
 // Author:      Vaclav Slavik
 // Created:     2000/03/05
-// RCS-ID:      $Id: xmlres.cpp,v 1.1 2004/03/13 04:01:18 hopeseekr Exp $
+// RCS-ID:      $Id: xmlres.cpp,v 1.2 2004/08/28 02:37:38 HopeSeekr Exp $
 // Copyright:   (c) 2000 Vaclav Slavik
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -13,34 +13,33 @@
 #endif
 
 // For compilers that support precompilation, includes "wx.h".
-#include "wx/wxprec.h"
+#include <wx/wxprec.h>
 
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 
-#include "wx/dialog.h"
-#include "wx/panel.h"
-#include "wx/frame.h"
-#include "wx/wfstream.h"
-#include "wx/filesys.h"
-#include "wx/filename.h"
-#include "wx/log.h"
-#include "wx/intl.h"
-#include "wx/tokenzr.h"
-#include "wx/fontenum.h"
-#include "wx/module.h"
-#include "wx/bitmap.h"
-#include "wx/image.h"
-#include "wx/fontmap.h"
-#include "wx/artprov.h"
 
-#include "wx/xrc/xml.h"
-#include "wx/xrc/xmlres.h"
-
-#include "wx/arrimpl.cpp"
-WX_DEFINE_OBJARRAY(wxXmlResourceDataRecords);
+#include <wx/artprov.h>
+#include <wx/bitmap.h>
+#include <wx/dialog.h>
+#include <wx/filename.h>
+#include <wx/filesys.h>
+#include <wx/fontenum.h>
+#include <wx/fontmap.h>
+#include <wx/frame.h>
+#include <wx/image.h>
+#include <wx/intl.h>
+#include <wx/list.h>
+#include <wx/listimpl.cpp>
+#include <wx/log.h>
+#include <wx/module.h>
+#include <wx/panel.h>
+#include <wx/tokenzr.h>
+#include <wx/wfstream.h>
 
+#include <wx/xrc/xml.h>
+#include <wx/xrc/xmlres.h>
 
 wxXmlResource *wxXmlResource::ms_instance = NULL;
 
@@ -58,9 +57,14 @@ wxXmlResource *wxXmlResource::ms_instance = NULL;
     return old;
 }
 
+wxXmlResource::wxXmlResource()
+{
+    m_flags = wxXRC_USE_LOCALE;
+    m_version = -1;
+}
+
 wxXmlResource::wxXmlResource(int flags)
 {
-    m_handlers.DeleteContents(TRUE);
     m_flags = flags;
     m_version = -1;
 }
@@ -69,13 +73,20 @@ wxXmlResource::wxXmlResource(const wxString& filemask, int flags)
 {
     m_flags = flags;
     m_version = -1;
-    m_handlers.DeleteContents(TRUE);
     Load(filemask);
 }
 
 wxXmlResource::~wxXmlResource()
 {
     ClearHandlers();
+    
+    std::list<wxXmlSubclassFactory *>::iterator it;
+    for (it = ms_subclassFactories->begin(); it != ms_subclassFactories->end(); ++it)
+    {
+        delete *it;
+    }
+    ms_subclassFactories->clear();
+    delete ms_subclassFactories;
 }
 
 
@@ -126,10 +137,10 @@ bool wxXmlResource::Load(const wxString& filemask)
         }
         else
 #endif
-        {
+        {            
             drec = new wxXmlResourceDataRecord;
             drec->File = fnd;
-            m_data.Add(drec);
+            m_data.push_back(drec);
         }
 
         if (iswild)
@@ -144,15 +155,15 @@ bool wxXmlResource::Load(const wxString& filemask)
 
 
 
-void wxXmlResource::AddHandler(wxXmlResourceHandler *handler)
+void wxXmlResource::AddHandler(wxXmlResourceHandler* handler)
 {
-    m_handlers.Append(handler);
+    m_handlers.push_back(handler);
     handler->SetParentResource(this);
 }
 
 void wxXmlResource::InsertHandler(wxXmlResourceHandler *handler)
 {
-    m_handlers.Insert(handler);
+    m_handlers.push_front(handler);
     handler->SetParentResource(this);
 }
 
@@ -160,7 +171,14 @@ void wxXmlResource::InsertHandler(wxXmlResourceHandler *handler)
 
 void wxXmlResource::ClearHandlers()
 {
-    m_handlers.Clear();
+    // The equivalent of wxList::DeleteContents()
+    std::list<wxXmlResourceHandler *>::iterator it;
+    for (it = m_handlers.begin(); it != m_handlers.end(); ++it)
+    {
+        delete *it;
+    }
+    
+    m_handlers.clear();
 }
 
 
@@ -335,20 +353,20 @@ void wxXmlResource::UpdateResources()
     }
 #endif
 
-    for (size_t i = 0; i < m_data.GetCount(); i++)
+    for (size_t i = 0; i < m_data.size(); i++)
     {
-        modif = (m_data[i].Doc == NULL);
+        modif = (m_data[i]->Doc == NULL);
 
         if (!modif)
         {
 #           if wxUSE_FILESYSTEM
-            file = fsys.OpenFile(m_data[i].File);
-            modif = file && file->GetModificationTime() > m_data[i].Time;
+            file = fsys.OpenFile(m_data[i]->File);
+            modif = file && file->GetModificationTime() > m_data[i]->Time;
             if (!file)
-                wxLogError(_("Cannot open file '%s'."), m_data[i].File.c_str());
+                wxLogError(_("Cannot open file '%s'."), m_data[i]->File.c_str());
             wxDELETE(file);
 #           else
-            modif = wxDateTime(wxFileModificationTime(m_data[i].File)) > m_data[i].Time;
+            modif = wxDateTime(wxFileModificationTime(m_data[i]->File)) > m_data[i]->Time;
 #           endif
         }
 
@@ -357,34 +375,34 @@ void wxXmlResource::UpdateResources()
             wxInputStream *stream = NULL;
 
 #           if wxUSE_FILESYSTEM
-            file = fsys.OpenFile(m_data[i].File);
+            file = fsys.OpenFile(m_data[i]->File);
 			if (file)
 				stream = file->GetStream();
 #           else
-            stream = new wxFileInputStream(m_data[i].File);
+            stream = new wxFileInputStream(m_data[i]->File);
 #           endif
 
             if (stream)
             {
-                delete m_data[i].Doc;
-                m_data[i].Doc = new wxXmlDocument;
+                delete m_data[i]->Doc;
+                m_data[i]->Doc = new wxXmlDocument;
             }
-            if (!stream || !m_data[i].Doc->Load(*stream, encoding))
+            if (!stream || !m_data[i]->Doc->Load(*stream, encoding))
             {
                 wxLogError(_("Cannot load resources from file '%s'."),
-                           m_data[i].File.c_str());
-                wxDELETE(m_data[i].Doc);
+                           m_data[i]->File.c_str());
+                wxDELETE(m_data[i]->Doc);
             }
-            else if (m_data[i].Doc->GetRoot()->GetName() != wxT("resource"))
+            else if (m_data[i]->Doc->GetRoot()->GetName() != wxT("resource"))
             {
-                wxLogError(_("Invalid XRC resource '%s': doesn't have root node 'resource'."), m_data[i].File.c_str());
-                wxDELETE(m_data[i].Doc);
+                wxLogError(_("Invalid XRC resource '%s': doesn't have root node 'resource'."), m_data[i]->File.c_str());
+                wxDELETE(m_data[i]->Doc);
             }
             else
 			{
                 long version;
                 int v1, v2, v3, v4;
-                wxString verstr = m_data[i].Doc->GetRoot()->GetPropVal(
+                wxString verstr = m_data[i]->Doc->GetRoot()->GetPropVal(
                                       wxT("version"), wxT("0.0.0.0"));
                 if (wxSscanf(verstr.c_str(), wxT("%i.%i.%i.%i"),
                     &v1, &v2, &v3, &v4) == 4)
@@ -396,8 +414,8 @@ void wxXmlResource::UpdateResources()
                 if (m_version != version)
                     wxLogError(_("Resource files must have same version number!"));
 
-                ProcessPlatformProperty(m_data[i].Doc->GetRoot());
-				m_data[i].Time = file->GetModificationTime();
+                ProcessPlatformProperty(m_data[i]->Doc->GetRoot());
+				m_data[i]->Time = file->GetModificationTime();
 			}
 
 #           if wxUSE_FILESYSTEM
@@ -469,17 +487,17 @@ wxXmlNode *wxXmlResource::FindResource(const wxString& name,
     UpdateResources(); //ensure everything is up-to-date
 
     wxString dummy;
-    for (size_t f = 0; f < m_data.GetCount(); f++)
+    for (size_t f = 0; f < m_data.size(); f++)
     {
-        if ( m_data[f].Doc == NULL || m_data[f].Doc->GetRoot() == NULL )
+        if ( m_data[f]->Doc == NULL || m_data[f]->Doc->GetRoot() == NULL )
             continue;
 
-        wxXmlNode* found = DoFindResource(m_data[f].Doc->GetRoot(),
+        wxXmlNode* found = DoFindResource(m_data[f]->Doc->GetRoot(),
                                           name, classname, recursive);
         if ( found )
         {
 #if wxUSE_FILESYSTEM
-            m_curFileSystem.ChangePathTo(m_data[f].File);
+            m_curFileSystem.ChangePathTo(m_data[f]->File);
 #endif
             return found;
         }
@@ -566,7 +584,7 @@ wxObject *wxXmlResource::CreateResFromNode2(wxXmlNode *node, wxObject *parent,
         return CreateResFromNode(&copy, parent, instance);
     }
 
-    wxXmlResourceHandler *handler;
+    wxXmlResourceHandler* handler;
 
     if (handlerToUse)
     {        
@@ -577,15 +595,14 @@ wxObject *wxXmlResource::CreateResFromNode2(wxXmlNode *node, wxObject *parent,
     }
     else if (node->GetName() == wxT("object"))
     {    
-        wxNode *ND = m_handlers.GetFirst();
-        while (ND)
+        std::list<wxXmlResourceHandler *>::const_iterator it;
+        for (it = m_handlers.begin(); it != m_handlers.end(); ++it)
         {
-            handler = (wxXmlResourceHandler*)ND->GetData();
+            handler = *it;
             if (handler->CanHandle(node))
             {
                 return handler->CreateResource(node, parent, instance);
             }
-            ND = ND->GetNext();
         }
     }
 
@@ -595,11 +612,6 @@ wxObject *wxXmlResource::CreateResFromNode2(wxXmlNode *node, wxObject *parent,
     return NULL;
 }
 
-
-#include "wx/listimpl.cpp"
-WX_DECLARE_LIST(wxXmlSubclassFactory, wxXmlSubclassFactoriesList);
-WX_DEFINE_LIST(wxXmlSubclassFactoriesList);
-
 wxXmlSubclassFactoriesList *wxXmlResource::ms_subclassFactories = NULL;
 
 /*static*/ void wxXmlResource::AddSubclassFactory(wxXmlSubclassFactory *factory)
@@ -607,9 +619,9 @@ wxXmlSubclassFactoriesList *wxXmlResource::ms_subclassFactories = NULL;
     if (!ms_subclassFactories)
     {
         ms_subclassFactories = new wxXmlSubclassFactoriesList;
-        ms_subclassFactories->DeleteContents(TRUE);
+//        ms_subclassFactories->DeleteContents(TRUE);
     }
-    ms_subclassFactories->Append(factory);
+    ms_subclassFactories->push_back(factory);
 }
 
 class wxXmlSubclassFactoryCXX : public wxXmlSubclassFactory
@@ -628,16 +640,14 @@ public:
     }
 };
 
-
-
-
-
 wxXmlResourceHandler::wxXmlResourceHandler()
         : m_node(NULL), m_parent(NULL), m_instance(NULL),
           m_parentAsWindow(NULL), m_instanceAsWindow(NULL)
 {}
 
-
+wxXmlResourceHandler::~wxXmlResourceHandler()
+{
+}
 
 wxObject *wxXmlResourceHandler::CreateResource(wxXmlNode *node, wxObject *parent, wxObject *instance)
 {
@@ -653,12 +663,14 @@ wxObject *wxXmlResourceHandler::CreateResource(wxXmlNode *node, wxObject *parent
         wxString subclass = node->GetPropVal(wxT("subclass"), wxEmptyString);
         if (!subclass.empty())
         {
-            for (wxXmlSubclassFactoriesList::Node *i = wxXmlResource::ms_subclassFactories->GetFirst();
-                 i; i = i->GetNext())
+            std::list<wxXmlSubclassFactory *>::iterator it;
+            for (it = wxXmlResource::ms_subclassFactories->begin(); it != wxXmlResource::ms_subclassFactories->end(); ++it)
             {
-                m_instance = i->GetData()->Create(subclass);
+                m_instance = (*it)->Create(subclass);
                 if (m_instance)
+                {
                     break;
+                }
             }
 
             if (!m_instance)
@@ -1276,7 +1288,6 @@ public:
     void OnExit()
     {
         delete wxXmlResource::Set(NULL);
-        wxDELETE(wxXmlResource::ms_subclassFactories);
         CleanXRCID_Records();
     }
 };
